#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#define LANGUAGE_VERSION 14
#define STATE_COUNT 2112
#define LARGE_STATE_COUNT 405
#define SYMBOL_COUNT 136
#define ALIAS_COUNT 0
#define TOKEN_COUNT 82
#define EXTERNAL_TOKEN_COUNT 16
#define FIELD_COUNT 20
#define MAX_ALIAS_SEQUENCE_LENGTH 10
#define PRODUCTION_ID_COUNT 59

enum ts_symbol_identifiers {
  sym_identifier = 1,
  anon_sym_BSLASH = 2,
  anon_sym_function = 3,
  anon_sym_EQ = 4,
  anon_sym_if = 5,
  anon_sym_for = 6,
  anon_sym_in = 7,
  anon_sym_while = 8,
  anon_sym_repeat = 9,
  anon_sym_QMARK = 10,
  anon_sym_TILDE = 11,
  anon_sym_BANG = 12,
  anon_sym_PLUS = 13,
  anon_sym_DASH = 14,
  anon_sym_LT_DASH = 15,
  anon_sym_LT_LT_DASH = 16,
  anon_sym_COLON_EQ = 17,
  anon_sym_DASH_GT = 18,
  anon_sym_DASH_GT_GT = 19,
  anon_sym_PIPE = 20,
  anon_sym_AMP = 21,
  anon_sym_PIPE_PIPE = 22,
  anon_sym_AMP_AMP = 23,
  anon_sym_LT = 24,
  anon_sym_LT_EQ = 25,
  anon_sym_GT = 26,
  anon_sym_GT_EQ = 27,
  anon_sym_EQ_EQ = 28,
  anon_sym_BANG_EQ = 29,
  anon_sym_STAR = 30,
  anon_sym_SLASH = 31,
  anon_sym_STAR_STAR = 32,
  anon_sym_CARET = 33,
  aux_sym_binary_operator_token1 = 34,
  anon_sym_PIPE_GT = 35,
  anon_sym_COLON = 36,
  anon_sym_DOLLAR = 37,
  anon_sym_AT = 38,
  anon_sym_COLON_COLON = 39,
  anon_sym_COLON_COLON_COLON = 40,
  anon_sym_L = 41,
  anon_sym_i = 42,
  sym__hex_literal = 43,
  sym__number_literal = 44,
  anon_sym_SQUOTE = 45,
  anon_sym_DQUOTE = 46,
  aux_sym__single_quoted_string_content_token1 = 47,
  aux_sym__double_quoted_string_content_token1 = 48,
  sym_escape_sequence = 49,
  sym_dots = 50,
  sym_dot_dot_i = 51,
  sym_next = 52,
  sym_break = 53,
  sym_true = 54,
  sym_false = 55,
  sym_null = 56,
  sym_inf = 57,
  sym_nan = 58,
  anon_sym_NA = 59,
  anon_sym_NA_integer_ = 60,
  anon_sym_NA_real_ = 61,
  anon_sym_NA_complex_ = 62,
  anon_sym_NA_character_ = 63,
  sym_comment = 64,
  sym_comma = 65,
  sym__start = 66,
  sym__newline = 67,
  sym__semicolon = 68,
  sym__raw_string_open = 69,
  sym__raw_string_content = 70,
  sym__raw_string_close = 71,
  sym__external_else = 72,
  sym__external_open_parenthesis = 73,
  sym__external_close_parenthesis = 74,
  sym__external_open_brace = 75,
  sym__external_close_brace = 76,
  sym__external_open_bracket = 77,
  sym__external_close_bracket = 78,
  sym__external_open_bracket2 = 79,
  sym__external_close_bracket2 = 80,
  sym__error_sentinel = 81,
  sym_program = 82,
  sym_function_definition = 83,
  sym_parameters = 84,
  sym_parameter = 85,
  sym__parameter_with_default = 86,
  sym__parameter_without_default = 87,
  sym__parameter_name = 88,
  sym_if_statement = 89,
  sym_for_statement = 90,
  sym_while_statement = 91,
  sym_repeat_statement = 92,
  sym_braced_expression = 93,
  sym_parenthesized_expression = 94,
  sym_call = 95,
  sym_subset = 96,
  sym_subset2 = 97,
  sym_call_arguments = 98,
  sym_subset_arguments = 99,
  sym_subset2_arguments = 100,
  sym_argument = 101,
  sym__argument_named = 102,
  sym__argument_unnamed = 103,
  sym__argument_value = 104,
  sym_unary_operator = 105,
  sym_binary_operator = 106,
  sym_extract_operator = 107,
  sym_namespace_operator = 108,
  sym_integer = 109,
  sym_complex = 110,
  sym_float = 111,
  sym__float_literal = 112,
  sym_string = 113,
  sym__raw_string = 114,
  sym__single_quoted_string = 115,
  sym__double_quoted_string = 116,
  aux_sym__single_quoted_string_content = 117,
  aux_sym__double_quoted_string_content = 118,
  sym__argument_name_string_or_identifier_or_null = 119,
  sym_na = 120,
  sym__expression = 121,
  sym__else = 122,
  sym__open_parenthesis = 123,
  sym__close_parenthesis = 124,
  sym__open_brace = 125,
  sym__close_brace = 126,
  sym__open_bracket = 127,
  sym__close_bracket = 128,
  sym__open_bracket2 = 129,
  sym__close_bracket2 = 130,
  aux_sym_program_repeat1 = 131,
  aux_sym_function_definition_repeat1 = 132,
  aux_sym_parameters_repeat1 = 133,
  aux_sym_braced_expression_repeat1 = 134,
  aux_sym_call_arguments_repeat1 = 135,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [sym_identifier] = "identifier",
  [anon_sym_BSLASH] = "\\",
  [anon_sym_function] = "function",
  [anon_sym_EQ] = "=",
  [anon_sym_if] = "if",
  [anon_sym_for] = "for",
  [anon_sym_in] = "in",
  [anon_sym_while] = "while",
  [anon_sym_repeat] = "repeat",
  [anon_sym_QMARK] = "\?",
  [anon_sym_TILDE] = "~",
  [anon_sym_BANG] = "!",
  [anon_sym_PLUS] = "+",
  [anon_sym_DASH] = "-",
  [anon_sym_LT_DASH] = "<-",
  [anon_sym_LT_LT_DASH] = "<<-",
  [anon_sym_COLON_EQ] = ":=",
  [anon_sym_DASH_GT] = "->",
  [anon_sym_DASH_GT_GT] = "->>",
  [anon_sym_PIPE] = "|",
  [anon_sym_AMP] = "&",
  [anon_sym_PIPE_PIPE] = "||",
  [anon_sym_AMP_AMP] = "&&",
  [anon_sym_LT] = "<",
  [anon_sym_LT_EQ] = "<=",
  [anon_sym_GT] = ">",
  [anon_sym_GT_EQ] = ">=",
  [anon_sym_EQ_EQ] = "==",
  [anon_sym_BANG_EQ] = "!=",
  [anon_sym_STAR] = "*",
  [anon_sym_SLASH] = "/",
  [anon_sym_STAR_STAR] = "**",
  [anon_sym_CARET] = "^",
  [aux_sym_binary_operator_token1] = "special",
  [anon_sym_PIPE_GT] = "|>",
  [anon_sym_COLON] = ":",
  [anon_sym_DOLLAR] = "$",
  [anon_sym_AT] = "@",
  [anon_sym_COLON_COLON] = "::",
  [anon_sym_COLON_COLON_COLON] = ":::",
  [anon_sym_L] = "L",
  [anon_sym_i] = "i",
  [sym__hex_literal] = "_hex_literal",
  [sym__number_literal] = "_number_literal",
  [anon_sym_SQUOTE] = "string_open",
  [anon_sym_DQUOTE] = "string_open",
  [aux_sym__single_quoted_string_content_token1] = "_single_quoted_string_content_token1",
  [aux_sym__double_quoted_string_content_token1] = "_double_quoted_string_content_token1",
  [sym_escape_sequence] = "escape_sequence",
  [sym_dots] = "dots",
  [sym_dot_dot_i] = "dot_dot_i",
  [sym_next] = "next",
  [sym_break] = "break",
  [sym_true] = "true",
  [sym_false] = "false",
  [sym_null] = "null",
  [sym_inf] = "inf",
  [sym_nan] = "nan",
  [anon_sym_NA] = "NA",
  [anon_sym_NA_integer_] = "NA_integer_",
  [anon_sym_NA_real_] = "NA_real_",
  [anon_sym_NA_complex_] = "NA_complex_",
  [anon_sym_NA_character_] = "NA_character_",
  [sym_comment] = "comment",
  [sym_comma] = "comma",
  [sym__start] = "_start",
  [sym__newline] = "_newline",
  [sym__semicolon] = "_semicolon",
  [sym__raw_string_open] = "string_open",
  [sym__raw_string_content] = "string_content",
  [sym__raw_string_close] = "string_close",
  [sym__external_else] = "else",
  [sym__external_open_parenthesis] = "(",
  [sym__external_close_parenthesis] = ")",
  [sym__external_open_brace] = "{",
  [sym__external_close_brace] = "}",
  [sym__external_open_bracket] = "[",
  [sym__external_close_bracket] = "]",
  [sym__external_open_bracket2] = "[[",
  [sym__external_close_bracket2] = "]]",
  [sym__error_sentinel] = "_error_sentinel",
  [sym_program] = "program",
  [sym_function_definition] = "function_definition",
  [sym_parameters] = "parameters",
  [sym_parameter] = "parameter",
  [sym__parameter_with_default] = "_parameter_with_default",
  [sym__parameter_without_default] = "_parameter_without_default",
  [sym__parameter_name] = "_parameter_name",
  [sym_if_statement] = "if_statement",
  [sym_for_statement] = "for_statement",
  [sym_while_statement] = "while_statement",
  [sym_repeat_statement] = "repeat_statement",
  [sym_braced_expression] = "braced_expression",
  [sym_parenthesized_expression] = "parenthesized_expression",
  [sym_call] = "call",
  [sym_subset] = "subset",
  [sym_subset2] = "subset2",
  [sym_call_arguments] = "arguments",
  [sym_subset_arguments] = "arguments",
  [sym_subset2_arguments] = "arguments",
  [sym_argument] = "argument",
  [sym__argument_named] = "_argument_named",
  [sym__argument_unnamed] = "_argument_unnamed",
  [sym__argument_value] = "_argument_value",
  [sym_unary_operator] = "unary_operator",
  [sym_binary_operator] = "binary_operator",
  [sym_extract_operator] = "extract_operator",
  [sym_namespace_operator] = "namespace_operator",
  [sym_integer] = "integer",
  [sym_complex] = "complex",
  [sym_float] = "float",
  [sym__float_literal] = "_float_literal",
  [sym_string] = "string",
  [sym__raw_string] = "_raw_string",
  [sym__single_quoted_string] = "_single_quoted_string",
  [sym__double_quoted_string] = "_double_quoted_string",
  [aux_sym__single_quoted_string_content] = "_single_quoted_string_content",
  [aux_sym__double_quoted_string_content] = "_double_quoted_string_content",
  [sym__argument_name_string_or_identifier_or_null] = "_argument_name_string_or_identifier_or_null",
  [sym_na] = "na",
  [sym__expression] = "_expression",
  [sym__else] = "_else",
  [sym__open_parenthesis] = "_open_parenthesis",
  [sym__close_parenthesis] = "_close_parenthesis",
  [sym__open_brace] = "_open_brace",
  [sym__close_brace] = "_close_brace",
  [sym__open_bracket] = "_open_bracket",
  [sym__close_bracket] = "_close_bracket",
  [sym__open_bracket2] = "_open_bracket2",
  [sym__close_bracket2] = "_close_bracket2",
  [aux_sym_program_repeat1] = "program_repeat1",
  [aux_sym_function_definition_repeat1] = "function_definition_repeat1",
  [aux_sym_parameters_repeat1] = "parameters_repeat1",
  [aux_sym_braced_expression_repeat1] = "braced_expression_repeat1",
  [aux_sym_call_arguments_repeat1] = "call_arguments_repeat1",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [sym_identifier] = sym_identifier,
  [anon_sym_BSLASH] = anon_sym_BSLASH,
  [anon_sym_function] = anon_sym_function,
  [anon_sym_EQ] = anon_sym_EQ,
  [anon_sym_if] = anon_sym_if,
  [anon_sym_for] = anon_sym_for,
  [anon_sym_in] = anon_sym_in,
  [anon_sym_while] = anon_sym_while,
  [anon_sym_repeat] = anon_sym_repeat,
  [anon_sym_QMARK] = anon_sym_QMARK,
  [anon_sym_TILDE] = anon_sym_TILDE,
  [anon_sym_BANG] = anon_sym_BANG,
  [anon_sym_PLUS] = anon_sym_PLUS,
  [anon_sym_DASH] = anon_sym_DASH,
  [anon_sym_LT_DASH] = anon_sym_LT_DASH,
  [anon_sym_LT_LT_DASH] = anon_sym_LT_LT_DASH,
  [anon_sym_COLON_EQ] = anon_sym_COLON_EQ,
  [anon_sym_DASH_GT] = anon_sym_DASH_GT,
  [anon_sym_DASH_GT_GT] = anon_sym_DASH_GT_GT,
  [anon_sym_PIPE] = anon_sym_PIPE,
  [anon_sym_AMP] = anon_sym_AMP,
  [anon_sym_PIPE_PIPE] = anon_sym_PIPE_PIPE,
  [anon_sym_AMP_AMP] = anon_sym_AMP_AMP,
  [anon_sym_LT] = anon_sym_LT,
  [anon_sym_LT_EQ] = anon_sym_LT_EQ,
  [anon_sym_GT] = anon_sym_GT,
  [anon_sym_GT_EQ] = anon_sym_GT_EQ,
  [anon_sym_EQ_EQ] = anon_sym_EQ_EQ,
  [anon_sym_BANG_EQ] = anon_sym_BANG_EQ,
  [anon_sym_STAR] = anon_sym_STAR,
  [anon_sym_SLASH] = anon_sym_SLASH,
  [anon_sym_STAR_STAR] = anon_sym_STAR_STAR,
  [anon_sym_CARET] = anon_sym_CARET,
  [aux_sym_binary_operator_token1] = aux_sym_binary_operator_token1,
  [anon_sym_PIPE_GT] = anon_sym_PIPE_GT,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym_DOLLAR] = anon_sym_DOLLAR,
  [anon_sym_AT] = anon_sym_AT,
  [anon_sym_COLON_COLON] = anon_sym_COLON_COLON,
  [anon_sym_COLON_COLON_COLON] = anon_sym_COLON_COLON_COLON,
  [anon_sym_L] = anon_sym_L,
  [anon_sym_i] = anon_sym_i,
  [sym__hex_literal] = sym__hex_literal,
  [sym__number_literal] = sym__number_literal,
  [anon_sym_SQUOTE] = sym__raw_string_open,
  [anon_sym_DQUOTE] = sym__raw_string_open,
  [aux_sym__single_quoted_string_content_token1] = aux_sym__single_quoted_string_content_token1,
  [aux_sym__double_quoted_string_content_token1] = aux_sym__double_quoted_string_content_token1,
  [sym_escape_sequence] = sym_escape_sequence,
  [sym_dots] = sym_dots,
  [sym_dot_dot_i] = sym_dot_dot_i,
  [sym_next] = sym_next,
  [sym_break] = sym_break,
  [sym_true] = sym_true,
  [sym_false] = sym_false,
  [sym_null] = sym_null,
  [sym_inf] = sym_inf,
  [sym_nan] = sym_nan,
  [anon_sym_NA] = anon_sym_NA,
  [anon_sym_NA_integer_] = anon_sym_NA_integer_,
  [anon_sym_NA_real_] = anon_sym_NA_real_,
  [anon_sym_NA_complex_] = anon_sym_NA_complex_,
  [anon_sym_NA_character_] = anon_sym_NA_character_,
  [sym_comment] = sym_comment,
  [sym_comma] = sym_comma,
  [sym__start] = sym__start,
  [sym__newline] = sym__newline,
  [sym__semicolon] = sym__semicolon,
  [sym__raw_string_open] = sym__raw_string_open,
  [sym__raw_string_content] = sym__raw_string_content,
  [sym__raw_string_close] = sym__raw_string_close,
  [sym__external_else] = sym__external_else,
  [sym__external_open_parenthesis] = sym__external_open_parenthesis,
  [sym__external_close_parenthesis] = sym__external_close_parenthesis,
  [sym__external_open_brace] = sym__external_open_brace,
  [sym__external_close_brace] = sym__external_close_brace,
  [sym__external_open_bracket] = sym__external_open_bracket,
  [sym__external_close_bracket] = sym__external_close_bracket,
  [sym__external_open_bracket2] = sym__external_open_bracket2,
  [sym__external_close_bracket2] = sym__external_close_bracket2,
  [sym__error_sentinel] = sym__error_sentinel,
  [sym_program] = sym_program,
  [sym_function_definition] = sym_function_definition,
  [sym_parameters] = sym_parameters,
  [sym_parameter] = sym_parameter,
  [sym__parameter_with_default] = sym__parameter_with_default,
  [sym__parameter_without_default] = sym__parameter_without_default,
  [sym__parameter_name] = sym__parameter_name,
  [sym_if_statement] = sym_if_statement,
  [sym_for_statement] = sym_for_statement,
  [sym_while_statement] = sym_while_statement,
  [sym_repeat_statement] = sym_repeat_statement,
  [sym_braced_expression] = sym_braced_expression,
  [sym_parenthesized_expression] = sym_parenthesized_expression,
  [sym_call] = sym_call,
  [sym_subset] = sym_subset,
  [sym_subset2] = sym_subset2,
  [sym_call_arguments] = sym_call_arguments,
  [sym_subset_arguments] = sym_call_arguments,
  [sym_subset2_arguments] = sym_call_arguments,
  [sym_argument] = sym_argument,
  [sym__argument_named] = sym__argument_named,
  [sym__argument_unnamed] = sym__argument_unnamed,
  [sym__argument_value] = sym__argument_value,
  [sym_unary_operator] = sym_unary_operator,
  [sym_binary_operator] = sym_binary_operator,
  [sym_extract_operator] = sym_extract_operator,
  [sym_namespace_operator] = sym_namespace_operator,
  [sym_integer] = sym_integer,
  [sym_complex] = sym_complex,
  [sym_float] = sym_float,
  [sym__float_literal] = sym__float_literal,
  [sym_string] = sym_string,
  [sym__raw_string] = sym__raw_string,
  [sym__single_quoted_string] = sym__single_quoted_string,
  [sym__double_quoted_string] = sym__double_quoted_string,
  [aux_sym__single_quoted_string_content] = aux_sym__single_quoted_string_content,
  [aux_sym__double_quoted_string_content] = aux_sym__double_quoted_string_content,
  [sym__argument_name_string_or_identifier_or_null] = sym__argument_name_string_or_identifier_or_null,
  [sym_na] = sym_na,
  [sym__expression] = sym__expression,
  [sym__else] = sym__else,
  [sym__open_parenthesis] = sym__open_parenthesis,
  [sym__close_parenthesis] = sym__close_parenthesis,
  [sym__open_brace] = sym__open_brace,
  [sym__close_brace] = sym__close_brace,
  [sym__open_bracket] = sym__open_bracket,
  [sym__close_bracket] = sym__close_bracket,
  [sym__open_bracket2] = sym__open_bracket2,
  [sym__close_bracket2] = sym__close_bracket2,
  [aux_sym_program_repeat1] = aux_sym_program_repeat1,
  [aux_sym_function_definition_repeat1] = aux_sym_function_definition_repeat1,
  [aux_sym_parameters_repeat1] = aux_sym_parameters_repeat1,
  [aux_sym_braced_expression_repeat1] = aux_sym_braced_expression_repeat1,
  [aux_sym_call_arguments_repeat1] = aux_sym_call_arguments_repeat1,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [sym_identifier] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_BSLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_function] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_if] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_for] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_in] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_while] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_repeat] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_LT_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_GT_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_binary_operator_token1] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOLLAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON_COLON_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_L] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_i] = {
    .visible = true,
    .named = false,
  },
  [sym__hex_literal] = {
    .visible = false,
    .named = true,
  },
  [sym__number_literal] = {
    .visible = false,
    .named = true,
  },
  [anon_sym_SQUOTE] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_DQUOTE] = {
    .visible = true,
    .named = true,
  },
  [aux_sym__single_quoted_string_content_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__double_quoted_string_content_token1] = {
    .visible = false,
    .named = false,
  },
  [sym_escape_sequence] = {
    .visible = true,
    .named = true,
  },
  [sym_dots] = {
    .visible = true,
    .named = true,
  },
  [sym_dot_dot_i] = {
    .visible = true,
    .named = true,
  },
  [sym_next] = {
    .visible = true,
    .named = true,
  },
  [sym_break] = {
    .visible = true,
    .named = true,
  },
  [sym_true] = {
    .visible = true,
    .named = true,
  },
  [sym_false] = {
    .visible = true,
    .named = true,
  },
  [sym_null] = {
    .visible = true,
    .named = true,
  },
  [sym_inf] = {
    .visible = true,
    .named = true,
  },
  [sym_nan] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_NA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_NA_integer_] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_NA_real_] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_NA_complex_] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_NA_character_] = {
    .visible = true,
    .named = false,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_comma] = {
    .visible = true,
    .named = true,
  },
  [sym__start] = {
    .visible = false,
    .named = true,
  },
  [sym__newline] = {
    .visible = false,
    .named = true,
  },
  [sym__semicolon] = {
    .visible = false,
    .named = true,
  },
  [sym__raw_string_open] = {
    .visible = true,
    .named = true,
  },
  [sym__raw_string_content] = {
    .visible = true,
    .named = true,
  },
  [sym__raw_string_close] = {
    .visible = true,
    .named = true,
  },
  [sym__external_else] = {
    .visible = true,
    .named = false,
  },
  [sym__external_open_parenthesis] = {
    .visible = true,
    .named = false,
  },
  [sym__external_close_parenthesis] = {
    .visible = true,
    .named = false,
  },
  [sym__external_open_brace] = {
    .visible = true,
    .named = false,
  },
  [sym__external_close_brace] = {
    .visible = true,
    .named = false,
  },
  [sym__external_open_bracket] = {
    .visible = true,
    .named = false,
  },
  [sym__external_close_bracket] = {
    .visible = true,
    .named = false,
  },
  [sym__external_open_bracket2] = {
    .visible = true,
    .named = false,
  },
  [sym__external_close_bracket2] = {
    .visible = true,
    .named = false,
  },
  [sym__error_sentinel] = {
    .visible = false,
    .named = true,
  },
  [sym_program] = {
    .visible = true,
    .named = true,
  },
  [sym_function_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_parameters] = {
    .visible = true,
    .named = true,
  },
  [sym_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym__parameter_with_default] = {
    .visible = false,
    .named = true,
  },
  [sym__parameter_without_default] = {
    .visible = false,
    .named = true,
  },
  [sym__parameter_name] = {
    .visible = false,
    .named = true,
  },
  [sym_if_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_for_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_while_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_repeat_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_braced_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_parenthesized_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_call] = {
    .visible = true,
    .named = true,
  },
  [sym_subset] = {
    .visible = true,
    .named = true,
  },
  [sym_subset2] = {
    .visible = true,
    .named = true,
  },
  [sym_call_arguments] = {
    .visible = true,
    .named = true,
  },
  [sym_subset_arguments] = {
    .visible = true,
    .named = true,
  },
  [sym_subset2_arguments] = {
    .visible = true,
    .named = true,
  },
  [sym_argument] = {
    .visible = true,
    .named = true,
  },
  [sym__argument_named] = {
    .visible = false,
    .named = true,
  },
  [sym__argument_unnamed] = {
    .visible = false,
    .named = true,
  },
  [sym__argument_value] = {
    .visible = false,
    .named = true,
  },
  [sym_unary_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_binary_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_extract_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_namespace_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_integer] = {
    .visible = true,
    .named = true,
  },
  [sym_complex] = {
    .visible = true,
    .named = true,
  },
  [sym_float] = {
    .visible = true,
    .named = true,
  },
  [sym__float_literal] = {
    .visible = false,
    .named = true,
  },
  [sym_string] = {
    .visible = true,
    .named = true,
  },
  [sym__raw_string] = {
    .visible = false,
    .named = true,
  },
  [sym__single_quoted_string] = {
    .visible = false,
    .named = true,
  },
  [sym__double_quoted_string] = {
    .visible = false,
    .named = true,
  },
  [aux_sym__single_quoted_string_content] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__double_quoted_string_content] = {
    .visible = false,
    .named = false,
  },
  [sym__argument_name_string_or_identifier_or_null] = {
    .visible = false,
    .named = true,
  },
  [sym_na] = {
    .visible = true,
    .named = true,
  },
  [sym__expression] = {
    .visible = false,
    .named = true,
  },
  [sym__else] = {
    .visible = false,
    .named = true,
  },
  [sym__open_parenthesis] = {
    .visible = false,
    .named = true,
  },
  [sym__close_parenthesis] = {
    .visible = false,
    .named = true,
  },
  [sym__open_brace] = {
    .visible = false,
    .named = true,
  },
  [sym__close_brace] = {
    .visible = false,
    .named = true,
  },
  [sym__open_bracket] = {
    .visible = false,
    .named = true,
  },
  [sym__close_bracket] = {
    .visible = false,
    .named = true,
  },
  [sym__open_bracket2] = {
    .visible = false,
    .named = true,
  },
  [sym__close_bracket2] = {
    .visible = false,
    .named = true,
  },
  [aux_sym_program_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_function_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_parameters_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_braced_expression_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_call_arguments_repeat1] = {
    .visible = false,
    .named = false,
  },
};

enum ts_field_identifiers {
  field_alternative = 1,
  field_argument = 2,
  field_arguments = 3,
  field_body = 4,
  field_close = 5,
  field_condition = 6,
  field_consequence = 7,
  field_content = 8,
  field_default = 9,
  field_function = 10,
  field_lhs = 11,
  field_name = 12,
  field_open = 13,
  field_operator = 14,
  field_parameter = 15,
  field_parameters = 16,
  field_rhs = 17,
  field_sequence = 18,
  field_value = 19,
  field_variable = 20,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_alternative] = "alternative",
  [field_argument] = "argument",
  [field_arguments] = "arguments",
  [field_body] = "body",
  [field_close] = "close",
  [field_condition] = "condition",
  [field_consequence] = "consequence",
  [field_content] = "content",
  [field_default] = "default",
  [field_function] = "function",
  [field_lhs] = "lhs",
  [field_name] = "name",
  [field_open] = "open",
  [field_operator] = "operator",
  [field_parameter] = "parameter",
  [field_parameters] = "parameters",
  [field_rhs] = "rhs",
  [field_sequence] = "sequence",
  [field_value] = "value",
  [field_variable] = "variable",
};

static const TSFieldMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [1] = {.index = 0, .length = 3},
  [2] = {.index = 3, .length = 2},
  [3] = {.index = 5, .length = 1},
  [4] = {.index = 6, .length = 2},
  [5] = {.index = 3, .length = 2},
  [6] = {.index = 8, .length = 2},
  [7] = {.index = 10, .length = 2},
  [8] = {.index = 12, .length = 1},
  [9] = {.index = 13, .length = 3},
  [10] = {.index = 16, .length = 3},
  [11] = {.index = 19, .length = 1},
  [12] = {.index = 20, .length = 2},
  [13] = {.index = 22, .length = 1},
  [14] = {.index = 23, .length = 1},
  [15] = {.index = 24, .length = 2},
  [16] = {.index = 13, .length = 3},
  [17] = {.index = 26, .length = 3},
  [18] = {.index = 29, .length = 2},
  [19] = {.index = 31, .length = 1},
  [20] = {.index = 32, .length = 1},
  [21] = {.index = 33, .length = 3},
  [22] = {.index = 36, .length = 3},
  [23] = {.index = 39, .length = 2},
  [24] = {.index = 41, .length = 3},
  [25] = {.index = 44, .length = 3},
  [26] = {.index = 47, .length = 3},
  [27] = {.index = 50, .length = 3},
  [28] = {.index = 53, .length = 1},
  [29] = {.index = 54, .length = 3},
  [30] = {.index = 57, .length = 3},
  [31] = {.index = 60, .length = 2},
  [32] = {.index = 62, .length = 1},
  [33] = {.index = 63, .length = 4},
  [34] = {.index = 67, .length = 2},
  [35] = {.index = 69, .length = 2},
  [36] = {.index = 71, .length = 3},
  [37] = {.index = 74, .length = 4},
  [38] = {.index = 78, .length = 4},
  [39] = {.index = 82, .length = 4},
  [40] = {.index = 86, .length = 2},
  [41] = {.index = 88, .length = 4},
  [42] = {.index = 92, .length = 4},
  [43] = {.index = 96, .length = 4},
  [44] = {.index = 100, .length = 4},
  [45] = {.index = 104, .length = 5},
  [46] = {.index = 109, .length = 4},
  [47] = {.index = 113, .length = 5},
  [48] = {.index = 118, .length = 4},
  [49] = {.index = 122, .length = 5},
  [50] = {.index = 127, .length = 5},
  [51] = {.index = 132, .length = 5},
  [52] = {.index = 137, .length = 5},
  [53] = {.index = 142, .length = 5},
  [54] = {.index = 147, .length = 5},
  [55] = {.index = 152, .length = 5},
  [56] = {.index = 157, .length = 5},
  [57] = {.index = 162, .length = 5},
  [58] = {.index = 167, .length = 5},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_close, 0, .inherited = true},
    {field_content, 0, .inherited = true},
    {field_open, 0, .inherited = true},
  [3] =
    {field_close, 1},
    {field_open, 0},
  [5] =
    {field_body, 1},
  [6] =
    {field_operator, 0},
    {field_rhs, 1},
  [8] =
    {field_lhs, 0},
    {field_operator, 1},
  [10] =
    {field_arguments, 1},
    {field_function, 0},
  [12] =
    {field_body, 0},
  [13] =
    {field_close, 2},
    {field_content, 1},
    {field_open, 0},
  [16] =
    {field_body, 2},
    {field_name, 0},
    {field_parameters, 1},
  [19] =
    {field_name, 0},
  [20] =
    {field_default, 0, .inherited = true},
    {field_name, 0, .inherited = true},
  [22] =
    {field_name, 0, .inherited = true},
  [23] =
    {field_body, 2},
  [24] =
    {field_operator, 0},
    {field_rhs, 2},
  [26] =
    {field_lhs, 0},
    {field_operator, 1},
    {field_rhs, 2},
  [29] =
    {field_name, 0, .inherited = true},
    {field_value, 0, .inherited = true},
  [31] =
    {field_value, 0, .inherited = true},
  [32] =
    {field_value, 0},
  [33] =
    {field_body, 1},
    {field_close, 2},
    {field_open, 0},
  [36] =
    {field_body, 1, .inherited = true},
    {field_close, 2},
    {field_open, 0},
  [39] =
    {field_body, 0, .inherited = true},
    {field_body, 1, .inherited = true},
  [41] =
    {field_body, 3},
    {field_name, 0},
    {field_parameters, 1},
  [44] =
    {field_close, 2},
    {field_open, 0},
    {field_parameter, 1},
  [47] =
    {field_body, 3},
    {field_name, 0},
    {field_parameters, 2},
  [50] =
    {field_lhs, 0},
    {field_operator, 1},
    {field_rhs, 3},
  [53] =
    {field_argument, 1},
  [54] =
    {field_argument, 1},
    {field_close, 2},
    {field_open, 0},
  [57] =
    {field_argument, 1, .inherited = true},
    {field_close, 2},
    {field_open, 0},
  [60] =
    {field_argument, 0, .inherited = true},
    {field_argument, 1, .inherited = true},
  [62] =
    {field_parameter, 1},
  [63] =
    {field_close, 3},
    {field_open, 0},
    {field_parameter, 1},
    {field_parameter, 2, .inherited = true},
  [67] =
    {field_parameter, 0, .inherited = true},
    {field_parameter, 1, .inherited = true},
  [69] =
    {field_default, 2},
    {field_name, 0, .inherited = true},
  [71] =
    {field_body, 4},
    {field_name, 0},
    {field_parameters, 2},
  [74] =
    {field_close, 3},
    {field_condition, 2},
    {field_consequence, 4},
    {field_open, 1},
  [78] =
    {field_body, 4},
    {field_close, 3},
    {field_condition, 2},
    {field_open, 1},
  [82] =
    {field_argument, 1},
    {field_argument, 2, .inherited = true},
    {field_close, 3},
    {field_open, 0},
  [86] =
    {field_name, 0},
    {field_value, 2, .inherited = true},
  [88] =
    {field_close, 3},
    {field_condition, 2},
    {field_consequence, 5},
    {field_open, 1},
  [92] =
    {field_close, 4},
    {field_condition, 3},
    {field_consequence, 5},
    {field_open, 2},
  [96] =
    {field_body, 5},
    {field_close, 3},
    {field_condition, 2},
    {field_open, 1},
  [100] =
    {field_body, 5},
    {field_close, 4},
    {field_condition, 3},
    {field_open, 2},
  [104] =
    {field_alternative, 6},
    {field_close, 3},
    {field_condition, 2},
    {field_consequence, 4},
    {field_open, 1},
  [109] =
    {field_close, 4},
    {field_condition, 3},
    {field_consequence, 6},
    {field_open, 2},
  [113] =
    {field_body, 6},
    {field_close, 5},
    {field_open, 1},
    {field_sequence, 4},
    {field_variable, 2},
  [118] =
    {field_body, 6},
    {field_close, 4},
    {field_condition, 3},
    {field_open, 2},
  [122] =
    {field_alternative, 7},
    {field_close, 3},
    {field_condition, 2},
    {field_consequence, 4},
    {field_open, 1},
  [127] =
    {field_alternative, 7},
    {field_close, 3},
    {field_condition, 2},
    {field_consequence, 5},
    {field_open, 1},
  [132] =
    {field_alternative, 7},
    {field_close, 4},
    {field_condition, 3},
    {field_consequence, 5},
    {field_open, 2},
  [137] =
    {field_body, 7},
    {field_close, 5},
    {field_open, 1},
    {field_sequence, 4},
    {field_variable, 2},
  [142] =
    {field_body, 7},
    {field_close, 6},
    {field_open, 2},
    {field_sequence, 5},
    {field_variable, 3},
  [147] =
    {field_alternative, 8},
    {field_close, 3},
    {field_condition, 2},
    {field_consequence, 5},
    {field_open, 1},
  [152] =
    {field_alternative, 8},
    {field_close, 4},
    {field_condition, 3},
    {field_consequence, 5},
    {field_open, 2},
  [157] =
    {field_alternative, 8},
    {field_close, 4},
    {field_condition, 3},
    {field_consequence, 6},
    {field_open, 2},
  [162] =
    {field_body, 8},
    {field_close, 6},
    {field_open, 2},
    {field_sequence, 5},
    {field_variable, 3},
  [167] =
    {field_alternative, 9},
    {field_close, 4},
    {field_condition, 3},
    {field_consequence, 6},
    {field_open, 2},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
  [5] = {
    [1] = sym__raw_string_close,
  },
  [16] = {
    [1] = sym__raw_string_content,
    [2] = sym__raw_string_close,
  },
};

static const uint16_t ts_non_terminal_alias_map[] = {
  aux_sym__single_quoted_string_content, 2,
    aux_sym__single_quoted_string_content,
    sym__raw_string_content,
  aux_sym__double_quoted_string_content, 2,
    aux_sym__double_quoted_string_content,
    sym__raw_string_content,
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 3,
  [4] = 4,
  [5] = 3,
  [6] = 6,
  [7] = 2,
  [8] = 6,
  [9] = 4,
  [10] = 3,
  [11] = 2,
  [12] = 6,
  [13] = 4,
  [14] = 3,
  [15] = 2,
  [16] = 6,
  [17] = 4,
  [18] = 18,
  [19] = 19,
  [20] = 20,
  [21] = 21,
  [22] = 22,
  [23] = 23,
  [24] = 24,
  [25] = 25,
  [26] = 26,
  [27] = 27,
  [28] = 28,
  [29] = 29,
  [30] = 30,
  [31] = 31,
  [32] = 32,
  [33] = 33,
  [34] = 34,
  [35] = 35,
  [36] = 36,
  [37] = 37,
  [38] = 38,
  [39] = 39,
  [40] = 40,
  [41] = 41,
  [42] = 42,
  [43] = 43,
  [44] = 44,
  [45] = 45,
  [46] = 46,
  [47] = 47,
  [48] = 48,
  [49] = 49,
  [50] = 50,
  [51] = 51,
  [52] = 52,
  [53] = 53,
  [54] = 54,
  [55] = 55,
  [56] = 56,
  [57] = 57,
  [58] = 58,
  [59] = 59,
  [60] = 60,
  [61] = 61,
  [62] = 62,
  [63] = 63,
  [64] = 64,
  [65] = 65,
  [66] = 66,
  [67] = 67,
  [68] = 68,
  [69] = 69,
  [70] = 70,
  [71] = 71,
  [72] = 72,
  [73] = 19,
  [74] = 20,
  [75] = 21,
  [76] = 22,
  [77] = 23,
  [78] = 24,
  [79] = 25,
  [80] = 26,
  [81] = 27,
  [82] = 28,
  [83] = 29,
  [84] = 30,
  [85] = 31,
  [86] = 32,
  [87] = 18,
  [88] = 88,
  [89] = 33,
  [90] = 34,
  [91] = 35,
  [92] = 36,
  [93] = 37,
  [94] = 38,
  [95] = 39,
  [96] = 40,
  [97] = 41,
  [98] = 42,
  [99] = 43,
  [100] = 44,
  [101] = 45,
  [102] = 46,
  [103] = 47,
  [104] = 48,
  [105] = 49,
  [106] = 50,
  [107] = 51,
  [108] = 52,
  [109] = 53,
  [110] = 54,
  [111] = 55,
  [112] = 56,
  [113] = 57,
  [114] = 58,
  [115] = 59,
  [116] = 60,
  [117] = 61,
  [118] = 62,
  [119] = 63,
  [120] = 64,
  [121] = 65,
  [122] = 66,
  [123] = 67,
  [124] = 68,
  [125] = 69,
  [126] = 70,
  [127] = 71,
  [128] = 72,
  [129] = 88,
  [130] = 27,
  [131] = 28,
  [132] = 29,
  [133] = 133,
  [134] = 30,
  [135] = 31,
  [136] = 32,
  [137] = 18,
  [138] = 88,
  [139] = 33,
  [140] = 34,
  [141] = 35,
  [142] = 24,
  [143] = 36,
  [144] = 37,
  [145] = 38,
  [146] = 39,
  [147] = 40,
  [148] = 41,
  [149] = 42,
  [150] = 43,
  [151] = 44,
  [152] = 152,
  [153] = 45,
  [154] = 46,
  [155] = 47,
  [156] = 48,
  [157] = 49,
  [158] = 50,
  [159] = 51,
  [160] = 52,
  [161] = 53,
  [162] = 54,
  [163] = 55,
  [164] = 56,
  [165] = 57,
  [166] = 58,
  [167] = 59,
  [168] = 60,
  [169] = 61,
  [170] = 62,
  [171] = 63,
  [172] = 64,
  [173] = 65,
  [174] = 66,
  [175] = 67,
  [176] = 68,
  [177] = 69,
  [178] = 70,
  [179] = 71,
  [180] = 72,
  [181] = 19,
  [182] = 20,
  [183] = 21,
  [184] = 22,
  [185] = 23,
  [186] = 24,
  [187] = 25,
  [188] = 26,
  [189] = 189,
  [190] = 27,
  [191] = 28,
  [192] = 29,
  [193] = 30,
  [194] = 31,
  [195] = 32,
  [196] = 18,
  [197] = 88,
  [198] = 33,
  [199] = 34,
  [200] = 35,
  [201] = 36,
  [202] = 37,
  [203] = 38,
  [204] = 39,
  [205] = 40,
  [206] = 41,
  [207] = 42,
  [208] = 43,
  [209] = 44,
  [210] = 152,
  [211] = 45,
  [212] = 46,
  [213] = 47,
  [214] = 48,
  [215] = 49,
  [216] = 50,
  [217] = 51,
  [218] = 52,
  [219] = 53,
  [220] = 54,
  [221] = 55,
  [222] = 56,
  [223] = 57,
  [224] = 58,
  [225] = 225,
  [226] = 59,
  [227] = 60,
  [228] = 61,
  [229] = 62,
  [230] = 63,
  [231] = 64,
  [232] = 65,
  [233] = 66,
  [234] = 67,
  [235] = 68,
  [236] = 69,
  [237] = 70,
  [238] = 71,
  [239] = 72,
  [240] = 19,
  [241] = 25,
  [242] = 26,
  [243] = 20,
  [244] = 21,
  [245] = 22,
  [246] = 23,
  [247] = 133,
  [248] = 248,
  [249] = 152,
  [250] = 152,
  [251] = 251,
  [252] = 252,
  [253] = 133,
  [254] = 254,
  [255] = 251,
  [256] = 133,
  [257] = 252,
  [258] = 254,
  [259] = 248,
  [260] = 251,
  [261] = 248,
  [262] = 248,
  [263] = 248,
  [264] = 251,
  [265] = 254,
  [266] = 248,
  [267] = 251,
  [268] = 254,
  [269] = 248,
  [270] = 251,
  [271] = 254,
  [272] = 248,
  [273] = 251,
  [274] = 254,
  [275] = 251,
  [276] = 254,
  [277] = 248,
  [278] = 251,
  [279] = 254,
  [280] = 248,
  [281] = 251,
  [282] = 254,
  [283] = 254,
  [284] = 252,
  [285] = 252,
  [286] = 286,
  [287] = 287,
  [288] = 288,
  [289] = 289,
  [290] = 290,
  [291] = 291,
  [292] = 292,
  [293] = 293,
  [294] = 294,
  [295] = 295,
  [296] = 296,
  [297] = 297,
  [298] = 294,
  [299] = 288,
  [300] = 289,
  [301] = 290,
  [302] = 291,
  [303] = 286,
  [304] = 293,
  [305] = 295,
  [306] = 296,
  [307] = 297,
  [308] = 287,
  [309] = 292,
  [310] = 294,
  [311] = 288,
  [312] = 292,
  [313] = 295,
  [314] = 296,
  [315] = 287,
  [316] = 289,
  [317] = 317,
  [318] = 288,
  [319] = 290,
  [320] = 292,
  [321] = 287,
  [322] = 297,
  [323] = 317,
  [324] = 291,
  [325] = 286,
  [326] = 293,
  [327] = 295,
  [328] = 296,
  [329] = 297,
  [330] = 289,
  [331] = 290,
  [332] = 291,
  [333] = 286,
  [334] = 293,
  [335] = 335,
  [336] = 336,
  [337] = 337,
  [338] = 337,
  [339] = 339,
  [340] = 339,
  [341] = 341,
  [342] = 342,
  [343] = 343,
  [344] = 344,
  [345] = 345,
  [346] = 346,
  [347] = 347,
  [348] = 348,
  [349] = 349,
  [350] = 350,
  [351] = 337,
  [352] = 337,
  [353] = 317,
  [354] = 354,
  [355] = 355,
  [356] = 356,
  [357] = 357,
  [358] = 358,
  [359] = 341,
  [360] = 348,
  [361] = 349,
  [362] = 350,
  [363] = 354,
  [364] = 356,
  [365] = 357,
  [366] = 366,
  [367] = 358,
  [368] = 366,
  [369] = 369,
  [370] = 369,
  [371] = 371,
  [372] = 372,
  [373] = 373,
  [374] = 374,
  [375] = 375,
  [376] = 371,
  [377] = 336,
  [378] = 337,
  [379] = 337,
  [380] = 337,
  [381] = 335,
  [382] = 337,
  [383] = 337,
  [384] = 335,
  [385] = 337,
  [386] = 335,
  [387] = 342,
  [388] = 355,
  [389] = 335,
  [390] = 343,
  [391] = 344,
  [392] = 345,
  [393] = 335,
  [394] = 346,
  [395] = 335,
  [396] = 335,
  [397] = 347,
  [398] = 335,
  [399] = 372,
  [400] = 373,
  [401] = 335,
  [402] = 374,
  [403] = 375,
  [404] = 317,
  [405] = 345,
  [406] = 372,
  [407] = 366,
  [408] = 355,
  [409] = 409,
  [410] = 346,
  [411] = 339,
  [412] = 343,
  [413] = 347,
  [414] = 347,
  [415] = 415,
  [416] = 354,
  [417] = 339,
  [418] = 371,
  [419] = 336,
  [420] = 343,
  [421] = 356,
  [422] = 373,
  [423] = 336,
  [424] = 344,
  [425] = 425,
  [426] = 345,
  [427] = 357,
  [428] = 375,
  [429] = 346,
  [430] = 369,
  [431] = 355,
  [432] = 374,
  [433] = 342,
  [434] = 358,
  [435] = 358,
  [436] = 366,
  [437] = 372,
  [438] = 349,
  [439] = 341,
  [440] = 348,
  [441] = 375,
  [442] = 349,
  [443] = 443,
  [444] = 350,
  [445] = 373,
  [446] = 354,
  [447] = 371,
  [448] = 348,
  [449] = 374,
  [450] = 344,
  [451] = 350,
  [452] = 357,
  [453] = 356,
  [454] = 369,
  [455] = 342,
  [456] = 341,
  [457] = 457,
  [458] = 457,
  [459] = 457,
  [460] = 460,
  [461] = 461,
  [462] = 462,
  [463] = 463,
  [464] = 464,
  [465] = 465,
  [466] = 466,
  [467] = 467,
  [468] = 468,
  [469] = 469,
  [470] = 470,
  [471] = 471,
  [472] = 472,
  [473] = 473,
  [474] = 474,
  [475] = 475,
  [476] = 476,
  [477] = 477,
  [478] = 478,
  [479] = 479,
  [480] = 480,
  [481] = 481,
  [482] = 482,
  [483] = 483,
  [484] = 484,
  [485] = 485,
  [486] = 486,
  [487] = 480,
  [488] = 483,
  [489] = 489,
  [490] = 490,
  [491] = 491,
  [492] = 492,
  [493] = 493,
  [494] = 494,
  [495] = 495,
  [496] = 496,
  [497] = 497,
  [498] = 498,
  [499] = 499,
  [500] = 500,
  [501] = 501,
  [502] = 502,
  [503] = 492,
  [504] = 504,
  [505] = 505,
  [506] = 493,
  [507] = 507,
  [508] = 508,
  [509] = 509,
  [510] = 494,
  [511] = 511,
  [512] = 512,
  [513] = 513,
  [514] = 496,
  [515] = 490,
  [516] = 516,
  [517] = 517,
  [518] = 460,
  [519] = 519,
  [520] = 520,
  [521] = 521,
  [522] = 522,
  [523] = 523,
  [524] = 524,
  [525] = 525,
  [526] = 461,
  [527] = 463,
  [528] = 466,
  [529] = 468,
  [530] = 470,
  [531] = 472,
  [532] = 478,
  [533] = 484,
  [534] = 491,
  [535] = 502,
  [536] = 462,
  [537] = 464,
  [538] = 465,
  [539] = 467,
  [540] = 469,
  [541] = 471,
  [542] = 473,
  [543] = 474,
  [544] = 475,
  [545] = 476,
  [546] = 477,
  [547] = 479,
  [548] = 481,
  [549] = 480,
  [550] = 483,
  [551] = 492,
  [552] = 493,
  [553] = 494,
  [554] = 496,
  [555] = 498,
  [556] = 499,
  [557] = 500,
  [558] = 501,
  [559] = 504,
  [560] = 505,
  [561] = 507,
  [562] = 508,
  [563] = 509,
  [564] = 511,
  [565] = 513,
  [566] = 490,
  [567] = 516,
  [568] = 517,
  [569] = 460,
  [570] = 519,
  [571] = 520,
  [572] = 521,
  [573] = 522,
  [574] = 523,
  [575] = 524,
  [576] = 525,
  [577] = 461,
  [578] = 463,
  [579] = 466,
  [580] = 468,
  [581] = 470,
  [582] = 472,
  [583] = 478,
  [584] = 484,
  [585] = 491,
  [586] = 502,
  [587] = 498,
  [588] = 462,
  [589] = 464,
  [590] = 465,
  [591] = 467,
  [592] = 469,
  [593] = 471,
  [594] = 473,
  [595] = 474,
  [596] = 475,
  [597] = 476,
  [598] = 477,
  [599] = 479,
  [600] = 481,
  [601] = 480,
  [602] = 483,
  [603] = 492,
  [604] = 493,
  [605] = 494,
  [606] = 496,
  [607] = 498,
  [608] = 499,
  [609] = 500,
  [610] = 501,
  [611] = 504,
  [612] = 505,
  [613] = 507,
  [614] = 508,
  [615] = 509,
  [616] = 511,
  [617] = 513,
  [618] = 499,
  [619] = 500,
  [620] = 501,
  [621] = 621,
  [622] = 516,
  [623] = 504,
  [624] = 490,
  [625] = 505,
  [626] = 516,
  [627] = 517,
  [628] = 517,
  [629] = 460,
  [630] = 519,
  [631] = 507,
  [632] = 520,
  [633] = 508,
  [634] = 509,
  [635] = 460,
  [636] = 521,
  [637] = 523,
  [638] = 524,
  [639] = 525,
  [640] = 461,
  [641] = 463,
  [642] = 466,
  [643] = 468,
  [644] = 470,
  [645] = 472,
  [646] = 478,
  [647] = 484,
  [648] = 511,
  [649] = 519,
  [650] = 462,
  [651] = 513,
  [652] = 464,
  [653] = 491,
  [654] = 502,
  [655] = 490,
  [656] = 516,
  [657] = 462,
  [658] = 464,
  [659] = 517,
  [660] = 465,
  [661] = 467,
  [662] = 520,
  [663] = 469,
  [664] = 471,
  [665] = 519,
  [666] = 473,
  [667] = 474,
  [668] = 520,
  [669] = 475,
  [670] = 476,
  [671] = 477,
  [672] = 479,
  [673] = 481,
  [674] = 521,
  [675] = 522,
  [676] = 523,
  [677] = 524,
  [678] = 525,
  [679] = 461,
  [680] = 463,
  [681] = 466,
  [682] = 480,
  [683] = 483,
  [684] = 468,
  [685] = 470,
  [686] = 472,
  [687] = 478,
  [688] = 484,
  [689] = 465,
  [690] = 491,
  [691] = 502,
  [692] = 492,
  [693] = 493,
  [694] = 494,
  [695] = 496,
  [696] = 462,
  [697] = 498,
  [698] = 464,
  [699] = 499,
  [700] = 500,
  [701] = 501,
  [702] = 504,
  [703] = 505,
  [704] = 465,
  [705] = 467,
  [706] = 507,
  [707] = 508,
  [708] = 509,
  [709] = 469,
  [710] = 511,
  [711] = 471,
  [712] = 473,
  [713] = 513,
  [714] = 474,
  [715] = 490,
  [716] = 516,
  [717] = 517,
  [718] = 460,
  [719] = 519,
  [720] = 520,
  [721] = 521,
  [722] = 523,
  [723] = 524,
  [724] = 525,
  [725] = 461,
  [726] = 463,
  [727] = 466,
  [728] = 468,
  [729] = 470,
  [730] = 472,
  [731] = 478,
  [732] = 484,
  [733] = 491,
  [734] = 502,
  [735] = 462,
  [736] = 464,
  [737] = 465,
  [738] = 467,
  [739] = 469,
  [740] = 471,
  [741] = 473,
  [742] = 474,
  [743] = 475,
  [744] = 476,
  [745] = 477,
  [746] = 479,
  [747] = 481,
  [748] = 480,
  [749] = 483,
  [750] = 492,
  [751] = 493,
  [752] = 494,
  [753] = 496,
  [754] = 498,
  [755] = 499,
  [756] = 500,
  [757] = 501,
  [758] = 504,
  [759] = 505,
  [760] = 507,
  [761] = 508,
  [762] = 509,
  [763] = 511,
  [764] = 513,
  [765] = 475,
  [766] = 476,
  [767] = 477,
  [768] = 479,
  [769] = 490,
  [770] = 516,
  [771] = 481,
  [772] = 517,
  [773] = 460,
  [774] = 519,
  [775] = 520,
  [776] = 521,
  [777] = 523,
  [778] = 524,
  [779] = 525,
  [780] = 461,
  [781] = 463,
  [782] = 466,
  [783] = 468,
  [784] = 470,
  [785] = 472,
  [786] = 478,
  [787] = 484,
  [788] = 491,
  [789] = 502,
  [790] = 480,
  [791] = 483,
  [792] = 462,
  [793] = 464,
  [794] = 465,
  [795] = 467,
  [796] = 525,
  [797] = 471,
  [798] = 473,
  [799] = 474,
  [800] = 475,
  [801] = 476,
  [802] = 477,
  [803] = 479,
  [804] = 481,
  [805] = 467,
  [806] = 480,
  [807] = 483,
  [808] = 492,
  [809] = 493,
  [810] = 494,
  [811] = 496,
  [812] = 498,
  [813] = 499,
  [814] = 500,
  [815] = 501,
  [816] = 492,
  [817] = 493,
  [818] = 504,
  [819] = 505,
  [820] = 494,
  [821] = 496,
  [822] = 498,
  [823] = 507,
  [824] = 499,
  [825] = 500,
  [826] = 501,
  [827] = 504,
  [828] = 505,
  [829] = 508,
  [830] = 509,
  [831] = 507,
  [832] = 508,
  [833] = 509,
  [834] = 511,
  [835] = 511,
  [836] = 513,
  [837] = 513,
  [838] = 490,
  [839] = 516,
  [840] = 517,
  [841] = 460,
  [842] = 519,
  [843] = 520,
  [844] = 521,
  [845] = 523,
  [846] = 524,
  [847] = 525,
  [848] = 461,
  [849] = 463,
  [850] = 466,
  [851] = 468,
  [852] = 470,
  [853] = 472,
  [854] = 478,
  [855] = 484,
  [856] = 491,
  [857] = 502,
  [858] = 462,
  [859] = 464,
  [860] = 465,
  [861] = 467,
  [862] = 469,
  [863] = 471,
  [864] = 473,
  [865] = 474,
  [866] = 475,
  [867] = 476,
  [868] = 477,
  [869] = 479,
  [870] = 481,
  [871] = 480,
  [872] = 483,
  [873] = 492,
  [874] = 493,
  [875] = 494,
  [876] = 496,
  [877] = 498,
  [878] = 499,
  [879] = 500,
  [880] = 501,
  [881] = 504,
  [882] = 505,
  [883] = 507,
  [884] = 508,
  [885] = 509,
  [886] = 511,
  [887] = 513,
  [888] = 490,
  [889] = 516,
  [890] = 517,
  [891] = 460,
  [892] = 519,
  [893] = 520,
  [894] = 521,
  [895] = 523,
  [896] = 524,
  [897] = 525,
  [898] = 461,
  [899] = 463,
  [900] = 466,
  [901] = 468,
  [902] = 470,
  [903] = 472,
  [904] = 478,
  [905] = 484,
  [906] = 469,
  [907] = 491,
  [908] = 502,
  [909] = 462,
  [910] = 464,
  [911] = 465,
  [912] = 467,
  [913] = 469,
  [914] = 471,
  [915] = 473,
  [916] = 474,
  [917] = 475,
  [918] = 476,
  [919] = 477,
  [920] = 479,
  [921] = 481,
  [922] = 480,
  [923] = 483,
  [924] = 492,
  [925] = 493,
  [926] = 494,
  [927] = 496,
  [928] = 498,
  [929] = 499,
  [930] = 500,
  [931] = 501,
  [932] = 504,
  [933] = 505,
  [934] = 507,
  [935] = 508,
  [936] = 509,
  [937] = 511,
  [938] = 513,
  [939] = 939,
  [940] = 485,
  [941] = 486,
  [942] = 489,
  [943] = 621,
  [944] = 471,
  [945] = 473,
  [946] = 482,
  [947] = 490,
  [948] = 495,
  [949] = 497,
  [950] = 474,
  [951] = 516,
  [952] = 512,
  [953] = 517,
  [954] = 475,
  [955] = 460,
  [956] = 939,
  [957] = 485,
  [958] = 486,
  [959] = 489,
  [960] = 621,
  [961] = 519,
  [962] = 476,
  [963] = 520,
  [964] = 482,
  [965] = 495,
  [966] = 497,
  [967] = 512,
  [968] = 939,
  [969] = 485,
  [970] = 486,
  [971] = 489,
  [972] = 621,
  [973] = 477,
  [974] = 939,
  [975] = 479,
  [976] = 521,
  [977] = 482,
  [978] = 495,
  [979] = 497,
  [980] = 512,
  [981] = 939,
  [982] = 485,
  [983] = 486,
  [984] = 489,
  [985] = 621,
  [986] = 521,
  [987] = 522,
  [988] = 523,
  [989] = 524,
  [990] = 482,
  [991] = 495,
  [992] = 497,
  [993] = 512,
  [994] = 939,
  [995] = 485,
  [996] = 486,
  [997] = 489,
  [998] = 621,
  [999] = 525,
  [1000] = 461,
  [1001] = 463,
  [1002] = 466,
  [1003] = 482,
  [1004] = 495,
  [1005] = 497,
  [1006] = 512,
  [1007] = 939,
  [1008] = 485,
  [1009] = 486,
  [1010] = 489,
  [1011] = 621,
  [1012] = 468,
  [1013] = 470,
  [1014] = 472,
  [1015] = 478,
  [1016] = 482,
  [1017] = 495,
  [1018] = 497,
  [1019] = 512,
  [1020] = 939,
  [1021] = 485,
  [1022] = 486,
  [1023] = 489,
  [1024] = 621,
  [1025] = 484,
  [1026] = 481,
  [1027] = 522,
  [1028] = 523,
  [1029] = 482,
  [1030] = 495,
  [1031] = 497,
  [1032] = 512,
  [1033] = 939,
  [1034] = 485,
  [1035] = 486,
  [1036] = 489,
  [1037] = 621,
  [1038] = 524,
  [1039] = 482,
  [1040] = 495,
  [1041] = 497,
  [1042] = 512,
  [1043] = 939,
  [1044] = 485,
  [1045] = 486,
  [1046] = 489,
  [1047] = 621,
  [1048] = 491,
  [1049] = 502,
  [1050] = 482,
  [1051] = 495,
  [1052] = 497,
  [1053] = 512,
  [1054] = 469,
  [1055] = 1055,
  [1056] = 1055,
  [1057] = 1057,
  [1058] = 1058,
  [1059] = 1055,
  [1060] = 1060,
  [1061] = 1061,
  [1062] = 1062,
  [1063] = 1063,
  [1064] = 1064,
  [1065] = 1058,
  [1066] = 1061,
  [1067] = 1064,
  [1068] = 1057,
  [1069] = 1060,
  [1070] = 1058,
  [1071] = 1062,
  [1072] = 1064,
  [1073] = 1057,
  [1074] = 1060,
  [1075] = 1058,
  [1076] = 1062,
  [1077] = 1064,
  [1078] = 1057,
  [1079] = 1060,
  [1080] = 1058,
  [1081] = 1062,
  [1082] = 1064,
  [1083] = 1057,
  [1084] = 1060,
  [1085] = 1058,
  [1086] = 1062,
  [1087] = 1064,
  [1088] = 1057,
  [1089] = 1060,
  [1090] = 1058,
  [1091] = 1062,
  [1092] = 1064,
  [1093] = 1057,
  [1094] = 1060,
  [1095] = 1058,
  [1096] = 1062,
  [1097] = 1064,
  [1098] = 1057,
  [1099] = 1060,
  [1100] = 1058,
  [1101] = 1062,
  [1102] = 1064,
  [1103] = 1057,
  [1104] = 1060,
  [1105] = 1058,
  [1106] = 1062,
  [1107] = 1064,
  [1108] = 1057,
  [1109] = 1060,
  [1110] = 1061,
  [1111] = 1055,
  [1112] = 1061,
  [1113] = 1055,
  [1114] = 1061,
  [1115] = 1055,
  [1116] = 1061,
  [1117] = 1055,
  [1118] = 1061,
  [1119] = 1055,
  [1120] = 1061,
  [1121] = 1055,
  [1122] = 1061,
  [1123] = 1055,
  [1124] = 1061,
  [1125] = 1062,
  [1126] = 133,
  [1127] = 152,
  [1128] = 152,
  [1129] = 152,
  [1130] = 133,
  [1131] = 133,
  [1132] = 133,
  [1133] = 133,
  [1134] = 152,
  [1135] = 152,
  [1136] = 133,
  [1137] = 152,
  [1138] = 252,
  [1139] = 252,
  [1140] = 252,
  [1141] = 252,
  [1142] = 252,
  [1143] = 252,
  [1144] = 317,
  [1145] = 317,
  [1146] = 317,
  [1147] = 317,
  [1148] = 3,
  [1149] = 317,
  [1150] = 6,
  [1151] = 2,
  [1152] = 6,
  [1153] = 4,
  [1154] = 6,
  [1155] = 2,
  [1156] = 3,
  [1157] = 2,
  [1158] = 4,
  [1159] = 6,
  [1160] = 4,
  [1161] = 3,
  [1162] = 3,
  [1163] = 2,
  [1164] = 2,
  [1165] = 3,
  [1166] = 317,
  [1167] = 4,
  [1168] = 6,
  [1169] = 4,
  [1170] = 6,
  [1171] = 3,
  [1172] = 2,
  [1173] = 4,
  [1174] = 48,
  [1175] = 37,
  [1176] = 60,
  [1177] = 38,
  [1178] = 49,
  [1179] = 39,
  [1180] = 61,
  [1181] = 27,
  [1182] = 40,
  [1183] = 26,
  [1184] = 27,
  [1185] = 28,
  [1186] = 29,
  [1187] = 30,
  [1188] = 31,
  [1189] = 28,
  [1190] = 32,
  [1191] = 29,
  [1192] = 18,
  [1193] = 50,
  [1194] = 88,
  [1195] = 30,
  [1196] = 33,
  [1197] = 31,
  [1198] = 34,
  [1199] = 41,
  [1200] = 35,
  [1201] = 32,
  [1202] = 36,
  [1203] = 25,
  [1204] = 37,
  [1205] = 18,
  [1206] = 38,
  [1207] = 54,
  [1208] = 39,
  [1209] = 88,
  [1210] = 40,
  [1211] = 42,
  [1212] = 41,
  [1213] = 33,
  [1214] = 43,
  [1215] = 42,
  [1216] = 43,
  [1217] = 55,
  [1218] = 34,
  [1219] = 44,
  [1220] = 45,
  [1221] = 46,
  [1222] = 47,
  [1223] = 47,
  [1224] = 49,
  [1225] = 50,
  [1226] = 51,
  [1227] = 52,
  [1228] = 53,
  [1229] = 54,
  [1230] = 55,
  [1231] = 56,
  [1232] = 57,
  [1233] = 58,
  [1234] = 62,
  [1235] = 35,
  [1236] = 44,
  [1237] = 36,
  [1238] = 59,
  [1239] = 60,
  [1240] = 20,
  [1241] = 61,
  [1242] = 37,
  [1243] = 45,
  [1244] = 38,
  [1245] = 62,
  [1246] = 21,
  [1247] = 39,
  [1248] = 63,
  [1249] = 64,
  [1250] = 65,
  [1251] = 46,
  [1252] = 66,
  [1253] = 40,
  [1254] = 22,
  [1255] = 67,
  [1256] = 68,
  [1257] = 41,
  [1258] = 69,
  [1259] = 70,
  [1260] = 71,
  [1261] = 47,
  [1262] = 48,
  [1263] = 19,
  [1264] = 48,
  [1265] = 20,
  [1266] = 42,
  [1267] = 21,
  [1268] = 43,
  [1269] = 22,
  [1270] = 23,
  [1271] = 23,
  [1272] = 49,
  [1273] = 24,
  [1274] = 44,
  [1275] = 50,
  [1276] = 51,
  [1277] = 52,
  [1278] = 53,
  [1279] = 54,
  [1280] = 45,
  [1281] = 55,
  [1282] = 56,
  [1283] = 46,
  [1284] = 57,
  [1285] = 58,
  [1286] = 26,
  [1287] = 27,
  [1288] = 63,
  [1289] = 64,
  [1290] = 59,
  [1291] = 60,
  [1292] = 65,
  [1293] = 61,
  [1294] = 28,
  [1295] = 20,
  [1296] = 66,
  [1297] = 62,
  [1298] = 21,
  [1299] = 29,
  [1300] = 63,
  [1301] = 64,
  [1302] = 65,
  [1303] = 22,
  [1304] = 66,
  [1305] = 30,
  [1306] = 23,
  [1307] = 67,
  [1308] = 68,
  [1309] = 67,
  [1310] = 69,
  [1311] = 70,
  [1312] = 71,
  [1313] = 24,
  [1314] = 72,
  [1315] = 19,
  [1316] = 31,
  [1317] = 56,
  [1318] = 68,
  [1319] = 32,
  [1320] = 57,
  [1321] = 69,
  [1322] = 70,
  [1323] = 71,
  [1324] = 18,
  [1325] = 72,
  [1326] = 19,
  [1327] = 58,
  [1328] = 25,
  [1329] = 88,
  [1330] = 24,
  [1331] = 33,
  [1332] = 51,
  [1333] = 34,
  [1334] = 52,
  [1335] = 35,
  [1336] = 53,
  [1337] = 25,
  [1338] = 26,
  [1339] = 36,
  [1340] = 59,
  [1341] = 72,
  [1342] = 39,
  [1343] = 70,
  [1344] = 71,
  [1345] = 42,
  [1346] = 72,
  [1347] = 19,
  [1348] = 43,
  [1349] = 44,
  [1350] = 45,
  [1351] = 46,
  [1352] = 47,
  [1353] = 48,
  [1354] = 20,
  [1355] = 49,
  [1356] = 50,
  [1357] = 21,
  [1358] = 51,
  [1359] = 52,
  [1360] = 53,
  [1361] = 22,
  [1362] = 54,
  [1363] = 55,
  [1364] = 56,
  [1365] = 23,
  [1366] = 24,
  [1367] = 57,
  [1368] = 58,
  [1369] = 1369,
  [1370] = 59,
  [1371] = 60,
  [1372] = 1372,
  [1373] = 61,
  [1374] = 1374,
  [1375] = 1375,
  [1376] = 25,
  [1377] = 62,
  [1378] = 26,
  [1379] = 27,
  [1380] = 28,
  [1381] = 29,
  [1382] = 30,
  [1383] = 31,
  [1384] = 63,
  [1385] = 64,
  [1386] = 65,
  [1387] = 32,
  [1388] = 66,
  [1389] = 1389,
  [1390] = 67,
  [1391] = 18,
  [1392] = 68,
  [1393] = 69,
  [1394] = 88,
  [1395] = 70,
  [1396] = 71,
  [1397] = 33,
  [1398] = 72,
  [1399] = 19,
  [1400] = 34,
  [1401] = 35,
  [1402] = 36,
  [1403] = 20,
  [1404] = 21,
  [1405] = 22,
  [1406] = 23,
  [1407] = 24,
  [1408] = 20,
  [1409] = 21,
  [1410] = 22,
  [1411] = 23,
  [1412] = 37,
  [1413] = 24,
  [1414] = 25,
  [1415] = 26,
  [1416] = 27,
  [1417] = 28,
  [1418] = 29,
  [1419] = 30,
  [1420] = 31,
  [1421] = 32,
  [1422] = 18,
  [1423] = 88,
  [1424] = 33,
  [1425] = 34,
  [1426] = 35,
  [1427] = 36,
  [1428] = 37,
  [1429] = 38,
  [1430] = 39,
  [1431] = 40,
  [1432] = 41,
  [1433] = 1375,
  [1434] = 1434,
  [1435] = 1435,
  [1436] = 1436,
  [1437] = 1389,
  [1438] = 42,
  [1439] = 43,
  [1440] = 1434,
  [1441] = 44,
  [1442] = 45,
  [1443] = 46,
  [1444] = 69,
  [1445] = 48,
  [1446] = 49,
  [1447] = 50,
  [1448] = 51,
  [1449] = 52,
  [1450] = 53,
  [1451] = 1375,
  [1452] = 1434,
  [1453] = 54,
  [1454] = 1435,
  [1455] = 55,
  [1456] = 56,
  [1457] = 1436,
  [1458] = 1389,
  [1459] = 38,
  [1460] = 39,
  [1461] = 1375,
  [1462] = 1434,
  [1463] = 1435,
  [1464] = 40,
  [1465] = 57,
  [1466] = 1436,
  [1467] = 25,
  [1468] = 1389,
  [1469] = 41,
  [1470] = 58,
  [1471] = 1375,
  [1472] = 1434,
  [1473] = 1435,
  [1474] = 1436,
  [1475] = 1389,
  [1476] = 26,
  [1477] = 27,
  [1478] = 28,
  [1479] = 59,
  [1480] = 60,
  [1481] = 29,
  [1482] = 61,
  [1483] = 1375,
  [1484] = 1434,
  [1485] = 30,
  [1486] = 1435,
  [1487] = 1436,
  [1488] = 1389,
  [1489] = 62,
  [1490] = 1372,
  [1491] = 1375,
  [1492] = 1434,
  [1493] = 31,
  [1494] = 1435,
  [1495] = 1495,
  [1496] = 1436,
  [1497] = 1389,
  [1498] = 42,
  [1499] = 43,
  [1500] = 63,
  [1501] = 64,
  [1502] = 44,
  [1503] = 45,
  [1504] = 46,
  [1505] = 47,
  [1506] = 65,
  [1507] = 1375,
  [1508] = 1434,
  [1509] = 48,
  [1510] = 1435,
  [1511] = 32,
  [1512] = 49,
  [1513] = 1436,
  [1514] = 66,
  [1515] = 1389,
  [1516] = 50,
  [1517] = 51,
  [1518] = 18,
  [1519] = 52,
  [1520] = 67,
  [1521] = 1375,
  [1522] = 1434,
  [1523] = 53,
  [1524] = 1435,
  [1525] = 68,
  [1526] = 54,
  [1527] = 1436,
  [1528] = 1389,
  [1529] = 55,
  [1530] = 69,
  [1531] = 56,
  [1532] = 70,
  [1533] = 71,
  [1534] = 1375,
  [1535] = 1434,
  [1536] = 1435,
  [1537] = 1436,
  [1538] = 1389,
  [1539] = 88,
  [1540] = 1369,
  [1541] = 72,
  [1542] = 19,
  [1543] = 1374,
  [1544] = 1369,
  [1545] = 1374,
  [1546] = 1369,
  [1547] = 1374,
  [1548] = 57,
  [1549] = 33,
  [1550] = 58,
  [1551] = 1369,
  [1552] = 1372,
  [1553] = 1374,
  [1554] = 34,
  [1555] = 1369,
  [1556] = 1374,
  [1557] = 35,
  [1558] = 36,
  [1559] = 1369,
  [1560] = 59,
  [1561] = 1374,
  [1562] = 60,
  [1563] = 1436,
  [1564] = 61,
  [1565] = 1369,
  [1566] = 1374,
  [1567] = 37,
  [1568] = 38,
  [1569] = 1369,
  [1570] = 62,
  [1571] = 1374,
  [1572] = 63,
  [1573] = 40,
  [1574] = 64,
  [1575] = 1369,
  [1576] = 65,
  [1577] = 1374,
  [1578] = 1435,
  [1579] = 41,
  [1580] = 66,
  [1581] = 67,
  [1582] = 68,
  [1583] = 47,
  [1584] = 291,
  [1585] = 293,
  [1586] = 292,
  [1587] = 295,
  [1588] = 296,
  [1589] = 297,
  [1590] = 287,
  [1591] = 292,
  [1592] = 293,
  [1593] = 288,
  [1594] = 289,
  [1595] = 297,
  [1596] = 287,
  [1597] = 292,
  [1598] = 290,
  [1599] = 295,
  [1600] = 296,
  [1601] = 297,
  [1602] = 288,
  [1603] = 289,
  [1604] = 290,
  [1605] = 291,
  [1606] = 286,
  [1607] = 293,
  [1608] = 287,
  [1609] = 288,
  [1610] = 289,
  [1611] = 290,
  [1612] = 291,
  [1613] = 295,
  [1614] = 296,
  [1615] = 286,
  [1616] = 286,
  [1617] = 291,
  [1618] = 296,
  [1619] = 286,
  [1620] = 287,
  [1621] = 292,
  [1622] = 297,
  [1623] = 1623,
  [1624] = 287,
  [1625] = 292,
  [1626] = 289,
  [1627] = 290,
  [1628] = 291,
  [1629] = 286,
  [1630] = 288,
  [1631] = 293,
  [1632] = 290,
  [1633] = 288,
  [1634] = 1634,
  [1635] = 1634,
  [1636] = 1634,
  [1637] = 293,
  [1638] = 289,
  [1639] = 290,
  [1640] = 288,
  [1641] = 291,
  [1642] = 295,
  [1643] = 296,
  [1644] = 295,
  [1645] = 297,
  [1646] = 295,
  [1647] = 297,
  [1648] = 296,
  [1649] = 289,
  [1650] = 287,
  [1651] = 286,
  [1652] = 293,
  [1653] = 292,
  [1654] = 343,
  [1655] = 347,
  [1656] = 341,
  [1657] = 348,
  [1658] = 349,
  [1659] = 350,
  [1660] = 354,
  [1661] = 356,
  [1662] = 357,
  [1663] = 371,
  [1664] = 358,
  [1665] = 366,
  [1666] = 369,
  [1667] = 355,
  [1668] = 336,
  [1669] = 342,
  [1670] = 344,
  [1671] = 345,
  [1672] = 355,
  [1673] = 346,
  [1674] = 347,
  [1675] = 372,
  [1676] = 373,
  [1677] = 317,
  [1678] = 372,
  [1679] = 374,
  [1680] = 375,
  [1681] = 371,
  [1682] = 336,
  [1683] = 341,
  [1684] = 348,
  [1685] = 349,
  [1686] = 372,
  [1687] = 373,
  [1688] = 350,
  [1689] = 354,
  [1690] = 356,
  [1691] = 339,
  [1692] = 357,
  [1693] = 375,
  [1694] = 371,
  [1695] = 336,
  [1696] = 373,
  [1697] = 358,
  [1698] = 366,
  [1699] = 369,
  [1700] = 339,
  [1701] = 339,
  [1702] = 342,
  [1703] = 343,
  [1704] = 344,
  [1705] = 345,
  [1706] = 346,
  [1707] = 347,
  [1708] = 355,
  [1709] = 374,
  [1710] = 341,
  [1711] = 348,
  [1712] = 349,
  [1713] = 350,
  [1714] = 354,
  [1715] = 356,
  [1716] = 357,
  [1717] = 358,
  [1718] = 366,
  [1719] = 369,
  [1720] = 375,
  [1721] = 342,
  [1722] = 343,
  [1723] = 344,
  [1724] = 345,
  [1725] = 346,
  [1726] = 374,
  [1727] = 371,
  [1728] = 344,
  [1729] = 366,
  [1730] = 369,
  [1731] = 372,
  [1732] = 355,
  [1733] = 373,
  [1734] = 339,
  [1735] = 342,
  [1736] = 343,
  [1737] = 344,
  [1738] = 345,
  [1739] = 350,
  [1740] = 355,
  [1741] = 346,
  [1742] = 341,
  [1743] = 347,
  [1744] = 345,
  [1745] = 348,
  [1746] = 347,
  [1747] = 349,
  [1748] = 1748,
  [1749] = 350,
  [1750] = 354,
  [1751] = 372,
  [1752] = 373,
  [1753] = 374,
  [1754] = 375,
  [1755] = 356,
  [1756] = 374,
  [1757] = 371,
  [1758] = 375,
  [1759] = 371,
  [1760] = 336,
  [1761] = 1748,
  [1762] = 357,
  [1763] = 346,
  [1764] = 336,
  [1765] = 354,
  [1766] = 339,
  [1767] = 356,
  [1768] = 341,
  [1769] = 341,
  [1770] = 357,
  [1771] = 339,
  [1772] = 348,
  [1773] = 348,
  [1774] = 346,
  [1775] = 349,
  [1776] = 342,
  [1777] = 349,
  [1778] = 350,
  [1779] = 358,
  [1780] = 354,
  [1781] = 356,
  [1782] = 357,
  [1783] = 1783,
  [1784] = 366,
  [1785] = 372,
  [1786] = 369,
  [1787] = 347,
  [1788] = 358,
  [1789] = 366,
  [1790] = 336,
  [1791] = 369,
  [1792] = 373,
  [1793] = 1793,
  [1794] = 1748,
  [1795] = 355,
  [1796] = 1796,
  [1797] = 342,
  [1798] = 358,
  [1799] = 343,
  [1800] = 344,
  [1801] = 374,
  [1802] = 345,
  [1803] = 375,
  [1804] = 343,
  [1805] = 1805,
  [1806] = 1806,
  [1807] = 1807,
  [1808] = 1807,
  [1809] = 1807,
  [1810] = 1810,
  [1811] = 1807,
  [1812] = 1810,
  [1813] = 1807,
  [1814] = 1810,
  [1815] = 1807,
  [1816] = 1807,
  [1817] = 1807,
  [1818] = 1810,
  [1819] = 1807,
  [1820] = 1810,
  [1821] = 1810,
  [1822] = 1810,
  [1823] = 1810,
  [1824] = 1807,
  [1825] = 1810,
  [1826] = 1810,
  [1827] = 1827,
  [1828] = 1828,
  [1829] = 1829,
  [1830] = 1830,
  [1831] = 1831,
  [1832] = 1832,
  [1833] = 1830,
  [1834] = 1834,
  [1835] = 1835,
  [1836] = 1836,
  [1837] = 1831,
  [1838] = 1838,
  [1839] = 1839,
  [1840] = 1840,
  [1841] = 1841,
  [1842] = 1842,
  [1843] = 1842,
  [1844] = 1834,
  [1845] = 1835,
  [1846] = 1842,
  [1847] = 1841,
  [1848] = 1830,
  [1849] = 1849,
  [1850] = 1840,
  [1851] = 1830,
  [1852] = 1831,
  [1853] = 1834,
  [1854] = 1835,
  [1855] = 1842,
  [1856] = 1841,
  [1857] = 1834,
  [1858] = 1849,
  [1859] = 1840,
  [1860] = 1829,
  [1861] = 1835,
  [1862] = 1842,
  [1863] = 1832,
  [1864] = 1836,
  [1865] = 1828,
  [1866] = 1829,
  [1867] = 1832,
  [1868] = 1836,
  [1869] = 1830,
  [1870] = 1831,
  [1871] = 1830,
  [1872] = 1830,
  [1873] = 1834,
  [1874] = 1835,
  [1875] = 1831,
  [1876] = 1838,
  [1877] = 1849,
  [1878] = 1831,
  [1879] = 1849,
  [1880] = 1840,
  [1881] = 1827,
  [1882] = 1882,
  [1883] = 1842,
  [1884] = 1828,
  [1885] = 1834,
  [1886] = 1835,
  [1887] = 1829,
  [1888] = 1834,
  [1889] = 1830,
  [1890] = 1831,
  [1891] = 1835,
  [1892] = 1834,
  [1893] = 1835,
  [1894] = 1838,
  [1895] = 1841,
  [1896] = 1849,
  [1897] = 1849,
  [1898] = 1840,
  [1899] = 1840,
  [1900] = 1842,
  [1901] = 1828,
  [1902] = 1828,
  [1903] = 1842,
  [1904] = 1904,
  [1905] = 1835,
  [1906] = 1849,
  [1907] = 1829,
  [1908] = 1832,
  [1909] = 1836,
  [1910] = 1828,
  [1911] = 1828,
  [1912] = 1838,
  [1913] = 1841,
  [1914] = 1840,
  [1915] = 1836,
  [1916] = 1916,
  [1917] = 1841,
  [1918] = 1832,
  [1919] = 1830,
  [1920] = 1831,
  [1921] = 1828,
  [1922] = 1842,
  [1923] = 1923,
  [1924] = 1840,
  [1925] = 1834,
  [1926] = 1835,
  [1927] = 1834,
  [1928] = 1928,
  [1929] = 1831,
  [1930] = 1829,
  [1931] = 1828,
  [1932] = 1841,
  [1933] = 1829,
  [1934] = 1849,
  [1935] = 1829,
  [1936] = 1840,
  [1937] = 1828,
  [1938] = 1832,
  [1939] = 1830,
  [1940] = 1836,
  [1941] = 1849,
  [1942] = 1841,
  [1943] = 1838,
  [1944] = 1838,
  [1945] = 1836,
  [1946] = 1842,
  [1947] = 1841,
  [1948] = 1831,
  [1949] = 1832,
  [1950] = 1836,
  [1951] = 1829,
  [1952] = 1952,
  [1953] = 1904,
  [1954] = 1916,
  [1955] = 1832,
  [1956] = 1841,
  [1957] = 1904,
  [1958] = 1836,
  [1959] = 1916,
  [1960] = 1904,
  [1961] = 1961,
  [1962] = 1916,
  [1963] = 1838,
  [1964] = 1904,
  [1965] = 1916,
  [1966] = 1904,
  [1967] = 1832,
  [1968] = 1916,
  [1969] = 1838,
  [1970] = 1904,
  [1971] = 1829,
  [1972] = 1916,
  [1973] = 1904,
  [1974] = 1916,
  [1975] = 1832,
  [1976] = 1904,
  [1977] = 1838,
  [1978] = 1916,
  [1979] = 1836,
  [1980] = 1904,
  [1981] = 1916,
  [1982] = 1827,
  [1983] = 1983,
  [1984] = 1928,
  [1985] = 1838,
  [1986] = 1827,
  [1987] = 1928,
  [1988] = 1827,
  [1989] = 1928,
  [1990] = 1827,
  [1991] = 1928,
  [1992] = 1827,
  [1993] = 1928,
  [1994] = 1827,
  [1995] = 1928,
  [1996] = 1840,
  [1997] = 1928,
  [1998] = 1827,
  [1999] = 1928,
  [2000] = 1827,
  [2001] = 1983,
  [2002] = 1928,
  [2003] = 1839,
  [2004] = 1983,
  [2005] = 1839,
  [2006] = 1983,
  [2007] = 1839,
  [2008] = 1983,
  [2009] = 1839,
  [2010] = 1983,
  [2011] = 1839,
  [2012] = 1983,
  [2013] = 1839,
  [2014] = 1983,
  [2015] = 1839,
  [2016] = 1983,
  [2017] = 1839,
  [2018] = 1983,
  [2019] = 1839,
  [2020] = 1849,
  [2021] = 2021,
  [2022] = 2022,
  [2023] = 2023,
  [2024] = 2022,
  [2025] = 2025,
  [2026] = 2023,
  [2027] = 2022,
  [2028] = 2023,
  [2029] = 2029,
  [2030] = 2022,
  [2031] = 2023,
  [2032] = 2032,
  [2033] = 2022,
  [2034] = 2023,
  [2035] = 2029,
  [2036] = 2022,
  [2037] = 2023,
  [2038] = 2038,
  [2039] = 2022,
  [2040] = 2023,
  [2041] = 2041,
  [2042] = 2022,
  [2043] = 2023,
  [2044] = 2022,
  [2045] = 2023,
  [2046] = 2022,
  [2047] = 2023,
  [2048] = 317,
  [2049] = 2029,
  [2050] = 2050,
  [2051] = 2051,
  [2052] = 2051,
  [2053] = 2051,
  [2054] = 2054,
  [2055] = 2051,
  [2056] = 2056,
  [2057] = 2057,
  [2058] = 2051,
  [2059] = 2057,
  [2060] = 2056,
  [2061] = 2054,
  [2062] = 2062,
  [2063] = 2051,
  [2064] = 2064,
  [2065] = 2056,
  [2066] = 2066,
  [2067] = 2051,
  [2068] = 2066,
  [2069] = 2051,
  [2070] = 2062,
  [2071] = 2054,
  [2072] = 2051,
  [2073] = 2051,
  [2074] = 2074,
  [2075] = 2066,
  [2076] = 2057,
  [2077] = 2062,
  [2078] = 2078,
  [2079] = 2079,
  [2080] = 2080,
  [2081] = 2080,
  [2082] = 2082,
  [2083] = 2078,
  [2084] = 2079,
  [2085] = 2082,
  [2086] = 2078,
  [2087] = 2079,
  [2088] = 2078,
  [2089] = 2080,
  [2090] = 2078,
  [2091] = 2079,
  [2092] = 2079,
  [2093] = 2080,
  [2094] = 2080,
  [2095] = 2079,
  [2096] = 2080,
  [2097] = 2078,
  [2098] = 2098,
  [2099] = 2079,
  [2100] = 2080,
  [2101] = 2080,
  [2102] = 2080,
  [2103] = 2078,
  [2104] = 2079,
  [2105] = 2079,
  [2106] = 2082,
  [2107] = 2079,
  [2108] = 2080,
  [2109] = 2078,
  [2110] = 2078,
  [2111] = 2078,
};

static TSCharacterRange sym_identifier_character_set_2[] = {
  {'.', '.'}, {'A', 'Z'}, {'_', '_'}, {'a', 'z'}, {0xaa, 0xaa}, {0xb5, 0xb5}, {0xba, 0xba}, {0xc0, 0xd6},
  {0xd8, 0xf6}, {0xf8, 0x2c1}, {0x2c6, 0x2d1}, {0x2e0, 0x2e4}, {0x2ec, 0x2ec}, {0x2ee, 0x2ee}, {0x370, 0x374}, {0x376, 0x377},
  {0x37b, 0x37d}, {0x37f, 0x37f}, {0x386, 0x386}, {0x388, 0x38a}, {0x38c, 0x38c}, {0x38e, 0x3a1}, {0x3a3, 0x3f5}, {0x3f7, 0x481},
  {0x48a, 0x52f}, {0x531, 0x556}, {0x559, 0x559}, {0x560, 0x588}, {0x5d0, 0x5ea}, {0x5ef, 0x5f2}, {0x620, 0x64a}, {0x66e, 0x66f},
  {0x671, 0x6d3}, {0x6d5, 0x6d5}, {0x6e5, 0x6e6}, {0x6ee, 0x6ef}, {0x6fa, 0x6fc}, {0x6ff, 0x6ff}, {0x710, 0x710}, {0x712, 0x72f},
  {0x74d, 0x7a5}, {0x7b1, 0x7b1}, {0x7ca, 0x7ea}, {0x7f4, 0x7f5}, {0x7fa, 0x7fa}, {0x800, 0x815}, {0x81a, 0x81a}, {0x824, 0x824},
  {0x828, 0x828}, {0x840, 0x858}, {0x860, 0x86a}, {0x870, 0x887}, {0x889, 0x88e}, {0x8a0, 0x8c9}, {0x904, 0x939}, {0x93d, 0x93d},
  {0x950, 0x950}, {0x958, 0x961}, {0x971, 0x980}, {0x985, 0x98c}, {0x98f, 0x990}, {0x993, 0x9a8}, {0x9aa, 0x9b0}, {0x9b2, 0x9b2},
  {0x9b6, 0x9b9}, {0x9bd, 0x9bd}, {0x9ce, 0x9ce}, {0x9dc, 0x9dd}, {0x9df, 0x9e1}, {0x9f0, 0x9f1}, {0x9fc, 0x9fc}, {0xa05, 0xa0a},
  {0xa0f, 0xa10}, {0xa13, 0xa28}, {0xa2a, 0xa30}, {0xa32, 0xa33}, {0xa35, 0xa36}, {0xa38, 0xa39}, {0xa59, 0xa5c}, {0xa5e, 0xa5e},
  {0xa72, 0xa74}, {0xa85, 0xa8d}, {0xa8f, 0xa91}, {0xa93, 0xaa8}, {0xaaa, 0xab0}, {0xab2, 0xab3}, {0xab5, 0xab9}, {0xabd, 0xabd},
  {0xad0, 0xad0}, {0xae0, 0xae1}, {0xaf9, 0xaf9}, {0xb05, 0xb0c}, {0xb0f, 0xb10}, {0xb13, 0xb28}, {0xb2a, 0xb30}, {0xb32, 0xb33},
  {0xb35, 0xb39}, {0xb3d, 0xb3d}, {0xb5c, 0xb5d}, {0xb5f, 0xb61}, {0xb71, 0xb71}, {0xb83, 0xb83}, {0xb85, 0xb8a}, {0xb8e, 0xb90},
  {0xb92, 0xb95}, {0xb99, 0xb9a}, {0xb9c, 0xb9c}, {0xb9e, 0xb9f}, {0xba3, 0xba4}, {0xba8, 0xbaa}, {0xbae, 0xbb9}, {0xbd0, 0xbd0},
  {0xc05, 0xc0c}, {0xc0e, 0xc10}, {0xc12, 0xc28}, {0xc2a, 0xc39}, {0xc3d, 0xc3d}, {0xc58, 0xc5a}, {0xc5d, 0xc5d}, {0xc60, 0xc61},
  {0xc80, 0xc80}, {0xc85, 0xc8c}, {0xc8e, 0xc90}, {0xc92, 0xca8}, {0xcaa, 0xcb3}, {0xcb5, 0xcb9}, {0xcbd, 0xcbd}, {0xcdd, 0xcde},
  {0xce0, 0xce1}, {0xcf1, 0xcf2}, {0xd04, 0xd0c}, {0xd0e, 0xd10}, {0xd12, 0xd3a}, {0xd3d, 0xd3d}, {0xd4e, 0xd4e}, {0xd54, 0xd56},
  {0xd5f, 0xd61}, {0xd7a, 0xd7f}, {0xd85, 0xd96}, {0xd9a, 0xdb1}, {0xdb3, 0xdbb}, {0xdbd, 0xdbd}, {0xdc0, 0xdc6}, {0xe01, 0xe30},
  {0xe32, 0xe32}, {0xe40, 0xe46}, {0xe81, 0xe82}, {0xe84, 0xe84}, {0xe86, 0xe8a}, {0xe8c, 0xea3}, {0xea5, 0xea5}, {0xea7, 0xeb0},
  {0xeb2, 0xeb2}, {0xebd, 0xebd}, {0xec0, 0xec4}, {0xec6, 0xec6}, {0xedc, 0xedf}, {0xf00, 0xf00}, {0xf40, 0xf47}, {0xf49, 0xf6c},
  {0xf88, 0xf8c}, {0x1000, 0x102a}, {0x103f, 0x103f}, {0x1050, 0x1055}, {0x105a, 0x105d}, {0x1061, 0x1061}, {0x1065, 0x1066}, {0x106e, 0x1070},
  {0x1075, 0x1081}, {0x108e, 0x108e}, {0x10a0, 0x10c5}, {0x10c7, 0x10c7}, {0x10cd, 0x10cd}, {0x10d0, 0x10fa}, {0x10fc, 0x1248}, {0x124a, 0x124d},
  {0x1250, 0x1256}, {0x1258, 0x1258}, {0x125a, 0x125d}, {0x1260, 0x1288}, {0x128a, 0x128d}, {0x1290, 0x12b0}, {0x12b2, 0x12b5}, {0x12b8, 0x12be},
  {0x12c0, 0x12c0}, {0x12c2, 0x12c5}, {0x12c8, 0x12d6}, {0x12d8, 0x1310}, {0x1312, 0x1315}, {0x1318, 0x135a}, {0x1380, 0x138f}, {0x13a0, 0x13f5},
  {0x13f8, 0x13fd}, {0x1401, 0x166c}, {0x166f, 0x167f}, {0x1681, 0x169a}, {0x16a0, 0x16ea}, {0x16ee, 0x16f8}, {0x1700, 0x1711}, {0x171f, 0x1731},
  {0x1740, 0x1751}, {0x1760, 0x176c}, {0x176e, 0x1770}, {0x1780, 0x17b3}, {0x17d7, 0x17d7}, {0x17dc, 0x17dc}, {0x1820, 0x1878}, {0x1880, 0x18a8},
  {0x18aa, 0x18aa}, {0x18b0, 0x18f5}, {0x1900, 0x191e}, {0x1950, 0x196d}, {0x1970, 0x1974}, {0x1980, 0x19ab}, {0x19b0, 0x19c9}, {0x1a00, 0x1a16},
  {0x1a20, 0x1a54}, {0x1aa7, 0x1aa7}, {0x1b05, 0x1b33}, {0x1b45, 0x1b4c}, {0x1b83, 0x1ba0}, {0x1bae, 0x1baf}, {0x1bba, 0x1be5}, {0x1c00, 0x1c23},
  {0x1c4d, 0x1c4f}, {0x1c5a, 0x1c7d}, {0x1c80, 0x1c88}, {0x1c90, 0x1cba}, {0x1cbd, 0x1cbf}, {0x1ce9, 0x1cec}, {0x1cee, 0x1cf3}, {0x1cf5, 0x1cf6},
  {0x1cfa, 0x1cfa}, {0x1d00, 0x1dbf}, {0x1e00, 0x1f15}, {0x1f18, 0x1f1d}, {0x1f20, 0x1f45}, {0x1f48, 0x1f4d}, {0x1f50, 0x1f57}, {0x1f59, 0x1f59},
  {0x1f5b, 0x1f5b}, {0x1f5d, 0x1f5d}, {0x1f5f, 0x1f7d}, {0x1f80, 0x1fb4}, {0x1fb6, 0x1fbc}, {0x1fbe, 0x1fbe}, {0x1fc2, 0x1fc4}, {0x1fc6, 0x1fcc},
  {0x1fd0, 0x1fd3}, {0x1fd6, 0x1fdb}, {0x1fe0, 0x1fec}, {0x1ff2, 0x1ff4}, {0x1ff6, 0x1ffc}, {0x2071, 0x2071}, {0x207f, 0x207f}, {0x2090, 0x209c},
  {0x2102, 0x2102}, {0x2107, 0x2107}, {0x210a, 0x2113}, {0x2115, 0x2115}, {0x2118, 0x211d}, {0x2124, 0x2124}, {0x2126, 0x2126}, {0x2128, 0x2128},
  {0x212a, 0x2139}, {0x213c, 0x213f}, {0x2145, 0x2149}, {0x214e, 0x214e}, {0x2160, 0x2188}, {0x2c00, 0x2ce4}, {0x2ceb, 0x2cee}, {0x2cf2, 0x2cf3},
  {0x2d00, 0x2d25}, {0x2d27, 0x2d27}, {0x2d2d, 0x2d2d}, {0x2d30, 0x2d67}, {0x2d6f, 0x2d6f}, {0x2d80, 0x2d96}, {0x2da0, 0x2da6}, {0x2da8, 0x2dae},
  {0x2db0, 0x2db6}, {0x2db8, 0x2dbe}, {0x2dc0, 0x2dc6}, {0x2dc8, 0x2dce}, {0x2dd0, 0x2dd6}, {0x2dd8, 0x2dde}, {0x3005, 0x3007}, {0x3021, 0x3029},
  {0x3031, 0x3035}, {0x3038, 0x303c}, {0x3041, 0x3096}, {0x309d, 0x309f}, {0x30a1, 0x30fa}, {0x30fc, 0x30ff}, {0x3105, 0x312f}, {0x3131, 0x318e},
  {0x31a0, 0x31bf}, {0x31f0, 0x31ff}, {0x3400, 0x4dbf}, {0x4e00, 0xa48c}, {0xa4d0, 0xa4fd}, {0xa500, 0xa60c}, {0xa610, 0xa61f}, {0xa62a, 0xa62b},
  {0xa640, 0xa66e}, {0xa67f, 0xa69d}, {0xa6a0, 0xa6ef}, {0xa717, 0xa71f}, {0xa722, 0xa788}, {0xa78b, 0xa7ca}, {0xa7d0, 0xa7d1}, {0xa7d3, 0xa7d3},
  {0xa7d5, 0xa7d9}, {0xa7f2, 0xa801}, {0xa803, 0xa805}, {0xa807, 0xa80a}, {0xa80c, 0xa822}, {0xa840, 0xa873}, {0xa882, 0xa8b3}, {0xa8f2, 0xa8f7},
  {0xa8fb, 0xa8fb}, {0xa8fd, 0xa8fe}, {0xa90a, 0xa925}, {0xa930, 0xa946}, {0xa960, 0xa97c}, {0xa984, 0xa9b2}, {0xa9cf, 0xa9cf}, {0xa9e0, 0xa9e4},
  {0xa9e6, 0xa9ef}, {0xa9fa, 0xa9fe}, {0xaa00, 0xaa28}, {0xaa40, 0xaa42}, {0xaa44, 0xaa4b}, {0xaa60, 0xaa76}, {0xaa7a, 0xaa7a}, {0xaa7e, 0xaaaf},
  {0xaab1, 0xaab1}, {0xaab5, 0xaab6}, {0xaab9, 0xaabd}, {0xaac0, 0xaac0}, {0xaac2, 0xaac2}, {0xaadb, 0xaadd}, {0xaae0, 0xaaea}, {0xaaf2, 0xaaf4},
  {0xab01, 0xab06}, {0xab09, 0xab0e}, {0xab11, 0xab16}, {0xab20, 0xab26}, {0xab28, 0xab2e}, {0xab30, 0xab5a}, {0xab5c, 0xab69}, {0xab70, 0xabe2},
  {0xac00, 0xd7a3}, {0xd7b0, 0xd7c6}, {0xd7cb, 0xd7fb}, {0xf900, 0xfa6d}, {0xfa70, 0xfad9}, {0xfb00, 0xfb06}, {0xfb13, 0xfb17}, {0xfb1d, 0xfb1d},
  {0xfb1f, 0xfb28}, {0xfb2a, 0xfb36}, {0xfb38, 0xfb3c}, {0xfb3e, 0xfb3e}, {0xfb40, 0xfb41}, {0xfb43, 0xfb44}, {0xfb46, 0xfbb1}, {0xfbd3, 0xfc5d},
  {0xfc64, 0xfd3d}, {0xfd50, 0xfd8f}, {0xfd92, 0xfdc7}, {0xfdf0, 0xfdf9}, {0xfe71, 0xfe71}, {0xfe73, 0xfe73}, {0xfe77, 0xfe77}, {0xfe79, 0xfe79},
  {0xfe7b, 0xfe7b}, {0xfe7d, 0xfe7d}, {0xfe7f, 0xfefc}, {0xff21, 0xff3a}, {0xff41, 0xff5a}, {0xff66, 0xff9d}, {0xffa0, 0xffbe}, {0xffc2, 0xffc7},
  {0xffca, 0xffcf}, {0xffd2, 0xffd7}, {0xffda, 0xffdc}, {0x10000, 0x1000b}, {0x1000d, 0x10026}, {0x10028, 0x1003a}, {0x1003c, 0x1003d}, {0x1003f, 0x1004d},
  {0x10050, 0x1005d}, {0x10080, 0x100fa}, {0x10140, 0x10174}, {0x10280, 0x1029c}, {0x102a0, 0x102d0}, {0x10300, 0x1031f}, {0x1032d, 0x1034a}, {0x10350, 0x10375},
  {0x10380, 0x1039d}, {0x103a0, 0x103c3}, {0x103c8, 0x103cf}, {0x103d1, 0x103d5}, {0x10400, 0x1049d}, {0x104b0, 0x104d3}, {0x104d8, 0x104fb}, {0x10500, 0x10527},
  {0x10530, 0x10563}, {0x10570, 0x1057a}, {0x1057c, 0x1058a}, {0x1058c, 0x10592}, {0x10594, 0x10595}, {0x10597, 0x105a1}, {0x105a3, 0x105b1}, {0x105b3, 0x105b9},
  {0x105bb, 0x105bc}, {0x10600, 0x10736}, {0x10740, 0x10755}, {0x10760, 0x10767}, {0x10780, 0x10785}, {0x10787, 0x107b0}, {0x107b2, 0x107ba}, {0x10800, 0x10805},
  {0x10808, 0x10808}, {0x1080a, 0x10835}, {0x10837, 0x10838}, {0x1083c, 0x1083c}, {0x1083f, 0x10855}, {0x10860, 0x10876}, {0x10880, 0x1089e}, {0x108e0, 0x108f2},
  {0x108f4, 0x108f5}, {0x10900, 0x10915}, {0x10920, 0x10939}, {0x10980, 0x109b7}, {0x109be, 0x109bf}, {0x10a00, 0x10a00}, {0x10a10, 0x10a13}, {0x10a15, 0x10a17},
  {0x10a19, 0x10a35}, {0x10a60, 0x10a7c}, {0x10a80, 0x10a9c}, {0x10ac0, 0x10ac7}, {0x10ac9, 0x10ae4}, {0x10b00, 0x10b35}, {0x10b40, 0x10b55}, {0x10b60, 0x10b72},
  {0x10b80, 0x10b91}, {0x10c00, 0x10c48}, {0x10c80, 0x10cb2}, {0x10cc0, 0x10cf2}, {0x10d00, 0x10d23}, {0x10e80, 0x10ea9}, {0x10eb0, 0x10eb1}, {0x10f00, 0x10f1c},
  {0x10f27, 0x10f27}, {0x10f30, 0x10f45}, {0x10f70, 0x10f81}, {0x10fb0, 0x10fc4}, {0x10fe0, 0x10ff6}, {0x11003, 0x11037}, {0x11071, 0x11072}, {0x11075, 0x11075},
  {0x11083, 0x110af}, {0x110d0, 0x110e8}, {0x11103, 0x11126}, {0x11144, 0x11144}, {0x11147, 0x11147}, {0x11150, 0x11172}, {0x11176, 0x11176}, {0x11183, 0x111b2},
  {0x111c1, 0x111c4}, {0x111da, 0x111da}, {0x111dc, 0x111dc}, {0x11200, 0x11211}, {0x11213, 0x1122b}, {0x1123f, 0x11240}, {0x11280, 0x11286}, {0x11288, 0x11288},
  {0x1128a, 0x1128d}, {0x1128f, 0x1129d}, {0x1129f, 0x112a8}, {0x112b0, 0x112de}, {0x11305, 0x1130c}, {0x1130f, 0x11310}, {0x11313, 0x11328}, {0x1132a, 0x11330},
  {0x11332, 0x11333}, {0x11335, 0x11339}, {0x1133d, 0x1133d}, {0x11350, 0x11350}, {0x1135d, 0x11361}, {0x11400, 0x11434}, {0x11447, 0x1144a}, {0x1145f, 0x11461},
  {0x11480, 0x114af}, {0x114c4, 0x114c5}, {0x114c7, 0x114c7}, {0x11580, 0x115ae}, {0x115d8, 0x115db}, {0x11600, 0x1162f}, {0x11644, 0x11644}, {0x11680, 0x116aa},
  {0x116b8, 0x116b8}, {0x11700, 0x1171a}, {0x11740, 0x11746}, {0x11800, 0x1182b}, {0x118a0, 0x118df}, {0x118ff, 0x11906}, {0x11909, 0x11909}, {0x1190c, 0x11913},
  {0x11915, 0x11916}, {0x11918, 0x1192f}, {0x1193f, 0x1193f}, {0x11941, 0x11941}, {0x119a0, 0x119a7}, {0x119aa, 0x119d0}, {0x119e1, 0x119e1}, {0x119e3, 0x119e3},
  {0x11a00, 0x11a00}, {0x11a0b, 0x11a32}, {0x11a3a, 0x11a3a}, {0x11a50, 0x11a50}, {0x11a5c, 0x11a89}, {0x11a9d, 0x11a9d}, {0x11ab0, 0x11af8}, {0x11c00, 0x11c08},
  {0x11c0a, 0x11c2e}, {0x11c40, 0x11c40}, {0x11c72, 0x11c8f}, {0x11d00, 0x11d06}, {0x11d08, 0x11d09}, {0x11d0b, 0x11d30}, {0x11d46, 0x11d46}, {0x11d60, 0x11d65},
  {0x11d67, 0x11d68}, {0x11d6a, 0x11d89}, {0x11d98, 0x11d98}, {0x11ee0, 0x11ef2}, {0x11f02, 0x11f02}, {0x11f04, 0x11f10}, {0x11f12, 0x11f33}, {0x11fb0, 0x11fb0},
  {0x12000, 0x12399}, {0x12400, 0x1246e}, {0x12480, 0x12543}, {0x12f90, 0x12ff0}, {0x13000, 0x1342f}, {0x13441, 0x13446}, {0x14400, 0x14646}, {0x16800, 0x16a38},
  {0x16a40, 0x16a5e}, {0x16a70, 0x16abe}, {0x16ad0, 0x16aed}, {0x16b00, 0x16b2f}, {0x16b40, 0x16b43}, {0x16b63, 0x16b77}, {0x16b7d, 0x16b8f}, {0x16e40, 0x16e7f},
  {0x16f00, 0x16f4a}, {0x16f50, 0x16f50}, {0x16f93, 0x16f9f}, {0x16fe0, 0x16fe1}, {0x16fe3, 0x16fe3}, {0x17000, 0x187f7}, {0x18800, 0x18cd5}, {0x18d00, 0x18d08},
  {0x1aff0, 0x1aff3}, {0x1aff5, 0x1affb}, {0x1affd, 0x1affe}, {0x1b000, 0x1b122}, {0x1b132, 0x1b132}, {0x1b150, 0x1b152}, {0x1b155, 0x1b155}, {0x1b164, 0x1b167},
  {0x1b170, 0x1b2fb}, {0x1bc00, 0x1bc6a}, {0x1bc70, 0x1bc7c}, {0x1bc80, 0x1bc88}, {0x1bc90, 0x1bc99}, {0x1d400, 0x1d454}, {0x1d456, 0x1d49c}, {0x1d49e, 0x1d49f},
  {0x1d4a2, 0x1d4a2}, {0x1d4a5, 0x1d4a6}, {0x1d4a9, 0x1d4ac}, {0x1d4ae, 0x1d4b9}, {0x1d4bb, 0x1d4bb}, {0x1d4bd, 0x1d4c3}, {0x1d4c5, 0x1d505}, {0x1d507, 0x1d50a},
  {0x1d50d, 0x1d514}, {0x1d516, 0x1d51c}, {0x1d51e, 0x1d539}, {0x1d53b, 0x1d53e}, {0x1d540, 0x1d544}, {0x1d546, 0x1d546}, {0x1d54a, 0x1d550}, {0x1d552, 0x1d6a5},
  {0x1d6a8, 0x1d6c0}, {0x1d6c2, 0x1d6da}, {0x1d6dc, 0x1d6fa}, {0x1d6fc, 0x1d714}, {0x1d716, 0x1d734}, {0x1d736, 0x1d74e}, {0x1d750, 0x1d76e}, {0x1d770, 0x1d788},
  {0x1d78a, 0x1d7a8}, {0x1d7aa, 0x1d7c2}, {0x1d7c4, 0x1d7cb}, {0x1df00, 0x1df1e}, {0x1df25, 0x1df2a}, {0x1e030, 0x1e06d}, {0x1e100, 0x1e12c}, {0x1e137, 0x1e13d},
  {0x1e14e, 0x1e14e}, {0x1e290, 0x1e2ad}, {0x1e2c0, 0x1e2eb}, {0x1e4d0, 0x1e4eb}, {0x1e7e0, 0x1e7e6}, {0x1e7e8, 0x1e7eb}, {0x1e7ed, 0x1e7ee}, {0x1e7f0, 0x1e7fe},
  {0x1e800, 0x1e8c4}, {0x1e900, 0x1e943}, {0x1e94b, 0x1e94b}, {0x1ee00, 0x1ee03}, {0x1ee05, 0x1ee1f}, {0x1ee21, 0x1ee22}, {0x1ee24, 0x1ee24}, {0x1ee27, 0x1ee27},
  {0x1ee29, 0x1ee32}, {0x1ee34, 0x1ee37}, {0x1ee39, 0x1ee39}, {0x1ee3b, 0x1ee3b}, {0x1ee42, 0x1ee42}, {0x1ee47, 0x1ee47}, {0x1ee49, 0x1ee49}, {0x1ee4b, 0x1ee4b},
  {0x1ee4d, 0x1ee4f}, {0x1ee51, 0x1ee52}, {0x1ee54, 0x1ee54}, {0x1ee57, 0x1ee57}, {0x1ee59, 0x1ee59}, {0x1ee5b, 0x1ee5b}, {0x1ee5d, 0x1ee5d}, {0x1ee5f, 0x1ee5f},
  {0x1ee61, 0x1ee62}, {0x1ee64, 0x1ee64}, {0x1ee67, 0x1ee6a}, {0x1ee6c, 0x1ee72}, {0x1ee74, 0x1ee77}, {0x1ee79, 0x1ee7c}, {0x1ee7e, 0x1ee7e}, {0x1ee80, 0x1ee89},
  {0x1ee8b, 0x1ee9b}, {0x1eea1, 0x1eea3}, {0x1eea5, 0x1eea9}, {0x1eeab, 0x1eebb}, {0x20000, 0x2a6df}, {0x2a700, 0x2b739}, {0x2b740, 0x2b81d}, {0x2b820, 0x2cea1},
  {0x2ceb0, 0x2ebe0}, {0x2ebf0, 0x2ee5d}, {0x2f800, 0x2fa1d}, {0x30000, 0x3134a}, {0x31350, 0x323af},
};

static TSCharacterRange sym_identifier_character_set_3[] = {
  {'.', '.'}, {'0', '9'}, {'A', 'Z'}, {'_', '_'}, {'a', 'z'}, {0xaa, 0xaa}, {0xb5, 0xb5}, {0xb7, 0xb7},
  {0xba, 0xba}, {0xc0, 0xd6}, {0xd8, 0xf6}, {0xf8, 0x2c1}, {0x2c6, 0x2d1}, {0x2e0, 0x2e4}, {0x2ec, 0x2ec}, {0x2ee, 0x2ee},
  {0x300, 0x374}, {0x376, 0x377}, {0x37b, 0x37d}, {0x37f, 0x37f}, {0x386, 0x38a}, {0x38c, 0x38c}, {0x38e, 0x3a1}, {0x3a3, 0x3f5},
  {0x3f7, 0x481}, {0x483, 0x487}, {0x48a, 0x52f}, {0x531, 0x556}, {0x559, 0x559}, {0x560, 0x588}, {0x591, 0x5bd}, {0x5bf, 0x5bf},
  {0x5c1, 0x5c2}, {0x5c4, 0x5c5}, {0x5c7, 0x5c7}, {0x5d0, 0x5ea}, {0x5ef, 0x5f2}, {0x610, 0x61a}, {0x620, 0x669}, {0x66e, 0x6d3},
  {0x6d5, 0x6dc}, {0x6df, 0x6e8}, {0x6ea, 0x6fc}, {0x6ff, 0x6ff}, {0x710, 0x74a}, {0x74d, 0x7b1}, {0x7c0, 0x7f5}, {0x7fa, 0x7fa},
  {0x7fd, 0x7fd}, {0x800, 0x82d}, {0x840, 0x85b}, {0x860, 0x86a}, {0x870, 0x887}, {0x889, 0x88e}, {0x898, 0x8e1}, {0x8e3, 0x963},
  {0x966, 0x96f}, {0x971, 0x983}, {0x985, 0x98c}, {0x98f, 0x990}, {0x993, 0x9a8}, {0x9aa, 0x9b0}, {0x9b2, 0x9b2}, {0x9b6, 0x9b9},
  {0x9bc, 0x9c4}, {0x9c7, 0x9c8}, {0x9cb, 0x9ce}, {0x9d7, 0x9d7}, {0x9dc, 0x9dd}, {0x9df, 0x9e3}, {0x9e6, 0x9f1}, {0x9fc, 0x9fc},
  {0x9fe, 0x9fe}, {0xa01, 0xa03}, {0xa05, 0xa0a}, {0xa0f, 0xa10}, {0xa13, 0xa28}, {0xa2a, 0xa30}, {0xa32, 0xa33}, {0xa35, 0xa36},
  {0xa38, 0xa39}, {0xa3c, 0xa3c}, {0xa3e, 0xa42}, {0xa47, 0xa48}, {0xa4b, 0xa4d}, {0xa51, 0xa51}, {0xa59, 0xa5c}, {0xa5e, 0xa5e},
  {0xa66, 0xa75}, {0xa81, 0xa83}, {0xa85, 0xa8d}, {0xa8f, 0xa91}, {0xa93, 0xaa8}, {0xaaa, 0xab0}, {0xab2, 0xab3}, {0xab5, 0xab9},
  {0xabc, 0xac5}, {0xac7, 0xac9}, {0xacb, 0xacd}, {0xad0, 0xad0}, {0xae0, 0xae3}, {0xae6, 0xaef}, {0xaf9, 0xaff}, {0xb01, 0xb03},
  {0xb05, 0xb0c}, {0xb0f, 0xb10}, {0xb13, 0xb28}, {0xb2a, 0xb30}, {0xb32, 0xb33}, {0xb35, 0xb39}, {0xb3c, 0xb44}, {0xb47, 0xb48},
  {0xb4b, 0xb4d}, {0xb55, 0xb57}, {0xb5c, 0xb5d}, {0xb5f, 0xb63}, {0xb66, 0xb6f}, {0xb71, 0xb71}, {0xb82, 0xb83}, {0xb85, 0xb8a},
  {0xb8e, 0xb90}, {0xb92, 0xb95}, {0xb99, 0xb9a}, {0xb9c, 0xb9c}, {0xb9e, 0xb9f}, {0xba3, 0xba4}, {0xba8, 0xbaa}, {0xbae, 0xbb9},
  {0xbbe, 0xbc2}, {0xbc6, 0xbc8}, {0xbca, 0xbcd}, {0xbd0, 0xbd0}, {0xbd7, 0xbd7}, {0xbe6, 0xbef}, {0xc00, 0xc0c}, {0xc0e, 0xc10},
  {0xc12, 0xc28}, {0xc2a, 0xc39}, {0xc3c, 0xc44}, {0xc46, 0xc48}, {0xc4a, 0xc4d}, {0xc55, 0xc56}, {0xc58, 0xc5a}, {0xc5d, 0xc5d},
  {0xc60, 0xc63}, {0xc66, 0xc6f}, {0xc80, 0xc83}, {0xc85, 0xc8c}, {0xc8e, 0xc90}, {0xc92, 0xca8}, {0xcaa, 0xcb3}, {0xcb5, 0xcb9},
  {0xcbc, 0xcc4}, {0xcc6, 0xcc8}, {0xcca, 0xccd}, {0xcd5, 0xcd6}, {0xcdd, 0xcde}, {0xce0, 0xce3}, {0xce6, 0xcef}, {0xcf1, 0xcf3},
  {0xd00, 0xd0c}, {0xd0e, 0xd10}, {0xd12, 0xd44}, {0xd46, 0xd48}, {0xd4a, 0xd4e}, {0xd54, 0xd57}, {0xd5f, 0xd63}, {0xd66, 0xd6f},
  {0xd7a, 0xd7f}, {0xd81, 0xd83}, {0xd85, 0xd96}, {0xd9a, 0xdb1}, {0xdb3, 0xdbb}, {0xdbd, 0xdbd}, {0xdc0, 0xdc6}, {0xdca, 0xdca},
  {0xdcf, 0xdd4}, {0xdd6, 0xdd6}, {0xdd8, 0xddf}, {0xde6, 0xdef}, {0xdf2, 0xdf3}, {0xe01, 0xe3a}, {0xe40, 0xe4e}, {0xe50, 0xe59},
  {0xe81, 0xe82}, {0xe84, 0xe84}, {0xe86, 0xe8a}, {0xe8c, 0xea3}, {0xea5, 0xea5}, {0xea7, 0xebd}, {0xec0, 0xec4}, {0xec6, 0xec6},
  {0xec8, 0xece}, {0xed0, 0xed9}, {0xedc, 0xedf}, {0xf00, 0xf00}, {0xf18, 0xf19}, {0xf20, 0xf29}, {0xf35, 0xf35}, {0xf37, 0xf37},
  {0xf39, 0xf39}, {0xf3e, 0xf47}, {0xf49, 0xf6c}, {0xf71, 0xf84}, {0xf86, 0xf97}, {0xf99, 0xfbc}, {0xfc6, 0xfc6}, {0x1000, 0x1049},
  {0x1050, 0x109d}, {0x10a0, 0x10c5}, {0x10c7, 0x10c7}, {0x10cd, 0x10cd}, {0x10d0, 0x10fa}, {0x10fc, 0x1248}, {0x124a, 0x124d}, {0x1250, 0x1256},
  {0x1258, 0x1258}, {0x125a, 0x125d}, {0x1260, 0x1288}, {0x128a, 0x128d}, {0x1290, 0x12b0}, {0x12b2, 0x12b5}, {0x12b8, 0x12be}, {0x12c0, 0x12c0},
  {0x12c2, 0x12c5}, {0x12c8, 0x12d6}, {0x12d8, 0x1310}, {0x1312, 0x1315}, {0x1318, 0x135a}, {0x135d, 0x135f}, {0x1369, 0x1371}, {0x1380, 0x138f},
  {0x13a0, 0x13f5}, {0x13f8, 0x13fd}, {0x1401, 0x166c}, {0x166f, 0x167f}, {0x1681, 0x169a}, {0x16a0, 0x16ea}, {0x16ee, 0x16f8}, {0x1700, 0x1715},
  {0x171f, 0x1734}, {0x1740, 0x1753}, {0x1760, 0x176c}, {0x176e, 0x1770}, {0x1772, 0x1773}, {0x1780, 0x17d3}, {0x17d7, 0x17d7}, {0x17dc, 0x17dd},
  {0x17e0, 0x17e9}, {0x180b, 0x180d}, {0x180f, 0x1819}, {0x1820, 0x1878}, {0x1880, 0x18aa}, {0x18b0, 0x18f5}, {0x1900, 0x191e}, {0x1920, 0x192b},
  {0x1930, 0x193b}, {0x1946, 0x196d}, {0x1970, 0x1974}, {0x1980, 0x19ab}, {0x19b0, 0x19c9}, {0x19d0, 0x19da}, {0x1a00, 0x1a1b}, {0x1a20, 0x1a5e},
  {0x1a60, 0x1a7c}, {0x1a7f, 0x1a89}, {0x1a90, 0x1a99}, {0x1aa7, 0x1aa7}, {0x1ab0, 0x1abd}, {0x1abf, 0x1ace}, {0x1b00, 0x1b4c}, {0x1b50, 0x1b59},
  {0x1b6b, 0x1b73}, {0x1b80, 0x1bf3}, {0x1c00, 0x1c37}, {0x1c40, 0x1c49}, {0x1c4d, 0x1c7d}, {0x1c80, 0x1c88}, {0x1c90, 0x1cba}, {0x1cbd, 0x1cbf},
  {0x1cd0, 0x1cd2}, {0x1cd4, 0x1cfa}, {0x1d00, 0x1f15}, {0x1f18, 0x1f1d}, {0x1f20, 0x1f45}, {0x1f48, 0x1f4d}, {0x1f50, 0x1f57}, {0x1f59, 0x1f59},
  {0x1f5b, 0x1f5b}, {0x1f5d, 0x1f5d}, {0x1f5f, 0x1f7d}, {0x1f80, 0x1fb4}, {0x1fb6, 0x1fbc}, {0x1fbe, 0x1fbe}, {0x1fc2, 0x1fc4}, {0x1fc6, 0x1fcc},
  {0x1fd0, 0x1fd3}, {0x1fd6, 0x1fdb}, {0x1fe0, 0x1fec}, {0x1ff2, 0x1ff4}, {0x1ff6, 0x1ffc}, {0x200c, 0x200d}, {0x203f, 0x2040}, {0x2054, 0x2054},
  {0x2071, 0x2071}, {0x207f, 0x207f}, {0x2090, 0x209c}, {0x20d0, 0x20dc}, {0x20e1, 0x20e1}, {0x20e5, 0x20f0}, {0x2102, 0x2102}, {0x2107, 0x2107},
  {0x210a, 0x2113}, {0x2115, 0x2115}, {0x2118, 0x211d}, {0x2124, 0x2124}, {0x2126, 0x2126}, {0x2128, 0x2128}, {0x212a, 0x2139}, {0x213c, 0x213f},
  {0x2145, 0x2149}, {0x214e, 0x214e}, {0x2160, 0x2188}, {0x2c00, 0x2ce4}, {0x2ceb, 0x2cf3}, {0x2d00, 0x2d25}, {0x2d27, 0x2d27}, {0x2d2d, 0x2d2d},
  {0x2d30, 0x2d67}, {0x2d6f, 0x2d6f}, {0x2d7f, 0x2d96}, {0x2da0, 0x2da6}, {0x2da8, 0x2dae}, {0x2db0, 0x2db6}, {0x2db8, 0x2dbe}, {0x2dc0, 0x2dc6},
  {0x2dc8, 0x2dce}, {0x2dd0, 0x2dd6}, {0x2dd8, 0x2dde}, {0x2de0, 0x2dff}, {0x3005, 0x3007}, {0x3021, 0x302f}, {0x3031, 0x3035}, {0x3038, 0x303c},
  {0x3041, 0x3096}, {0x3099, 0x309a}, {0x309d, 0x309f}, {0x30a1, 0x30ff}, {0x3105, 0x312f}, {0x3131, 0x318e}, {0x31a0, 0x31bf}, {0x31f0, 0x31ff},
  {0x3400, 0x4dbf}, {0x4e00, 0xa48c}, {0xa4d0, 0xa4fd}, {0xa500, 0xa60c}, {0xa610, 0xa62b}, {0xa640, 0xa66f}, {0xa674, 0xa67d}, {0xa67f, 0xa6f1},
  {0xa717, 0xa71f}, {0xa722, 0xa788}, {0xa78b, 0xa7ca}, {0xa7d0, 0xa7d1}, {0xa7d3, 0xa7d3}, {0xa7d5, 0xa7d9}, {0xa7f2, 0xa827}, {0xa82c, 0xa82c},
  {0xa840, 0xa873}, {0xa880, 0xa8c5}, {0xa8d0, 0xa8d9}, {0xa8e0, 0xa8f7}, {0xa8fb, 0xa8fb}, {0xa8fd, 0xa92d}, {0xa930, 0xa953}, {0xa960, 0xa97c},
  {0xa980, 0xa9c0}, {0xa9cf, 0xa9d9}, {0xa9e0, 0xa9fe}, {0xaa00, 0xaa36}, {0xaa40, 0xaa4d}, {0xaa50, 0xaa59}, {0xaa60, 0xaa76}, {0xaa7a, 0xaac2},
  {0xaadb, 0xaadd}, {0xaae0, 0xaaef}, {0xaaf2, 0xaaf6}, {0xab01, 0xab06}, {0xab09, 0xab0e}, {0xab11, 0xab16}, {0xab20, 0xab26}, {0xab28, 0xab2e},
  {0xab30, 0xab5a}, {0xab5c, 0xab69}, {0xab70, 0xabea}, {0xabec, 0xabed}, {0xabf0, 0xabf9}, {0xac00, 0xd7a3}, {0xd7b0, 0xd7c6}, {0xd7cb, 0xd7fb},
  {0xf900, 0xfa6d}, {0xfa70, 0xfad9}, {0xfb00, 0xfb06}, {0xfb13, 0xfb17}, {0xfb1d, 0xfb28}, {0xfb2a, 0xfb36}, {0xfb38, 0xfb3c}, {0xfb3e, 0xfb3e},
  {0xfb40, 0xfb41}, {0xfb43, 0xfb44}, {0xfb46, 0xfbb1}, {0xfbd3, 0xfc5d}, {0xfc64, 0xfd3d}, {0xfd50, 0xfd8f}, {0xfd92, 0xfdc7}, {0xfdf0, 0xfdf9},
  {0xfe00, 0xfe0f}, {0xfe20, 0xfe2f}, {0xfe33, 0xfe34}, {0xfe4d, 0xfe4f}, {0xfe71, 0xfe71}, {0xfe73, 0xfe73}, {0xfe77, 0xfe77}, {0xfe79, 0xfe79},
  {0xfe7b, 0xfe7b}, {0xfe7d, 0xfe7d}, {0xfe7f, 0xfefc}, {0xff10, 0xff19}, {0xff21, 0xff3a}, {0xff3f, 0xff3f}, {0xff41, 0xff5a}, {0xff65, 0xffbe},
  {0xffc2, 0xffc7}, {0xffca, 0xffcf}, {0xffd2, 0xffd7}, {0xffda, 0xffdc}, {0x10000, 0x1000b}, {0x1000d, 0x10026}, {0x10028, 0x1003a}, {0x1003c, 0x1003d},
  {0x1003f, 0x1004d}, {0x10050, 0x1005d}, {0x10080, 0x100fa}, {0x10140, 0x10174}, {0x101fd, 0x101fd}, {0x10280, 0x1029c}, {0x102a0, 0x102d0}, {0x102e0, 0x102e0},
  {0x10300, 0x1031f}, {0x1032d, 0x1034a}, {0x10350, 0x1037a}, {0x10380, 0x1039d}, {0x103a0, 0x103c3}, {0x103c8, 0x103cf}, {0x103d1, 0x103d5}, {0x10400, 0x1049d},
  {0x104a0, 0x104a9}, {0x104b0, 0x104d3}, {0x104d8, 0x104fb}, {0x10500, 0x10527}, {0x10530, 0x10563}, {0x10570, 0x1057a}, {0x1057c, 0x1058a}, {0x1058c, 0x10592},
  {0x10594, 0x10595}, {0x10597, 0x105a1}, {0x105a3, 0x105b1}, {0x105b3, 0x105b9}, {0x105bb, 0x105bc}, {0x10600, 0x10736}, {0x10740, 0x10755}, {0x10760, 0x10767},
  {0x10780, 0x10785}, {0x10787, 0x107b0}, {0x107b2, 0x107ba}, {0x10800, 0x10805}, {0x10808, 0x10808}, {0x1080a, 0x10835}, {0x10837, 0x10838}, {0x1083c, 0x1083c},
  {0x1083f, 0x10855}, {0x10860, 0x10876}, {0x10880, 0x1089e}, {0x108e0, 0x108f2}, {0x108f4, 0x108f5}, {0x10900, 0x10915}, {0x10920, 0x10939}, {0x10980, 0x109b7},
  {0x109be, 0x109bf}, {0x10a00, 0x10a03}, {0x10a05, 0x10a06}, {0x10a0c, 0x10a13}, {0x10a15, 0x10a17}, {0x10a19, 0x10a35}, {0x10a38, 0x10a3a}, {0x10a3f, 0x10a3f},
  {0x10a60, 0x10a7c}, {0x10a80, 0x10a9c}, {0x10ac0, 0x10ac7}, {0x10ac9, 0x10ae6}, {0x10b00, 0x10b35}, {0x10b40, 0x10b55}, {0x10b60, 0x10b72}, {0x10b80, 0x10b91},
  {0x10c00, 0x10c48}, {0x10c80, 0x10cb2}, {0x10cc0, 0x10cf2}, {0x10d00, 0x10d27}, {0x10d30, 0x10d39}, {0x10e80, 0x10ea9}, {0x10eab, 0x10eac}, {0x10eb0, 0x10eb1},
  {0x10efd, 0x10f1c}, {0x10f27, 0x10f27}, {0x10f30, 0x10f50}, {0x10f70, 0x10f85}, {0x10fb0, 0x10fc4}, {0x10fe0, 0x10ff6}, {0x11000, 0x11046}, {0x11066, 0x11075},
  {0x1107f, 0x110ba}, {0x110c2, 0x110c2}, {0x110d0, 0x110e8}, {0x110f0, 0x110f9}, {0x11100, 0x11134}, {0x11136, 0x1113f}, {0x11144, 0x11147}, {0x11150, 0x11173},
  {0x11176, 0x11176}, {0x11180, 0x111c4}, {0x111c9, 0x111cc}, {0x111ce, 0x111da}, {0x111dc, 0x111dc}, {0x11200, 0x11211}, {0x11213, 0x11237}, {0x1123e, 0x11241},
  {0x11280, 0x11286}, {0x11288, 0x11288}, {0x1128a, 0x1128d}, {0x1128f, 0x1129d}, {0x1129f, 0x112a8}, {0x112b0, 0x112ea}, {0x112f0, 0x112f9}, {0x11300, 0x11303},
  {0x11305, 0x1130c}, {0x1130f, 0x11310}, {0x11313, 0x11328}, {0x1132a, 0x11330}, {0x11332, 0x11333}, {0x11335, 0x11339}, {0x1133b, 0x11344}, {0x11347, 0x11348},
  {0x1134b, 0x1134d}, {0x11350, 0x11350}, {0x11357, 0x11357}, {0x1135d, 0x11363}, {0x11366, 0x1136c}, {0x11370, 0x11374}, {0x11400, 0x1144a}, {0x11450, 0x11459},
  {0x1145e, 0x11461}, {0x11480, 0x114c5}, {0x114c7, 0x114c7}, {0x114d0, 0x114d9}, {0x11580, 0x115b5}, {0x115b8, 0x115c0}, {0x115d8, 0x115dd}, {0x11600, 0x11640},
  {0x11644, 0x11644}, {0x11650, 0x11659}, {0x11680, 0x116b8}, {0x116c0, 0x116c9}, {0x11700, 0x1171a}, {0x1171d, 0x1172b}, {0x11730, 0x11739}, {0x11740, 0x11746},
  {0x11800, 0x1183a}, {0x118a0, 0x118e9}, {0x118ff, 0x11906}, {0x11909, 0x11909}, {0x1190c, 0x11913}, {0x11915, 0x11916}, {0x11918, 0x11935}, {0x11937, 0x11938},
  {0x1193b, 0x11943}, {0x11950, 0x11959}, {0x119a0, 0x119a7}, {0x119aa, 0x119d7}, {0x119da, 0x119e1}, {0x119e3, 0x119e4}, {0x11a00, 0x11a3e}, {0x11a47, 0x11a47},
  {0x11a50, 0x11a99}, {0x11a9d, 0x11a9d}, {0x11ab0, 0x11af8}, {0x11c00, 0x11c08}, {0x11c0a, 0x11c36}, {0x11c38, 0x11c40}, {0x11c50, 0x11c59}, {0x11c72, 0x11c8f},
  {0x11c92, 0x11ca7}, {0x11ca9, 0x11cb6}, {0x11d00, 0x11d06}, {0x11d08, 0x11d09}, {0x11d0b, 0x11d36}, {0x11d3a, 0x11d3a}, {0x11d3c, 0x11d3d}, {0x11d3f, 0x11d47},
  {0x11d50, 0x11d59}, {0x11d60, 0x11d65}, {0x11d67, 0x11d68}, {0x11d6a, 0x11d8e}, {0x11d90, 0x11d91}, {0x11d93, 0x11d98}, {0x11da0, 0x11da9}, {0x11ee0, 0x11ef6},
  {0x11f00, 0x11f10}, {0x11f12, 0x11f3a}, {0x11f3e, 0x11f42}, {0x11f50, 0x11f59}, {0x11fb0, 0x11fb0}, {0x12000, 0x12399}, {0x12400, 0x1246e}, {0x12480, 0x12543},
  {0x12f90, 0x12ff0}, {0x13000, 0x1342f}, {0x13440, 0x13455}, {0x14400, 0x14646}, {0x16800, 0x16a38}, {0x16a40, 0x16a5e}, {0x16a60, 0x16a69}, {0x16a70, 0x16abe},
  {0x16ac0, 0x16ac9}, {0x16ad0, 0x16aed}, {0x16af0, 0x16af4}, {0x16b00, 0x16b36}, {0x16b40, 0x16b43}, {0x16b50, 0x16b59}, {0x16b63, 0x16b77}, {0x16b7d, 0x16b8f},
  {0x16e40, 0x16e7f}, {0x16f00, 0x16f4a}, {0x16f4f, 0x16f87}, {0x16f8f, 0x16f9f}, {0x16fe0, 0x16fe1}, {0x16fe3, 0x16fe4}, {0x16ff0, 0x16ff1}, {0x17000, 0x187f7},
  {0x18800, 0x18cd5}, {0x18d00, 0x18d08}, {0x1aff0, 0x1aff3}, {0x1aff5, 0x1affb}, {0x1affd, 0x1affe}, {0x1b000, 0x1b122}, {0x1b132, 0x1b132}, {0x1b150, 0x1b152},
  {0x1b155, 0x1b155}, {0x1b164, 0x1b167}, {0x1b170, 0x1b2fb}, {0x1bc00, 0x1bc6a}, {0x1bc70, 0x1bc7c}, {0x1bc80, 0x1bc88}, {0x1bc90, 0x1bc99}, {0x1bc9d, 0x1bc9e},
  {0x1cf00, 0x1cf2d}, {0x1cf30, 0x1cf46}, {0x1d165, 0x1d169}, {0x1d16d, 0x1d172}, {0x1d17b, 0x1d182}, {0x1d185, 0x1d18b}, {0x1d1aa, 0x1d1ad}, {0x1d242, 0x1d244},
  {0x1d400, 0x1d454}, {0x1d456, 0x1d49c}, {0x1d49e, 0x1d49f}, {0x1d4a2, 0x1d4a2}, {0x1d4a5, 0x1d4a6}, {0x1d4a9, 0x1d4ac}, {0x1d4ae, 0x1d4b9}, {0x1d4bb, 0x1d4bb},
  {0x1d4bd, 0x1d4c3}, {0x1d4c5, 0x1d505}, {0x1d507, 0x1d50a}, {0x1d50d, 0x1d514}, {0x1d516, 0x1d51c}, {0x1d51e, 0x1d539}, {0x1d53b, 0x1d53e}, {0x1d540, 0x1d544},
  {0x1d546, 0x1d546}, {0x1d54a, 0x1d550}, {0x1d552, 0x1d6a5}, {0x1d6a8, 0x1d6c0}, {0x1d6c2, 0x1d6da}, {0x1d6dc, 0x1d6fa}, {0x1d6fc, 0x1d714}, {0x1d716, 0x1d734},
  {0x1d736, 0x1d74e}, {0x1d750, 0x1d76e}, {0x1d770, 0x1d788}, {0x1d78a, 0x1d7a8}, {0x1d7aa, 0x1d7c2}, {0x1d7c4, 0x1d7cb}, {0x1d7ce, 0x1d7ff}, {0x1da00, 0x1da36},
  {0x1da3b, 0x1da6c}, {0x1da75, 0x1da75}, {0x1da84, 0x1da84}, {0x1da9b, 0x1da9f}, {0x1daa1, 0x1daaf}, {0x1df00, 0x1df1e}, {0x1df25, 0x1df2a}, {0x1e000, 0x1e006},
  {0x1e008, 0x1e018}, {0x1e01b, 0x1e021}, {0x1e023, 0x1e024}, {0x1e026, 0x1e02a}, {0x1e030, 0x1e06d}, {0x1e08f, 0x1e08f}, {0x1e100, 0x1e12c}, {0x1e130, 0x1e13d},
  {0x1e140, 0x1e149}, {0x1e14e, 0x1e14e}, {0x1e290, 0x1e2ae}, {0x1e2c0, 0x1e2f9}, {0x1e4d0, 0x1e4f9}, {0x1e7e0, 0x1e7e6}, {0x1e7e8, 0x1e7eb}, {0x1e7ed, 0x1e7ee},
  {0x1e7f0, 0x1e7fe}, {0x1e800, 0x1e8c4}, {0x1e8d0, 0x1e8d6}, {0x1e900, 0x1e94b}, {0x1e950, 0x1e959}, {0x1ee00, 0x1ee03}, {0x1ee05, 0x1ee1f}, {0x1ee21, 0x1ee22},
  {0x1ee24, 0x1ee24}, {0x1ee27, 0x1ee27}, {0x1ee29, 0x1ee32}, {0x1ee34, 0x1ee37}, {0x1ee39, 0x1ee39}, {0x1ee3b, 0x1ee3b}, {0x1ee42, 0x1ee42}, {0x1ee47, 0x1ee47},
  {0x1ee49, 0x1ee49}, {0x1ee4b, 0x1ee4b}, {0x1ee4d, 0x1ee4f}, {0x1ee51, 0x1ee52}, {0x1ee54, 0x1ee54}, {0x1ee57, 0x1ee57}, {0x1ee59, 0x1ee59}, {0x1ee5b, 0x1ee5b},
  {0x1ee5d, 0x1ee5d}, {0x1ee5f, 0x1ee5f}, {0x1ee61, 0x1ee62}, {0x1ee64, 0x1ee64}, {0x1ee67, 0x1ee6a}, {0x1ee6c, 0x1ee72}, {0x1ee74, 0x1ee77}, {0x1ee79, 0x1ee7c},
  {0x1ee7e, 0x1ee7e}, {0x1ee80, 0x1ee89}, {0x1ee8b, 0x1ee9b}, {0x1eea1, 0x1eea3}, {0x1eea5, 0x1eea9}, {0x1eeab, 0x1eebb}, {0x1fbf0, 0x1fbf9}, {0x20000, 0x2a6df},
  {0x2a700, 0x2b739}, {0x2b740, 0x2b81d}, {0x2b820, 0x2cea1}, {0x2ceb0, 0x2ebe0}, {0x2ebf0, 0x2ee5d}, {0x2f800, 0x2fa1d}, {0x30000, 0x3134a}, {0x31350, 0x323af},
  {0xe0100, 0xe01ef},
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(27);
      ADVANCE_MAP(
        '!', 32,
        '"', 71,
        '#', 96,
        '$', 58,
        '%', 5,
        '&', 41,
        '\'', 70,
        '*', 50,
        '+', 33,
        ',', 97,
        '-', 34,
        '.', 91,
        '/', 51,
        '0', 65,
        ':', 56,
        '<', 44,
        '=', 29,
        '>', 46,
        '?', 30,
        '@', 59,
        '\\', 28,
        '^', 53,
        '`', 10,
        '|', 40,
        '~', 31,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(0);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(66);
      if (set_contains(sym_identifier_character_set_2, 669, lookahead)) ADVANCE(95);
      END_STATE();
    case 1:
      ADVANCE_MAP(
        '!', 8,
        '"', 71,
        '#', 96,
        '$', 58,
        '%', 5,
        '&', 41,
        '\'', 70,
        '*', 50,
        '+', 33,
        ',', 97,
        '-', 34,
        '.', 92,
        '/', 51,
        ':', 57,
        '<', 44,
        '=', 29,
        '>', 46,
        '?', 30,
        '@', 59,
        '^', 53,
        '`', 10,
        '|', 40,
        '~', 31,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(1);
      if (set_contains(sym_identifier_character_set_2, 669, lookahead)) ADVANCE(95);
      END_STATE();
    case 2:
      ADVANCE_MAP(
        '!', 8,
        '#', 96,
        '$', 58,
        '%', 5,
        '&', 41,
        '*', 50,
        '+', 33,
        ',', 97,
        '-', 34,
        '.', 94,
        '/', 51,
        ':', 57,
        '<', 44,
        '=', 29,
        '>', 46,
        '?', 30,
        '@', 59,
        '^', 53,
        '`', 10,
        '|', 40,
        '~', 31,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(2);
      if (set_contains(sym_identifier_character_set_2, 669, lookahead)) ADVANCE(95);
      END_STATE();
    case 3:
      if (lookahead == '"') ADVANCE(71);
      if (lookahead == '#') ADVANCE(76);
      if (lookahead == '\\') ADVANCE(9);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(75);
      if (lookahead != 0) ADVANCE(77);
      END_STATE();
    case 4:
      if (lookahead == '#') ADVANCE(73);
      if (lookahead == '\'') ADVANCE(70);
      if (lookahead == '\\') ADVANCE(9);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(72);
      if (lookahead != 0) ADVANCE(74);
      END_STATE();
    case 5:
      if (lookahead == '%') ADVANCE(54);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\\') ADVANCE(5);
      END_STATE();
    case 6:
      if (lookahead == '-') ADVANCE(36);
      END_STATE();
    case 7:
      if (lookahead == '.') ADVANCE(63);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(62);
      END_STATE();
    case 8:
      if (lookahead == '=') ADVANCE(49);
      END_STATE();
    case 9:
      if (lookahead == 'U') ADVANCE(11);
      if (lookahead == 'u') ADVANCE(12);
      if (lookahead == 'x') ADVANCE(24);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(80);
      if (lookahead != 0 &&
          (lookahead < '0' || '9' < lookahead)) ADVANCE(78);
      END_STATE();
    case 10:
      if (lookahead == '\\') ADVANCE(26);
      if (lookahead == '`') ADVANCE(90);
      if (lookahead != 0) ADVANCE(10);
      END_STATE();
    case 11:
      if (lookahead == '{') ADVANCE(23);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(87);
      END_STATE();
    case 12:
      if (lookahead == '{') ADVANCE(25);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(83);
      END_STATE();
    case 13:
      if (lookahead == '}') ADVANCE(78);
      END_STATE();
    case 14:
      if (lookahead == '}') ADVANCE(78);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(13);
      END_STATE();
    case 15:
      if (lookahead == '}') ADVANCE(78);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(14);
      END_STATE();
    case 16:
      if (lookahead == '}') ADVANCE(78);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(15);
      END_STATE();
    case 17:
      if (lookahead == '}') ADVANCE(78);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(16);
      END_STATE();
    case 18:
      if (lookahead == '}') ADVANCE(78);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(17);
      END_STATE();
    case 19:
      if (lookahead == '}') ADVANCE(78);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(18);
      END_STATE();
    case 20:
      if (lookahead == '}') ADVANCE(78);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(19);
      END_STATE();
    case 21:
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(22);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(64);
      END_STATE();
    case 22:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(64);
      END_STATE();
    case 23:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(20);
      END_STATE();
    case 24:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(81);
      END_STATE();
    case 25:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(16);
      END_STATE();
    case 26:
      if (lookahead != 0) ADVANCE(10);
      END_STATE();
    case 27:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 28:
      ACCEPT_TOKEN(anon_sym_BSLASH);
      END_STATE();
    case 29:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '=') ADVANCE(48);
      END_STATE();
    case 30:
      ACCEPT_TOKEN(anon_sym_QMARK);
      END_STATE();
    case 31:
      ACCEPT_TOKEN(anon_sym_TILDE);
      END_STATE();
    case 32:
      ACCEPT_TOKEN(anon_sym_BANG);
      if (lookahead == '=') ADVANCE(49);
      END_STATE();
    case 33:
      ACCEPT_TOKEN(anon_sym_PLUS);
      END_STATE();
    case 34:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '>') ADVANCE(38);
      END_STATE();
    case 35:
      ACCEPT_TOKEN(anon_sym_LT_DASH);
      END_STATE();
    case 36:
      ACCEPT_TOKEN(anon_sym_LT_LT_DASH);
      END_STATE();
    case 37:
      ACCEPT_TOKEN(anon_sym_COLON_EQ);
      END_STATE();
    case 38:
      ACCEPT_TOKEN(anon_sym_DASH_GT);
      if (lookahead == '>') ADVANCE(39);
      END_STATE();
    case 39:
      ACCEPT_TOKEN(anon_sym_DASH_GT_GT);
      END_STATE();
    case 40:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '>') ADVANCE(55);
      if (lookahead == '|') ADVANCE(42);
      END_STATE();
    case 41:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '&') ADVANCE(43);
      END_STATE();
    case 42:
      ACCEPT_TOKEN(anon_sym_PIPE_PIPE);
      END_STATE();
    case 43:
      ACCEPT_TOKEN(anon_sym_AMP_AMP);
      END_STATE();
    case 44:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '<') ADVANCE(6);
      if (lookahead == '=') ADVANCE(45);
      END_STATE();
    case 45:
      ACCEPT_TOKEN(anon_sym_LT_EQ);
      END_STATE();
    case 46:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(47);
      END_STATE();
    case 47:
      ACCEPT_TOKEN(anon_sym_GT_EQ);
      END_STATE();
    case 48:
      ACCEPT_TOKEN(anon_sym_EQ_EQ);
      END_STATE();
    case 49:
      ACCEPT_TOKEN(anon_sym_BANG_EQ);
      END_STATE();
    case 50:
      ACCEPT_TOKEN(anon_sym_STAR);
      if (lookahead == '*') ADVANCE(52);
      END_STATE();
    case 51:
      ACCEPT_TOKEN(anon_sym_SLASH);
      END_STATE();
    case 52:
      ACCEPT_TOKEN(anon_sym_STAR_STAR);
      END_STATE();
    case 53:
      ACCEPT_TOKEN(anon_sym_CARET);
      END_STATE();
    case 54:
      ACCEPT_TOKEN(aux_sym_binary_operator_token1);
      END_STATE();
    case 55:
      ACCEPT_TOKEN(anon_sym_PIPE_GT);
      END_STATE();
    case 56:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == ':') ADVANCE(60);
      if (lookahead == '=') ADVANCE(37);
      END_STATE();
    case 57:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == '=') ADVANCE(37);
      END_STATE();
    case 58:
      ACCEPT_TOKEN(anon_sym_DOLLAR);
      END_STATE();
    case 59:
      ACCEPT_TOKEN(anon_sym_AT);
      END_STATE();
    case 60:
      ACCEPT_TOKEN(anon_sym_COLON_COLON);
      if (lookahead == ':') ADVANCE(61);
      END_STATE();
    case 61:
      ACCEPT_TOKEN(anon_sym_COLON_COLON_COLON);
      END_STATE();
    case 62:
      ACCEPT_TOKEN(sym__hex_literal);
      if (lookahead == '.') ADVANCE(63);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(21);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(62);
      END_STATE();
    case 63:
      ACCEPT_TOKEN(sym__hex_literal);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(21);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(63);
      END_STATE();
    case 64:
      ACCEPT_TOKEN(sym__hex_literal);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(64);
      END_STATE();
    case 65:
      ACCEPT_TOKEN(sym__number_literal);
      if (lookahead == '.') ADVANCE(68);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(67);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(7);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(66);
      END_STATE();
    case 66:
      ACCEPT_TOKEN(sym__number_literal);
      if (lookahead == '.') ADVANCE(68);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(67);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(66);
      END_STATE();
    case 67:
      ACCEPT_TOKEN(sym__number_literal);
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(69);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(69);
      END_STATE();
    case 68:
      ACCEPT_TOKEN(sym__number_literal);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(67);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(68);
      END_STATE();
    case 69:
      ACCEPT_TOKEN(sym__number_literal);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(69);
      END_STATE();
    case 70:
      ACCEPT_TOKEN(anon_sym_SQUOTE);
      END_STATE();
    case 71:
      ACCEPT_TOKEN(anon_sym_DQUOTE);
      END_STATE();
    case 72:
      ACCEPT_TOKEN(aux_sym__single_quoted_string_content_token1);
      if (lookahead == '#') ADVANCE(73);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(72);
      if (lookahead != 0 &&
          lookahead != '\'' &&
          lookahead != '\\') ADVANCE(74);
      END_STATE();
    case 73:
      ACCEPT_TOKEN(aux_sym__single_quoted_string_content_token1);
      if (lookahead == '\n' ||
          lookahead == '\r') ADVANCE(74);
      if (lookahead != 0 &&
          lookahead != '\'' &&
          lookahead != '\\') ADVANCE(73);
      END_STATE();
    case 74:
      ACCEPT_TOKEN(aux_sym__single_quoted_string_content_token1);
      if (lookahead != 0 &&
          lookahead != '\'' &&
          lookahead != '\\') ADVANCE(74);
      END_STATE();
    case 75:
      ACCEPT_TOKEN(aux_sym__double_quoted_string_content_token1);
      if (lookahead == '#') ADVANCE(76);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(75);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '#' &&
          lookahead != '\\') ADVANCE(77);
      END_STATE();
    case 76:
      ACCEPT_TOKEN(aux_sym__double_quoted_string_content_token1);
      if (lookahead == '\n' ||
          lookahead == '\r') ADVANCE(77);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(76);
      END_STATE();
    case 77:
      ACCEPT_TOKEN(aux_sym__double_quoted_string_content_token1);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(77);
      END_STATE();
    case 78:
      ACCEPT_TOKEN(sym_escape_sequence);
      END_STATE();
    case 79:
      ACCEPT_TOKEN(sym_escape_sequence);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(78);
      END_STATE();
    case 80:
      ACCEPT_TOKEN(sym_escape_sequence);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(79);
      END_STATE();
    case 81:
      ACCEPT_TOKEN(sym_escape_sequence);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(78);
      END_STATE();
    case 82:
      ACCEPT_TOKEN(sym_escape_sequence);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(81);
      END_STATE();
    case 83:
      ACCEPT_TOKEN(sym_escape_sequence);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(82);
      END_STATE();
    case 84:
      ACCEPT_TOKEN(sym_escape_sequence);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(83);
      END_STATE();
    case 85:
      ACCEPT_TOKEN(sym_escape_sequence);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(84);
      END_STATE();
    case 86:
      ACCEPT_TOKEN(sym_escape_sequence);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(85);
      END_STATE();
    case 87:
      ACCEPT_TOKEN(sym_escape_sequence);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(86);
      END_STATE();
    case 88:
      ACCEPT_TOKEN(sym_dots);
      if (set_contains(sym_identifier_character_set_3, 777, lookahead)) ADVANCE(95);
      END_STATE();
    case 89:
      ACCEPT_TOKEN(sym_dot_dot_i);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(89);
      if (set_contains(sym_identifier_character_set_3, 777, lookahead)) ADVANCE(95);
      END_STATE();
    case 90:
      ACCEPT_TOKEN(sym_identifier);
      END_STATE();
    case 91:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '.') ADVANCE(93);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(68);
      if (set_contains(sym_identifier_character_set_2, 669, lookahead)) ADVANCE(95);
      END_STATE();
    case 92:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '.') ADVANCE(93);
      if (set_contains(sym_identifier_character_set_2, 669, lookahead)) ADVANCE(95);
      END_STATE();
    case 93:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '.') ADVANCE(88);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(89);
      if (set_contains(sym_identifier_character_set_3, 777, lookahead)) ADVANCE(95);
      END_STATE();
    case 94:
      ACCEPT_TOKEN(sym_identifier);
      if (set_contains(sym_identifier_character_set_2, 669, lookahead)) ADVANCE(95);
      END_STATE();
    case 95:
      ACCEPT_TOKEN(sym_identifier);
      if (set_contains(sym_identifier_character_set_3, 777, lookahead)) ADVANCE(95);
      END_STATE();
    case 96:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(96);
      END_STATE();
    case 97:
      ACCEPT_TOKEN(sym_comma);
      END_STATE();
    default:
      return false;
  }
}

static bool ts_lex_keywords(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      ADVANCE_MAP(
        'F', 1,
        'I', 2,
        'L', 3,
        'N', 4,
        'T', 5,
        'b', 6,
        'f', 7,
        'i', 8,
        'n', 9,
        'r', 10,
        'w', 11,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(0);
      END_STATE();
    case 1:
      if (lookahead == 'A') ADVANCE(12);
      END_STATE();
    case 2:
      if (lookahead == 'n') ADVANCE(13);
      END_STATE();
    case 3:
      ACCEPT_TOKEN(anon_sym_L);
      END_STATE();
    case 4:
      if (lookahead == 'A') ADVANCE(14);
      if (lookahead == 'U') ADVANCE(15);
      if (lookahead == 'a') ADVANCE(16);
      END_STATE();
    case 5:
      if (lookahead == 'R') ADVANCE(17);
      END_STATE();
    case 6:
      if (lookahead == 'r') ADVANCE(18);
      END_STATE();
    case 7:
      if (lookahead == 'o') ADVANCE(19);
      if (lookahead == 'u') ADVANCE(20);
      END_STATE();
    case 8:
      ACCEPT_TOKEN(anon_sym_i);
      if (lookahead == 'f') ADVANCE(21);
      if (lookahead == 'n') ADVANCE(22);
      END_STATE();
    case 9:
      if (lookahead == 'e') ADVANCE(23);
      END_STATE();
    case 10:
      if (lookahead == 'e') ADVANCE(24);
      END_STATE();
    case 11:
      if (lookahead == 'h') ADVANCE(25);
      END_STATE();
    case 12:
      if (lookahead == 'L') ADVANCE(26);
      END_STATE();
    case 13:
      if (lookahead == 'f') ADVANCE(27);
      END_STATE();
    case 14:
      ACCEPT_TOKEN(anon_sym_NA);
      if (lookahead == '_') ADVANCE(28);
      END_STATE();
    case 15:
      if (lookahead == 'L') ADVANCE(29);
      END_STATE();
    case 16:
      if (lookahead == 'N') ADVANCE(30);
      END_STATE();
    case 17:
      if (lookahead == 'U') ADVANCE(31);
      END_STATE();
    case 18:
      if (lookahead == 'e') ADVANCE(32);
      END_STATE();
    case 19:
      if (lookahead == 'r') ADVANCE(33);
      END_STATE();
    case 20:
      if (lookahead == 'n') ADVANCE(34);
      END_STATE();
    case 21:
      ACCEPT_TOKEN(anon_sym_if);
      END_STATE();
    case 22:
      ACCEPT_TOKEN(anon_sym_in);
      END_STATE();
    case 23:
      if (lookahead == 'x') ADVANCE(35);
      END_STATE();
    case 24:
      if (lookahead == 'p') ADVANCE(36);
      END_STATE();
    case 25:
      if (lookahead == 'i') ADVANCE(37);
      END_STATE();
    case 26:
      if (lookahead == 'S') ADVANCE(38);
      END_STATE();
    case 27:
      ACCEPT_TOKEN(sym_inf);
      END_STATE();
    case 28:
      if (lookahead == 'c') ADVANCE(39);
      if (lookahead == 'i') ADVANCE(40);
      if (lookahead == 'r') ADVANCE(41);
      END_STATE();
    case 29:
      if (lookahead == 'L') ADVANCE(42);
      END_STATE();
    case 30:
      ACCEPT_TOKEN(sym_nan);
      END_STATE();
    case 31:
      if (lookahead == 'E') ADVANCE(43);
      END_STATE();
    case 32:
      if (lookahead == 'a') ADVANCE(44);
      END_STATE();
    case 33:
      ACCEPT_TOKEN(anon_sym_for);
      END_STATE();
    case 34:
      if (lookahead == 'c') ADVANCE(45);
      END_STATE();
    case 35:
      if (lookahead == 't') ADVANCE(46);
      END_STATE();
    case 36:
      if (lookahead == 'e') ADVANCE(47);
      END_STATE();
    case 37:
      if (lookahead == 'l') ADVANCE(48);
      END_STATE();
    case 38:
      if (lookahead == 'E') ADVANCE(49);
      END_STATE();
    case 39:
      if (lookahead == 'h') ADVANCE(50);
      if (lookahead == 'o') ADVANCE(51);
      END_STATE();
    case 40:
      if (lookahead == 'n') ADVANCE(52);
      END_STATE();
    case 41:
      if (lookahead == 'e') ADVANCE(53);
      END_STATE();
    case 42:
      ACCEPT_TOKEN(sym_null);
      END_STATE();
    case 43:
      ACCEPT_TOKEN(sym_true);
      END_STATE();
    case 44:
      if (lookahead == 'k') ADVANCE(54);
      END_STATE();
    case 45:
      if (lookahead == 't') ADVANCE(55);
      END_STATE();
    case 46:
      ACCEPT_TOKEN(sym_next);
      END_STATE();
    case 47:
      if (lookahead == 'a') ADVANCE(56);
      END_STATE();
    case 48:
      if (lookahead == 'e') ADVANCE(57);
      END_STATE();
    case 49:
      ACCEPT_TOKEN(sym_false);
      END_STATE();
    case 50:
      if (lookahead == 'a') ADVANCE(58);
      END_STATE();
    case 51:
      if (lookahead == 'm') ADVANCE(59);
      END_STATE();
    case 52:
      if (lookahead == 't') ADVANCE(60);
      END_STATE();
    case 53:
      if (lookahead == 'a') ADVANCE(61);
      END_STATE();
    case 54:
      ACCEPT_TOKEN(sym_break);
      END_STATE();
    case 55:
      if (lookahead == 'i') ADVANCE(62);
      END_STATE();
    case 56:
      if (lookahead == 't') ADVANCE(63);
      END_STATE();
    case 57:
      ACCEPT_TOKEN(anon_sym_while);
      END_STATE();
    case 58:
      if (lookahead == 'r') ADVANCE(64);
      END_STATE();
    case 59:
      if (lookahead == 'p') ADVANCE(65);
      END_STATE();
    case 60:
      if (lookahead == 'e') ADVANCE(66);
      END_STATE();
    case 61:
      if (lookahead == 'l') ADVANCE(67);
      END_STATE();
    case 62:
      if (lookahead == 'o') ADVANCE(68);
      END_STATE();
    case 63:
      ACCEPT_TOKEN(anon_sym_repeat);
      END_STATE();
    case 64:
      if (lookahead == 'a') ADVANCE(69);
      END_STATE();
    case 65:
      if (lookahead == 'l') ADVANCE(70);
      END_STATE();
    case 66:
      if (lookahead == 'g') ADVANCE(71);
      END_STATE();
    case 67:
      if (lookahead == '_') ADVANCE(72);
      END_STATE();
    case 68:
      if (lookahead == 'n') ADVANCE(73);
      END_STATE();
    case 69:
      if (lookahead == 'c') ADVANCE(74);
      END_STATE();
    case 70:
      if (lookahead == 'e') ADVANCE(75);
      END_STATE();
    case 71:
      if (lookahead == 'e') ADVANCE(76);
      END_STATE();
    case 72:
      ACCEPT_TOKEN(anon_sym_NA_real_);
      END_STATE();
    case 73:
      ACCEPT_TOKEN(anon_sym_function);
      END_STATE();
    case 74:
      if (lookahead == 't') ADVANCE(77);
      END_STATE();
    case 75:
      if (lookahead == 'x') ADVANCE(78);
      END_STATE();
    case 76:
      if (lookahead == 'r') ADVANCE(79);
      END_STATE();
    case 77:
      if (lookahead == 'e') ADVANCE(80);
      END_STATE();
    case 78:
      if (lookahead == '_') ADVANCE(81);
      END_STATE();
    case 79:
      if (lookahead == '_') ADVANCE(82);
      END_STATE();
    case 80:
      if (lookahead == 'r') ADVANCE(83);
      END_STATE();
    case 81:
      ACCEPT_TOKEN(anon_sym_NA_complex_);
      END_STATE();
    case 82:
      ACCEPT_TOKEN(anon_sym_NA_integer_);
      END_STATE();
    case 83:
      if (lookahead == '_') ADVANCE(84);
      END_STATE();
    case 84:
      ACCEPT_TOKEN(anon_sym_NA_character_);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0, .external_lex_state = 1},
  [1] = {.lex_state = 0, .external_lex_state = 2},
  [2] = {.lex_state = 0, .external_lex_state = 3},
  [3] = {.lex_state = 0, .external_lex_state = 4},
  [4] = {.lex_state = 0, .external_lex_state = 3},
  [5] = {.lex_state = 0, .external_lex_state = 3},
  [6] = {.lex_state = 0, .external_lex_state = 3},
  [7] = {.lex_state = 0, .external_lex_state = 4},
  [8] = {.lex_state = 0, .external_lex_state = 4},
  [9] = {.lex_state = 0, .external_lex_state = 4},
  [10] = {.lex_state = 0, .external_lex_state = 4},
  [11] = {.lex_state = 0, .external_lex_state = 3},
  [12] = {.lex_state = 0, .external_lex_state = 3},
  [13] = {.lex_state = 0, .external_lex_state = 3},
  [14] = {.lex_state = 0, .external_lex_state = 3},
  [15] = {.lex_state = 0, .external_lex_state = 4},
  [16] = {.lex_state = 0, .external_lex_state = 4},
  [17] = {.lex_state = 0, .external_lex_state = 4},
  [18] = {.lex_state = 0, .external_lex_state = 3},
  [19] = {.lex_state = 0, .external_lex_state = 4},
  [20] = {.lex_state = 0, .external_lex_state = 3},
  [21] = {.lex_state = 0, .external_lex_state = 3},
  [22] = {.lex_state = 0, .external_lex_state = 3},
  [23] = {.lex_state = 0, .external_lex_state = 3},
  [24] = {.lex_state = 0, .external_lex_state = 3},
  [25] = {.lex_state = 0, .external_lex_state = 3},
  [26] = {.lex_state = 0, .external_lex_state = 3},
  [27] = {.lex_state = 0, .external_lex_state = 3},
  [28] = {.lex_state = 0, .external_lex_state = 3},
  [29] = {.lex_state = 0, .external_lex_state = 3},
  [30] = {.lex_state = 0, .external_lex_state = 3},
  [31] = {.lex_state = 0, .external_lex_state = 3},
  [32] = {.lex_state = 0, .external_lex_state = 3},
  [33] = {.lex_state = 0, .external_lex_state = 3},
  [34] = {.lex_state = 0, .external_lex_state = 3},
  [35] = {.lex_state = 0, .external_lex_state = 3},
  [36] = {.lex_state = 0, .external_lex_state = 3},
  [37] = {.lex_state = 0, .external_lex_state = 3},
  [38] = {.lex_state = 0, .external_lex_state = 3},
  [39] = {.lex_state = 0, .external_lex_state = 3},
  [40] = {.lex_state = 0, .external_lex_state = 3},
  [41] = {.lex_state = 0, .external_lex_state = 3},
  [42] = {.lex_state = 0, .external_lex_state = 3},
  [43] = {.lex_state = 0, .external_lex_state = 3},
  [44] = {.lex_state = 0, .external_lex_state = 3},
  [45] = {.lex_state = 0, .external_lex_state = 3},
  [46] = {.lex_state = 0, .external_lex_state = 3},
  [47] = {.lex_state = 0, .external_lex_state = 3},
  [48] = {.lex_state = 0, .external_lex_state = 3},
  [49] = {.lex_state = 0, .external_lex_state = 3},
  [50] = {.lex_state = 0, .external_lex_state = 3},
  [51] = {.lex_state = 0, .external_lex_state = 3},
  [52] = {.lex_state = 0, .external_lex_state = 3},
  [53] = {.lex_state = 0, .external_lex_state = 3},
  [54] = {.lex_state = 0, .external_lex_state = 3},
  [55] = {.lex_state = 0, .external_lex_state = 3},
  [56] = {.lex_state = 0, .external_lex_state = 3},
  [57] = {.lex_state = 0, .external_lex_state = 3},
  [58] = {.lex_state = 0, .external_lex_state = 3},
  [59] = {.lex_state = 0, .external_lex_state = 3},
  [60] = {.lex_state = 0, .external_lex_state = 3},
  [61] = {.lex_state = 0, .external_lex_state = 3},
  [62] = {.lex_state = 0, .external_lex_state = 3},
  [63] = {.lex_state = 0, .external_lex_state = 3},
  [64] = {.lex_state = 0, .external_lex_state = 3},
  [65] = {.lex_state = 0, .external_lex_state = 3},
  [66] = {.lex_state = 0, .external_lex_state = 3},
  [67] = {.lex_state = 0, .external_lex_state = 3},
  [68] = {.lex_state = 0, .external_lex_state = 3},
  [69] = {.lex_state = 0, .external_lex_state = 3},
  [70] = {.lex_state = 0, .external_lex_state = 3},
  [71] = {.lex_state = 0, .external_lex_state = 3},
  [72] = {.lex_state = 0, .external_lex_state = 3},
  [73] = {.lex_state = 0, .external_lex_state = 3},
  [74] = {.lex_state = 0, .external_lex_state = 4},
  [75] = {.lex_state = 0, .external_lex_state = 4},
  [76] = {.lex_state = 0, .external_lex_state = 4},
  [77] = {.lex_state = 0, .external_lex_state = 4},
  [78] = {.lex_state = 0, .external_lex_state = 4},
  [79] = {.lex_state = 0, .external_lex_state = 4},
  [80] = {.lex_state = 0, .external_lex_state = 4},
  [81] = {.lex_state = 0, .external_lex_state = 4},
  [82] = {.lex_state = 0, .external_lex_state = 4},
  [83] = {.lex_state = 0, .external_lex_state = 4},
  [84] = {.lex_state = 0, .external_lex_state = 4},
  [85] = {.lex_state = 0, .external_lex_state = 4},
  [86] = {.lex_state = 0, .external_lex_state = 4},
  [87] = {.lex_state = 0, .external_lex_state = 4},
  [88] = {.lex_state = 0, .external_lex_state = 4},
  [89] = {.lex_state = 0, .external_lex_state = 4},
  [90] = {.lex_state = 0, .external_lex_state = 4},
  [91] = {.lex_state = 0, .external_lex_state = 4},
  [92] = {.lex_state = 0, .external_lex_state = 4},
  [93] = {.lex_state = 0, .external_lex_state = 4},
  [94] = {.lex_state = 0, .external_lex_state = 4},
  [95] = {.lex_state = 0, .external_lex_state = 4},
  [96] = {.lex_state = 0, .external_lex_state = 4},
  [97] = {.lex_state = 0, .external_lex_state = 4},
  [98] = {.lex_state = 0, .external_lex_state = 4},
  [99] = {.lex_state = 0, .external_lex_state = 4},
  [100] = {.lex_state = 0, .external_lex_state = 4},
  [101] = {.lex_state = 0, .external_lex_state = 4},
  [102] = {.lex_state = 0, .external_lex_state = 4},
  [103] = {.lex_state = 0, .external_lex_state = 4},
  [104] = {.lex_state = 0, .external_lex_state = 4},
  [105] = {.lex_state = 0, .external_lex_state = 4},
  [106] = {.lex_state = 0, .external_lex_state = 4},
  [107] = {.lex_state = 0, .external_lex_state = 4},
  [108] = {.lex_state = 0, .external_lex_state = 4},
  [109] = {.lex_state = 0, .external_lex_state = 4},
  [110] = {.lex_state = 0, .external_lex_state = 4},
  [111] = {.lex_state = 0, .external_lex_state = 4},
  [112] = {.lex_state = 0, .external_lex_state = 4},
  [113] = {.lex_state = 0, .external_lex_state = 4},
  [114] = {.lex_state = 0, .external_lex_state = 4},
  [115] = {.lex_state = 0, .external_lex_state = 4},
  [116] = {.lex_state = 0, .external_lex_state = 4},
  [117] = {.lex_state = 0, .external_lex_state = 4},
  [118] = {.lex_state = 0, .external_lex_state = 4},
  [119] = {.lex_state = 0, .external_lex_state = 4},
  [120] = {.lex_state = 0, .external_lex_state = 4},
  [121] = {.lex_state = 0, .external_lex_state = 4},
  [122] = {.lex_state = 0, .external_lex_state = 4},
  [123] = {.lex_state = 0, .external_lex_state = 4},
  [124] = {.lex_state = 0, .external_lex_state = 4},
  [125] = {.lex_state = 0, .external_lex_state = 4},
  [126] = {.lex_state = 0, .external_lex_state = 4},
  [127] = {.lex_state = 0, .external_lex_state = 4},
  [128] = {.lex_state = 0, .external_lex_state = 4},
  [129] = {.lex_state = 0, .external_lex_state = 3},
  [130] = {.lex_state = 0, .external_lex_state = 5},
  [131] = {.lex_state = 0, .external_lex_state = 6},
  [132] = {.lex_state = 0, .external_lex_state = 6},
  [133] = {.lex_state = 0, .external_lex_state = 3},
  [134] = {.lex_state = 0, .external_lex_state = 6},
  [135] = {.lex_state = 0, .external_lex_state = 6},
  [136] = {.lex_state = 0, .external_lex_state = 6},
  [137] = {.lex_state = 0, .external_lex_state = 6},
  [138] = {.lex_state = 0, .external_lex_state = 6},
  [139] = {.lex_state = 0, .external_lex_state = 6},
  [140] = {.lex_state = 0, .external_lex_state = 6},
  [141] = {.lex_state = 0, .external_lex_state = 6},
  [142] = {.lex_state = 0, .external_lex_state = 6},
  [143] = {.lex_state = 0, .external_lex_state = 6},
  [144] = {.lex_state = 0, .external_lex_state = 6},
  [145] = {.lex_state = 0, .external_lex_state = 6},
  [146] = {.lex_state = 0, .external_lex_state = 6},
  [147] = {.lex_state = 0, .external_lex_state = 6},
  [148] = {.lex_state = 0, .external_lex_state = 6},
  [149] = {.lex_state = 0, .external_lex_state = 6},
  [150] = {.lex_state = 0, .external_lex_state = 6},
  [151] = {.lex_state = 0, .external_lex_state = 6},
  [152] = {.lex_state = 0, .external_lex_state = 3},
  [153] = {.lex_state = 0, .external_lex_state = 6},
  [154] = {.lex_state = 0, .external_lex_state = 6},
  [155] = {.lex_state = 0, .external_lex_state = 6},
  [156] = {.lex_state = 0, .external_lex_state = 6},
  [157] = {.lex_state = 0, .external_lex_state = 6},
  [158] = {.lex_state = 0, .external_lex_state = 6},
  [159] = {.lex_state = 0, .external_lex_state = 6},
  [160] = {.lex_state = 0, .external_lex_state = 6},
  [161] = {.lex_state = 0, .external_lex_state = 6},
  [162] = {.lex_state = 0, .external_lex_state = 6},
  [163] = {.lex_state = 0, .external_lex_state = 6},
  [164] = {.lex_state = 0, .external_lex_state = 6},
  [165] = {.lex_state = 0, .external_lex_state = 6},
  [166] = {.lex_state = 0, .external_lex_state = 6},
  [167] = {.lex_state = 0, .external_lex_state = 6},
  [168] = {.lex_state = 0, .external_lex_state = 6},
  [169] = {.lex_state = 0, .external_lex_state = 6},
  [170] = {.lex_state = 0, .external_lex_state = 6},
  [171] = {.lex_state = 0, .external_lex_state = 6},
  [172] = {.lex_state = 0, .external_lex_state = 6},
  [173] = {.lex_state = 0, .external_lex_state = 6},
  [174] = {.lex_state = 0, .external_lex_state = 6},
  [175] = {.lex_state = 0, .external_lex_state = 6},
  [176] = {.lex_state = 0, .external_lex_state = 6},
  [177] = {.lex_state = 0, .external_lex_state = 6},
  [178] = {.lex_state = 0, .external_lex_state = 6},
  [179] = {.lex_state = 0, .external_lex_state = 6},
  [180] = {.lex_state = 0, .external_lex_state = 6},
  [181] = {.lex_state = 0, .external_lex_state = 6},
  [182] = {.lex_state = 0, .external_lex_state = 5},
  [183] = {.lex_state = 0, .external_lex_state = 5},
  [184] = {.lex_state = 0, .external_lex_state = 5},
  [185] = {.lex_state = 0, .external_lex_state = 5},
  [186] = {.lex_state = 0, .external_lex_state = 5},
  [187] = {.lex_state = 0, .external_lex_state = 5},
  [188] = {.lex_state = 0, .external_lex_state = 5},
  [189] = {.lex_state = 0, .external_lex_state = 5},
  [190] = {.lex_state = 0, .external_lex_state = 6},
  [191] = {.lex_state = 0, .external_lex_state = 5},
  [192] = {.lex_state = 0, .external_lex_state = 5},
  [193] = {.lex_state = 0, .external_lex_state = 5},
  [194] = {.lex_state = 0, .external_lex_state = 5},
  [195] = {.lex_state = 0, .external_lex_state = 5},
  [196] = {.lex_state = 0, .external_lex_state = 5},
  [197] = {.lex_state = 0, .external_lex_state = 5},
  [198] = {.lex_state = 0, .external_lex_state = 5},
  [199] = {.lex_state = 0, .external_lex_state = 5},
  [200] = {.lex_state = 0, .external_lex_state = 5},
  [201] = {.lex_state = 0, .external_lex_state = 5},
  [202] = {.lex_state = 0, .external_lex_state = 5},
  [203] = {.lex_state = 0, .external_lex_state = 5},
  [204] = {.lex_state = 0, .external_lex_state = 5},
  [205] = {.lex_state = 0, .external_lex_state = 5},
  [206] = {.lex_state = 0, .external_lex_state = 5},
  [207] = {.lex_state = 0, .external_lex_state = 5},
  [208] = {.lex_state = 0, .external_lex_state = 5},
  [209] = {.lex_state = 0, .external_lex_state = 5},
  [210] = {.lex_state = 0, .external_lex_state = 4},
  [211] = {.lex_state = 0, .external_lex_state = 5},
  [212] = {.lex_state = 0, .external_lex_state = 5},
  [213] = {.lex_state = 0, .external_lex_state = 5},
  [214] = {.lex_state = 0, .external_lex_state = 5},
  [215] = {.lex_state = 0, .external_lex_state = 5},
  [216] = {.lex_state = 0, .external_lex_state = 5},
  [217] = {.lex_state = 0, .external_lex_state = 5},
  [218] = {.lex_state = 0, .external_lex_state = 5},
  [219] = {.lex_state = 0, .external_lex_state = 5},
  [220] = {.lex_state = 0, .external_lex_state = 5},
  [221] = {.lex_state = 0, .external_lex_state = 5},
  [222] = {.lex_state = 0, .external_lex_state = 5},
  [223] = {.lex_state = 0, .external_lex_state = 5},
  [224] = {.lex_state = 0, .external_lex_state = 5},
  [225] = {.lex_state = 0, .external_lex_state = 6},
  [226] = {.lex_state = 0, .external_lex_state = 5},
  [227] = {.lex_state = 0, .external_lex_state = 5},
  [228] = {.lex_state = 0, .external_lex_state = 5},
  [229] = {.lex_state = 0, .external_lex_state = 5},
  [230] = {.lex_state = 0, .external_lex_state = 5},
  [231] = {.lex_state = 0, .external_lex_state = 5},
  [232] = {.lex_state = 0, .external_lex_state = 5},
  [233] = {.lex_state = 0, .external_lex_state = 5},
  [234] = {.lex_state = 0, .external_lex_state = 5},
  [235] = {.lex_state = 0, .external_lex_state = 5},
  [236] = {.lex_state = 0, .external_lex_state = 5},
  [237] = {.lex_state = 0, .external_lex_state = 5},
  [238] = {.lex_state = 0, .external_lex_state = 5},
  [239] = {.lex_state = 0, .external_lex_state = 5},
  [240] = {.lex_state = 0, .external_lex_state = 5},
  [241] = {.lex_state = 0, .external_lex_state = 6},
  [242] = {.lex_state = 0, .external_lex_state = 6},
  [243] = {.lex_state = 0, .external_lex_state = 6},
  [244] = {.lex_state = 0, .external_lex_state = 6},
  [245] = {.lex_state = 0, .external_lex_state = 6},
  [246] = {.lex_state = 0, .external_lex_state = 6},
  [247] = {.lex_state = 0, .external_lex_state = 4},
  [248] = {.lex_state = 0, .external_lex_state = 7},
  [249] = {.lex_state = 0, .external_lex_state = 6},
  [250] = {.lex_state = 0, .external_lex_state = 5},
  [251] = {.lex_state = 0, .external_lex_state = 8},
  [252] = {.lex_state = 0, .external_lex_state = 4},
  [253] = {.lex_state = 0, .external_lex_state = 6},
  [254] = {.lex_state = 0, .external_lex_state = 9},
  [255] = {.lex_state = 0, .external_lex_state = 8},
  [256] = {.lex_state = 0, .external_lex_state = 5},
  [257] = {.lex_state = 0, .external_lex_state = 3},
  [258] = {.lex_state = 0, .external_lex_state = 9},
  [259] = {.lex_state = 0, .external_lex_state = 7},
  [260] = {.lex_state = 0, .external_lex_state = 8},
  [261] = {.lex_state = 0, .external_lex_state = 7},
  [262] = {.lex_state = 0, .external_lex_state = 7},
  [263] = {.lex_state = 0, .external_lex_state = 7},
  [264] = {.lex_state = 0, .external_lex_state = 8},
  [265] = {.lex_state = 0, .external_lex_state = 9},
  [266] = {.lex_state = 0, .external_lex_state = 7},
  [267] = {.lex_state = 0, .external_lex_state = 8},
  [268] = {.lex_state = 0, .external_lex_state = 9},
  [269] = {.lex_state = 0, .external_lex_state = 7},
  [270] = {.lex_state = 0, .external_lex_state = 8},
  [271] = {.lex_state = 0, .external_lex_state = 9},
  [272] = {.lex_state = 0, .external_lex_state = 7},
  [273] = {.lex_state = 0, .external_lex_state = 8},
  [274] = {.lex_state = 0, .external_lex_state = 9},
  [275] = {.lex_state = 0, .external_lex_state = 8},
  [276] = {.lex_state = 0, .external_lex_state = 9},
  [277] = {.lex_state = 0, .external_lex_state = 7},
  [278] = {.lex_state = 0, .external_lex_state = 8},
  [279] = {.lex_state = 0, .external_lex_state = 9},
  [280] = {.lex_state = 0, .external_lex_state = 7},
  [281] = {.lex_state = 0, .external_lex_state = 8},
  [282] = {.lex_state = 0, .external_lex_state = 9},
  [283] = {.lex_state = 0, .external_lex_state = 9},
  [284] = {.lex_state = 0, .external_lex_state = 6},
  [285] = {.lex_state = 0, .external_lex_state = 5},
  [286] = {.lex_state = 0, .external_lex_state = 3},
  [287] = {.lex_state = 0, .external_lex_state = 3},
  [288] = {.lex_state = 0, .external_lex_state = 3},
  [289] = {.lex_state = 0, .external_lex_state = 3},
  [290] = {.lex_state = 0, .external_lex_state = 3},
  [291] = {.lex_state = 0, .external_lex_state = 3},
  [292] = {.lex_state = 0, .external_lex_state = 3},
  [293] = {.lex_state = 0, .external_lex_state = 3},
  [294] = {.lex_state = 0, .external_lex_state = 9},
  [295] = {.lex_state = 0, .external_lex_state = 3},
  [296] = {.lex_state = 0, .external_lex_state = 3},
  [297] = {.lex_state = 0, .external_lex_state = 3},
  [298] = {.lex_state = 0, .external_lex_state = 8},
  [299] = {.lex_state = 0, .external_lex_state = 4},
  [300] = {.lex_state = 0, .external_lex_state = 4},
  [301] = {.lex_state = 0, .external_lex_state = 4},
  [302] = {.lex_state = 0, .external_lex_state = 4},
  [303] = {.lex_state = 0, .external_lex_state = 4},
  [304] = {.lex_state = 0, .external_lex_state = 4},
  [305] = {.lex_state = 0, .external_lex_state = 4},
  [306] = {.lex_state = 0, .external_lex_state = 4},
  [307] = {.lex_state = 0, .external_lex_state = 4},
  [308] = {.lex_state = 0, .external_lex_state = 4},
  [309] = {.lex_state = 0, .external_lex_state = 4},
  [310] = {.lex_state = 0, .external_lex_state = 7},
  [311] = {.lex_state = 0, .external_lex_state = 5},
  [312] = {.lex_state = 0, .external_lex_state = 5},
  [313] = {.lex_state = 0, .external_lex_state = 5},
  [314] = {.lex_state = 0, .external_lex_state = 5},
  [315] = {.lex_state = 0, .external_lex_state = 6},
  [316] = {.lex_state = 0, .external_lex_state = 6},
  [317] = {.lex_state = 0, .external_lex_state = 4},
  [318] = {.lex_state = 0, .external_lex_state = 6},
  [319] = {.lex_state = 0, .external_lex_state = 6},
  [320] = {.lex_state = 0, .external_lex_state = 6},
  [321] = {.lex_state = 0, .external_lex_state = 5},
  [322] = {.lex_state = 0, .external_lex_state = 5},
  [323] = {.lex_state = 0, .external_lex_state = 3},
  [324] = {.lex_state = 0, .external_lex_state = 6},
  [325] = {.lex_state = 0, .external_lex_state = 6},
  [326] = {.lex_state = 0, .external_lex_state = 6},
  [327] = {.lex_state = 0, .external_lex_state = 6},
  [328] = {.lex_state = 0, .external_lex_state = 6},
  [329] = {.lex_state = 0, .external_lex_state = 6},
  [330] = {.lex_state = 0, .external_lex_state = 5},
  [331] = {.lex_state = 0, .external_lex_state = 5},
  [332] = {.lex_state = 0, .external_lex_state = 5},
  [333] = {.lex_state = 0, .external_lex_state = 5},
  [334] = {.lex_state = 0, .external_lex_state = 5},
  [335] = {.lex_state = 0, .external_lex_state = 10},
  [336] = {.lex_state = 0, .external_lex_state = 4},
  [337] = {.lex_state = 0, .external_lex_state = 10},
  [338] = {.lex_state = 0, .external_lex_state = 10},
  [339] = {.lex_state = 0, .external_lex_state = 4},
  [340] = {.lex_state = 0, .external_lex_state = 3},
  [341] = {.lex_state = 0, .external_lex_state = 3},
  [342] = {.lex_state = 0, .external_lex_state = 4},
  [343] = {.lex_state = 0, .external_lex_state = 4},
  [344] = {.lex_state = 0, .external_lex_state = 4},
  [345] = {.lex_state = 0, .external_lex_state = 4},
  [346] = {.lex_state = 0, .external_lex_state = 4},
  [347] = {.lex_state = 0, .external_lex_state = 4},
  [348] = {.lex_state = 0, .external_lex_state = 3},
  [349] = {.lex_state = 0, .external_lex_state = 3},
  [350] = {.lex_state = 0, .external_lex_state = 3},
  [351] = {.lex_state = 0, .external_lex_state = 10},
  [352] = {.lex_state = 0, .external_lex_state = 10},
  [353] = {.lex_state = 0, .external_lex_state = 5},
  [354] = {.lex_state = 0, .external_lex_state = 3},
  [355] = {.lex_state = 0, .external_lex_state = 3},
  [356] = {.lex_state = 0, .external_lex_state = 3},
  [357] = {.lex_state = 0, .external_lex_state = 3},
  [358] = {.lex_state = 0, .external_lex_state = 3},
  [359] = {.lex_state = 0, .external_lex_state = 4},
  [360] = {.lex_state = 0, .external_lex_state = 4},
  [361] = {.lex_state = 0, .external_lex_state = 4},
  [362] = {.lex_state = 0, .external_lex_state = 4},
  [363] = {.lex_state = 0, .external_lex_state = 4},
  [364] = {.lex_state = 0, .external_lex_state = 4},
  [365] = {.lex_state = 0, .external_lex_state = 4},
  [366] = {.lex_state = 0, .external_lex_state = 3},
  [367] = {.lex_state = 0, .external_lex_state = 4},
  [368] = {.lex_state = 0, .external_lex_state = 4},
  [369] = {.lex_state = 0, .external_lex_state = 4},
  [370] = {.lex_state = 0, .external_lex_state = 3},
  [371] = {.lex_state = 0, .external_lex_state = 4},
  [372] = {.lex_state = 0, .external_lex_state = 3},
  [373] = {.lex_state = 0, .external_lex_state = 3},
  [374] = {.lex_state = 0, .external_lex_state = 3},
  [375] = {.lex_state = 0, .external_lex_state = 3},
  [376] = {.lex_state = 0, .external_lex_state = 3},
  [377] = {.lex_state = 0, .external_lex_state = 3},
  [378] = {.lex_state = 0, .external_lex_state = 10},
  [379] = {.lex_state = 0, .external_lex_state = 10},
  [380] = {.lex_state = 0, .external_lex_state = 10},
  [381] = {.lex_state = 0, .external_lex_state = 10},
  [382] = {.lex_state = 0, .external_lex_state = 10},
  [383] = {.lex_state = 0, .external_lex_state = 10},
  [384] = {.lex_state = 0, .external_lex_state = 10},
  [385] = {.lex_state = 0, .external_lex_state = 10},
  [386] = {.lex_state = 0, .external_lex_state = 10},
  [387] = {.lex_state = 0, .external_lex_state = 3},
  [388] = {.lex_state = 0, .external_lex_state = 4},
  [389] = {.lex_state = 0, .external_lex_state = 10},
  [390] = {.lex_state = 0, .external_lex_state = 3},
  [391] = {.lex_state = 0, .external_lex_state = 3},
  [392] = {.lex_state = 0, .external_lex_state = 3},
  [393] = {.lex_state = 0, .external_lex_state = 10},
  [394] = {.lex_state = 0, .external_lex_state = 3},
  [395] = {.lex_state = 0, .external_lex_state = 10},
  [396] = {.lex_state = 0, .external_lex_state = 10},
  [397] = {.lex_state = 0, .external_lex_state = 3},
  [398] = {.lex_state = 0, .external_lex_state = 10},
  [399] = {.lex_state = 0, .external_lex_state = 4},
  [400] = {.lex_state = 0, .external_lex_state = 4},
  [401] = {.lex_state = 0, .external_lex_state = 10},
  [402] = {.lex_state = 0, .external_lex_state = 4},
  [403] = {.lex_state = 0, .external_lex_state = 4},
  [404] = {.lex_state = 0, .external_lex_state = 6},
  [405] = {.lex_state = 0, .external_lex_state = 6},
  [406] = {.lex_state = 0, .external_lex_state = 6},
  [407] = {.lex_state = 0, .external_lex_state = 6},
  [408] = {.lex_state = 0, .external_lex_state = 5},
  [409] = {.lex_state = 0, .external_lex_state = 11},
  [410] = {.lex_state = 0, .external_lex_state = 6},
  [411] = {.lex_state = 0, .external_lex_state = 5},
  [412] = {.lex_state = 0, .external_lex_state = 5},
  [413] = {.lex_state = 0, .external_lex_state = 6},
  [414] = {.lex_state = 0, .external_lex_state = 5},
  [415] = {.lex_state = 0, .external_lex_state = 10},
  [416] = {.lex_state = 0, .external_lex_state = 6},
  [417] = {.lex_state = 0, .external_lex_state = 6},
  [418] = {.lex_state = 0, .external_lex_state = 5},
  [419] = {.lex_state = 0, .external_lex_state = 5},
  [420] = {.lex_state = 0, .external_lex_state = 6},
  [421] = {.lex_state = 0, .external_lex_state = 6},
  [422] = {.lex_state = 0, .external_lex_state = 6},
  [423] = {.lex_state = 0, .external_lex_state = 6},
  [424] = {.lex_state = 0, .external_lex_state = 5},
  [425] = {.lex_state = 0, .external_lex_state = 11},
  [426] = {.lex_state = 0, .external_lex_state = 5},
  [427] = {.lex_state = 0, .external_lex_state = 6},
  [428] = {.lex_state = 0, .external_lex_state = 5},
  [429] = {.lex_state = 0, .external_lex_state = 5},
  [430] = {.lex_state = 0, .external_lex_state = 6},
  [431] = {.lex_state = 0, .external_lex_state = 6},
  [432] = {.lex_state = 0, .external_lex_state = 6},
  [433] = {.lex_state = 0, .external_lex_state = 6},
  [434] = {.lex_state = 0, .external_lex_state = 6},
  [435] = {.lex_state = 0, .external_lex_state = 5},
  [436] = {.lex_state = 0, .external_lex_state = 5},
  [437] = {.lex_state = 0, .external_lex_state = 5},
  [438] = {.lex_state = 0, .external_lex_state = 6},
  [439] = {.lex_state = 0, .external_lex_state = 6},
  [440] = {.lex_state = 0, .external_lex_state = 5},
  [441] = {.lex_state = 0, .external_lex_state = 6},
  [442] = {.lex_state = 0, .external_lex_state = 5},
  [443] = {.lex_state = 0, .external_lex_state = 11},
  [444] = {.lex_state = 0, .external_lex_state = 5},
  [445] = {.lex_state = 0, .external_lex_state = 5},
  [446] = {.lex_state = 0, .external_lex_state = 5},
  [447] = {.lex_state = 0, .external_lex_state = 6},
  [448] = {.lex_state = 0, .external_lex_state = 6},
  [449] = {.lex_state = 0, .external_lex_state = 5},
  [450] = {.lex_state = 0, .external_lex_state = 6},
  [451] = {.lex_state = 0, .external_lex_state = 6},
  [452] = {.lex_state = 0, .external_lex_state = 5},
  [453] = {.lex_state = 0, .external_lex_state = 5},
  [454] = {.lex_state = 0, .external_lex_state = 5},
  [455] = {.lex_state = 0, .external_lex_state = 5},
  [456] = {.lex_state = 0, .external_lex_state = 5},
  [457] = {.lex_state = 0, .external_lex_state = 8},
  [458] = {.lex_state = 0, .external_lex_state = 7},
  [459] = {.lex_state = 0, .external_lex_state = 9},
  [460] = {.lex_state = 0, .external_lex_state = 12},
  [461] = {.lex_state = 0, .external_lex_state = 12},
  [462] = {.lex_state = 0, .external_lex_state = 12},
  [463] = {.lex_state = 0, .external_lex_state = 12},
  [464] = {.lex_state = 0, .external_lex_state = 12},
  [465] = {.lex_state = 0, .external_lex_state = 12},
  [466] = {.lex_state = 0, .external_lex_state = 12},
  [467] = {.lex_state = 0, .external_lex_state = 12},
  [468] = {.lex_state = 0, .external_lex_state = 12},
  [469] = {.lex_state = 0, .external_lex_state = 12},
  [470] = {.lex_state = 0, .external_lex_state = 12},
  [471] = {.lex_state = 0, .external_lex_state = 12},
  [472] = {.lex_state = 0, .external_lex_state = 12},
  [473] = {.lex_state = 0, .external_lex_state = 12},
  [474] = {.lex_state = 0, .external_lex_state = 12},
  [475] = {.lex_state = 0, .external_lex_state = 12},
  [476] = {.lex_state = 0, .external_lex_state = 12},
  [477] = {.lex_state = 0, .external_lex_state = 12},
  [478] = {.lex_state = 0, .external_lex_state = 12},
  [479] = {.lex_state = 0, .external_lex_state = 12},
  [480] = {.lex_state = 0, .external_lex_state = 12},
  [481] = {.lex_state = 0, .external_lex_state = 12},
  [482] = {.lex_state = 0, .external_lex_state = 12},
  [483] = {.lex_state = 0, .external_lex_state = 12},
  [484] = {.lex_state = 0, .external_lex_state = 12},
  [485] = {.lex_state = 0, .external_lex_state = 12},
  [486] = {.lex_state = 0, .external_lex_state = 12},
  [487] = {.lex_state = 0, .external_lex_state = 12},
  [488] = {.lex_state = 0, .external_lex_state = 12},
  [489] = {.lex_state = 0, .external_lex_state = 12},
  [490] = {.lex_state = 0, .external_lex_state = 12},
  [491] = {.lex_state = 0, .external_lex_state = 12},
  [492] = {.lex_state = 0, .external_lex_state = 12},
  [493] = {.lex_state = 0, .external_lex_state = 12},
  [494] = {.lex_state = 0, .external_lex_state = 12},
  [495] = {.lex_state = 0, .external_lex_state = 12},
  [496] = {.lex_state = 0, .external_lex_state = 12},
  [497] = {.lex_state = 0, .external_lex_state = 12},
  [498] = {.lex_state = 0, .external_lex_state = 12},
  [499] = {.lex_state = 0, .external_lex_state = 12},
  [500] = {.lex_state = 0, .external_lex_state = 12},
  [501] = {.lex_state = 0, .external_lex_state = 12},
  [502] = {.lex_state = 0, .external_lex_state = 12},
  [503] = {.lex_state = 0, .external_lex_state = 12},
  [504] = {.lex_state = 0, .external_lex_state = 12},
  [505] = {.lex_state = 0, .external_lex_state = 12},
  [506] = {.lex_state = 0, .external_lex_state = 12},
  [507] = {.lex_state = 0, .external_lex_state = 12},
  [508] = {.lex_state = 0, .external_lex_state = 12},
  [509] = {.lex_state = 0, .external_lex_state = 12},
  [510] = {.lex_state = 0, .external_lex_state = 12},
  [511] = {.lex_state = 0, .external_lex_state = 12},
  [512] = {.lex_state = 0, .external_lex_state = 12},
  [513] = {.lex_state = 0, .external_lex_state = 12},
  [514] = {.lex_state = 0, .external_lex_state = 12},
  [515] = {.lex_state = 0, .external_lex_state = 12},
  [516] = {.lex_state = 0, .external_lex_state = 12},
  [517] = {.lex_state = 0, .external_lex_state = 12},
  [518] = {.lex_state = 0, .external_lex_state = 12},
  [519] = {.lex_state = 0, .external_lex_state = 12},
  [520] = {.lex_state = 0, .external_lex_state = 12},
  [521] = {.lex_state = 0, .external_lex_state = 12},
  [522] = {.lex_state = 0, .external_lex_state = 12},
  [523] = {.lex_state = 0, .external_lex_state = 12},
  [524] = {.lex_state = 0, .external_lex_state = 12},
  [525] = {.lex_state = 0, .external_lex_state = 12},
  [526] = {.lex_state = 0, .external_lex_state = 12},
  [527] = {.lex_state = 0, .external_lex_state = 12},
  [528] = {.lex_state = 0, .external_lex_state = 12},
  [529] = {.lex_state = 0, .external_lex_state = 12},
  [530] = {.lex_state = 0, .external_lex_state = 12},
  [531] = {.lex_state = 0, .external_lex_state = 12},
  [532] = {.lex_state = 0, .external_lex_state = 12},
  [533] = {.lex_state = 0, .external_lex_state = 12},
  [534] = {.lex_state = 0, .external_lex_state = 12},
  [535] = {.lex_state = 0, .external_lex_state = 12},
  [536] = {.lex_state = 0, .external_lex_state = 12},
  [537] = {.lex_state = 0, .external_lex_state = 12},
  [538] = {.lex_state = 0, .external_lex_state = 12},
  [539] = {.lex_state = 0, .external_lex_state = 12},
  [540] = {.lex_state = 0, .external_lex_state = 12},
  [541] = {.lex_state = 0, .external_lex_state = 12},
  [542] = {.lex_state = 0, .external_lex_state = 12},
  [543] = {.lex_state = 0, .external_lex_state = 12},
  [544] = {.lex_state = 0, .external_lex_state = 12},
  [545] = {.lex_state = 0, .external_lex_state = 12},
  [546] = {.lex_state = 0, .external_lex_state = 12},
  [547] = {.lex_state = 0, .external_lex_state = 12},
  [548] = {.lex_state = 0, .external_lex_state = 12},
  [549] = {.lex_state = 0, .external_lex_state = 12},
  [550] = {.lex_state = 0, .external_lex_state = 12},
  [551] = {.lex_state = 0, .external_lex_state = 12},
  [552] = {.lex_state = 0, .external_lex_state = 12},
  [553] = {.lex_state = 0, .external_lex_state = 12},
  [554] = {.lex_state = 0, .external_lex_state = 12},
  [555] = {.lex_state = 0, .external_lex_state = 12},
  [556] = {.lex_state = 0, .external_lex_state = 12},
  [557] = {.lex_state = 0, .external_lex_state = 12},
  [558] = {.lex_state = 0, .external_lex_state = 12},
  [559] = {.lex_state = 0, .external_lex_state = 12},
  [560] = {.lex_state = 0, .external_lex_state = 12},
  [561] = {.lex_state = 0, .external_lex_state = 12},
  [562] = {.lex_state = 0, .external_lex_state = 12},
  [563] = {.lex_state = 0, .external_lex_state = 12},
  [564] = {.lex_state = 0, .external_lex_state = 12},
  [565] = {.lex_state = 0, .external_lex_state = 12},
  [566] = {.lex_state = 0, .external_lex_state = 12},
  [567] = {.lex_state = 0, .external_lex_state = 12},
  [568] = {.lex_state = 0, .external_lex_state = 12},
  [569] = {.lex_state = 0, .external_lex_state = 12},
  [570] = {.lex_state = 0, .external_lex_state = 12},
  [571] = {.lex_state = 0, .external_lex_state = 12},
  [572] = {.lex_state = 0, .external_lex_state = 12},
  [573] = {.lex_state = 0, .external_lex_state = 12},
  [574] = {.lex_state = 0, .external_lex_state = 12},
  [575] = {.lex_state = 0, .external_lex_state = 12},
  [576] = {.lex_state = 0, .external_lex_state = 12},
  [577] = {.lex_state = 0, .external_lex_state = 12},
  [578] = {.lex_state = 0, .external_lex_state = 12},
  [579] = {.lex_state = 0, .external_lex_state = 12},
  [580] = {.lex_state = 0, .external_lex_state = 12},
  [581] = {.lex_state = 0, .external_lex_state = 12},
  [582] = {.lex_state = 0, .external_lex_state = 12},
  [583] = {.lex_state = 0, .external_lex_state = 12},
  [584] = {.lex_state = 0, .external_lex_state = 12},
  [585] = {.lex_state = 0, .external_lex_state = 12},
  [586] = {.lex_state = 0, .external_lex_state = 12},
  [587] = {.lex_state = 0, .external_lex_state = 12},
  [588] = {.lex_state = 0, .external_lex_state = 12},
  [589] = {.lex_state = 0, .external_lex_state = 12},
  [590] = {.lex_state = 0, .external_lex_state = 12},
  [591] = {.lex_state = 0, .external_lex_state = 12},
  [592] = {.lex_state = 0, .external_lex_state = 12},
  [593] = {.lex_state = 0, .external_lex_state = 12},
  [594] = {.lex_state = 0, .external_lex_state = 12},
  [595] = {.lex_state = 0, .external_lex_state = 12},
  [596] = {.lex_state = 0, .external_lex_state = 12},
  [597] = {.lex_state = 0, .external_lex_state = 12},
  [598] = {.lex_state = 0, .external_lex_state = 12},
  [599] = {.lex_state = 0, .external_lex_state = 12},
  [600] = {.lex_state = 0, .external_lex_state = 12},
  [601] = {.lex_state = 0, .external_lex_state = 12},
  [602] = {.lex_state = 0, .external_lex_state = 12},
  [603] = {.lex_state = 0, .external_lex_state = 12},
  [604] = {.lex_state = 0, .external_lex_state = 12},
  [605] = {.lex_state = 0, .external_lex_state = 12},
  [606] = {.lex_state = 0, .external_lex_state = 12},
  [607] = {.lex_state = 0, .external_lex_state = 12},
  [608] = {.lex_state = 0, .external_lex_state = 12},
  [609] = {.lex_state = 0, .external_lex_state = 12},
  [610] = {.lex_state = 0, .external_lex_state = 12},
  [611] = {.lex_state = 0, .external_lex_state = 12},
  [612] = {.lex_state = 0, .external_lex_state = 12},
  [613] = {.lex_state = 0, .external_lex_state = 12},
  [614] = {.lex_state = 0, .external_lex_state = 12},
  [615] = {.lex_state = 0, .external_lex_state = 12},
  [616] = {.lex_state = 0, .external_lex_state = 12},
  [617] = {.lex_state = 0, .external_lex_state = 12},
  [618] = {.lex_state = 0, .external_lex_state = 12},
  [619] = {.lex_state = 0, .external_lex_state = 12},
  [620] = {.lex_state = 0, .external_lex_state = 12},
  [621] = {.lex_state = 0, .external_lex_state = 12},
  [622] = {.lex_state = 0, .external_lex_state = 12},
  [623] = {.lex_state = 0, .external_lex_state = 12},
  [624] = {.lex_state = 0, .external_lex_state = 12},
  [625] = {.lex_state = 0, .external_lex_state = 12},
  [626] = {.lex_state = 0, .external_lex_state = 12},
  [627] = {.lex_state = 0, .external_lex_state = 12},
  [628] = {.lex_state = 0, .external_lex_state = 12},
  [629] = {.lex_state = 0, .external_lex_state = 12},
  [630] = {.lex_state = 0, .external_lex_state = 12},
  [631] = {.lex_state = 0, .external_lex_state = 12},
  [632] = {.lex_state = 0, .external_lex_state = 12},
  [633] = {.lex_state = 0, .external_lex_state = 12},
  [634] = {.lex_state = 0, .external_lex_state = 12},
  [635] = {.lex_state = 0, .external_lex_state = 12},
  [636] = {.lex_state = 0, .external_lex_state = 12},
  [637] = {.lex_state = 0, .external_lex_state = 12},
  [638] = {.lex_state = 0, .external_lex_state = 12},
  [639] = {.lex_state = 0, .external_lex_state = 12},
  [640] = {.lex_state = 0, .external_lex_state = 12},
  [641] = {.lex_state = 0, .external_lex_state = 12},
  [642] = {.lex_state = 0, .external_lex_state = 12},
  [643] = {.lex_state = 0, .external_lex_state = 12},
  [644] = {.lex_state = 0, .external_lex_state = 12},
  [645] = {.lex_state = 0, .external_lex_state = 12},
  [646] = {.lex_state = 0, .external_lex_state = 12},
  [647] = {.lex_state = 0, .external_lex_state = 12},
  [648] = {.lex_state = 0, .external_lex_state = 12},
  [649] = {.lex_state = 0, .external_lex_state = 12},
  [650] = {.lex_state = 0, .external_lex_state = 12},
  [651] = {.lex_state = 0, .external_lex_state = 12},
  [652] = {.lex_state = 0, .external_lex_state = 12},
  [653] = {.lex_state = 0, .external_lex_state = 12},
  [654] = {.lex_state = 0, .external_lex_state = 12},
  [655] = {.lex_state = 0, .external_lex_state = 12},
  [656] = {.lex_state = 0, .external_lex_state = 12},
  [657] = {.lex_state = 0, .external_lex_state = 12},
  [658] = {.lex_state = 0, .external_lex_state = 12},
  [659] = {.lex_state = 0, .external_lex_state = 12},
  [660] = {.lex_state = 0, .external_lex_state = 12},
  [661] = {.lex_state = 0, .external_lex_state = 12},
  [662] = {.lex_state = 0, .external_lex_state = 12},
  [663] = {.lex_state = 0, .external_lex_state = 12},
  [664] = {.lex_state = 0, .external_lex_state = 12},
  [665] = {.lex_state = 0, .external_lex_state = 12},
  [666] = {.lex_state = 0, .external_lex_state = 12},
  [667] = {.lex_state = 0, .external_lex_state = 12},
  [668] = {.lex_state = 0, .external_lex_state = 12},
  [669] = {.lex_state = 0, .external_lex_state = 12},
  [670] = {.lex_state = 0, .external_lex_state = 12},
  [671] = {.lex_state = 0, .external_lex_state = 12},
  [672] = {.lex_state = 0, .external_lex_state = 12},
  [673] = {.lex_state = 0, .external_lex_state = 12},
  [674] = {.lex_state = 0, .external_lex_state = 12},
  [675] = {.lex_state = 0, .external_lex_state = 12},
  [676] = {.lex_state = 0, .external_lex_state = 12},
  [677] = {.lex_state = 0, .external_lex_state = 12},
  [678] = {.lex_state = 0, .external_lex_state = 12},
  [679] = {.lex_state = 0, .external_lex_state = 12},
  [680] = {.lex_state = 0, .external_lex_state = 12},
  [681] = {.lex_state = 0, .external_lex_state = 12},
  [682] = {.lex_state = 0, .external_lex_state = 12},
  [683] = {.lex_state = 0, .external_lex_state = 12},
  [684] = {.lex_state = 0, .external_lex_state = 12},
  [685] = {.lex_state = 0, .external_lex_state = 12},
  [686] = {.lex_state = 0, .external_lex_state = 12},
  [687] = {.lex_state = 0, .external_lex_state = 12},
  [688] = {.lex_state = 0, .external_lex_state = 12},
  [689] = {.lex_state = 0, .external_lex_state = 12},
  [690] = {.lex_state = 0, .external_lex_state = 12},
  [691] = {.lex_state = 0, .external_lex_state = 12},
  [692] = {.lex_state = 0, .external_lex_state = 12},
  [693] = {.lex_state = 0, .external_lex_state = 12},
  [694] = {.lex_state = 0, .external_lex_state = 12},
  [695] = {.lex_state = 0, .external_lex_state = 12},
  [696] = {.lex_state = 0, .external_lex_state = 12},
  [697] = {.lex_state = 0, .external_lex_state = 12},
  [698] = {.lex_state = 0, .external_lex_state = 12},
  [699] = {.lex_state = 0, .external_lex_state = 12},
  [700] = {.lex_state = 0, .external_lex_state = 12},
  [701] = {.lex_state = 0, .external_lex_state = 12},
  [702] = {.lex_state = 0, .external_lex_state = 12},
  [703] = {.lex_state = 0, .external_lex_state = 12},
  [704] = {.lex_state = 0, .external_lex_state = 12},
  [705] = {.lex_state = 0, .external_lex_state = 12},
  [706] = {.lex_state = 0, .external_lex_state = 12},
  [707] = {.lex_state = 0, .external_lex_state = 12},
  [708] = {.lex_state = 0, .external_lex_state = 12},
  [709] = {.lex_state = 0, .external_lex_state = 12},
  [710] = {.lex_state = 0, .external_lex_state = 12},
  [711] = {.lex_state = 0, .external_lex_state = 12},
  [712] = {.lex_state = 0, .external_lex_state = 12},
  [713] = {.lex_state = 0, .external_lex_state = 12},
  [714] = {.lex_state = 0, .external_lex_state = 12},
  [715] = {.lex_state = 0, .external_lex_state = 12},
  [716] = {.lex_state = 0, .external_lex_state = 12},
  [717] = {.lex_state = 0, .external_lex_state = 12},
  [718] = {.lex_state = 0, .external_lex_state = 12},
  [719] = {.lex_state = 0, .external_lex_state = 12},
  [720] = {.lex_state = 0, .external_lex_state = 12},
  [721] = {.lex_state = 0, .external_lex_state = 12},
  [722] = {.lex_state = 0, .external_lex_state = 12},
  [723] = {.lex_state = 0, .external_lex_state = 12},
  [724] = {.lex_state = 0, .external_lex_state = 12},
  [725] = {.lex_state = 0, .external_lex_state = 12},
  [726] = {.lex_state = 0, .external_lex_state = 12},
  [727] = {.lex_state = 0, .external_lex_state = 12},
  [728] = {.lex_state = 0, .external_lex_state = 12},
  [729] = {.lex_state = 0, .external_lex_state = 12},
  [730] = {.lex_state = 0, .external_lex_state = 12},
  [731] = {.lex_state = 0, .external_lex_state = 12},
  [732] = {.lex_state = 0, .external_lex_state = 12},
  [733] = {.lex_state = 0, .external_lex_state = 12},
  [734] = {.lex_state = 0, .external_lex_state = 12},
  [735] = {.lex_state = 0, .external_lex_state = 12},
  [736] = {.lex_state = 0, .external_lex_state = 12},
  [737] = {.lex_state = 0, .external_lex_state = 12},
  [738] = {.lex_state = 0, .external_lex_state = 12},
  [739] = {.lex_state = 0, .external_lex_state = 12},
  [740] = {.lex_state = 0, .external_lex_state = 12},
  [741] = {.lex_state = 0, .external_lex_state = 12},
  [742] = {.lex_state = 0, .external_lex_state = 12},
  [743] = {.lex_state = 0, .external_lex_state = 12},
  [744] = {.lex_state = 0, .external_lex_state = 12},
  [745] = {.lex_state = 0, .external_lex_state = 12},
  [746] = {.lex_state = 0, .external_lex_state = 12},
  [747] = {.lex_state = 0, .external_lex_state = 12},
  [748] = {.lex_state = 0, .external_lex_state = 12},
  [749] = {.lex_state = 0, .external_lex_state = 12},
  [750] = {.lex_state = 0, .external_lex_state = 12},
  [751] = {.lex_state = 0, .external_lex_state = 12},
  [752] = {.lex_state = 0, .external_lex_state = 12},
  [753] = {.lex_state = 0, .external_lex_state = 12},
  [754] = {.lex_state = 0, .external_lex_state = 12},
  [755] = {.lex_state = 0, .external_lex_state = 12},
  [756] = {.lex_state = 0, .external_lex_state = 12},
  [757] = {.lex_state = 0, .external_lex_state = 12},
  [758] = {.lex_state = 0, .external_lex_state = 12},
  [759] = {.lex_state = 0, .external_lex_state = 12},
  [760] = {.lex_state = 0, .external_lex_state = 12},
  [761] = {.lex_state = 0, .external_lex_state = 12},
  [762] = {.lex_state = 0, .external_lex_state = 12},
  [763] = {.lex_state = 0, .external_lex_state = 12},
  [764] = {.lex_state = 0, .external_lex_state = 12},
  [765] = {.lex_state = 0, .external_lex_state = 12},
  [766] = {.lex_state = 0, .external_lex_state = 12},
  [767] = {.lex_state = 0, .external_lex_state = 12},
  [768] = {.lex_state = 0, .external_lex_state = 12},
  [769] = {.lex_state = 0, .external_lex_state = 12},
  [770] = {.lex_state = 0, .external_lex_state = 12},
  [771] = {.lex_state = 0, .external_lex_state = 12},
  [772] = {.lex_state = 0, .external_lex_state = 12},
  [773] = {.lex_state = 0, .external_lex_state = 12},
  [774] = {.lex_state = 0, .external_lex_state = 12},
  [775] = {.lex_state = 0, .external_lex_state = 12},
  [776] = {.lex_state = 0, .external_lex_state = 12},
  [777] = {.lex_state = 0, .external_lex_state = 12},
  [778] = {.lex_state = 0, .external_lex_state = 12},
  [779] = {.lex_state = 0, .external_lex_state = 12},
  [780] = {.lex_state = 0, .external_lex_state = 12},
  [781] = {.lex_state = 0, .external_lex_state = 12},
  [782] = {.lex_state = 0, .external_lex_state = 12},
  [783] = {.lex_state = 0, .external_lex_state = 12},
  [784] = {.lex_state = 0, .external_lex_state = 12},
  [785] = {.lex_state = 0, .external_lex_state = 12},
  [786] = {.lex_state = 0, .external_lex_state = 12},
  [787] = {.lex_state = 0, .external_lex_state = 12},
  [788] = {.lex_state = 0, .external_lex_state = 12},
  [789] = {.lex_state = 0, .external_lex_state = 12},
  [790] = {.lex_state = 0, .external_lex_state = 12},
  [791] = {.lex_state = 0, .external_lex_state = 12},
  [792] = {.lex_state = 0, .external_lex_state = 12},
  [793] = {.lex_state = 0, .external_lex_state = 12},
  [794] = {.lex_state = 0, .external_lex_state = 12},
  [795] = {.lex_state = 0, .external_lex_state = 12},
  [796] = {.lex_state = 0, .external_lex_state = 12},
  [797] = {.lex_state = 0, .external_lex_state = 12},
  [798] = {.lex_state = 0, .external_lex_state = 12},
  [799] = {.lex_state = 0, .external_lex_state = 12},
  [800] = {.lex_state = 0, .external_lex_state = 12},
  [801] = {.lex_state = 0, .external_lex_state = 12},
  [802] = {.lex_state = 0, .external_lex_state = 12},
  [803] = {.lex_state = 0, .external_lex_state = 12},
  [804] = {.lex_state = 0, .external_lex_state = 12},
  [805] = {.lex_state = 0, .external_lex_state = 12},
  [806] = {.lex_state = 0, .external_lex_state = 12},
  [807] = {.lex_state = 0, .external_lex_state = 12},
  [808] = {.lex_state = 0, .external_lex_state = 12},
  [809] = {.lex_state = 0, .external_lex_state = 12},
  [810] = {.lex_state = 0, .external_lex_state = 12},
  [811] = {.lex_state = 0, .external_lex_state = 12},
  [812] = {.lex_state = 0, .external_lex_state = 12},
  [813] = {.lex_state = 0, .external_lex_state = 12},
  [814] = {.lex_state = 0, .external_lex_state = 12},
  [815] = {.lex_state = 0, .external_lex_state = 12},
  [816] = {.lex_state = 0, .external_lex_state = 12},
  [817] = {.lex_state = 0, .external_lex_state = 12},
  [818] = {.lex_state = 0, .external_lex_state = 12},
  [819] = {.lex_state = 0, .external_lex_state = 12},
  [820] = {.lex_state = 0, .external_lex_state = 12},
  [821] = {.lex_state = 0, .external_lex_state = 12},
  [822] = {.lex_state = 0, .external_lex_state = 12},
  [823] = {.lex_state = 0, .external_lex_state = 12},
  [824] = {.lex_state = 0, .external_lex_state = 12},
  [825] = {.lex_state = 0, .external_lex_state = 12},
  [826] = {.lex_state = 0, .external_lex_state = 12},
  [827] = {.lex_state = 0, .external_lex_state = 12},
  [828] = {.lex_state = 0, .external_lex_state = 12},
  [829] = {.lex_state = 0, .external_lex_state = 12},
  [830] = {.lex_state = 0, .external_lex_state = 12},
  [831] = {.lex_state = 0, .external_lex_state = 12},
  [832] = {.lex_state = 0, .external_lex_state = 12},
  [833] = {.lex_state = 0, .external_lex_state = 12},
  [834] = {.lex_state = 0, .external_lex_state = 12},
  [835] = {.lex_state = 0, .external_lex_state = 12},
  [836] = {.lex_state = 0, .external_lex_state = 12},
  [837] = {.lex_state = 0, .external_lex_state = 12},
  [838] = {.lex_state = 0, .external_lex_state = 12},
  [839] = {.lex_state = 0, .external_lex_state = 12},
  [840] = {.lex_state = 0, .external_lex_state = 12},
  [841] = {.lex_state = 0, .external_lex_state = 12},
  [842] = {.lex_state = 0, .external_lex_state = 12},
  [843] = {.lex_state = 0, .external_lex_state = 12},
  [844] = {.lex_state = 0, .external_lex_state = 12},
  [845] = {.lex_state = 0, .external_lex_state = 12},
  [846] = {.lex_state = 0, .external_lex_state = 12},
  [847] = {.lex_state = 0, .external_lex_state = 12},
  [848] = {.lex_state = 0, .external_lex_state = 12},
  [849] = {.lex_state = 0, .external_lex_state = 12},
  [850] = {.lex_state = 0, .external_lex_state = 12},
  [851] = {.lex_state = 0, .external_lex_state = 12},
  [852] = {.lex_state = 0, .external_lex_state = 12},
  [853] = {.lex_state = 0, .external_lex_state = 12},
  [854] = {.lex_state = 0, .external_lex_state = 12},
  [855] = {.lex_state = 0, .external_lex_state = 12},
  [856] = {.lex_state = 0, .external_lex_state = 12},
  [857] = {.lex_state = 0, .external_lex_state = 12},
  [858] = {.lex_state = 0, .external_lex_state = 12},
  [859] = {.lex_state = 0, .external_lex_state = 12},
  [860] = {.lex_state = 0, .external_lex_state = 12},
  [861] = {.lex_state = 0, .external_lex_state = 12},
  [862] = {.lex_state = 0, .external_lex_state = 12},
  [863] = {.lex_state = 0, .external_lex_state = 12},
  [864] = {.lex_state = 0, .external_lex_state = 12},
  [865] = {.lex_state = 0, .external_lex_state = 12},
  [866] = {.lex_state = 0, .external_lex_state = 12},
  [867] = {.lex_state = 0, .external_lex_state = 12},
  [868] = {.lex_state = 0, .external_lex_state = 12},
  [869] = {.lex_state = 0, .external_lex_state = 12},
  [870] = {.lex_state = 0, .external_lex_state = 12},
  [871] = {.lex_state = 0, .external_lex_state = 12},
  [872] = {.lex_state = 0, .external_lex_state = 12},
  [873] = {.lex_state = 0, .external_lex_state = 12},
  [874] = {.lex_state = 0, .external_lex_state = 12},
  [875] = {.lex_state = 0, .external_lex_state = 12},
  [876] = {.lex_state = 0, .external_lex_state = 12},
  [877] = {.lex_state = 0, .external_lex_state = 12},
  [878] = {.lex_state = 0, .external_lex_state = 12},
  [879] = {.lex_state = 0, .external_lex_state = 12},
  [880] = {.lex_state = 0, .external_lex_state = 12},
  [881] = {.lex_state = 0, .external_lex_state = 12},
  [882] = {.lex_state = 0, .external_lex_state = 12},
  [883] = {.lex_state = 0, .external_lex_state = 12},
  [884] = {.lex_state = 0, .external_lex_state = 12},
  [885] = {.lex_state = 0, .external_lex_state = 12},
  [886] = {.lex_state = 0, .external_lex_state = 12},
  [887] = {.lex_state = 0, .external_lex_state = 12},
  [888] = {.lex_state = 0, .external_lex_state = 12},
  [889] = {.lex_state = 0, .external_lex_state = 12},
  [890] = {.lex_state = 0, .external_lex_state = 12},
  [891] = {.lex_state = 0, .external_lex_state = 12},
  [892] = {.lex_state = 0, .external_lex_state = 12},
  [893] = {.lex_state = 0, .external_lex_state = 12},
  [894] = {.lex_state = 0, .external_lex_state = 12},
  [895] = {.lex_state = 0, .external_lex_state = 12},
  [896] = {.lex_state = 0, .external_lex_state = 12},
  [897] = {.lex_state = 0, .external_lex_state = 12},
  [898] = {.lex_state = 0, .external_lex_state = 12},
  [899] = {.lex_state = 0, .external_lex_state = 12},
  [900] = {.lex_state = 0, .external_lex_state = 12},
  [901] = {.lex_state = 0, .external_lex_state = 12},
  [902] = {.lex_state = 0, .external_lex_state = 12},
  [903] = {.lex_state = 0, .external_lex_state = 12},
  [904] = {.lex_state = 0, .external_lex_state = 12},
  [905] = {.lex_state = 0, .external_lex_state = 12},
  [906] = {.lex_state = 0, .external_lex_state = 12},
  [907] = {.lex_state = 0, .external_lex_state = 12},
  [908] = {.lex_state = 0, .external_lex_state = 12},
  [909] = {.lex_state = 0, .external_lex_state = 12},
  [910] = {.lex_state = 0, .external_lex_state = 12},
  [911] = {.lex_state = 0, .external_lex_state = 12},
  [912] = {.lex_state = 0, .external_lex_state = 12},
  [913] = {.lex_state = 0, .external_lex_state = 12},
  [914] = {.lex_state = 0, .external_lex_state = 12},
  [915] = {.lex_state = 0, .external_lex_state = 12},
  [916] = {.lex_state = 0, .external_lex_state = 12},
  [917] = {.lex_state = 0, .external_lex_state = 12},
  [918] = {.lex_state = 0, .external_lex_state = 12},
  [919] = {.lex_state = 0, .external_lex_state = 12},
  [920] = {.lex_state = 0, .external_lex_state = 12},
  [921] = {.lex_state = 0, .external_lex_state = 12},
  [922] = {.lex_state = 0, .external_lex_state = 12},
  [923] = {.lex_state = 0, .external_lex_state = 12},
  [924] = {.lex_state = 0, .external_lex_state = 12},
  [925] = {.lex_state = 0, .external_lex_state = 12},
  [926] = {.lex_state = 0, .external_lex_state = 12},
  [927] = {.lex_state = 0, .external_lex_state = 12},
  [928] = {.lex_state = 0, .external_lex_state = 12},
  [929] = {.lex_state = 0, .external_lex_state = 12},
  [930] = {.lex_state = 0, .external_lex_state = 12},
  [931] = {.lex_state = 0, .external_lex_state = 12},
  [932] = {.lex_state = 0, .external_lex_state = 12},
  [933] = {.lex_state = 0, .external_lex_state = 12},
  [934] = {.lex_state = 0, .external_lex_state = 12},
  [935] = {.lex_state = 0, .external_lex_state = 12},
  [936] = {.lex_state = 0, .external_lex_state = 12},
  [937] = {.lex_state = 0, .external_lex_state = 12},
  [938] = {.lex_state = 0, .external_lex_state = 12},
  [939] = {.lex_state = 0, .external_lex_state = 12},
  [940] = {.lex_state = 0, .external_lex_state = 12},
  [941] = {.lex_state = 0, .external_lex_state = 12},
  [942] = {.lex_state = 0, .external_lex_state = 12},
  [943] = {.lex_state = 0, .external_lex_state = 12},
  [944] = {.lex_state = 0, .external_lex_state = 12},
  [945] = {.lex_state = 0, .external_lex_state = 12},
  [946] = {.lex_state = 0, .external_lex_state = 12},
  [947] = {.lex_state = 0, .external_lex_state = 12},
  [948] = {.lex_state = 0, .external_lex_state = 12},
  [949] = {.lex_state = 0, .external_lex_state = 12},
  [950] = {.lex_state = 0, .external_lex_state = 12},
  [951] = {.lex_state = 0, .external_lex_state = 12},
  [952] = {.lex_state = 0, .external_lex_state = 12},
  [953] = {.lex_state = 0, .external_lex_state = 12},
  [954] = {.lex_state = 0, .external_lex_state = 12},
  [955] = {.lex_state = 0, .external_lex_state = 12},
  [956] = {.lex_state = 0, .external_lex_state = 12},
  [957] = {.lex_state = 0, .external_lex_state = 12},
  [958] = {.lex_state = 0, .external_lex_state = 12},
  [959] = {.lex_state = 0, .external_lex_state = 12},
  [960] = {.lex_state = 0, .external_lex_state = 12},
  [961] = {.lex_state = 0, .external_lex_state = 12},
  [962] = {.lex_state = 0, .external_lex_state = 12},
  [963] = {.lex_state = 0, .external_lex_state = 12},
  [964] = {.lex_state = 0, .external_lex_state = 12},
  [965] = {.lex_state = 0, .external_lex_state = 12},
  [966] = {.lex_state = 0, .external_lex_state = 12},
  [967] = {.lex_state = 0, .external_lex_state = 12},
  [968] = {.lex_state = 0, .external_lex_state = 12},
  [969] = {.lex_state = 0, .external_lex_state = 12},
  [970] = {.lex_state = 0, .external_lex_state = 12},
  [971] = {.lex_state = 0, .external_lex_state = 12},
  [972] = {.lex_state = 0, .external_lex_state = 12},
  [973] = {.lex_state = 0, .external_lex_state = 12},
  [974] = {.lex_state = 0, .external_lex_state = 12},
  [975] = {.lex_state = 0, .external_lex_state = 12},
  [976] = {.lex_state = 0, .external_lex_state = 12},
  [977] = {.lex_state = 0, .external_lex_state = 12},
  [978] = {.lex_state = 0, .external_lex_state = 12},
  [979] = {.lex_state = 0, .external_lex_state = 12},
  [980] = {.lex_state = 0, .external_lex_state = 12},
  [981] = {.lex_state = 0, .external_lex_state = 12},
  [982] = {.lex_state = 0, .external_lex_state = 12},
  [983] = {.lex_state = 0, .external_lex_state = 12},
  [984] = {.lex_state = 0, .external_lex_state = 12},
  [985] = {.lex_state = 0, .external_lex_state = 12},
  [986] = {.lex_state = 0, .external_lex_state = 12},
  [987] = {.lex_state = 0, .external_lex_state = 12},
  [988] = {.lex_state = 0, .external_lex_state = 12},
  [989] = {.lex_state = 0, .external_lex_state = 12},
  [990] = {.lex_state = 0, .external_lex_state = 12},
  [991] = {.lex_state = 0, .external_lex_state = 12},
  [992] = {.lex_state = 0, .external_lex_state = 12},
  [993] = {.lex_state = 0, .external_lex_state = 12},
  [994] = {.lex_state = 0, .external_lex_state = 12},
  [995] = {.lex_state = 0, .external_lex_state = 12},
  [996] = {.lex_state = 0, .external_lex_state = 12},
  [997] = {.lex_state = 0, .external_lex_state = 12},
  [998] = {.lex_state = 0, .external_lex_state = 12},
  [999] = {.lex_state = 0, .external_lex_state = 12},
  [1000] = {.lex_state = 0, .external_lex_state = 12},
  [1001] = {.lex_state = 0, .external_lex_state = 12},
  [1002] = {.lex_state = 0, .external_lex_state = 12},
  [1003] = {.lex_state = 0, .external_lex_state = 12},
  [1004] = {.lex_state = 0, .external_lex_state = 12},
  [1005] = {.lex_state = 0, .external_lex_state = 12},
  [1006] = {.lex_state = 0, .external_lex_state = 12},
  [1007] = {.lex_state = 0, .external_lex_state = 12},
  [1008] = {.lex_state = 0, .external_lex_state = 12},
  [1009] = {.lex_state = 0, .external_lex_state = 12},
  [1010] = {.lex_state = 0, .external_lex_state = 12},
  [1011] = {.lex_state = 0, .external_lex_state = 12},
  [1012] = {.lex_state = 0, .external_lex_state = 12},
  [1013] = {.lex_state = 0, .external_lex_state = 12},
  [1014] = {.lex_state = 0, .external_lex_state = 12},
  [1015] = {.lex_state = 0, .external_lex_state = 12},
  [1016] = {.lex_state = 0, .external_lex_state = 12},
  [1017] = {.lex_state = 0, .external_lex_state = 12},
  [1018] = {.lex_state = 0, .external_lex_state = 12},
  [1019] = {.lex_state = 0, .external_lex_state = 12},
  [1020] = {.lex_state = 0, .external_lex_state = 12},
  [1021] = {.lex_state = 0, .external_lex_state = 12},
  [1022] = {.lex_state = 0, .external_lex_state = 12},
  [1023] = {.lex_state = 0, .external_lex_state = 12},
  [1024] = {.lex_state = 0, .external_lex_state = 12},
  [1025] = {.lex_state = 0, .external_lex_state = 12},
  [1026] = {.lex_state = 0, .external_lex_state = 12},
  [1027] = {.lex_state = 0, .external_lex_state = 12},
  [1028] = {.lex_state = 0, .external_lex_state = 12},
  [1029] = {.lex_state = 0, .external_lex_state = 12},
  [1030] = {.lex_state = 0, .external_lex_state = 12},
  [1031] = {.lex_state = 0, .external_lex_state = 12},
  [1032] = {.lex_state = 0, .external_lex_state = 12},
  [1033] = {.lex_state = 0, .external_lex_state = 12},
  [1034] = {.lex_state = 0, .external_lex_state = 12},
  [1035] = {.lex_state = 0, .external_lex_state = 12},
  [1036] = {.lex_state = 0, .external_lex_state = 12},
  [1037] = {.lex_state = 0, .external_lex_state = 12},
  [1038] = {.lex_state = 0, .external_lex_state = 12},
  [1039] = {.lex_state = 0, .external_lex_state = 12},
  [1040] = {.lex_state = 0, .external_lex_state = 12},
  [1041] = {.lex_state = 0, .external_lex_state = 12},
  [1042] = {.lex_state = 0, .external_lex_state = 12},
  [1043] = {.lex_state = 0, .external_lex_state = 12},
  [1044] = {.lex_state = 0, .external_lex_state = 12},
  [1045] = {.lex_state = 0, .external_lex_state = 12},
  [1046] = {.lex_state = 0, .external_lex_state = 12},
  [1047] = {.lex_state = 0, .external_lex_state = 12},
  [1048] = {.lex_state = 0, .external_lex_state = 12},
  [1049] = {.lex_state = 0, .external_lex_state = 12},
  [1050] = {.lex_state = 0, .external_lex_state = 12},
  [1051] = {.lex_state = 0, .external_lex_state = 12},
  [1052] = {.lex_state = 0, .external_lex_state = 12},
  [1053] = {.lex_state = 0, .external_lex_state = 12},
  [1054] = {.lex_state = 0, .external_lex_state = 12},
  [1055] = {.lex_state = 0, .external_lex_state = 13},
  [1056] = {.lex_state = 0, .external_lex_state = 13},
  [1057] = {.lex_state = 0, .external_lex_state = 13},
  [1058] = {.lex_state = 0, .external_lex_state = 13},
  [1059] = {.lex_state = 0, .external_lex_state = 13},
  [1060] = {.lex_state = 0, .external_lex_state = 13},
  [1061] = {.lex_state = 0, .external_lex_state = 13},
  [1062] = {.lex_state = 0, .external_lex_state = 13},
  [1063] = {.lex_state = 0, .external_lex_state = 13},
  [1064] = {.lex_state = 0, .external_lex_state = 13},
  [1065] = {.lex_state = 0, .external_lex_state = 13},
  [1066] = {.lex_state = 0, .external_lex_state = 13},
  [1067] = {.lex_state = 0, .external_lex_state = 13},
  [1068] = {.lex_state = 0, .external_lex_state = 13},
  [1069] = {.lex_state = 0, .external_lex_state = 13},
  [1070] = {.lex_state = 0, .external_lex_state = 13},
  [1071] = {.lex_state = 0, .external_lex_state = 13},
  [1072] = {.lex_state = 0, .external_lex_state = 13},
  [1073] = {.lex_state = 0, .external_lex_state = 13},
  [1074] = {.lex_state = 0, .external_lex_state = 13},
  [1075] = {.lex_state = 0, .external_lex_state = 13},
  [1076] = {.lex_state = 0, .external_lex_state = 13},
  [1077] = {.lex_state = 0, .external_lex_state = 13},
  [1078] = {.lex_state = 0, .external_lex_state = 13},
  [1079] = {.lex_state = 0, .external_lex_state = 13},
  [1080] = {.lex_state = 0, .external_lex_state = 13},
  [1081] = {.lex_state = 0, .external_lex_state = 13},
  [1082] = {.lex_state = 0, .external_lex_state = 13},
  [1083] = {.lex_state = 0, .external_lex_state = 13},
  [1084] = {.lex_state = 0, .external_lex_state = 13},
  [1085] = {.lex_state = 0, .external_lex_state = 13},
  [1086] = {.lex_state = 0, .external_lex_state = 13},
  [1087] = {.lex_state = 0, .external_lex_state = 13},
  [1088] = {.lex_state = 0, .external_lex_state = 13},
  [1089] = {.lex_state = 0, .external_lex_state = 13},
  [1090] = {.lex_state = 0, .external_lex_state = 13},
  [1091] = {.lex_state = 0, .external_lex_state = 13},
  [1092] = {.lex_state = 0, .external_lex_state = 13},
  [1093] = {.lex_state = 0, .external_lex_state = 13},
  [1094] = {.lex_state = 0, .external_lex_state = 13},
  [1095] = {.lex_state = 0, .external_lex_state = 13},
  [1096] = {.lex_state = 0, .external_lex_state = 13},
  [1097] = {.lex_state = 0, .external_lex_state = 13},
  [1098] = {.lex_state = 0, .external_lex_state = 13},
  [1099] = {.lex_state = 0, .external_lex_state = 13},
  [1100] = {.lex_state = 0, .external_lex_state = 13},
  [1101] = {.lex_state = 0, .external_lex_state = 13},
  [1102] = {.lex_state = 0, .external_lex_state = 13},
  [1103] = {.lex_state = 0, .external_lex_state = 13},
  [1104] = {.lex_state = 0, .external_lex_state = 13},
  [1105] = {.lex_state = 0, .external_lex_state = 13},
  [1106] = {.lex_state = 0, .external_lex_state = 13},
  [1107] = {.lex_state = 0, .external_lex_state = 13},
  [1108] = {.lex_state = 0, .external_lex_state = 13},
  [1109] = {.lex_state = 0, .external_lex_state = 13},
  [1110] = {.lex_state = 0, .external_lex_state = 13},
  [1111] = {.lex_state = 0, .external_lex_state = 13},
  [1112] = {.lex_state = 0, .external_lex_state = 13},
  [1113] = {.lex_state = 0, .external_lex_state = 13},
  [1114] = {.lex_state = 0, .external_lex_state = 13},
  [1115] = {.lex_state = 0, .external_lex_state = 13},
  [1116] = {.lex_state = 0, .external_lex_state = 13},
  [1117] = {.lex_state = 0, .external_lex_state = 13},
  [1118] = {.lex_state = 0, .external_lex_state = 13},
  [1119] = {.lex_state = 0, .external_lex_state = 13},
  [1120] = {.lex_state = 0, .external_lex_state = 13},
  [1121] = {.lex_state = 0, .external_lex_state = 13},
  [1122] = {.lex_state = 0, .external_lex_state = 13},
  [1123] = {.lex_state = 0, .external_lex_state = 13},
  [1124] = {.lex_state = 0, .external_lex_state = 13},
  [1125] = {.lex_state = 0, .external_lex_state = 13},
  [1126] = {.lex_state = 1, .external_lex_state = 14},
  [1127] = {.lex_state = 1, .external_lex_state = 14},
  [1128] = {.lex_state = 1, .external_lex_state = 15},
  [1129] = {.lex_state = 1, .external_lex_state = 16},
  [1130] = {.lex_state = 1, .external_lex_state = 15},
  [1131] = {.lex_state = 1, .external_lex_state = 16},
  [1132] = {.lex_state = 1, .external_lex_state = 17},
  [1133] = {.lex_state = 1, .external_lex_state = 18},
  [1134] = {.lex_state = 1, .external_lex_state = 18},
  [1135] = {.lex_state = 1, .external_lex_state = 19},
  [1136] = {.lex_state = 1, .external_lex_state = 19},
  [1137] = {.lex_state = 1, .external_lex_state = 17},
  [1138] = {.lex_state = 1, .external_lex_state = 20},
  [1139] = {.lex_state = 1, .external_lex_state = 21},
  [1140] = {.lex_state = 1, .external_lex_state = 22},
  [1141] = {.lex_state = 1, .external_lex_state = 23},
  [1142] = {.lex_state = 1, .external_lex_state = 24},
  [1143] = {.lex_state = 1, .external_lex_state = 25},
  [1144] = {.lex_state = 1, .external_lex_state = 16},
  [1145] = {.lex_state = 1, .external_lex_state = 14},
  [1146] = {.lex_state = 1, .external_lex_state = 15},
  [1147] = {.lex_state = 1, .external_lex_state = 18},
  [1148] = {.lex_state = 0, .external_lex_state = 26},
  [1149] = {.lex_state = 1, .external_lex_state = 19},
  [1150] = {.lex_state = 0, .external_lex_state = 26},
  [1151] = {.lex_state = 0, .external_lex_state = 27},
  [1152] = {.lex_state = 0, .external_lex_state = 27},
  [1153] = {.lex_state = 0, .external_lex_state = 27},
  [1154] = {.lex_state = 0, .external_lex_state = 28},
  [1155] = {.lex_state = 0, .external_lex_state = 28},
  [1156] = {.lex_state = 0, .external_lex_state = 27},
  [1157] = {.lex_state = 0, .external_lex_state = 28},
  [1158] = {.lex_state = 0, .external_lex_state = 28},
  [1159] = {.lex_state = 0, .external_lex_state = 28},
  [1160] = {.lex_state = 0, .external_lex_state = 28},
  [1161] = {.lex_state = 0, .external_lex_state = 28},
  [1162] = {.lex_state = 0, .external_lex_state = 27},
  [1163] = {.lex_state = 0, .external_lex_state = 26},
  [1164] = {.lex_state = 0, .external_lex_state = 26},
  [1165] = {.lex_state = 0, .external_lex_state = 26},
  [1166] = {.lex_state = 1, .external_lex_state = 17},
  [1167] = {.lex_state = 0, .external_lex_state = 26},
  [1168] = {.lex_state = 0, .external_lex_state = 26},
  [1169] = {.lex_state = 0, .external_lex_state = 26},
  [1170] = {.lex_state = 0, .external_lex_state = 27},
  [1171] = {.lex_state = 0, .external_lex_state = 28},
  [1172] = {.lex_state = 0, .external_lex_state = 27},
  [1173] = {.lex_state = 0, .external_lex_state = 27},
  [1174] = {.lex_state = 0, .external_lex_state = 27},
  [1175] = {.lex_state = 0, .external_lex_state = 28},
  [1176] = {.lex_state = 0, .external_lex_state = 26},
  [1177] = {.lex_state = 0, .external_lex_state = 28},
  [1178] = {.lex_state = 0, .external_lex_state = 26},
  [1179] = {.lex_state = 0, .external_lex_state = 28},
  [1180] = {.lex_state = 0, .external_lex_state = 26},
  [1181] = {.lex_state = 0, .external_lex_state = 26},
  [1182] = {.lex_state = 0, .external_lex_state = 28},
  [1183] = {.lex_state = 0, .external_lex_state = 27},
  [1184] = {.lex_state = 0, .external_lex_state = 27},
  [1185] = {.lex_state = 0, .external_lex_state = 27},
  [1186] = {.lex_state = 0, .external_lex_state = 27},
  [1187] = {.lex_state = 0, .external_lex_state = 27},
  [1188] = {.lex_state = 0, .external_lex_state = 27},
  [1189] = {.lex_state = 0, .external_lex_state = 26},
  [1190] = {.lex_state = 0, .external_lex_state = 27},
  [1191] = {.lex_state = 0, .external_lex_state = 26},
  [1192] = {.lex_state = 0, .external_lex_state = 27},
  [1193] = {.lex_state = 0, .external_lex_state = 26},
  [1194] = {.lex_state = 0, .external_lex_state = 27},
  [1195] = {.lex_state = 0, .external_lex_state = 26},
  [1196] = {.lex_state = 0, .external_lex_state = 27},
  [1197] = {.lex_state = 0, .external_lex_state = 26},
  [1198] = {.lex_state = 0, .external_lex_state = 27},
  [1199] = {.lex_state = 0, .external_lex_state = 28},
  [1200] = {.lex_state = 0, .external_lex_state = 27},
  [1201] = {.lex_state = 0, .external_lex_state = 26},
  [1202] = {.lex_state = 0, .external_lex_state = 27},
  [1203] = {.lex_state = 0, .external_lex_state = 28},
  [1204] = {.lex_state = 0, .external_lex_state = 27},
  [1205] = {.lex_state = 0, .external_lex_state = 26},
  [1206] = {.lex_state = 0, .external_lex_state = 27},
  [1207] = {.lex_state = 0, .external_lex_state = 26},
  [1208] = {.lex_state = 0, .external_lex_state = 27},
  [1209] = {.lex_state = 0, .external_lex_state = 26},
  [1210] = {.lex_state = 0, .external_lex_state = 27},
  [1211] = {.lex_state = 0, .external_lex_state = 28},
  [1212] = {.lex_state = 0, .external_lex_state = 27},
  [1213] = {.lex_state = 0, .external_lex_state = 26},
  [1214] = {.lex_state = 0, .external_lex_state = 28},
  [1215] = {.lex_state = 0, .external_lex_state = 27},
  [1216] = {.lex_state = 0, .external_lex_state = 27},
  [1217] = {.lex_state = 0, .external_lex_state = 26},
  [1218] = {.lex_state = 0, .external_lex_state = 26},
  [1219] = {.lex_state = 0, .external_lex_state = 27},
  [1220] = {.lex_state = 0, .external_lex_state = 27},
  [1221] = {.lex_state = 0, .external_lex_state = 27},
  [1222] = {.lex_state = 0, .external_lex_state = 27},
  [1223] = {.lex_state = 0, .external_lex_state = 26},
  [1224] = {.lex_state = 0, .external_lex_state = 27},
  [1225] = {.lex_state = 0, .external_lex_state = 27},
  [1226] = {.lex_state = 0, .external_lex_state = 27},
  [1227] = {.lex_state = 0, .external_lex_state = 27},
  [1228] = {.lex_state = 0, .external_lex_state = 27},
  [1229] = {.lex_state = 0, .external_lex_state = 27},
  [1230] = {.lex_state = 0, .external_lex_state = 27},
  [1231] = {.lex_state = 0, .external_lex_state = 27},
  [1232] = {.lex_state = 0, .external_lex_state = 27},
  [1233] = {.lex_state = 0, .external_lex_state = 27},
  [1234] = {.lex_state = 0, .external_lex_state = 26},
  [1235] = {.lex_state = 0, .external_lex_state = 26},
  [1236] = {.lex_state = 0, .external_lex_state = 28},
  [1237] = {.lex_state = 0, .external_lex_state = 26},
  [1238] = {.lex_state = 0, .external_lex_state = 27},
  [1239] = {.lex_state = 0, .external_lex_state = 27},
  [1240] = {.lex_state = 0, .external_lex_state = 26},
  [1241] = {.lex_state = 0, .external_lex_state = 27},
  [1242] = {.lex_state = 0, .external_lex_state = 26},
  [1243] = {.lex_state = 0, .external_lex_state = 28},
  [1244] = {.lex_state = 0, .external_lex_state = 26},
  [1245] = {.lex_state = 0, .external_lex_state = 27},
  [1246] = {.lex_state = 0, .external_lex_state = 26},
  [1247] = {.lex_state = 0, .external_lex_state = 26},
  [1248] = {.lex_state = 0, .external_lex_state = 27},
  [1249] = {.lex_state = 0, .external_lex_state = 27},
  [1250] = {.lex_state = 0, .external_lex_state = 27},
  [1251] = {.lex_state = 0, .external_lex_state = 28},
  [1252] = {.lex_state = 0, .external_lex_state = 27},
  [1253] = {.lex_state = 0, .external_lex_state = 26},
  [1254] = {.lex_state = 0, .external_lex_state = 26},
  [1255] = {.lex_state = 0, .external_lex_state = 27},
  [1256] = {.lex_state = 0, .external_lex_state = 27},
  [1257] = {.lex_state = 0, .external_lex_state = 26},
  [1258] = {.lex_state = 0, .external_lex_state = 27},
  [1259] = {.lex_state = 0, .external_lex_state = 27},
  [1260] = {.lex_state = 0, .external_lex_state = 27},
  [1261] = {.lex_state = 0, .external_lex_state = 28},
  [1262] = {.lex_state = 0, .external_lex_state = 26},
  [1263] = {.lex_state = 0, .external_lex_state = 27},
  [1264] = {.lex_state = 0, .external_lex_state = 28},
  [1265] = {.lex_state = 0, .external_lex_state = 28},
  [1266] = {.lex_state = 0, .external_lex_state = 26},
  [1267] = {.lex_state = 0, .external_lex_state = 28},
  [1268] = {.lex_state = 0, .external_lex_state = 26},
  [1269] = {.lex_state = 0, .external_lex_state = 28},
  [1270] = {.lex_state = 0, .external_lex_state = 26},
  [1271] = {.lex_state = 0, .external_lex_state = 28},
  [1272] = {.lex_state = 0, .external_lex_state = 28},
  [1273] = {.lex_state = 0, .external_lex_state = 28},
  [1274] = {.lex_state = 0, .external_lex_state = 26},
  [1275] = {.lex_state = 0, .external_lex_state = 28},
  [1276] = {.lex_state = 0, .external_lex_state = 28},
  [1277] = {.lex_state = 0, .external_lex_state = 28},
  [1278] = {.lex_state = 0, .external_lex_state = 28},
  [1279] = {.lex_state = 0, .external_lex_state = 28},
  [1280] = {.lex_state = 0, .external_lex_state = 26},
  [1281] = {.lex_state = 0, .external_lex_state = 28},
  [1282] = {.lex_state = 0, .external_lex_state = 28},
  [1283] = {.lex_state = 0, .external_lex_state = 26},
  [1284] = {.lex_state = 0, .external_lex_state = 28},
  [1285] = {.lex_state = 0, .external_lex_state = 28},
  [1286] = {.lex_state = 0, .external_lex_state = 28},
  [1287] = {.lex_state = 0, .external_lex_state = 28},
  [1288] = {.lex_state = 0, .external_lex_state = 26},
  [1289] = {.lex_state = 0, .external_lex_state = 26},
  [1290] = {.lex_state = 0, .external_lex_state = 28},
  [1291] = {.lex_state = 0, .external_lex_state = 28},
  [1292] = {.lex_state = 0, .external_lex_state = 26},
  [1293] = {.lex_state = 0, .external_lex_state = 28},
  [1294] = {.lex_state = 0, .external_lex_state = 28},
  [1295] = {.lex_state = 0, .external_lex_state = 27},
  [1296] = {.lex_state = 0, .external_lex_state = 26},
  [1297] = {.lex_state = 0, .external_lex_state = 28},
  [1298] = {.lex_state = 0, .external_lex_state = 27},
  [1299] = {.lex_state = 0, .external_lex_state = 28},
  [1300] = {.lex_state = 0, .external_lex_state = 28},
  [1301] = {.lex_state = 0, .external_lex_state = 28},
  [1302] = {.lex_state = 0, .external_lex_state = 28},
  [1303] = {.lex_state = 0, .external_lex_state = 27},
  [1304] = {.lex_state = 0, .external_lex_state = 28},
  [1305] = {.lex_state = 0, .external_lex_state = 28},
  [1306] = {.lex_state = 0, .external_lex_state = 27},
  [1307] = {.lex_state = 0, .external_lex_state = 28},
  [1308] = {.lex_state = 0, .external_lex_state = 28},
  [1309] = {.lex_state = 0, .external_lex_state = 26},
  [1310] = {.lex_state = 0, .external_lex_state = 28},
  [1311] = {.lex_state = 0, .external_lex_state = 28},
  [1312] = {.lex_state = 0, .external_lex_state = 28},
  [1313] = {.lex_state = 0, .external_lex_state = 27},
  [1314] = {.lex_state = 0, .external_lex_state = 28},
  [1315] = {.lex_state = 0, .external_lex_state = 28},
  [1316] = {.lex_state = 0, .external_lex_state = 28},
  [1317] = {.lex_state = 0, .external_lex_state = 26},
  [1318] = {.lex_state = 0, .external_lex_state = 26},
  [1319] = {.lex_state = 0, .external_lex_state = 28},
  [1320] = {.lex_state = 0, .external_lex_state = 26},
  [1321] = {.lex_state = 0, .external_lex_state = 26},
  [1322] = {.lex_state = 0, .external_lex_state = 26},
  [1323] = {.lex_state = 0, .external_lex_state = 26},
  [1324] = {.lex_state = 0, .external_lex_state = 28},
  [1325] = {.lex_state = 0, .external_lex_state = 26},
  [1326] = {.lex_state = 0, .external_lex_state = 26},
  [1327] = {.lex_state = 0, .external_lex_state = 26},
  [1328] = {.lex_state = 0, .external_lex_state = 26},
  [1329] = {.lex_state = 0, .external_lex_state = 28},
  [1330] = {.lex_state = 0, .external_lex_state = 26},
  [1331] = {.lex_state = 0, .external_lex_state = 28},
  [1332] = {.lex_state = 0, .external_lex_state = 26},
  [1333] = {.lex_state = 0, .external_lex_state = 28},
  [1334] = {.lex_state = 0, .external_lex_state = 26},
  [1335] = {.lex_state = 0, .external_lex_state = 28},
  [1336] = {.lex_state = 0, .external_lex_state = 26},
  [1337] = {.lex_state = 0, .external_lex_state = 27},
  [1338] = {.lex_state = 0, .external_lex_state = 26},
  [1339] = {.lex_state = 0, .external_lex_state = 28},
  [1340] = {.lex_state = 0, .external_lex_state = 26},
  [1341] = {.lex_state = 0, .external_lex_state = 27},
  [1342] = {.lex_state = 0, .external_lex_state = 29},
  [1343] = {.lex_state = 0, .external_lex_state = 30},
  [1344] = {.lex_state = 0, .external_lex_state = 30},
  [1345] = {.lex_state = 0, .external_lex_state = 29},
  [1346] = {.lex_state = 0, .external_lex_state = 30},
  [1347] = {.lex_state = 0, .external_lex_state = 30},
  [1348] = {.lex_state = 0, .external_lex_state = 29},
  [1349] = {.lex_state = 0, .external_lex_state = 29},
  [1350] = {.lex_state = 0, .external_lex_state = 29},
  [1351] = {.lex_state = 0, .external_lex_state = 29},
  [1352] = {.lex_state = 0, .external_lex_state = 29},
  [1353] = {.lex_state = 0, .external_lex_state = 29},
  [1354] = {.lex_state = 0, .external_lex_state = 30},
  [1355] = {.lex_state = 0, .external_lex_state = 29},
  [1356] = {.lex_state = 0, .external_lex_state = 29},
  [1357] = {.lex_state = 0, .external_lex_state = 30},
  [1358] = {.lex_state = 0, .external_lex_state = 29},
  [1359] = {.lex_state = 0, .external_lex_state = 29},
  [1360] = {.lex_state = 0, .external_lex_state = 29},
  [1361] = {.lex_state = 0, .external_lex_state = 30},
  [1362] = {.lex_state = 0, .external_lex_state = 29},
  [1363] = {.lex_state = 0, .external_lex_state = 29},
  [1364] = {.lex_state = 0, .external_lex_state = 29},
  [1365] = {.lex_state = 0, .external_lex_state = 30},
  [1366] = {.lex_state = 0, .external_lex_state = 30},
  [1367] = {.lex_state = 0, .external_lex_state = 29},
  [1368] = {.lex_state = 0, .external_lex_state = 29},
  [1369] = {.lex_state = 0, .external_lex_state = 30},
  [1370] = {.lex_state = 0, .external_lex_state = 29},
  [1371] = {.lex_state = 0, .external_lex_state = 29},
  [1372] = {.lex_state = 0, .external_lex_state = 30},
  [1373] = {.lex_state = 0, .external_lex_state = 29},
  [1374] = {.lex_state = 0, .external_lex_state = 30},
  [1375] = {.lex_state = 0, .external_lex_state = 30},
  [1376] = {.lex_state = 0, .external_lex_state = 30},
  [1377] = {.lex_state = 0, .external_lex_state = 29},
  [1378] = {.lex_state = 0, .external_lex_state = 30},
  [1379] = {.lex_state = 0, .external_lex_state = 30},
  [1380] = {.lex_state = 0, .external_lex_state = 30},
  [1381] = {.lex_state = 0, .external_lex_state = 30},
  [1382] = {.lex_state = 0, .external_lex_state = 30},
  [1383] = {.lex_state = 0, .external_lex_state = 30},
  [1384] = {.lex_state = 0, .external_lex_state = 29},
  [1385] = {.lex_state = 0, .external_lex_state = 29},
  [1386] = {.lex_state = 0, .external_lex_state = 29},
  [1387] = {.lex_state = 0, .external_lex_state = 30},
  [1388] = {.lex_state = 0, .external_lex_state = 29},
  [1389] = {.lex_state = 0, .external_lex_state = 30},
  [1390] = {.lex_state = 0, .external_lex_state = 29},
  [1391] = {.lex_state = 0, .external_lex_state = 30},
  [1392] = {.lex_state = 0, .external_lex_state = 29},
  [1393] = {.lex_state = 0, .external_lex_state = 29},
  [1394] = {.lex_state = 0, .external_lex_state = 30},
  [1395] = {.lex_state = 0, .external_lex_state = 29},
  [1396] = {.lex_state = 0, .external_lex_state = 29},
  [1397] = {.lex_state = 0, .external_lex_state = 30},
  [1398] = {.lex_state = 0, .external_lex_state = 29},
  [1399] = {.lex_state = 0, .external_lex_state = 29},
  [1400] = {.lex_state = 0, .external_lex_state = 30},
  [1401] = {.lex_state = 0, .external_lex_state = 30},
  [1402] = {.lex_state = 0, .external_lex_state = 30},
  [1403] = {.lex_state = 0, .external_lex_state = 31},
  [1404] = {.lex_state = 0, .external_lex_state = 31},
  [1405] = {.lex_state = 0, .external_lex_state = 31},
  [1406] = {.lex_state = 0, .external_lex_state = 31},
  [1407] = {.lex_state = 0, .external_lex_state = 31},
  [1408] = {.lex_state = 0, .external_lex_state = 29},
  [1409] = {.lex_state = 0, .external_lex_state = 29},
  [1410] = {.lex_state = 0, .external_lex_state = 29},
  [1411] = {.lex_state = 0, .external_lex_state = 29},
  [1412] = {.lex_state = 0, .external_lex_state = 30},
  [1413] = {.lex_state = 0, .external_lex_state = 29},
  [1414] = {.lex_state = 0, .external_lex_state = 31},
  [1415] = {.lex_state = 0, .external_lex_state = 31},
  [1416] = {.lex_state = 0, .external_lex_state = 31},
  [1417] = {.lex_state = 0, .external_lex_state = 31},
  [1418] = {.lex_state = 0, .external_lex_state = 31},
  [1419] = {.lex_state = 0, .external_lex_state = 31},
  [1420] = {.lex_state = 0, .external_lex_state = 31},
  [1421] = {.lex_state = 0, .external_lex_state = 31},
  [1422] = {.lex_state = 0, .external_lex_state = 31},
  [1423] = {.lex_state = 0, .external_lex_state = 31},
  [1424] = {.lex_state = 0, .external_lex_state = 31},
  [1425] = {.lex_state = 0, .external_lex_state = 31},
  [1426] = {.lex_state = 0, .external_lex_state = 31},
  [1427] = {.lex_state = 0, .external_lex_state = 31},
  [1428] = {.lex_state = 0, .external_lex_state = 31},
  [1429] = {.lex_state = 0, .external_lex_state = 31},
  [1430] = {.lex_state = 0, .external_lex_state = 31},
  [1431] = {.lex_state = 0, .external_lex_state = 31},
  [1432] = {.lex_state = 0, .external_lex_state = 31},
  [1433] = {.lex_state = 0, .external_lex_state = 30},
  [1434] = {.lex_state = 0, .external_lex_state = 30},
  [1435] = {.lex_state = 0, .external_lex_state = 30},
  [1436] = {.lex_state = 0, .external_lex_state = 30},
  [1437] = {.lex_state = 0, .external_lex_state = 30},
  [1438] = {.lex_state = 0, .external_lex_state = 31},
  [1439] = {.lex_state = 0, .external_lex_state = 31},
  [1440] = {.lex_state = 0, .external_lex_state = 30},
  [1441] = {.lex_state = 0, .external_lex_state = 31},
  [1442] = {.lex_state = 0, .external_lex_state = 31},
  [1443] = {.lex_state = 0, .external_lex_state = 31},
  [1444] = {.lex_state = 0, .external_lex_state = 30},
  [1445] = {.lex_state = 0, .external_lex_state = 31},
  [1446] = {.lex_state = 0, .external_lex_state = 31},
  [1447] = {.lex_state = 0, .external_lex_state = 31},
  [1448] = {.lex_state = 0, .external_lex_state = 31},
  [1449] = {.lex_state = 0, .external_lex_state = 31},
  [1450] = {.lex_state = 0, .external_lex_state = 31},
  [1451] = {.lex_state = 0, .external_lex_state = 30},
  [1452] = {.lex_state = 0, .external_lex_state = 30},
  [1453] = {.lex_state = 0, .external_lex_state = 31},
  [1454] = {.lex_state = 0, .external_lex_state = 30},
  [1455] = {.lex_state = 0, .external_lex_state = 31},
  [1456] = {.lex_state = 0, .external_lex_state = 31},
  [1457] = {.lex_state = 0, .external_lex_state = 30},
  [1458] = {.lex_state = 0, .external_lex_state = 30},
  [1459] = {.lex_state = 0, .external_lex_state = 30},
  [1460] = {.lex_state = 0, .external_lex_state = 30},
  [1461] = {.lex_state = 0, .external_lex_state = 30},
  [1462] = {.lex_state = 0, .external_lex_state = 30},
  [1463] = {.lex_state = 0, .external_lex_state = 30},
  [1464] = {.lex_state = 0, .external_lex_state = 30},
  [1465] = {.lex_state = 0, .external_lex_state = 31},
  [1466] = {.lex_state = 0, .external_lex_state = 30},
  [1467] = {.lex_state = 0, .external_lex_state = 29},
  [1468] = {.lex_state = 0, .external_lex_state = 30},
  [1469] = {.lex_state = 0, .external_lex_state = 30},
  [1470] = {.lex_state = 0, .external_lex_state = 31},
  [1471] = {.lex_state = 0, .external_lex_state = 30},
  [1472] = {.lex_state = 0, .external_lex_state = 30},
  [1473] = {.lex_state = 0, .external_lex_state = 30},
  [1474] = {.lex_state = 0, .external_lex_state = 30},
  [1475] = {.lex_state = 0, .external_lex_state = 30},
  [1476] = {.lex_state = 0, .external_lex_state = 29},
  [1477] = {.lex_state = 0, .external_lex_state = 29},
  [1478] = {.lex_state = 0, .external_lex_state = 29},
  [1479] = {.lex_state = 0, .external_lex_state = 31},
  [1480] = {.lex_state = 0, .external_lex_state = 31},
  [1481] = {.lex_state = 0, .external_lex_state = 29},
  [1482] = {.lex_state = 0, .external_lex_state = 31},
  [1483] = {.lex_state = 0, .external_lex_state = 30},
  [1484] = {.lex_state = 0, .external_lex_state = 30},
  [1485] = {.lex_state = 0, .external_lex_state = 29},
  [1486] = {.lex_state = 0, .external_lex_state = 30},
  [1487] = {.lex_state = 0, .external_lex_state = 30},
  [1488] = {.lex_state = 0, .external_lex_state = 30},
  [1489] = {.lex_state = 0, .external_lex_state = 31},
  [1490] = {.lex_state = 0, .external_lex_state = 29},
  [1491] = {.lex_state = 0, .external_lex_state = 30},
  [1492] = {.lex_state = 0, .external_lex_state = 30},
  [1493] = {.lex_state = 0, .external_lex_state = 29},
  [1494] = {.lex_state = 0, .external_lex_state = 30},
  [1495] = {.lex_state = 0, .external_lex_state = 30},
  [1496] = {.lex_state = 0, .external_lex_state = 30},
  [1497] = {.lex_state = 0, .external_lex_state = 30},
  [1498] = {.lex_state = 0, .external_lex_state = 30},
  [1499] = {.lex_state = 0, .external_lex_state = 30},
  [1500] = {.lex_state = 0, .external_lex_state = 31},
  [1501] = {.lex_state = 0, .external_lex_state = 31},
  [1502] = {.lex_state = 0, .external_lex_state = 30},
  [1503] = {.lex_state = 0, .external_lex_state = 30},
  [1504] = {.lex_state = 0, .external_lex_state = 30},
  [1505] = {.lex_state = 0, .external_lex_state = 30},
  [1506] = {.lex_state = 0, .external_lex_state = 31},
  [1507] = {.lex_state = 0, .external_lex_state = 30},
  [1508] = {.lex_state = 0, .external_lex_state = 30},
  [1509] = {.lex_state = 0, .external_lex_state = 30},
  [1510] = {.lex_state = 0, .external_lex_state = 30},
  [1511] = {.lex_state = 0, .external_lex_state = 29},
  [1512] = {.lex_state = 0, .external_lex_state = 30},
  [1513] = {.lex_state = 0, .external_lex_state = 30},
  [1514] = {.lex_state = 0, .external_lex_state = 31},
  [1515] = {.lex_state = 0, .external_lex_state = 30},
  [1516] = {.lex_state = 0, .external_lex_state = 30},
  [1517] = {.lex_state = 0, .external_lex_state = 30},
  [1518] = {.lex_state = 0, .external_lex_state = 29},
  [1519] = {.lex_state = 0, .external_lex_state = 30},
  [1520] = {.lex_state = 0, .external_lex_state = 31},
  [1521] = {.lex_state = 0, .external_lex_state = 30},
  [1522] = {.lex_state = 0, .external_lex_state = 30},
  [1523] = {.lex_state = 0, .external_lex_state = 30},
  [1524] = {.lex_state = 0, .external_lex_state = 30},
  [1525] = {.lex_state = 0, .external_lex_state = 31},
  [1526] = {.lex_state = 0, .external_lex_state = 30},
  [1527] = {.lex_state = 0, .external_lex_state = 30},
  [1528] = {.lex_state = 0, .external_lex_state = 30},
  [1529] = {.lex_state = 0, .external_lex_state = 30},
  [1530] = {.lex_state = 0, .external_lex_state = 31},
  [1531] = {.lex_state = 0, .external_lex_state = 30},
  [1532] = {.lex_state = 0, .external_lex_state = 31},
  [1533] = {.lex_state = 0, .external_lex_state = 31},
  [1534] = {.lex_state = 0, .external_lex_state = 30},
  [1535] = {.lex_state = 0, .external_lex_state = 30},
  [1536] = {.lex_state = 0, .external_lex_state = 30},
  [1537] = {.lex_state = 0, .external_lex_state = 30},
  [1538] = {.lex_state = 0, .external_lex_state = 30},
  [1539] = {.lex_state = 0, .external_lex_state = 29},
  [1540] = {.lex_state = 0, .external_lex_state = 30},
  [1541] = {.lex_state = 0, .external_lex_state = 31},
  [1542] = {.lex_state = 0, .external_lex_state = 31},
  [1543] = {.lex_state = 0, .external_lex_state = 30},
  [1544] = {.lex_state = 0, .external_lex_state = 30},
  [1545] = {.lex_state = 0, .external_lex_state = 30},
  [1546] = {.lex_state = 0, .external_lex_state = 30},
  [1547] = {.lex_state = 0, .external_lex_state = 30},
  [1548] = {.lex_state = 0, .external_lex_state = 30},
  [1549] = {.lex_state = 0, .external_lex_state = 29},
  [1550] = {.lex_state = 0, .external_lex_state = 30},
  [1551] = {.lex_state = 0, .external_lex_state = 30},
  [1552] = {.lex_state = 0, .external_lex_state = 31},
  [1553] = {.lex_state = 0, .external_lex_state = 30},
  [1554] = {.lex_state = 0, .external_lex_state = 29},
  [1555] = {.lex_state = 0, .external_lex_state = 30},
  [1556] = {.lex_state = 0, .external_lex_state = 30},
  [1557] = {.lex_state = 0, .external_lex_state = 29},
  [1558] = {.lex_state = 0, .external_lex_state = 29},
  [1559] = {.lex_state = 0, .external_lex_state = 30},
  [1560] = {.lex_state = 0, .external_lex_state = 30},
  [1561] = {.lex_state = 0, .external_lex_state = 30},
  [1562] = {.lex_state = 0, .external_lex_state = 30},
  [1563] = {.lex_state = 0, .external_lex_state = 30},
  [1564] = {.lex_state = 0, .external_lex_state = 30},
  [1565] = {.lex_state = 0, .external_lex_state = 30},
  [1566] = {.lex_state = 0, .external_lex_state = 30},
  [1567] = {.lex_state = 0, .external_lex_state = 29},
  [1568] = {.lex_state = 0, .external_lex_state = 29},
  [1569] = {.lex_state = 0, .external_lex_state = 30},
  [1570] = {.lex_state = 0, .external_lex_state = 30},
  [1571] = {.lex_state = 0, .external_lex_state = 30},
  [1572] = {.lex_state = 0, .external_lex_state = 30},
  [1573] = {.lex_state = 0, .external_lex_state = 29},
  [1574] = {.lex_state = 0, .external_lex_state = 30},
  [1575] = {.lex_state = 0, .external_lex_state = 30},
  [1576] = {.lex_state = 0, .external_lex_state = 30},
  [1577] = {.lex_state = 0, .external_lex_state = 30},
  [1578] = {.lex_state = 0, .external_lex_state = 30},
  [1579] = {.lex_state = 0, .external_lex_state = 29},
  [1580] = {.lex_state = 0, .external_lex_state = 30},
  [1581] = {.lex_state = 0, .external_lex_state = 30},
  [1582] = {.lex_state = 0, .external_lex_state = 30},
  [1583] = {.lex_state = 0, .external_lex_state = 31},
  [1584] = {.lex_state = 0, .external_lex_state = 27},
  [1585] = {.lex_state = 0, .external_lex_state = 26},
  [1586] = {.lex_state = 0, .external_lex_state = 27},
  [1587] = {.lex_state = 0, .external_lex_state = 26},
  [1588] = {.lex_state = 0, .external_lex_state = 26},
  [1589] = {.lex_state = 0, .external_lex_state = 28},
  [1590] = {.lex_state = 0, .external_lex_state = 28},
  [1591] = {.lex_state = 0, .external_lex_state = 28},
  [1592] = {.lex_state = 0, .external_lex_state = 27},
  [1593] = {.lex_state = 0, .external_lex_state = 27},
  [1594] = {.lex_state = 2, .external_lex_state = 27},
  [1595] = {.lex_state = 0, .external_lex_state = 26},
  [1596] = {.lex_state = 0, .external_lex_state = 26},
  [1597] = {.lex_state = 0, .external_lex_state = 26},
  [1598] = {.lex_state = 0, .external_lex_state = 27},
  [1599] = {.lex_state = 0, .external_lex_state = 27},
  [1600] = {.lex_state = 0, .external_lex_state = 27},
  [1601] = {.lex_state = 0, .external_lex_state = 27},
  [1602] = {.lex_state = 0, .external_lex_state = 28},
  [1603] = {.lex_state = 2, .external_lex_state = 28},
  [1604] = {.lex_state = 0, .external_lex_state = 28},
  [1605] = {.lex_state = 0, .external_lex_state = 28},
  [1606] = {.lex_state = 0, .external_lex_state = 28},
  [1607] = {.lex_state = 0, .external_lex_state = 28},
  [1608] = {.lex_state = 0, .external_lex_state = 27},
  [1609] = {.lex_state = 0, .external_lex_state = 26},
  [1610] = {.lex_state = 2, .external_lex_state = 26},
  [1611] = {.lex_state = 0, .external_lex_state = 26},
  [1612] = {.lex_state = 0, .external_lex_state = 26},
  [1613] = {.lex_state = 0, .external_lex_state = 28},
  [1614] = {.lex_state = 0, .external_lex_state = 28},
  [1615] = {.lex_state = 0, .external_lex_state = 26},
  [1616] = {.lex_state = 0, .external_lex_state = 27},
  [1617] = {.lex_state = 0, .external_lex_state = 29},
  [1618] = {.lex_state = 0, .external_lex_state = 30},
  [1619] = {.lex_state = 0, .external_lex_state = 29},
  [1620] = {.lex_state = 0, .external_lex_state = 31},
  [1621] = {.lex_state = 0, .external_lex_state = 31},
  [1622] = {.lex_state = 0, .external_lex_state = 30},
  [1623] = {.lex_state = 0, .external_lex_state = 10},
  [1624] = {.lex_state = 0, .external_lex_state = 29},
  [1625] = {.lex_state = 0, .external_lex_state = 29},
  [1626] = {.lex_state = 2, .external_lex_state = 30},
  [1627] = {.lex_state = 0, .external_lex_state = 30},
  [1628] = {.lex_state = 0, .external_lex_state = 30},
  [1629] = {.lex_state = 0, .external_lex_state = 30},
  [1630] = {.lex_state = 0, .external_lex_state = 31},
  [1631] = {.lex_state = 0, .external_lex_state = 29},
  [1632] = {.lex_state = 0, .external_lex_state = 29},
  [1633] = {.lex_state = 0, .external_lex_state = 29},
  [1634] = {.lex_state = 0, .external_lex_state = 31},
  [1635] = {.lex_state = 0, .external_lex_state = 30},
  [1636] = {.lex_state = 0, .external_lex_state = 29},
  [1637] = {.lex_state = 0, .external_lex_state = 30},
  [1638] = {.lex_state = 2, .external_lex_state = 31},
  [1639] = {.lex_state = 0, .external_lex_state = 31},
  [1640] = {.lex_state = 0, .external_lex_state = 30},
  [1641] = {.lex_state = 0, .external_lex_state = 31},
  [1642] = {.lex_state = 0, .external_lex_state = 29},
  [1643] = {.lex_state = 0, .external_lex_state = 29},
  [1644] = {.lex_state = 0, .external_lex_state = 30},
  [1645] = {.lex_state = 0, .external_lex_state = 29},
  [1646] = {.lex_state = 0, .external_lex_state = 31},
  [1647] = {.lex_state = 0, .external_lex_state = 31},
  [1648] = {.lex_state = 0, .external_lex_state = 31},
  [1649] = {.lex_state = 2, .external_lex_state = 29},
  [1650] = {.lex_state = 0, .external_lex_state = 30},
  [1651] = {.lex_state = 0, .external_lex_state = 31},
  [1652] = {.lex_state = 0, .external_lex_state = 31},
  [1653] = {.lex_state = 0, .external_lex_state = 30},
  [1654] = {.lex_state = 0, .external_lex_state = 27},
  [1655] = {.lex_state = 0, .external_lex_state = 26},
  [1656] = {.lex_state = 0, .external_lex_state = 26},
  [1657] = {.lex_state = 0, .external_lex_state = 26},
  [1658] = {.lex_state = 0, .external_lex_state = 26},
  [1659] = {.lex_state = 0, .external_lex_state = 26},
  [1660] = {.lex_state = 0, .external_lex_state = 26},
  [1661] = {.lex_state = 0, .external_lex_state = 26},
  [1662] = {.lex_state = 0, .external_lex_state = 26},
  [1663] = {.lex_state = 0, .external_lex_state = 27},
  [1664] = {.lex_state = 0, .external_lex_state = 26},
  [1665] = {.lex_state = 0, .external_lex_state = 26},
  [1666] = {.lex_state = 0, .external_lex_state = 26},
  [1667] = {.lex_state = 0, .external_lex_state = 28},
  [1668] = {.lex_state = 0, .external_lex_state = 27},
  [1669] = {.lex_state = 0, .external_lex_state = 27},
  [1670] = {.lex_state = 0, .external_lex_state = 27},
  [1671] = {.lex_state = 0, .external_lex_state = 27},
  [1672] = {.lex_state = 0, .external_lex_state = 26},
  [1673] = {.lex_state = 0, .external_lex_state = 27},
  [1674] = {.lex_state = 0, .external_lex_state = 27},
  [1675] = {.lex_state = 0, .external_lex_state = 28},
  [1676] = {.lex_state = 0, .external_lex_state = 28},
  [1677] = {.lex_state = 0, .external_lex_state = 12},
  [1678] = {.lex_state = 0, .external_lex_state = 27},
  [1679] = {.lex_state = 0, .external_lex_state = 28},
  [1680] = {.lex_state = 0, .external_lex_state = 28},
  [1681] = {.lex_state = 0, .external_lex_state = 28},
  [1682] = {.lex_state = 0, .external_lex_state = 28},
  [1683] = {.lex_state = 0, .external_lex_state = 27},
  [1684] = {.lex_state = 0, .external_lex_state = 27},
  [1685] = {.lex_state = 0, .external_lex_state = 27},
  [1686] = {.lex_state = 0, .external_lex_state = 26},
  [1687] = {.lex_state = 0, .external_lex_state = 26},
  [1688] = {.lex_state = 0, .external_lex_state = 27},
  [1689] = {.lex_state = 0, .external_lex_state = 27},
  [1690] = {.lex_state = 0, .external_lex_state = 27},
  [1691] = {.lex_state = 0, .external_lex_state = 28},
  [1692] = {.lex_state = 0, .external_lex_state = 27},
  [1693] = {.lex_state = 0, .external_lex_state = 26},
  [1694] = {.lex_state = 0, .external_lex_state = 26},
  [1695] = {.lex_state = 0, .external_lex_state = 26},
  [1696] = {.lex_state = 0, .external_lex_state = 27},
  [1697] = {.lex_state = 0, .external_lex_state = 27},
  [1698] = {.lex_state = 0, .external_lex_state = 27},
  [1699] = {.lex_state = 0, .external_lex_state = 27},
  [1700] = {.lex_state = 0, .external_lex_state = 27},
  [1701] = {.lex_state = 0, .external_lex_state = 26},
  [1702] = {.lex_state = 0, .external_lex_state = 28},
  [1703] = {.lex_state = 0, .external_lex_state = 28},
  [1704] = {.lex_state = 0, .external_lex_state = 28},
  [1705] = {.lex_state = 0, .external_lex_state = 28},
  [1706] = {.lex_state = 0, .external_lex_state = 28},
  [1707] = {.lex_state = 0, .external_lex_state = 28},
  [1708] = {.lex_state = 0, .external_lex_state = 27},
  [1709] = {.lex_state = 0, .external_lex_state = 27},
  [1710] = {.lex_state = 0, .external_lex_state = 28},
  [1711] = {.lex_state = 0, .external_lex_state = 28},
  [1712] = {.lex_state = 0, .external_lex_state = 28},
  [1713] = {.lex_state = 0, .external_lex_state = 28},
  [1714] = {.lex_state = 0, .external_lex_state = 28},
  [1715] = {.lex_state = 0, .external_lex_state = 28},
  [1716] = {.lex_state = 0, .external_lex_state = 28},
  [1717] = {.lex_state = 0, .external_lex_state = 28},
  [1718] = {.lex_state = 0, .external_lex_state = 28},
  [1719] = {.lex_state = 0, .external_lex_state = 28},
  [1720] = {.lex_state = 0, .external_lex_state = 27},
  [1721] = {.lex_state = 0, .external_lex_state = 26},
  [1722] = {.lex_state = 0, .external_lex_state = 26},
  [1723] = {.lex_state = 0, .external_lex_state = 26},
  [1724] = {.lex_state = 0, .external_lex_state = 26},
  [1725] = {.lex_state = 0, .external_lex_state = 26},
  [1726] = {.lex_state = 0, .external_lex_state = 26},
  [1727] = {.lex_state = 0, .external_lex_state = 29},
  [1728] = {.lex_state = 0, .external_lex_state = 31},
  [1729] = {.lex_state = 0, .external_lex_state = 29},
  [1730] = {.lex_state = 0, .external_lex_state = 29},
  [1731] = {.lex_state = 0, .external_lex_state = 31},
  [1732] = {.lex_state = 0, .external_lex_state = 30},
  [1733] = {.lex_state = 0, .external_lex_state = 31},
  [1734] = {.lex_state = 0, .external_lex_state = 29},
  [1735] = {.lex_state = 0, .external_lex_state = 31},
  [1736] = {.lex_state = 0, .external_lex_state = 30},
  [1737] = {.lex_state = 0, .external_lex_state = 30},
  [1738] = {.lex_state = 0, .external_lex_state = 30},
  [1739] = {.lex_state = 0, .external_lex_state = 29},
  [1740] = {.lex_state = 0, .external_lex_state = 29},
  [1741] = {.lex_state = 0, .external_lex_state = 30},
  [1742] = {.lex_state = 0, .external_lex_state = 31},
  [1743] = {.lex_state = 0, .external_lex_state = 30},
  [1744] = {.lex_state = 0, .external_lex_state = 31},
  [1745] = {.lex_state = 0, .external_lex_state = 31},
  [1746] = {.lex_state = 0, .external_lex_state = 29},
  [1747] = {.lex_state = 0, .external_lex_state = 31},
  [1748] = {.lex_state = 0, .external_lex_state = 31},
  [1749] = {.lex_state = 0, .external_lex_state = 31},
  [1750] = {.lex_state = 0, .external_lex_state = 31},
  [1751] = {.lex_state = 0, .external_lex_state = 29},
  [1752] = {.lex_state = 0, .external_lex_state = 29},
  [1753] = {.lex_state = 0, .external_lex_state = 31},
  [1754] = {.lex_state = 0, .external_lex_state = 31},
  [1755] = {.lex_state = 0, .external_lex_state = 31},
  [1756] = {.lex_state = 0, .external_lex_state = 30},
  [1757] = {.lex_state = 0, .external_lex_state = 31},
  [1758] = {.lex_state = 0, .external_lex_state = 30},
  [1759] = {.lex_state = 0, .external_lex_state = 30},
  [1760] = {.lex_state = 0, .external_lex_state = 30},
  [1761] = {.lex_state = 0, .external_lex_state = 30},
  [1762] = {.lex_state = 0, .external_lex_state = 31},
  [1763] = {.lex_state = 0, .external_lex_state = 29},
  [1764] = {.lex_state = 0, .external_lex_state = 31},
  [1765] = {.lex_state = 0, .external_lex_state = 29},
  [1766] = {.lex_state = 0, .external_lex_state = 30},
  [1767] = {.lex_state = 0, .external_lex_state = 29},
  [1768] = {.lex_state = 0, .external_lex_state = 30},
  [1769] = {.lex_state = 0, .external_lex_state = 29},
  [1770] = {.lex_state = 0, .external_lex_state = 29},
  [1771] = {.lex_state = 0, .external_lex_state = 31},
  [1772] = {.lex_state = 0, .external_lex_state = 29},
  [1773] = {.lex_state = 0, .external_lex_state = 30},
  [1774] = {.lex_state = 0, .external_lex_state = 31},
  [1775] = {.lex_state = 0, .external_lex_state = 29},
  [1776] = {.lex_state = 0, .external_lex_state = 30},
  [1777] = {.lex_state = 0, .external_lex_state = 30},
  [1778] = {.lex_state = 0, .external_lex_state = 30},
  [1779] = {.lex_state = 0, .external_lex_state = 31},
  [1780] = {.lex_state = 0, .external_lex_state = 30},
  [1781] = {.lex_state = 0, .external_lex_state = 30},
  [1782] = {.lex_state = 0, .external_lex_state = 30},
  [1783] = {.lex_state = 0, .external_lex_state = 12},
  [1784] = {.lex_state = 0, .external_lex_state = 31},
  [1785] = {.lex_state = 0, .external_lex_state = 30},
  [1786] = {.lex_state = 0, .external_lex_state = 31},
  [1787] = {.lex_state = 0, .external_lex_state = 31},
  [1788] = {.lex_state = 0, .external_lex_state = 30},
  [1789] = {.lex_state = 0, .external_lex_state = 30},
  [1790] = {.lex_state = 0, .external_lex_state = 29},
  [1791] = {.lex_state = 0, .external_lex_state = 30},
  [1792] = {.lex_state = 0, .external_lex_state = 30},
  [1793] = {.lex_state = 0, .external_lex_state = 12},
  [1794] = {.lex_state = 0, .external_lex_state = 29},
  [1795] = {.lex_state = 0, .external_lex_state = 31},
  [1796] = {.lex_state = 0, .external_lex_state = 12},
  [1797] = {.lex_state = 0, .external_lex_state = 29},
  [1798] = {.lex_state = 0, .external_lex_state = 29},
  [1799] = {.lex_state = 0, .external_lex_state = 29},
  [1800] = {.lex_state = 0, .external_lex_state = 29},
  [1801] = {.lex_state = 0, .external_lex_state = 29},
  [1802] = {.lex_state = 0, .external_lex_state = 29},
  [1803] = {.lex_state = 0, .external_lex_state = 29},
  [1804] = {.lex_state = 0, .external_lex_state = 31},
  [1805] = {.lex_state = 1, .external_lex_state = 32},
  [1806] = {.lex_state = 1},
  [1807] = {.lex_state = 0, .external_lex_state = 33},
  [1808] = {.lex_state = 0, .external_lex_state = 33},
  [1809] = {.lex_state = 0, .external_lex_state = 33},
  [1810] = {.lex_state = 0, .external_lex_state = 33},
  [1811] = {.lex_state = 0, .external_lex_state = 33},
  [1812] = {.lex_state = 0, .external_lex_state = 33},
  [1813] = {.lex_state = 0, .external_lex_state = 33},
  [1814] = {.lex_state = 0, .external_lex_state = 33},
  [1815] = {.lex_state = 0, .external_lex_state = 33},
  [1816] = {.lex_state = 0, .external_lex_state = 33},
  [1817] = {.lex_state = 0, .external_lex_state = 33},
  [1818] = {.lex_state = 0, .external_lex_state = 33},
  [1819] = {.lex_state = 0, .external_lex_state = 33},
  [1820] = {.lex_state = 0, .external_lex_state = 33},
  [1821] = {.lex_state = 0, .external_lex_state = 33},
  [1822] = {.lex_state = 0, .external_lex_state = 33},
  [1823] = {.lex_state = 0, .external_lex_state = 33},
  [1824] = {.lex_state = 0, .external_lex_state = 33},
  [1825] = {.lex_state = 0, .external_lex_state = 33},
  [1826] = {.lex_state = 0, .external_lex_state = 33},
  [1827] = {.lex_state = 0, .external_lex_state = 33},
  [1828] = {.lex_state = 0, .external_lex_state = 34},
  [1829] = {.lex_state = 0, .external_lex_state = 34},
  [1830] = {.lex_state = 4},
  [1831] = {.lex_state = 3},
  [1832] = {.lex_state = 0, .external_lex_state = 34},
  [1833] = {.lex_state = 4},
  [1834] = {.lex_state = 4},
  [1835] = {.lex_state = 3},
  [1836] = {.lex_state = 0, .external_lex_state = 35},
  [1837] = {.lex_state = 3},
  [1838] = {.lex_state = 0, .external_lex_state = 35},
  [1839] = {.lex_state = 0, .external_lex_state = 33},
  [1840] = {.lex_state = 0, .external_lex_state = 32},
  [1841] = {.lex_state = 0, .external_lex_state = 35},
  [1842] = {.lex_state = 0, .external_lex_state = 32},
  [1843] = {.lex_state = 0, .external_lex_state = 32},
  [1844] = {.lex_state = 4},
  [1845] = {.lex_state = 3},
  [1846] = {.lex_state = 0, .external_lex_state = 32},
  [1847] = {.lex_state = 0, .external_lex_state = 35},
  [1848] = {.lex_state = 4},
  [1849] = {.lex_state = 0, .external_lex_state = 32},
  [1850] = {.lex_state = 0, .external_lex_state = 32},
  [1851] = {.lex_state = 4},
  [1852] = {.lex_state = 3},
  [1853] = {.lex_state = 4},
  [1854] = {.lex_state = 3},
  [1855] = {.lex_state = 0, .external_lex_state = 32},
  [1856] = {.lex_state = 0, .external_lex_state = 35},
  [1857] = {.lex_state = 4},
  [1858] = {.lex_state = 0, .external_lex_state = 32},
  [1859] = {.lex_state = 0, .external_lex_state = 32},
  [1860] = {.lex_state = 0, .external_lex_state = 34},
  [1861] = {.lex_state = 3},
  [1862] = {.lex_state = 0, .external_lex_state = 32},
  [1863] = {.lex_state = 0, .external_lex_state = 34},
  [1864] = {.lex_state = 0, .external_lex_state = 35},
  [1865] = {.lex_state = 0, .external_lex_state = 34},
  [1866] = {.lex_state = 0, .external_lex_state = 34},
  [1867] = {.lex_state = 0, .external_lex_state = 34},
  [1868] = {.lex_state = 0, .external_lex_state = 35},
  [1869] = {.lex_state = 4},
  [1870] = {.lex_state = 3},
  [1871] = {.lex_state = 4},
  [1872] = {.lex_state = 4},
  [1873] = {.lex_state = 4},
  [1874] = {.lex_state = 3},
  [1875] = {.lex_state = 3},
  [1876] = {.lex_state = 0, .external_lex_state = 35},
  [1877] = {.lex_state = 0, .external_lex_state = 32},
  [1878] = {.lex_state = 3},
  [1879] = {.lex_state = 0, .external_lex_state = 32},
  [1880] = {.lex_state = 0, .external_lex_state = 32},
  [1881] = {.lex_state = 0, .external_lex_state = 33},
  [1882] = {.lex_state = 0, .external_lex_state = 32},
  [1883] = {.lex_state = 0, .external_lex_state = 32},
  [1884] = {.lex_state = 0, .external_lex_state = 34},
  [1885] = {.lex_state = 4},
  [1886] = {.lex_state = 3},
  [1887] = {.lex_state = 0, .external_lex_state = 34},
  [1888] = {.lex_state = 4},
  [1889] = {.lex_state = 4},
  [1890] = {.lex_state = 3},
  [1891] = {.lex_state = 3},
  [1892] = {.lex_state = 4},
  [1893] = {.lex_state = 3},
  [1894] = {.lex_state = 0, .external_lex_state = 35},
  [1895] = {.lex_state = 0, .external_lex_state = 35},
  [1896] = {.lex_state = 0, .external_lex_state = 32},
  [1897] = {.lex_state = 0, .external_lex_state = 32},
  [1898] = {.lex_state = 0, .external_lex_state = 32},
  [1899] = {.lex_state = 0, .external_lex_state = 32},
  [1900] = {.lex_state = 0, .external_lex_state = 32},
  [1901] = {.lex_state = 0, .external_lex_state = 34},
  [1902] = {.lex_state = 0, .external_lex_state = 34},
  [1903] = {.lex_state = 0, .external_lex_state = 32},
  [1904] = {.lex_state = 0, .external_lex_state = 33},
  [1905] = {.lex_state = 3},
  [1906] = {.lex_state = 0, .external_lex_state = 32},
  [1907] = {.lex_state = 0, .external_lex_state = 34},
  [1908] = {.lex_state = 0, .external_lex_state = 34},
  [1909] = {.lex_state = 0, .external_lex_state = 35},
  [1910] = {.lex_state = 0, .external_lex_state = 34},
  [1911] = {.lex_state = 0, .external_lex_state = 34},
  [1912] = {.lex_state = 0, .external_lex_state = 35},
  [1913] = {.lex_state = 0, .external_lex_state = 35},
  [1914] = {.lex_state = 0, .external_lex_state = 32},
  [1915] = {.lex_state = 0, .external_lex_state = 35},
  [1916] = {.lex_state = 0, .external_lex_state = 33},
  [1917] = {.lex_state = 0, .external_lex_state = 35},
  [1918] = {.lex_state = 0, .external_lex_state = 34},
  [1919] = {.lex_state = 4},
  [1920] = {.lex_state = 3},
  [1921] = {.lex_state = 0, .external_lex_state = 34},
  [1922] = {.lex_state = 0, .external_lex_state = 32},
  [1923] = {.lex_state = 0, .external_lex_state = 32},
  [1924] = {.lex_state = 0, .external_lex_state = 32},
  [1925] = {.lex_state = 4},
  [1926] = {.lex_state = 3},
  [1927] = {.lex_state = 4},
  [1928] = {.lex_state = 0, .external_lex_state = 33},
  [1929] = {.lex_state = 3},
  [1930] = {.lex_state = 0, .external_lex_state = 34},
  [1931] = {.lex_state = 0, .external_lex_state = 34},
  [1932] = {.lex_state = 0, .external_lex_state = 35},
  [1933] = {.lex_state = 0, .external_lex_state = 34},
  [1934] = {.lex_state = 0, .external_lex_state = 32},
  [1935] = {.lex_state = 0, .external_lex_state = 34},
  [1936] = {.lex_state = 0, .external_lex_state = 32},
  [1937] = {.lex_state = 0, .external_lex_state = 34},
  [1938] = {.lex_state = 0, .external_lex_state = 34},
  [1939] = {.lex_state = 4},
  [1940] = {.lex_state = 0, .external_lex_state = 35},
  [1941] = {.lex_state = 0, .external_lex_state = 32},
  [1942] = {.lex_state = 0, .external_lex_state = 35},
  [1943] = {.lex_state = 0, .external_lex_state = 35},
  [1944] = {.lex_state = 0, .external_lex_state = 35},
  [1945] = {.lex_state = 0, .external_lex_state = 35},
  [1946] = {.lex_state = 0, .external_lex_state = 32},
  [1947] = {.lex_state = 0, .external_lex_state = 35},
  [1948] = {.lex_state = 3},
  [1949] = {.lex_state = 0, .external_lex_state = 34},
  [1950] = {.lex_state = 0, .external_lex_state = 35},
  [1951] = {.lex_state = 0, .external_lex_state = 34},
  [1952] = {.lex_state = 4},
  [1953] = {.lex_state = 0, .external_lex_state = 33},
  [1954] = {.lex_state = 0, .external_lex_state = 33},
  [1955] = {.lex_state = 0, .external_lex_state = 34},
  [1956] = {.lex_state = 0, .external_lex_state = 35},
  [1957] = {.lex_state = 0, .external_lex_state = 33},
  [1958] = {.lex_state = 0, .external_lex_state = 35},
  [1959] = {.lex_state = 0, .external_lex_state = 33},
  [1960] = {.lex_state = 0, .external_lex_state = 33},
  [1961] = {.lex_state = 3},
  [1962] = {.lex_state = 0, .external_lex_state = 33},
  [1963] = {.lex_state = 0, .external_lex_state = 35},
  [1964] = {.lex_state = 0, .external_lex_state = 33},
  [1965] = {.lex_state = 0, .external_lex_state = 33},
  [1966] = {.lex_state = 0, .external_lex_state = 33},
  [1967] = {.lex_state = 0, .external_lex_state = 34},
  [1968] = {.lex_state = 0, .external_lex_state = 33},
  [1969] = {.lex_state = 0, .external_lex_state = 35},
  [1970] = {.lex_state = 0, .external_lex_state = 33},
  [1971] = {.lex_state = 0, .external_lex_state = 34},
  [1972] = {.lex_state = 0, .external_lex_state = 33},
  [1973] = {.lex_state = 0, .external_lex_state = 33},
  [1974] = {.lex_state = 0, .external_lex_state = 33},
  [1975] = {.lex_state = 0, .external_lex_state = 34},
  [1976] = {.lex_state = 0, .external_lex_state = 33},
  [1977] = {.lex_state = 0, .external_lex_state = 35},
  [1978] = {.lex_state = 0, .external_lex_state = 33},
  [1979] = {.lex_state = 0, .external_lex_state = 35},
  [1980] = {.lex_state = 0, .external_lex_state = 33},
  [1981] = {.lex_state = 0, .external_lex_state = 33},
  [1982] = {.lex_state = 0, .external_lex_state = 33},
  [1983] = {.lex_state = 0, .external_lex_state = 33},
  [1984] = {.lex_state = 0, .external_lex_state = 33},
  [1985] = {.lex_state = 0, .external_lex_state = 35},
  [1986] = {.lex_state = 0, .external_lex_state = 33},
  [1987] = {.lex_state = 0, .external_lex_state = 33},
  [1988] = {.lex_state = 0, .external_lex_state = 33},
  [1989] = {.lex_state = 0, .external_lex_state = 33},
  [1990] = {.lex_state = 0, .external_lex_state = 33},
  [1991] = {.lex_state = 0, .external_lex_state = 33},
  [1992] = {.lex_state = 0, .external_lex_state = 33},
  [1993] = {.lex_state = 0, .external_lex_state = 33},
  [1994] = {.lex_state = 0, .external_lex_state = 33},
  [1995] = {.lex_state = 0, .external_lex_state = 33},
  [1996] = {.lex_state = 0, .external_lex_state = 32},
  [1997] = {.lex_state = 0, .external_lex_state = 33},
  [1998] = {.lex_state = 0, .external_lex_state = 33},
  [1999] = {.lex_state = 0, .external_lex_state = 33},
  [2000] = {.lex_state = 0, .external_lex_state = 33},
  [2001] = {.lex_state = 0, .external_lex_state = 33},
  [2002] = {.lex_state = 0, .external_lex_state = 33},
  [2003] = {.lex_state = 0, .external_lex_state = 33},
  [2004] = {.lex_state = 0, .external_lex_state = 33},
  [2005] = {.lex_state = 0, .external_lex_state = 33},
  [2006] = {.lex_state = 0, .external_lex_state = 33},
  [2007] = {.lex_state = 0, .external_lex_state = 33},
  [2008] = {.lex_state = 0, .external_lex_state = 33},
  [2009] = {.lex_state = 0, .external_lex_state = 33},
  [2010] = {.lex_state = 0, .external_lex_state = 33},
  [2011] = {.lex_state = 0, .external_lex_state = 33},
  [2012] = {.lex_state = 0, .external_lex_state = 33},
  [2013] = {.lex_state = 0, .external_lex_state = 33},
  [2014] = {.lex_state = 0, .external_lex_state = 33},
  [2015] = {.lex_state = 0, .external_lex_state = 33},
  [2016] = {.lex_state = 0, .external_lex_state = 33},
  [2017] = {.lex_state = 0, .external_lex_state = 33},
  [2018] = {.lex_state = 0, .external_lex_state = 33},
  [2019] = {.lex_state = 0, .external_lex_state = 33},
  [2020] = {.lex_state = 0, .external_lex_state = 32},
  [2021] = {.lex_state = 4},
  [2022] = {.lex_state = 1},
  [2023] = {.lex_state = 1},
  [2024] = {.lex_state = 1},
  [2025] = {.lex_state = 3},
  [2026] = {.lex_state = 1},
  [2027] = {.lex_state = 1},
  [2028] = {.lex_state = 1},
  [2029] = {.lex_state = 0, .external_lex_state = 34},
  [2030] = {.lex_state = 1},
  [2031] = {.lex_state = 1},
  [2032] = {.lex_state = 0, .external_lex_state = 32},
  [2033] = {.lex_state = 1},
  [2034] = {.lex_state = 1},
  [2035] = {.lex_state = 0, .external_lex_state = 32},
  [2036] = {.lex_state = 1},
  [2037] = {.lex_state = 1},
  [2038] = {.lex_state = 0, .external_lex_state = 32},
  [2039] = {.lex_state = 1},
  [2040] = {.lex_state = 1},
  [2041] = {.lex_state = 0, .external_lex_state = 32},
  [2042] = {.lex_state = 1},
  [2043] = {.lex_state = 1},
  [2044] = {.lex_state = 1},
  [2045] = {.lex_state = 1},
  [2046] = {.lex_state = 1},
  [2047] = {.lex_state = 1},
  [2048] = {.lex_state = 0, .external_lex_state = 33},
  [2049] = {.lex_state = 0, .external_lex_state = 35},
  [2050] = {.lex_state = 0, .external_lex_state = 32},
  [2051] = {.lex_state = 0, .external_lex_state = 36},
  [2052] = {.lex_state = 0, .external_lex_state = 36},
  [2053] = {.lex_state = 0, .external_lex_state = 36},
  [2054] = {.lex_state = 0, .external_lex_state = 35},
  [2055] = {.lex_state = 0, .external_lex_state = 36},
  [2056] = {.lex_state = 0, .external_lex_state = 32},
  [2057] = {.lex_state = 0, .external_lex_state = 32},
  [2058] = {.lex_state = 0, .external_lex_state = 36},
  [2059] = {.lex_state = 0, .external_lex_state = 34},
  [2060] = {.lex_state = 0, .external_lex_state = 35},
  [2061] = {.lex_state = 0, .external_lex_state = 32},
  [2062] = {.lex_state = 0, .external_lex_state = 34},
  [2063] = {.lex_state = 0, .external_lex_state = 36},
  [2064] = {.lex_state = 0, .external_lex_state = 32},
  [2065] = {.lex_state = 0, .external_lex_state = 34},
  [2066] = {.lex_state = 0, .external_lex_state = 32},
  [2067] = {.lex_state = 0, .external_lex_state = 36},
  [2068] = {.lex_state = 0, .external_lex_state = 34},
  [2069] = {.lex_state = 0, .external_lex_state = 36},
  [2070] = {.lex_state = 0, .external_lex_state = 32},
  [2071] = {.lex_state = 0, .external_lex_state = 34},
  [2072] = {.lex_state = 0, .external_lex_state = 36},
  [2073] = {.lex_state = 0, .external_lex_state = 36},
  [2074] = {.lex_state = 0, .external_lex_state = 32},
  [2075] = {.lex_state = 0, .external_lex_state = 35},
  [2076] = {.lex_state = 0, .external_lex_state = 35},
  [2077] = {.lex_state = 0, .external_lex_state = 35},
  [2078] = {.lex_state = 2},
  [2079] = {.lex_state = 2},
  [2080] = {.lex_state = 0, .external_lex_state = 37},
  [2081] = {.lex_state = 0, .external_lex_state = 37},
  [2082] = {.lex_state = 0},
  [2083] = {.lex_state = 2},
  [2084] = {.lex_state = 2},
  [2085] = {.lex_state = 0},
  [2086] = {.lex_state = 2},
  [2087] = {.lex_state = 2},
  [2088] = {.lex_state = 2},
  [2089] = {.lex_state = 0, .external_lex_state = 37},
  [2090] = {.lex_state = 2},
  [2091] = {.lex_state = 2},
  [2092] = {.lex_state = 2},
  [2093] = {.lex_state = 0, .external_lex_state = 37},
  [2094] = {.lex_state = 0, .external_lex_state = 37},
  [2095] = {.lex_state = 2},
  [2096] = {.lex_state = 0, .external_lex_state = 37},
  [2097] = {.lex_state = 2},
  [2098] = {.lex_state = 0},
  [2099] = {.lex_state = 2},
  [2100] = {.lex_state = 0, .external_lex_state = 37},
  [2101] = {.lex_state = 0, .external_lex_state = 37},
  [2102] = {.lex_state = 0, .external_lex_state = 37},
  [2103] = {.lex_state = 2},
  [2104] = {.lex_state = 2},
  [2105] = {.lex_state = 2},
  [2106] = {.lex_state = 0},
  [2107] = {.lex_state = 2},
  [2108] = {.lex_state = 0, .external_lex_state = 37},
  [2109] = {.lex_state = 2},
  [2110] = {.lex_state = 2},
  [2111] = {.lex_state = 2},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [0] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [sym_identifier] = ACTIONS(1),
    [anon_sym_BSLASH] = ACTIONS(1),
    [anon_sym_function] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_if] = ACTIONS(1),
    [anon_sym_for] = ACTIONS(1),
    [anon_sym_in] = ACTIONS(1),
    [anon_sym_while] = ACTIONS(1),
    [anon_sym_repeat] = ACTIONS(1),
    [anon_sym_QMARK] = ACTIONS(1),
    [anon_sym_TILDE] = ACTIONS(1),
    [anon_sym_BANG] = ACTIONS(1),
    [anon_sym_PLUS] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [anon_sym_LT_DASH] = ACTIONS(1),
    [anon_sym_LT_LT_DASH] = ACTIONS(1),
    [anon_sym_COLON_EQ] = ACTIONS(1),
    [anon_sym_DASH_GT] = ACTIONS(1),
    [anon_sym_DASH_GT_GT] = ACTIONS(1),
    [anon_sym_PIPE] = ACTIONS(1),
    [anon_sym_AMP] = ACTIONS(1),
    [anon_sym_PIPE_PIPE] = ACTIONS(1),
    [anon_sym_AMP_AMP] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [anon_sym_LT_EQ] = ACTIONS(1),
    [anon_sym_GT] = ACTIONS(1),
    [anon_sym_GT_EQ] = ACTIONS(1),
    [anon_sym_EQ_EQ] = ACTIONS(1),
    [anon_sym_BANG_EQ] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym_SLASH] = ACTIONS(1),
    [anon_sym_STAR_STAR] = ACTIONS(1),
    [anon_sym_CARET] = ACTIONS(1),
    [aux_sym_binary_operator_token1] = ACTIONS(1),
    [anon_sym_PIPE_GT] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym_DOLLAR] = ACTIONS(1),
    [anon_sym_AT] = ACTIONS(1),
    [anon_sym_COLON_COLON] = ACTIONS(1),
    [anon_sym_COLON_COLON_COLON] = ACTIONS(1),
    [anon_sym_L] = ACTIONS(1),
    [anon_sym_i] = ACTIONS(1),
    [sym__hex_literal] = ACTIONS(1),
    [sym__number_literal] = ACTIONS(1),
    [anon_sym_SQUOTE] = ACTIONS(1),
    [anon_sym_DQUOTE] = ACTIONS(1),
    [sym_dots] = ACTIONS(1),
    [sym_dot_dot_i] = ACTIONS(1),
    [sym_next] = ACTIONS(1),
    [sym_break] = ACTIONS(1),
    [sym_true] = ACTIONS(1),
    [sym_false] = ACTIONS(1),
    [sym_null] = ACTIONS(1),
    [sym_inf] = ACTIONS(1),
    [sym_nan] = ACTIONS(1),
    [anon_sym_NA] = ACTIONS(1),
    [anon_sym_NA_integer_] = ACTIONS(1),
    [anon_sym_NA_real_] = ACTIONS(1),
    [anon_sym_NA_complex_] = ACTIONS(1),
    [anon_sym_NA_character_] = ACTIONS(1),
    [sym_comment] = ACTIONS(3),
    [sym_comma] = ACTIONS(1),
    [sym__start] = ACTIONS(1),
    [sym__newline] = ACTIONS(1),
    [sym__semicolon] = ACTIONS(1),
    [sym__raw_string_open] = ACTIONS(1),
    [sym__raw_string_content] = ACTIONS(1),
    [sym__raw_string_close] = ACTIONS(1),
    [sym__external_else] = ACTIONS(1),
    [sym__external_open_parenthesis] = ACTIONS(1),
    [sym__external_close_parenthesis] = ACTIONS(1),
    [sym__external_open_brace] = ACTIONS(1),
    [sym__external_close_brace] = ACTIONS(1),
    [sym__external_open_bracket] = ACTIONS(1),
    [sym__external_close_bracket] = ACTIONS(1),
    [sym__external_open_bracket2] = ACTIONS(1),
    [sym__external_close_bracket2] = ACTIONS(1),
    [sym__error_sentinel] = ACTIONS(1),
  },
  [1] = {
    [sym_program] = STATE(2098),
    [sym_comment] = ACTIONS(3),
    [sym__start] = ACTIONS(5),
  },
  [2] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__else] = STATE(510),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(7),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_BSLASH] = ACTIONS(7),
    [anon_sym_function] = ACTIONS(9),
    [anon_sym_EQ] = ACTIONS(11),
    [anon_sym_if] = ACTIONS(9),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_while] = ACTIONS(9),
    [anon_sym_repeat] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(7),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_BANG] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(19),
    [anon_sym_LT_LT_DASH] = ACTIONS(19),
    [anon_sym_COLON_EQ] = ACTIONS(19),
    [anon_sym_DASH_GT] = ACTIONS(21),
    [anon_sym_DASH_GT_GT] = ACTIONS(23),
    [anon_sym_PIPE] = ACTIONS(25),
    [anon_sym_AMP] = ACTIONS(27),
    [anon_sym_PIPE_PIPE] = ACTIONS(29),
    [anon_sym_AMP_AMP] = ACTIONS(31),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(7),
    [sym__number_literal] = ACTIONS(9),
    [anon_sym_SQUOTE] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(7),
    [sym_dots] = ACTIONS(9),
    [sym_dot_dot_i] = ACTIONS(9),
    [sym_next] = ACTIONS(9),
    [sym_break] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_null] = ACTIONS(9),
    [sym_inf] = ACTIONS(9),
    [sym_nan] = ACTIONS(9),
    [anon_sym_NA] = ACTIONS(9),
    [anon_sym_NA_integer_] = ACTIONS(9),
    [anon_sym_NA_real_] = ACTIONS(9),
    [anon_sym_NA_complex_] = ACTIONS(9),
    [anon_sym_NA_character_] = ACTIONS(9),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(7),
    [sym__semicolon] = ACTIONS(7),
    [sym__raw_string_open] = ACTIONS(7),
    [sym__external_else] = ACTIONS(49),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(7),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [3] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__else] = STATE(833),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(57),
    [anon_sym_BSLASH] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(57),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(57),
    [anon_sym_for] = ACTIONS(57),
    [anon_sym_while] = ACTIONS(57),
    [anon_sym_repeat] = ACTIONS(57),
    [anon_sym_QMARK] = ACTIONS(59),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_BANG] = ACTIONS(57),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(69),
    [anon_sym_LT_LT_DASH] = ACTIONS(69),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(71),
    [anon_sym_DASH_GT_GT] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(77),
    [anon_sym_PIPE_PIPE] = ACTIONS(79),
    [anon_sym_AMP_AMP] = ACTIONS(81),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(59),
    [sym__number_literal] = ACTIONS(57),
    [anon_sym_SQUOTE] = ACTIONS(59),
    [anon_sym_DQUOTE] = ACTIONS(59),
    [sym_dots] = ACTIONS(57),
    [sym_dot_dot_i] = ACTIONS(57),
    [sym_next] = ACTIONS(57),
    [sym_break] = ACTIONS(57),
    [sym_true] = ACTIONS(57),
    [sym_false] = ACTIONS(57),
    [sym_null] = ACTIONS(57),
    [sym_inf] = ACTIONS(57),
    [sym_nan] = ACTIONS(57),
    [anon_sym_NA] = ACTIONS(57),
    [anon_sym_NA_integer_] = ACTIONS(57),
    [anon_sym_NA_real_] = ACTIONS(57),
    [anon_sym_NA_complex_] = ACTIONS(57),
    [anon_sym_NA_character_] = ACTIONS(57),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(59),
    [sym__semicolon] = ACTIONS(59),
    [sym__raw_string_open] = ACTIONS(59),
    [sym__external_else] = ACTIONS(99),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(59),
    [sym__external_close_brace] = ACTIONS(59),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [4] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__else] = STATE(620),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(107),
    [sym_identifier] = ACTIONS(109),
    [anon_sym_BSLASH] = ACTIONS(107),
    [anon_sym_function] = ACTIONS(109),
    [anon_sym_EQ] = ACTIONS(11),
    [anon_sym_if] = ACTIONS(109),
    [anon_sym_for] = ACTIONS(109),
    [anon_sym_while] = ACTIONS(109),
    [anon_sym_repeat] = ACTIONS(109),
    [anon_sym_QMARK] = ACTIONS(107),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_BANG] = ACTIONS(109),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(19),
    [anon_sym_LT_LT_DASH] = ACTIONS(19),
    [anon_sym_COLON_EQ] = ACTIONS(19),
    [anon_sym_DASH_GT] = ACTIONS(21),
    [anon_sym_DASH_GT_GT] = ACTIONS(23),
    [anon_sym_PIPE] = ACTIONS(25),
    [anon_sym_AMP] = ACTIONS(27),
    [anon_sym_PIPE_PIPE] = ACTIONS(29),
    [anon_sym_AMP_AMP] = ACTIONS(31),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(107),
    [sym__number_literal] = ACTIONS(109),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_dots] = ACTIONS(109),
    [sym_dot_dot_i] = ACTIONS(109),
    [sym_next] = ACTIONS(109),
    [sym_break] = ACTIONS(109),
    [sym_true] = ACTIONS(109),
    [sym_false] = ACTIONS(109),
    [sym_null] = ACTIONS(109),
    [sym_inf] = ACTIONS(109),
    [sym_nan] = ACTIONS(109),
    [anon_sym_NA] = ACTIONS(109),
    [anon_sym_NA_integer_] = ACTIONS(109),
    [anon_sym_NA_real_] = ACTIONS(109),
    [anon_sym_NA_complex_] = ACTIONS(109),
    [anon_sym_NA_character_] = ACTIONS(109),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(107),
    [sym__semicolon] = ACTIONS(107),
    [sym__raw_string_open] = ACTIONS(107),
    [sym__external_else] = ACTIONS(111),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(107),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [5] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__else] = STATE(634),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(59),
    [sym_identifier] = ACTIONS(57),
    [anon_sym_BSLASH] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(57),
    [anon_sym_EQ] = ACTIONS(11),
    [anon_sym_if] = ACTIONS(57),
    [anon_sym_for] = ACTIONS(57),
    [anon_sym_while] = ACTIONS(57),
    [anon_sym_repeat] = ACTIONS(57),
    [anon_sym_QMARK] = ACTIONS(59),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_BANG] = ACTIONS(57),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(19),
    [anon_sym_LT_LT_DASH] = ACTIONS(19),
    [anon_sym_COLON_EQ] = ACTIONS(19),
    [anon_sym_DASH_GT] = ACTIONS(21),
    [anon_sym_DASH_GT_GT] = ACTIONS(23),
    [anon_sym_PIPE] = ACTIONS(25),
    [anon_sym_AMP] = ACTIONS(27),
    [anon_sym_PIPE_PIPE] = ACTIONS(29),
    [anon_sym_AMP_AMP] = ACTIONS(31),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(59),
    [sym__number_literal] = ACTIONS(57),
    [anon_sym_SQUOTE] = ACTIONS(59),
    [anon_sym_DQUOTE] = ACTIONS(59),
    [sym_dots] = ACTIONS(57),
    [sym_dot_dot_i] = ACTIONS(57),
    [sym_next] = ACTIONS(57),
    [sym_break] = ACTIONS(57),
    [sym_true] = ACTIONS(57),
    [sym_false] = ACTIONS(57),
    [sym_null] = ACTIONS(57),
    [sym_inf] = ACTIONS(57),
    [sym_nan] = ACTIONS(57),
    [anon_sym_NA] = ACTIONS(57),
    [anon_sym_NA_integer_] = ACTIONS(57),
    [anon_sym_NA_real_] = ACTIONS(57),
    [anon_sym_NA_complex_] = ACTIONS(57),
    [anon_sym_NA_character_] = ACTIONS(57),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(59),
    [sym__semicolon] = ACTIONS(59),
    [sym__raw_string_open] = ACTIONS(59),
    [sym__external_else] = ACTIONS(113),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(59),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [6] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__else] = STATE(619),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(115),
    [sym_identifier] = ACTIONS(117),
    [anon_sym_BSLASH] = ACTIONS(115),
    [anon_sym_function] = ACTIONS(117),
    [anon_sym_EQ] = ACTIONS(11),
    [anon_sym_if] = ACTIONS(117),
    [anon_sym_for] = ACTIONS(117),
    [anon_sym_while] = ACTIONS(117),
    [anon_sym_repeat] = ACTIONS(117),
    [anon_sym_QMARK] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_BANG] = ACTIONS(117),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(19),
    [anon_sym_LT_LT_DASH] = ACTIONS(19),
    [anon_sym_COLON_EQ] = ACTIONS(19),
    [anon_sym_DASH_GT] = ACTIONS(21),
    [anon_sym_DASH_GT_GT] = ACTIONS(23),
    [anon_sym_PIPE] = ACTIONS(25),
    [anon_sym_AMP] = ACTIONS(27),
    [anon_sym_PIPE_PIPE] = ACTIONS(29),
    [anon_sym_AMP_AMP] = ACTIONS(31),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(115),
    [sym__number_literal] = ACTIONS(117),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_dots] = ACTIONS(117),
    [sym_dot_dot_i] = ACTIONS(117),
    [sym_next] = ACTIONS(117),
    [sym_break] = ACTIONS(117),
    [sym_true] = ACTIONS(117),
    [sym_false] = ACTIONS(117),
    [sym_null] = ACTIONS(117),
    [sym_inf] = ACTIONS(117),
    [sym_nan] = ACTIONS(117),
    [anon_sym_NA] = ACTIONS(117),
    [anon_sym_NA_integer_] = ACTIONS(117),
    [anon_sym_NA_real_] = ACTIONS(117),
    [anon_sym_NA_complex_] = ACTIONS(117),
    [anon_sym_NA_character_] = ACTIONS(117),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(115),
    [sym__semicolon] = ACTIONS(115),
    [sym__raw_string_open] = ACTIONS(115),
    [sym__external_else] = ACTIONS(119),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(115),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [7] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__else] = STATE(494),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_BSLASH] = ACTIONS(7),
    [anon_sym_function] = ACTIONS(9),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(9),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_while] = ACTIONS(9),
    [anon_sym_repeat] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(7),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_BANG] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(69),
    [anon_sym_LT_LT_DASH] = ACTIONS(69),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(71),
    [anon_sym_DASH_GT_GT] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(77),
    [anon_sym_PIPE_PIPE] = ACTIONS(79),
    [anon_sym_AMP_AMP] = ACTIONS(81),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(7),
    [sym__number_literal] = ACTIONS(9),
    [anon_sym_SQUOTE] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(7),
    [sym_dots] = ACTIONS(9),
    [sym_dot_dot_i] = ACTIONS(9),
    [sym_next] = ACTIONS(9),
    [sym_break] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_null] = ACTIONS(9),
    [sym_inf] = ACTIONS(9),
    [sym_nan] = ACTIONS(9),
    [anon_sym_NA] = ACTIONS(9),
    [anon_sym_NA_integer_] = ACTIONS(9),
    [anon_sym_NA_real_] = ACTIONS(9),
    [anon_sym_NA_complex_] = ACTIONS(9),
    [anon_sym_NA_character_] = ACTIONS(9),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(7),
    [sym__semicolon] = ACTIONS(7),
    [sym__raw_string_open] = ACTIONS(7),
    [sym__external_else] = ACTIONS(121),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(7),
    [sym__external_close_brace] = ACTIONS(7),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [8] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__else] = STATE(500),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(117),
    [anon_sym_BSLASH] = ACTIONS(115),
    [anon_sym_function] = ACTIONS(117),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(117),
    [anon_sym_for] = ACTIONS(117),
    [anon_sym_while] = ACTIONS(117),
    [anon_sym_repeat] = ACTIONS(117),
    [anon_sym_QMARK] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_BANG] = ACTIONS(117),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(69),
    [anon_sym_LT_LT_DASH] = ACTIONS(69),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(71),
    [anon_sym_DASH_GT_GT] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(77),
    [anon_sym_PIPE_PIPE] = ACTIONS(79),
    [anon_sym_AMP_AMP] = ACTIONS(81),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(115),
    [sym__number_literal] = ACTIONS(117),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_dots] = ACTIONS(117),
    [sym_dot_dot_i] = ACTIONS(117),
    [sym_next] = ACTIONS(117),
    [sym_break] = ACTIONS(117),
    [sym_true] = ACTIONS(117),
    [sym_false] = ACTIONS(117),
    [sym_null] = ACTIONS(117),
    [sym_inf] = ACTIONS(117),
    [sym_nan] = ACTIONS(117),
    [anon_sym_NA] = ACTIONS(117),
    [anon_sym_NA_integer_] = ACTIONS(117),
    [anon_sym_NA_real_] = ACTIONS(117),
    [anon_sym_NA_complex_] = ACTIONS(117),
    [anon_sym_NA_character_] = ACTIONS(117),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(115),
    [sym__semicolon] = ACTIONS(115),
    [sym__raw_string_open] = ACTIONS(115),
    [sym__external_else] = ACTIONS(123),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(115),
    [sym__external_close_brace] = ACTIONS(115),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [9] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__else] = STATE(501),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(109),
    [anon_sym_BSLASH] = ACTIONS(107),
    [anon_sym_function] = ACTIONS(109),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(109),
    [anon_sym_for] = ACTIONS(109),
    [anon_sym_while] = ACTIONS(109),
    [anon_sym_repeat] = ACTIONS(109),
    [anon_sym_QMARK] = ACTIONS(107),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_BANG] = ACTIONS(109),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(69),
    [anon_sym_LT_LT_DASH] = ACTIONS(69),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(71),
    [anon_sym_DASH_GT_GT] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(77),
    [anon_sym_PIPE_PIPE] = ACTIONS(79),
    [anon_sym_AMP_AMP] = ACTIONS(81),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(107),
    [sym__number_literal] = ACTIONS(109),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_dots] = ACTIONS(109),
    [sym_dot_dot_i] = ACTIONS(109),
    [sym_next] = ACTIONS(109),
    [sym_break] = ACTIONS(109),
    [sym_true] = ACTIONS(109),
    [sym_false] = ACTIONS(109),
    [sym_null] = ACTIONS(109),
    [sym_inf] = ACTIONS(109),
    [sym_nan] = ACTIONS(109),
    [anon_sym_NA] = ACTIONS(109),
    [anon_sym_NA_integer_] = ACTIONS(109),
    [anon_sym_NA_real_] = ACTIONS(109),
    [anon_sym_NA_complex_] = ACTIONS(109),
    [anon_sym_NA_character_] = ACTIONS(109),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(107),
    [sym__semicolon] = ACTIONS(107),
    [sym__raw_string_open] = ACTIONS(107),
    [sym__external_else] = ACTIONS(125),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(107),
    [sym__external_close_brace] = ACTIONS(107),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [10] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__else] = STATE(509),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(57),
    [anon_sym_BSLASH] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(57),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(57),
    [anon_sym_for] = ACTIONS(57),
    [anon_sym_while] = ACTIONS(57),
    [anon_sym_repeat] = ACTIONS(57),
    [anon_sym_QMARK] = ACTIONS(59),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_BANG] = ACTIONS(57),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(69),
    [anon_sym_LT_LT_DASH] = ACTIONS(69),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(71),
    [anon_sym_DASH_GT_GT] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(77),
    [anon_sym_PIPE_PIPE] = ACTIONS(79),
    [anon_sym_AMP_AMP] = ACTIONS(81),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(59),
    [sym__number_literal] = ACTIONS(57),
    [anon_sym_SQUOTE] = ACTIONS(59),
    [anon_sym_DQUOTE] = ACTIONS(59),
    [sym_dots] = ACTIONS(57),
    [sym_dot_dot_i] = ACTIONS(57),
    [sym_next] = ACTIONS(57),
    [sym_break] = ACTIONS(57),
    [sym_true] = ACTIONS(57),
    [sym_false] = ACTIONS(57),
    [sym_null] = ACTIONS(57),
    [sym_inf] = ACTIONS(57),
    [sym_nan] = ACTIONS(57),
    [anon_sym_NA] = ACTIONS(57),
    [anon_sym_NA_integer_] = ACTIONS(57),
    [anon_sym_NA_real_] = ACTIONS(57),
    [anon_sym_NA_complex_] = ACTIONS(57),
    [anon_sym_NA_character_] = ACTIONS(57),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(59),
    [sym__semicolon] = ACTIONS(59),
    [sym__raw_string_open] = ACTIONS(59),
    [sym__external_else] = ACTIONS(127),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(59),
    [sym__external_close_brace] = ACTIONS(59),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [11] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__else] = STATE(694),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(7),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_BSLASH] = ACTIONS(7),
    [anon_sym_function] = ACTIONS(9),
    [anon_sym_EQ] = ACTIONS(11),
    [anon_sym_if] = ACTIONS(9),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_while] = ACTIONS(9),
    [anon_sym_repeat] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(7),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_BANG] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(19),
    [anon_sym_LT_LT_DASH] = ACTIONS(19),
    [anon_sym_COLON_EQ] = ACTIONS(19),
    [anon_sym_DASH_GT] = ACTIONS(21),
    [anon_sym_DASH_GT_GT] = ACTIONS(23),
    [anon_sym_PIPE] = ACTIONS(25),
    [anon_sym_AMP] = ACTIONS(27),
    [anon_sym_PIPE_PIPE] = ACTIONS(29),
    [anon_sym_AMP_AMP] = ACTIONS(31),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(7),
    [sym__number_literal] = ACTIONS(9),
    [anon_sym_SQUOTE] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(7),
    [sym_dots] = ACTIONS(9),
    [sym_dot_dot_i] = ACTIONS(9),
    [sym_next] = ACTIONS(9),
    [sym_break] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_null] = ACTIONS(9),
    [sym_inf] = ACTIONS(9),
    [sym_nan] = ACTIONS(9),
    [anon_sym_NA] = ACTIONS(9),
    [anon_sym_NA_integer_] = ACTIONS(9),
    [anon_sym_NA_real_] = ACTIONS(9),
    [anon_sym_NA_complex_] = ACTIONS(9),
    [anon_sym_NA_character_] = ACTIONS(9),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(7),
    [sym__semicolon] = ACTIONS(7),
    [sym__raw_string_open] = ACTIONS(7),
    [sym__external_else] = ACTIONS(129),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(7),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [12] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__else] = STATE(700),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(115),
    [sym_identifier] = ACTIONS(117),
    [anon_sym_BSLASH] = ACTIONS(115),
    [anon_sym_function] = ACTIONS(117),
    [anon_sym_EQ] = ACTIONS(11),
    [anon_sym_if] = ACTIONS(117),
    [anon_sym_for] = ACTIONS(117),
    [anon_sym_while] = ACTIONS(117),
    [anon_sym_repeat] = ACTIONS(117),
    [anon_sym_QMARK] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_BANG] = ACTIONS(117),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(19),
    [anon_sym_LT_LT_DASH] = ACTIONS(19),
    [anon_sym_COLON_EQ] = ACTIONS(19),
    [anon_sym_DASH_GT] = ACTIONS(21),
    [anon_sym_DASH_GT_GT] = ACTIONS(23),
    [anon_sym_PIPE] = ACTIONS(25),
    [anon_sym_AMP] = ACTIONS(27),
    [anon_sym_PIPE_PIPE] = ACTIONS(29),
    [anon_sym_AMP_AMP] = ACTIONS(31),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(115),
    [sym__number_literal] = ACTIONS(117),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_dots] = ACTIONS(117),
    [sym_dot_dot_i] = ACTIONS(117),
    [sym_next] = ACTIONS(117),
    [sym_break] = ACTIONS(117),
    [sym_true] = ACTIONS(117),
    [sym_false] = ACTIONS(117),
    [sym_null] = ACTIONS(117),
    [sym_inf] = ACTIONS(117),
    [sym_nan] = ACTIONS(117),
    [anon_sym_NA] = ACTIONS(117),
    [anon_sym_NA_integer_] = ACTIONS(117),
    [anon_sym_NA_real_] = ACTIONS(117),
    [anon_sym_NA_complex_] = ACTIONS(117),
    [anon_sym_NA_character_] = ACTIONS(117),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(115),
    [sym__semicolon] = ACTIONS(115),
    [sym__raw_string_open] = ACTIONS(115),
    [sym__external_else] = ACTIONS(131),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(115),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [13] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__else] = STATE(701),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(107),
    [sym_identifier] = ACTIONS(109),
    [anon_sym_BSLASH] = ACTIONS(107),
    [anon_sym_function] = ACTIONS(109),
    [anon_sym_EQ] = ACTIONS(11),
    [anon_sym_if] = ACTIONS(109),
    [anon_sym_for] = ACTIONS(109),
    [anon_sym_while] = ACTIONS(109),
    [anon_sym_repeat] = ACTIONS(109),
    [anon_sym_QMARK] = ACTIONS(107),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_BANG] = ACTIONS(109),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(19),
    [anon_sym_LT_LT_DASH] = ACTIONS(19),
    [anon_sym_COLON_EQ] = ACTIONS(19),
    [anon_sym_DASH_GT] = ACTIONS(21),
    [anon_sym_DASH_GT_GT] = ACTIONS(23),
    [anon_sym_PIPE] = ACTIONS(25),
    [anon_sym_AMP] = ACTIONS(27),
    [anon_sym_PIPE_PIPE] = ACTIONS(29),
    [anon_sym_AMP_AMP] = ACTIONS(31),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(107),
    [sym__number_literal] = ACTIONS(109),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_dots] = ACTIONS(109),
    [sym_dot_dot_i] = ACTIONS(109),
    [sym_next] = ACTIONS(109),
    [sym_break] = ACTIONS(109),
    [sym_true] = ACTIONS(109),
    [sym_false] = ACTIONS(109),
    [sym_null] = ACTIONS(109),
    [sym_inf] = ACTIONS(109),
    [sym_nan] = ACTIONS(109),
    [anon_sym_NA] = ACTIONS(109),
    [anon_sym_NA_integer_] = ACTIONS(109),
    [anon_sym_NA_real_] = ACTIONS(109),
    [anon_sym_NA_complex_] = ACTIONS(109),
    [anon_sym_NA_character_] = ACTIONS(109),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(107),
    [sym__semicolon] = ACTIONS(107),
    [sym__raw_string_open] = ACTIONS(107),
    [sym__external_else] = ACTIONS(133),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(107),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [14] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__else] = STATE(708),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(59),
    [sym_identifier] = ACTIONS(57),
    [anon_sym_BSLASH] = ACTIONS(59),
    [anon_sym_function] = ACTIONS(57),
    [anon_sym_EQ] = ACTIONS(11),
    [anon_sym_if] = ACTIONS(57),
    [anon_sym_for] = ACTIONS(57),
    [anon_sym_while] = ACTIONS(57),
    [anon_sym_repeat] = ACTIONS(57),
    [anon_sym_QMARK] = ACTIONS(59),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_BANG] = ACTIONS(57),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(19),
    [anon_sym_LT_LT_DASH] = ACTIONS(19),
    [anon_sym_COLON_EQ] = ACTIONS(19),
    [anon_sym_DASH_GT] = ACTIONS(21),
    [anon_sym_DASH_GT_GT] = ACTIONS(23),
    [anon_sym_PIPE] = ACTIONS(25),
    [anon_sym_AMP] = ACTIONS(27),
    [anon_sym_PIPE_PIPE] = ACTIONS(29),
    [anon_sym_AMP_AMP] = ACTIONS(31),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(59),
    [sym__number_literal] = ACTIONS(57),
    [anon_sym_SQUOTE] = ACTIONS(59),
    [anon_sym_DQUOTE] = ACTIONS(59),
    [sym_dots] = ACTIONS(57),
    [sym_dot_dot_i] = ACTIONS(57),
    [sym_next] = ACTIONS(57),
    [sym_break] = ACTIONS(57),
    [sym_true] = ACTIONS(57),
    [sym_false] = ACTIONS(57),
    [sym_null] = ACTIONS(57),
    [sym_inf] = ACTIONS(57),
    [sym_nan] = ACTIONS(57),
    [anon_sym_NA] = ACTIONS(57),
    [anon_sym_NA_integer_] = ACTIONS(57),
    [anon_sym_NA_real_] = ACTIONS(57),
    [anon_sym_NA_complex_] = ACTIONS(57),
    [anon_sym_NA_character_] = ACTIONS(57),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(59),
    [sym__semicolon] = ACTIONS(59),
    [sym__raw_string_open] = ACTIONS(59),
    [sym__external_else] = ACTIONS(135),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(59),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [15] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__else] = STATE(820),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_BSLASH] = ACTIONS(7),
    [anon_sym_function] = ACTIONS(9),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(9),
    [anon_sym_for] = ACTIONS(9),
    [anon_sym_while] = ACTIONS(9),
    [anon_sym_repeat] = ACTIONS(9),
    [anon_sym_QMARK] = ACTIONS(7),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_BANG] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(69),
    [anon_sym_LT_LT_DASH] = ACTIONS(69),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(71),
    [anon_sym_DASH_GT_GT] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(77),
    [anon_sym_PIPE_PIPE] = ACTIONS(79),
    [anon_sym_AMP_AMP] = ACTIONS(81),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(7),
    [sym__number_literal] = ACTIONS(9),
    [anon_sym_SQUOTE] = ACTIONS(7),
    [anon_sym_DQUOTE] = ACTIONS(7),
    [sym_dots] = ACTIONS(9),
    [sym_dot_dot_i] = ACTIONS(9),
    [sym_next] = ACTIONS(9),
    [sym_break] = ACTIONS(9),
    [sym_true] = ACTIONS(9),
    [sym_false] = ACTIONS(9),
    [sym_null] = ACTIONS(9),
    [sym_inf] = ACTIONS(9),
    [sym_nan] = ACTIONS(9),
    [anon_sym_NA] = ACTIONS(9),
    [anon_sym_NA_integer_] = ACTIONS(9),
    [anon_sym_NA_real_] = ACTIONS(9),
    [anon_sym_NA_complex_] = ACTIONS(9),
    [anon_sym_NA_character_] = ACTIONS(9),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(7),
    [sym__semicolon] = ACTIONS(7),
    [sym__raw_string_open] = ACTIONS(7),
    [sym__external_else] = ACTIONS(137),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(7),
    [sym__external_close_brace] = ACTIONS(7),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [16] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__else] = STATE(825),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(117),
    [anon_sym_BSLASH] = ACTIONS(115),
    [anon_sym_function] = ACTIONS(117),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(117),
    [anon_sym_for] = ACTIONS(117),
    [anon_sym_while] = ACTIONS(117),
    [anon_sym_repeat] = ACTIONS(117),
    [anon_sym_QMARK] = ACTIONS(115),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_BANG] = ACTIONS(117),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(69),
    [anon_sym_LT_LT_DASH] = ACTIONS(69),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(71),
    [anon_sym_DASH_GT_GT] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(77),
    [anon_sym_PIPE_PIPE] = ACTIONS(79),
    [anon_sym_AMP_AMP] = ACTIONS(81),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(115),
    [sym__number_literal] = ACTIONS(117),
    [anon_sym_SQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_dots] = ACTIONS(117),
    [sym_dot_dot_i] = ACTIONS(117),
    [sym_next] = ACTIONS(117),
    [sym_break] = ACTIONS(117),
    [sym_true] = ACTIONS(117),
    [sym_false] = ACTIONS(117),
    [sym_null] = ACTIONS(117),
    [sym_inf] = ACTIONS(117),
    [sym_nan] = ACTIONS(117),
    [anon_sym_NA] = ACTIONS(117),
    [anon_sym_NA_integer_] = ACTIONS(117),
    [anon_sym_NA_real_] = ACTIONS(117),
    [anon_sym_NA_complex_] = ACTIONS(117),
    [anon_sym_NA_character_] = ACTIONS(117),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(115),
    [sym__semicolon] = ACTIONS(115),
    [sym__raw_string_open] = ACTIONS(115),
    [sym__external_else] = ACTIONS(139),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(115),
    [sym__external_close_brace] = ACTIONS(115),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [17] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__else] = STATE(826),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(109),
    [anon_sym_BSLASH] = ACTIONS(107),
    [anon_sym_function] = ACTIONS(109),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(109),
    [anon_sym_for] = ACTIONS(109),
    [anon_sym_while] = ACTIONS(109),
    [anon_sym_repeat] = ACTIONS(109),
    [anon_sym_QMARK] = ACTIONS(107),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_BANG] = ACTIONS(109),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(69),
    [anon_sym_LT_LT_DASH] = ACTIONS(69),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(71),
    [anon_sym_DASH_GT_GT] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(77),
    [anon_sym_PIPE_PIPE] = ACTIONS(79),
    [anon_sym_AMP_AMP] = ACTIONS(81),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(107),
    [sym__number_literal] = ACTIONS(109),
    [anon_sym_SQUOTE] = ACTIONS(107),
    [anon_sym_DQUOTE] = ACTIONS(107),
    [sym_dots] = ACTIONS(109),
    [sym_dot_dot_i] = ACTIONS(109),
    [sym_next] = ACTIONS(109),
    [sym_break] = ACTIONS(109),
    [sym_true] = ACTIONS(109),
    [sym_false] = ACTIONS(109),
    [sym_null] = ACTIONS(109),
    [sym_inf] = ACTIONS(109),
    [sym_nan] = ACTIONS(109),
    [anon_sym_NA] = ACTIONS(109),
    [anon_sym_NA_integer_] = ACTIONS(109),
    [anon_sym_NA_real_] = ACTIONS(109),
    [anon_sym_NA_complex_] = ACTIONS(109),
    [anon_sym_NA_character_] = ACTIONS(109),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(107),
    [sym__semicolon] = ACTIONS(107),
    [sym__raw_string_open] = ACTIONS(107),
    [sym__external_else] = ACTIONS(141),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(107),
    [sym__external_close_brace] = ACTIONS(107),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [18] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(143),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(143),
    [anon_sym_LT_LT_DASH] = ACTIONS(143),
    [anon_sym_COLON_EQ] = ACTIONS(143),
    [anon_sym_DASH_GT] = ACTIONS(145),
    [anon_sym_DASH_GT_GT] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(25),
    [anon_sym_AMP] = ACTIONS(27),
    [anon_sym_PIPE_PIPE] = ACTIONS(29),
    [anon_sym_AMP_AMP] = ACTIONS(31),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_else] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [19] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(147),
    [anon_sym_BSLASH] = ACTIONS(149),
    [anon_sym_function] = ACTIONS(147),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_for] = ACTIONS(147),
    [anon_sym_while] = ACTIONS(147),
    [anon_sym_repeat] = ACTIONS(147),
    [anon_sym_QMARK] = ACTIONS(149),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_BANG] = ACTIONS(147),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(69),
    [anon_sym_LT_LT_DASH] = ACTIONS(69),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(71),
    [anon_sym_DASH_GT_GT] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(77),
    [anon_sym_PIPE_PIPE] = ACTIONS(79),
    [anon_sym_AMP_AMP] = ACTIONS(81),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(149),
    [sym__number_literal] = ACTIONS(147),
    [anon_sym_SQUOTE] = ACTIONS(149),
    [anon_sym_DQUOTE] = ACTIONS(149),
    [sym_dots] = ACTIONS(147),
    [sym_dot_dot_i] = ACTIONS(147),
    [sym_next] = ACTIONS(147),
    [sym_break] = ACTIONS(147),
    [sym_true] = ACTIONS(147),
    [sym_false] = ACTIONS(147),
    [sym_null] = ACTIONS(147),
    [sym_inf] = ACTIONS(147),
    [sym_nan] = ACTIONS(147),
    [anon_sym_NA] = ACTIONS(147),
    [anon_sym_NA_integer_] = ACTIONS(147),
    [anon_sym_NA_real_] = ACTIONS(147),
    [anon_sym_NA_complex_] = ACTIONS(147),
    [anon_sym_NA_character_] = ACTIONS(147),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(149),
    [sym__semicolon] = ACTIONS(149),
    [sym__raw_string_open] = ACTIONS(149),
    [sym__external_else] = ACTIONS(149),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(149),
    [sym__external_close_brace] = ACTIONS(149),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [20] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(151),
    [sym_identifier] = ACTIONS(153),
    [anon_sym_BSLASH] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(153),
    [anon_sym_EQ] = ACTIONS(11),
    [anon_sym_if] = ACTIONS(153),
    [anon_sym_for] = ACTIONS(153),
    [anon_sym_while] = ACTIONS(153),
    [anon_sym_repeat] = ACTIONS(153),
    [anon_sym_QMARK] = ACTIONS(151),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_BANG] = ACTIONS(153),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(19),
    [anon_sym_LT_LT_DASH] = ACTIONS(19),
    [anon_sym_COLON_EQ] = ACTIONS(19),
    [anon_sym_DASH_GT] = ACTIONS(21),
    [anon_sym_DASH_GT_GT] = ACTIONS(23),
    [anon_sym_PIPE] = ACTIONS(25),
    [anon_sym_AMP] = ACTIONS(27),
    [anon_sym_PIPE_PIPE] = ACTIONS(29),
    [anon_sym_AMP_AMP] = ACTIONS(31),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(151),
    [sym__number_literal] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(151),
    [anon_sym_DQUOTE] = ACTIONS(151),
    [sym_dots] = ACTIONS(153),
    [sym_dot_dot_i] = ACTIONS(153),
    [sym_next] = ACTIONS(153),
    [sym_break] = ACTIONS(153),
    [sym_true] = ACTIONS(153),
    [sym_false] = ACTIONS(153),
    [sym_null] = ACTIONS(153),
    [sym_inf] = ACTIONS(153),
    [sym_nan] = ACTIONS(153),
    [anon_sym_NA] = ACTIONS(153),
    [anon_sym_NA_integer_] = ACTIONS(153),
    [anon_sym_NA_real_] = ACTIONS(153),
    [anon_sym_NA_complex_] = ACTIONS(153),
    [anon_sym_NA_character_] = ACTIONS(153),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(151),
    [sym__semicolon] = ACTIONS(151),
    [sym__raw_string_open] = ACTIONS(151),
    [sym__external_else] = ACTIONS(151),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(151),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [21] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(155),
    [sym_identifier] = ACTIONS(157),
    [anon_sym_BSLASH] = ACTIONS(155),
    [anon_sym_function] = ACTIONS(157),
    [anon_sym_EQ] = ACTIONS(11),
    [anon_sym_if] = ACTIONS(157),
    [anon_sym_for] = ACTIONS(157),
    [anon_sym_while] = ACTIONS(157),
    [anon_sym_repeat] = ACTIONS(157),
    [anon_sym_QMARK] = ACTIONS(155),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_BANG] = ACTIONS(157),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(19),
    [anon_sym_LT_LT_DASH] = ACTIONS(19),
    [anon_sym_COLON_EQ] = ACTIONS(19),
    [anon_sym_DASH_GT] = ACTIONS(21),
    [anon_sym_DASH_GT_GT] = ACTIONS(23),
    [anon_sym_PIPE] = ACTIONS(25),
    [anon_sym_AMP] = ACTIONS(27),
    [anon_sym_PIPE_PIPE] = ACTIONS(29),
    [anon_sym_AMP_AMP] = ACTIONS(31),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(155),
    [sym__number_literal] = ACTIONS(157),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [anon_sym_DQUOTE] = ACTIONS(155),
    [sym_dots] = ACTIONS(157),
    [sym_dot_dot_i] = ACTIONS(157),
    [sym_next] = ACTIONS(157),
    [sym_break] = ACTIONS(157),
    [sym_true] = ACTIONS(157),
    [sym_false] = ACTIONS(157),
    [sym_null] = ACTIONS(157),
    [sym_inf] = ACTIONS(157),
    [sym_nan] = ACTIONS(157),
    [anon_sym_NA] = ACTIONS(157),
    [anon_sym_NA_integer_] = ACTIONS(157),
    [anon_sym_NA_real_] = ACTIONS(157),
    [anon_sym_NA_complex_] = ACTIONS(157),
    [anon_sym_NA_character_] = ACTIONS(157),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(155),
    [sym__semicolon] = ACTIONS(155),
    [sym__raw_string_open] = ACTIONS(155),
    [sym__external_else] = ACTIONS(155),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(155),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [22] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(155),
    [sym_identifier] = ACTIONS(157),
    [anon_sym_BSLASH] = ACTIONS(155),
    [anon_sym_function] = ACTIONS(157),
    [anon_sym_EQ] = ACTIONS(157),
    [anon_sym_if] = ACTIONS(157),
    [anon_sym_for] = ACTIONS(157),
    [anon_sym_while] = ACTIONS(157),
    [anon_sym_repeat] = ACTIONS(157),
    [anon_sym_QMARK] = ACTIONS(155),
    [anon_sym_TILDE] = ACTIONS(155),
    [anon_sym_BANG] = ACTIONS(157),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(155),
    [anon_sym_LT_LT_DASH] = ACTIONS(155),
    [anon_sym_COLON_EQ] = ACTIONS(155),
    [anon_sym_DASH_GT] = ACTIONS(157),
    [anon_sym_DASH_GT_GT] = ACTIONS(155),
    [anon_sym_PIPE] = ACTIONS(25),
    [anon_sym_AMP] = ACTIONS(27),
    [anon_sym_PIPE_PIPE] = ACTIONS(29),
    [anon_sym_AMP_AMP] = ACTIONS(31),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(155),
    [sym__number_literal] = ACTIONS(157),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [anon_sym_DQUOTE] = ACTIONS(155),
    [sym_dots] = ACTIONS(157),
    [sym_dot_dot_i] = ACTIONS(157),
    [sym_next] = ACTIONS(157),
    [sym_break] = ACTIONS(157),
    [sym_true] = ACTIONS(157),
    [sym_false] = ACTIONS(157),
    [sym_null] = ACTIONS(157),
    [sym_inf] = ACTIONS(157),
    [sym_nan] = ACTIONS(157),
    [anon_sym_NA] = ACTIONS(157),
    [anon_sym_NA_integer_] = ACTIONS(157),
    [anon_sym_NA_real_] = ACTIONS(157),
    [anon_sym_NA_complex_] = ACTIONS(157),
    [anon_sym_NA_character_] = ACTIONS(157),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(155),
    [sym__semicolon] = ACTIONS(155),
    [sym__raw_string_open] = ACTIONS(155),
    [sym__external_else] = ACTIONS(155),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(155),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [23] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(155),
    [sym_identifier] = ACTIONS(157),
    [anon_sym_BSLASH] = ACTIONS(155),
    [anon_sym_function] = ACTIONS(157),
    [anon_sym_EQ] = ACTIONS(157),
    [anon_sym_if] = ACTIONS(157),
    [anon_sym_for] = ACTIONS(157),
    [anon_sym_while] = ACTIONS(157),
    [anon_sym_repeat] = ACTIONS(157),
    [anon_sym_QMARK] = ACTIONS(155),
    [anon_sym_TILDE] = ACTIONS(155),
    [anon_sym_BANG] = ACTIONS(157),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(155),
    [anon_sym_LT_LT_DASH] = ACTIONS(155),
    [anon_sym_COLON_EQ] = ACTIONS(155),
    [anon_sym_DASH_GT] = ACTIONS(157),
    [anon_sym_DASH_GT_GT] = ACTIONS(155),
    [anon_sym_PIPE] = ACTIONS(157),
    [anon_sym_AMP] = ACTIONS(157),
    [anon_sym_PIPE_PIPE] = ACTIONS(155),
    [anon_sym_AMP_AMP] = ACTIONS(155),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(155),
    [sym__number_literal] = ACTIONS(157),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [anon_sym_DQUOTE] = ACTIONS(155),
    [sym_dots] = ACTIONS(157),
    [sym_dot_dot_i] = ACTIONS(157),
    [sym_next] = ACTIONS(157),
    [sym_break] = ACTIONS(157),
    [sym_true] = ACTIONS(157),
    [sym_false] = ACTIONS(157),
    [sym_null] = ACTIONS(157),
    [sym_inf] = ACTIONS(157),
    [sym_nan] = ACTIONS(157),
    [anon_sym_NA] = ACTIONS(157),
    [anon_sym_NA_integer_] = ACTIONS(157),
    [anon_sym_NA_real_] = ACTIONS(157),
    [anon_sym_NA_complex_] = ACTIONS(157),
    [anon_sym_NA_character_] = ACTIONS(157),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(155),
    [sym__semicolon] = ACTIONS(155),
    [sym__raw_string_open] = ACTIONS(155),
    [sym__external_else] = ACTIONS(155),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(155),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [24] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(155),
    [sym_identifier] = ACTIONS(157),
    [anon_sym_BSLASH] = ACTIONS(155),
    [anon_sym_function] = ACTIONS(157),
    [anon_sym_EQ] = ACTIONS(157),
    [anon_sym_if] = ACTIONS(157),
    [anon_sym_for] = ACTIONS(157),
    [anon_sym_while] = ACTIONS(157),
    [anon_sym_repeat] = ACTIONS(157),
    [anon_sym_QMARK] = ACTIONS(155),
    [anon_sym_TILDE] = ACTIONS(155),
    [anon_sym_BANG] = ACTIONS(157),
    [anon_sym_PLUS] = ACTIONS(155),
    [anon_sym_DASH] = ACTIONS(157),
    [anon_sym_LT_DASH] = ACTIONS(155),
    [anon_sym_LT_LT_DASH] = ACTIONS(155),
    [anon_sym_COLON_EQ] = ACTIONS(155),
    [anon_sym_DASH_GT] = ACTIONS(157),
    [anon_sym_DASH_GT_GT] = ACTIONS(155),
    [anon_sym_PIPE] = ACTIONS(157),
    [anon_sym_AMP] = ACTIONS(157),
    [anon_sym_PIPE_PIPE] = ACTIONS(155),
    [anon_sym_AMP_AMP] = ACTIONS(155),
    [anon_sym_LT] = ACTIONS(157),
    [anon_sym_LT_EQ] = ACTIONS(155),
    [anon_sym_GT] = ACTIONS(157),
    [anon_sym_GT_EQ] = ACTIONS(155),
    [anon_sym_EQ_EQ] = ACTIONS(155),
    [anon_sym_BANG_EQ] = ACTIONS(155),
    [anon_sym_STAR] = ACTIONS(157),
    [anon_sym_SLASH] = ACTIONS(155),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(155),
    [anon_sym_PIPE_GT] = ACTIONS(155),
    [anon_sym_COLON] = ACTIONS(157),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(155),
    [sym__number_literal] = ACTIONS(157),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [anon_sym_DQUOTE] = ACTIONS(155),
    [sym_dots] = ACTIONS(157),
    [sym_dot_dot_i] = ACTIONS(157),
    [sym_next] = ACTIONS(157),
    [sym_break] = ACTIONS(157),
    [sym_true] = ACTIONS(157),
    [sym_false] = ACTIONS(157),
    [sym_null] = ACTIONS(157),
    [sym_inf] = ACTIONS(157),
    [sym_nan] = ACTIONS(157),
    [anon_sym_NA] = ACTIONS(157),
    [anon_sym_NA_integer_] = ACTIONS(157),
    [anon_sym_NA_real_] = ACTIONS(157),
    [anon_sym_NA_complex_] = ACTIONS(157),
    [anon_sym_NA_character_] = ACTIONS(157),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(155),
    [sym__semicolon] = ACTIONS(155),
    [sym__raw_string_open] = ACTIONS(155),
    [sym__external_else] = ACTIONS(155),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(155),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [25] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(159),
    [sym_identifier] = ACTIONS(161),
    [anon_sym_BSLASH] = ACTIONS(159),
    [anon_sym_function] = ACTIONS(161),
    [anon_sym_EQ] = ACTIONS(11),
    [anon_sym_if] = ACTIONS(161),
    [anon_sym_for] = ACTIONS(161),
    [anon_sym_while] = ACTIONS(161),
    [anon_sym_repeat] = ACTIONS(161),
    [anon_sym_QMARK] = ACTIONS(159),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_BANG] = ACTIONS(161),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(19),
    [anon_sym_LT_LT_DASH] = ACTIONS(19),
    [anon_sym_COLON_EQ] = ACTIONS(19),
    [anon_sym_DASH_GT] = ACTIONS(21),
    [anon_sym_DASH_GT_GT] = ACTIONS(23),
    [anon_sym_PIPE] = ACTIONS(25),
    [anon_sym_AMP] = ACTIONS(27),
    [anon_sym_PIPE_PIPE] = ACTIONS(29),
    [anon_sym_AMP_AMP] = ACTIONS(31),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(159),
    [sym__number_literal] = ACTIONS(161),
    [anon_sym_SQUOTE] = ACTIONS(159),
    [anon_sym_DQUOTE] = ACTIONS(159),
    [sym_dots] = ACTIONS(161),
    [sym_dot_dot_i] = ACTIONS(161),
    [sym_next] = ACTIONS(161),
    [sym_break] = ACTIONS(161),
    [sym_true] = ACTIONS(161),
    [sym_false] = ACTIONS(161),
    [sym_null] = ACTIONS(161),
    [sym_inf] = ACTIONS(161),
    [sym_nan] = ACTIONS(161),
    [anon_sym_NA] = ACTIONS(161),
    [anon_sym_NA_integer_] = ACTIONS(161),
    [anon_sym_NA_real_] = ACTIONS(161),
    [anon_sym_NA_complex_] = ACTIONS(161),
    [anon_sym_NA_character_] = ACTIONS(161),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(159),
    [sym__semicolon] = ACTIONS(159),
    [sym__raw_string_open] = ACTIONS(159),
    [sym__external_else] = ACTIONS(159),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(159),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [26] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(163),
    [sym_identifier] = ACTIONS(165),
    [anon_sym_BSLASH] = ACTIONS(163),
    [anon_sym_function] = ACTIONS(165),
    [anon_sym_EQ] = ACTIONS(11),
    [anon_sym_if] = ACTIONS(165),
    [anon_sym_for] = ACTIONS(165),
    [anon_sym_while] = ACTIONS(165),
    [anon_sym_repeat] = ACTIONS(165),
    [anon_sym_QMARK] = ACTIONS(163),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_BANG] = ACTIONS(165),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(19),
    [anon_sym_LT_LT_DASH] = ACTIONS(19),
    [anon_sym_COLON_EQ] = ACTIONS(19),
    [anon_sym_DASH_GT] = ACTIONS(21),
    [anon_sym_DASH_GT_GT] = ACTIONS(23),
    [anon_sym_PIPE] = ACTIONS(25),
    [anon_sym_AMP] = ACTIONS(27),
    [anon_sym_PIPE_PIPE] = ACTIONS(29),
    [anon_sym_AMP_AMP] = ACTIONS(31),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(163),
    [sym__number_literal] = ACTIONS(165),
    [anon_sym_SQUOTE] = ACTIONS(163),
    [anon_sym_DQUOTE] = ACTIONS(163),
    [sym_dots] = ACTIONS(165),
    [sym_dot_dot_i] = ACTIONS(165),
    [sym_next] = ACTIONS(165),
    [sym_break] = ACTIONS(165),
    [sym_true] = ACTIONS(165),
    [sym_false] = ACTIONS(165),
    [sym_null] = ACTIONS(165),
    [sym_inf] = ACTIONS(165),
    [sym_nan] = ACTIONS(165),
    [anon_sym_NA] = ACTIONS(165),
    [anon_sym_NA_integer_] = ACTIONS(165),
    [anon_sym_NA_real_] = ACTIONS(165),
    [anon_sym_NA_complex_] = ACTIONS(165),
    [anon_sym_NA_character_] = ACTIONS(165),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(163),
    [sym__semicolon] = ACTIONS(163),
    [sym__raw_string_open] = ACTIONS(163),
    [sym__external_else] = ACTIONS(163),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(163),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [27] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(167),
    [sym_identifier] = ACTIONS(169),
    [anon_sym_BSLASH] = ACTIONS(167),
    [anon_sym_function] = ACTIONS(169),
    [anon_sym_EQ] = ACTIONS(11),
    [anon_sym_if] = ACTIONS(169),
    [anon_sym_for] = ACTIONS(169),
    [anon_sym_while] = ACTIONS(169),
    [anon_sym_repeat] = ACTIONS(169),
    [anon_sym_QMARK] = ACTIONS(167),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_BANG] = ACTIONS(169),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(19),
    [anon_sym_LT_LT_DASH] = ACTIONS(19),
    [anon_sym_COLON_EQ] = ACTIONS(19),
    [anon_sym_DASH_GT] = ACTIONS(21),
    [anon_sym_DASH_GT_GT] = ACTIONS(23),
    [anon_sym_PIPE] = ACTIONS(25),
    [anon_sym_AMP] = ACTIONS(27),
    [anon_sym_PIPE_PIPE] = ACTIONS(29),
    [anon_sym_AMP_AMP] = ACTIONS(31),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(167),
    [sym__number_literal] = ACTIONS(169),
    [anon_sym_SQUOTE] = ACTIONS(167),
    [anon_sym_DQUOTE] = ACTIONS(167),
    [sym_dots] = ACTIONS(169),
    [sym_dot_dot_i] = ACTIONS(169),
    [sym_next] = ACTIONS(169),
    [sym_break] = ACTIONS(169),
    [sym_true] = ACTIONS(169),
    [sym_false] = ACTIONS(169),
    [sym_null] = ACTIONS(169),
    [sym_inf] = ACTIONS(169),
    [sym_nan] = ACTIONS(169),
    [anon_sym_NA] = ACTIONS(169),
    [anon_sym_NA_integer_] = ACTIONS(169),
    [anon_sym_NA_real_] = ACTIONS(169),
    [anon_sym_NA_complex_] = ACTIONS(169),
    [anon_sym_NA_character_] = ACTIONS(169),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(167),
    [sym__semicolon] = ACTIONS(167),
    [sym__raw_string_open] = ACTIONS(167),
    [sym__external_else] = ACTIONS(167),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(167),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [28] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(167),
    [sym_identifier] = ACTIONS(169),
    [anon_sym_BSLASH] = ACTIONS(167),
    [anon_sym_function] = ACTIONS(169),
    [anon_sym_EQ] = ACTIONS(169),
    [anon_sym_if] = ACTIONS(169),
    [anon_sym_for] = ACTIONS(169),
    [anon_sym_while] = ACTIONS(169),
    [anon_sym_repeat] = ACTIONS(169),
    [anon_sym_QMARK] = ACTIONS(167),
    [anon_sym_TILDE] = ACTIONS(167),
    [anon_sym_BANG] = ACTIONS(169),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(167),
    [anon_sym_LT_LT_DASH] = ACTIONS(167),
    [anon_sym_COLON_EQ] = ACTIONS(167),
    [anon_sym_DASH_GT] = ACTIONS(169),
    [anon_sym_DASH_GT_GT] = ACTIONS(167),
    [anon_sym_PIPE] = ACTIONS(25),
    [anon_sym_AMP] = ACTIONS(27),
    [anon_sym_PIPE_PIPE] = ACTIONS(29),
    [anon_sym_AMP_AMP] = ACTIONS(31),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(167),
    [sym__number_literal] = ACTIONS(169),
    [anon_sym_SQUOTE] = ACTIONS(167),
    [anon_sym_DQUOTE] = ACTIONS(167),
    [sym_dots] = ACTIONS(169),
    [sym_dot_dot_i] = ACTIONS(169),
    [sym_next] = ACTIONS(169),
    [sym_break] = ACTIONS(169),
    [sym_true] = ACTIONS(169),
    [sym_false] = ACTIONS(169),
    [sym_null] = ACTIONS(169),
    [sym_inf] = ACTIONS(169),
    [sym_nan] = ACTIONS(169),
    [anon_sym_NA] = ACTIONS(169),
    [anon_sym_NA_integer_] = ACTIONS(169),
    [anon_sym_NA_real_] = ACTIONS(169),
    [anon_sym_NA_complex_] = ACTIONS(169),
    [anon_sym_NA_character_] = ACTIONS(169),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(167),
    [sym__semicolon] = ACTIONS(167),
    [sym__raw_string_open] = ACTIONS(167),
    [sym__external_else] = ACTIONS(167),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(167),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [29] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(167),
    [sym_identifier] = ACTIONS(169),
    [anon_sym_BSLASH] = ACTIONS(167),
    [anon_sym_function] = ACTIONS(169),
    [anon_sym_EQ] = ACTIONS(169),
    [anon_sym_if] = ACTIONS(169),
    [anon_sym_for] = ACTIONS(169),
    [anon_sym_while] = ACTIONS(169),
    [anon_sym_repeat] = ACTIONS(169),
    [anon_sym_QMARK] = ACTIONS(167),
    [anon_sym_TILDE] = ACTIONS(167),
    [anon_sym_BANG] = ACTIONS(169),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(167),
    [anon_sym_LT_LT_DASH] = ACTIONS(167),
    [anon_sym_COLON_EQ] = ACTIONS(167),
    [anon_sym_DASH_GT] = ACTIONS(169),
    [anon_sym_DASH_GT_GT] = ACTIONS(167),
    [anon_sym_PIPE] = ACTIONS(169),
    [anon_sym_AMP] = ACTIONS(169),
    [anon_sym_PIPE_PIPE] = ACTIONS(167),
    [anon_sym_AMP_AMP] = ACTIONS(167),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(167),
    [sym__number_literal] = ACTIONS(169),
    [anon_sym_SQUOTE] = ACTIONS(167),
    [anon_sym_DQUOTE] = ACTIONS(167),
    [sym_dots] = ACTIONS(169),
    [sym_dot_dot_i] = ACTIONS(169),
    [sym_next] = ACTIONS(169),
    [sym_break] = ACTIONS(169),
    [sym_true] = ACTIONS(169),
    [sym_false] = ACTIONS(169),
    [sym_null] = ACTIONS(169),
    [sym_inf] = ACTIONS(169),
    [sym_nan] = ACTIONS(169),
    [anon_sym_NA] = ACTIONS(169),
    [anon_sym_NA_integer_] = ACTIONS(169),
    [anon_sym_NA_real_] = ACTIONS(169),
    [anon_sym_NA_complex_] = ACTIONS(169),
    [anon_sym_NA_character_] = ACTIONS(169),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(167),
    [sym__semicolon] = ACTIONS(167),
    [sym__raw_string_open] = ACTIONS(167),
    [sym__external_else] = ACTIONS(167),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(167),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [30] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(167),
    [sym_identifier] = ACTIONS(169),
    [anon_sym_BSLASH] = ACTIONS(167),
    [anon_sym_function] = ACTIONS(169),
    [anon_sym_EQ] = ACTIONS(169),
    [anon_sym_if] = ACTIONS(169),
    [anon_sym_for] = ACTIONS(169),
    [anon_sym_while] = ACTIONS(169),
    [anon_sym_repeat] = ACTIONS(169),
    [anon_sym_QMARK] = ACTIONS(167),
    [anon_sym_TILDE] = ACTIONS(167),
    [anon_sym_BANG] = ACTIONS(169),
    [anon_sym_PLUS] = ACTIONS(167),
    [anon_sym_DASH] = ACTIONS(169),
    [anon_sym_LT_DASH] = ACTIONS(167),
    [anon_sym_LT_LT_DASH] = ACTIONS(167),
    [anon_sym_COLON_EQ] = ACTIONS(167),
    [anon_sym_DASH_GT] = ACTIONS(169),
    [anon_sym_DASH_GT_GT] = ACTIONS(167),
    [anon_sym_PIPE] = ACTIONS(169),
    [anon_sym_AMP] = ACTIONS(169),
    [anon_sym_PIPE_PIPE] = ACTIONS(167),
    [anon_sym_AMP_AMP] = ACTIONS(167),
    [anon_sym_LT] = ACTIONS(169),
    [anon_sym_LT_EQ] = ACTIONS(167),
    [anon_sym_GT] = ACTIONS(169),
    [anon_sym_GT_EQ] = ACTIONS(167),
    [anon_sym_EQ_EQ] = ACTIONS(167),
    [anon_sym_BANG_EQ] = ACTIONS(167),
    [anon_sym_STAR] = ACTIONS(169),
    [anon_sym_SLASH] = ACTIONS(167),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(167),
    [anon_sym_PIPE_GT] = ACTIONS(167),
    [anon_sym_COLON] = ACTIONS(169),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(167),
    [sym__number_literal] = ACTIONS(169),
    [anon_sym_SQUOTE] = ACTIONS(167),
    [anon_sym_DQUOTE] = ACTIONS(167),
    [sym_dots] = ACTIONS(169),
    [sym_dot_dot_i] = ACTIONS(169),
    [sym_next] = ACTIONS(169),
    [sym_break] = ACTIONS(169),
    [sym_true] = ACTIONS(169),
    [sym_false] = ACTIONS(169),
    [sym_null] = ACTIONS(169),
    [sym_inf] = ACTIONS(169),
    [sym_nan] = ACTIONS(169),
    [anon_sym_NA] = ACTIONS(169),
    [anon_sym_NA_integer_] = ACTIONS(169),
    [anon_sym_NA_real_] = ACTIONS(169),
    [anon_sym_NA_complex_] = ACTIONS(169),
    [anon_sym_NA_character_] = ACTIONS(169),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(167),
    [sym__semicolon] = ACTIONS(167),
    [sym__raw_string_open] = ACTIONS(167),
    [sym__external_else] = ACTIONS(167),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(167),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [31] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(143),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(11),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(143),
    [anon_sym_LT_LT_DASH] = ACTIONS(143),
    [anon_sym_COLON_EQ] = ACTIONS(143),
    [anon_sym_DASH_GT] = ACTIONS(21),
    [anon_sym_DASH_GT_GT] = ACTIONS(23),
    [anon_sym_PIPE] = ACTIONS(25),
    [anon_sym_AMP] = ACTIONS(27),
    [anon_sym_PIPE_PIPE] = ACTIONS(29),
    [anon_sym_AMP_AMP] = ACTIONS(31),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_else] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [32] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(143),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(11),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(19),
    [anon_sym_LT_LT_DASH] = ACTIONS(19),
    [anon_sym_COLON_EQ] = ACTIONS(19),
    [anon_sym_DASH_GT] = ACTIONS(21),
    [anon_sym_DASH_GT_GT] = ACTIONS(23),
    [anon_sym_PIPE] = ACTIONS(25),
    [anon_sym_AMP] = ACTIONS(27),
    [anon_sym_PIPE_PIPE] = ACTIONS(29),
    [anon_sym_AMP_AMP] = ACTIONS(31),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_else] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [33] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(143),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(11),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(19),
    [anon_sym_LT_LT_DASH] = ACTIONS(19),
    [anon_sym_COLON_EQ] = ACTIONS(19),
    [anon_sym_DASH_GT] = ACTIONS(21),
    [anon_sym_DASH_GT_GT] = ACTIONS(23),
    [anon_sym_PIPE] = ACTIONS(25),
    [anon_sym_AMP] = ACTIONS(27),
    [anon_sym_PIPE_PIPE] = ACTIONS(29),
    [anon_sym_AMP_AMP] = ACTIONS(31),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_else] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [34] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(143),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(143),
    [anon_sym_LT_LT_DASH] = ACTIONS(143),
    [anon_sym_COLON_EQ] = ACTIONS(143),
    [anon_sym_DASH_GT] = ACTIONS(145),
    [anon_sym_DASH_GT_GT] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(25),
    [anon_sym_AMP] = ACTIONS(27),
    [anon_sym_PIPE_PIPE] = ACTIONS(29),
    [anon_sym_AMP_AMP] = ACTIONS(31),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_else] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [35] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(143),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(143),
    [anon_sym_LT_LT_DASH] = ACTIONS(143),
    [anon_sym_COLON_EQ] = ACTIONS(143),
    [anon_sym_DASH_GT] = ACTIONS(145),
    [anon_sym_DASH_GT_GT] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(27),
    [anon_sym_PIPE_PIPE] = ACTIONS(143),
    [anon_sym_AMP_AMP] = ACTIONS(31),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_else] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [36] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(143),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(143),
    [anon_sym_LT_LT_DASH] = ACTIONS(143),
    [anon_sym_COLON_EQ] = ACTIONS(143),
    [anon_sym_DASH_GT] = ACTIONS(145),
    [anon_sym_DASH_GT_GT] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(145),
    [anon_sym_PIPE_PIPE] = ACTIONS(143),
    [anon_sym_AMP_AMP] = ACTIONS(143),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_else] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [37] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(143),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(143),
    [anon_sym_LT_LT_DASH] = ACTIONS(143),
    [anon_sym_COLON_EQ] = ACTIONS(143),
    [anon_sym_DASH_GT] = ACTIONS(145),
    [anon_sym_DASH_GT_GT] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(145),
    [anon_sym_PIPE_PIPE] = ACTIONS(143),
    [anon_sym_AMP_AMP] = ACTIONS(143),
    [anon_sym_LT] = ACTIONS(145),
    [anon_sym_LT_EQ] = ACTIONS(143),
    [anon_sym_GT] = ACTIONS(145),
    [anon_sym_GT_EQ] = ACTIONS(143),
    [anon_sym_EQ_EQ] = ACTIONS(143),
    [anon_sym_BANG_EQ] = ACTIONS(143),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_else] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [38] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(143),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_LT_DASH] = ACTIONS(143),
    [anon_sym_LT_LT_DASH] = ACTIONS(143),
    [anon_sym_COLON_EQ] = ACTIONS(143),
    [anon_sym_DASH_GT] = ACTIONS(145),
    [anon_sym_DASH_GT_GT] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(145),
    [anon_sym_PIPE_PIPE] = ACTIONS(143),
    [anon_sym_AMP_AMP] = ACTIONS(143),
    [anon_sym_LT] = ACTIONS(145),
    [anon_sym_LT_EQ] = ACTIONS(143),
    [anon_sym_GT] = ACTIONS(145),
    [anon_sym_GT_EQ] = ACTIONS(143),
    [anon_sym_EQ_EQ] = ACTIONS(143),
    [anon_sym_BANG_EQ] = ACTIONS(143),
    [anon_sym_STAR] = ACTIONS(145),
    [anon_sym_SLASH] = ACTIONS(143),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_else] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [39] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(143),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_LT_DASH] = ACTIONS(143),
    [anon_sym_LT_LT_DASH] = ACTIONS(143),
    [anon_sym_COLON_EQ] = ACTIONS(143),
    [anon_sym_DASH_GT] = ACTIONS(145),
    [anon_sym_DASH_GT_GT] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(145),
    [anon_sym_PIPE_PIPE] = ACTIONS(143),
    [anon_sym_AMP_AMP] = ACTIONS(143),
    [anon_sym_LT] = ACTIONS(145),
    [anon_sym_LT_EQ] = ACTIONS(143),
    [anon_sym_GT] = ACTIONS(145),
    [anon_sym_GT_EQ] = ACTIONS(143),
    [anon_sym_EQ_EQ] = ACTIONS(143),
    [anon_sym_BANG_EQ] = ACTIONS(143),
    [anon_sym_STAR] = ACTIONS(145),
    [anon_sym_SLASH] = ACTIONS(143),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(143),
    [anon_sym_PIPE_GT] = ACTIONS(143),
    [anon_sym_COLON] = ACTIONS(145),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_else] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [40] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(143),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_LT_DASH] = ACTIONS(143),
    [anon_sym_LT_LT_DASH] = ACTIONS(143),
    [anon_sym_COLON_EQ] = ACTIONS(143),
    [anon_sym_DASH_GT] = ACTIONS(145),
    [anon_sym_DASH_GT_GT] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(145),
    [anon_sym_PIPE_PIPE] = ACTIONS(143),
    [anon_sym_AMP_AMP] = ACTIONS(143),
    [anon_sym_LT] = ACTIONS(145),
    [anon_sym_LT_EQ] = ACTIONS(143),
    [anon_sym_GT] = ACTIONS(145),
    [anon_sym_GT_EQ] = ACTIONS(143),
    [anon_sym_EQ_EQ] = ACTIONS(143),
    [anon_sym_BANG_EQ] = ACTIONS(143),
    [anon_sym_STAR] = ACTIONS(145),
    [anon_sym_SLASH] = ACTIONS(143),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(143),
    [anon_sym_PIPE_GT] = ACTIONS(143),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_else] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [41] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(143),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_LT_DASH] = ACTIONS(143),
    [anon_sym_LT_LT_DASH] = ACTIONS(143),
    [anon_sym_COLON_EQ] = ACTIONS(143),
    [anon_sym_DASH_GT] = ACTIONS(145),
    [anon_sym_DASH_GT_GT] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(145),
    [anon_sym_PIPE_PIPE] = ACTIONS(143),
    [anon_sym_AMP_AMP] = ACTIONS(143),
    [anon_sym_LT] = ACTIONS(145),
    [anon_sym_LT_EQ] = ACTIONS(143),
    [anon_sym_GT] = ACTIONS(145),
    [anon_sym_GT_EQ] = ACTIONS(143),
    [anon_sym_EQ_EQ] = ACTIONS(143),
    [anon_sym_BANG_EQ] = ACTIONS(143),
    [anon_sym_STAR] = ACTIONS(145),
    [anon_sym_SLASH] = ACTIONS(143),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(143),
    [anon_sym_PIPE_GT] = ACTIONS(143),
    [anon_sym_COLON] = ACTIONS(145),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_else] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [42] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(171),
    [sym_identifier] = ACTIONS(173),
    [anon_sym_BSLASH] = ACTIONS(171),
    [anon_sym_function] = ACTIONS(173),
    [anon_sym_EQ] = ACTIONS(11),
    [anon_sym_if] = ACTIONS(173),
    [anon_sym_for] = ACTIONS(173),
    [anon_sym_while] = ACTIONS(173),
    [anon_sym_repeat] = ACTIONS(173),
    [anon_sym_QMARK] = ACTIONS(171),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_BANG] = ACTIONS(173),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(19),
    [anon_sym_LT_LT_DASH] = ACTIONS(19),
    [anon_sym_COLON_EQ] = ACTIONS(19),
    [anon_sym_DASH_GT] = ACTIONS(21),
    [anon_sym_DASH_GT_GT] = ACTIONS(23),
    [anon_sym_PIPE] = ACTIONS(25),
    [anon_sym_AMP] = ACTIONS(27),
    [anon_sym_PIPE_PIPE] = ACTIONS(29),
    [anon_sym_AMP_AMP] = ACTIONS(31),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(171),
    [sym__number_literal] = ACTIONS(173),
    [anon_sym_SQUOTE] = ACTIONS(171),
    [anon_sym_DQUOTE] = ACTIONS(171),
    [sym_dots] = ACTIONS(173),
    [sym_dot_dot_i] = ACTIONS(173),
    [sym_next] = ACTIONS(173),
    [sym_break] = ACTIONS(173),
    [sym_true] = ACTIONS(173),
    [sym_false] = ACTIONS(173),
    [sym_null] = ACTIONS(173),
    [sym_inf] = ACTIONS(173),
    [sym_nan] = ACTIONS(173),
    [anon_sym_NA] = ACTIONS(173),
    [anon_sym_NA_integer_] = ACTIONS(173),
    [anon_sym_NA_real_] = ACTIONS(173),
    [anon_sym_NA_complex_] = ACTIONS(173),
    [anon_sym_NA_character_] = ACTIONS(173),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(171),
    [sym__semicolon] = ACTIONS(171),
    [sym__raw_string_open] = ACTIONS(171),
    [sym__external_else] = ACTIONS(171),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(171),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [43] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(175),
    [sym_identifier] = ACTIONS(177),
    [anon_sym_BSLASH] = ACTIONS(175),
    [anon_sym_function] = ACTIONS(177),
    [anon_sym_EQ] = ACTIONS(11),
    [anon_sym_if] = ACTIONS(177),
    [anon_sym_for] = ACTIONS(177),
    [anon_sym_while] = ACTIONS(177),
    [anon_sym_repeat] = ACTIONS(177),
    [anon_sym_QMARK] = ACTIONS(175),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_BANG] = ACTIONS(177),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(19),
    [anon_sym_LT_LT_DASH] = ACTIONS(19),
    [anon_sym_COLON_EQ] = ACTIONS(19),
    [anon_sym_DASH_GT] = ACTIONS(21),
    [anon_sym_DASH_GT_GT] = ACTIONS(23),
    [anon_sym_PIPE] = ACTIONS(25),
    [anon_sym_AMP] = ACTIONS(27),
    [anon_sym_PIPE_PIPE] = ACTIONS(29),
    [anon_sym_AMP_AMP] = ACTIONS(31),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(175),
    [sym__number_literal] = ACTIONS(177),
    [anon_sym_SQUOTE] = ACTIONS(175),
    [anon_sym_DQUOTE] = ACTIONS(175),
    [sym_dots] = ACTIONS(177),
    [sym_dot_dot_i] = ACTIONS(177),
    [sym_next] = ACTIONS(177),
    [sym_break] = ACTIONS(177),
    [sym_true] = ACTIONS(177),
    [sym_false] = ACTIONS(177),
    [sym_null] = ACTIONS(177),
    [sym_inf] = ACTIONS(177),
    [sym_nan] = ACTIONS(177),
    [anon_sym_NA] = ACTIONS(177),
    [anon_sym_NA_integer_] = ACTIONS(177),
    [anon_sym_NA_real_] = ACTIONS(177),
    [anon_sym_NA_complex_] = ACTIONS(177),
    [anon_sym_NA_character_] = ACTIONS(177),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(175),
    [sym__semicolon] = ACTIONS(175),
    [sym__raw_string_open] = ACTIONS(175),
    [sym__external_else] = ACTIONS(175),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(175),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [44] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(179),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(11),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(179),
    [anon_sym_LT_LT_DASH] = ACTIONS(179),
    [anon_sym_COLON_EQ] = ACTIONS(179),
    [anon_sym_DASH_GT] = ACTIONS(21),
    [anon_sym_DASH_GT_GT] = ACTIONS(23),
    [anon_sym_PIPE] = ACTIONS(25),
    [anon_sym_AMP] = ACTIONS(27),
    [anon_sym_PIPE_PIPE] = ACTIONS(29),
    [anon_sym_AMP_AMP] = ACTIONS(31),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_else] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [45] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(179),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(11),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(19),
    [anon_sym_LT_LT_DASH] = ACTIONS(19),
    [anon_sym_COLON_EQ] = ACTIONS(19),
    [anon_sym_DASH_GT] = ACTIONS(21),
    [anon_sym_DASH_GT_GT] = ACTIONS(23),
    [anon_sym_PIPE] = ACTIONS(25),
    [anon_sym_AMP] = ACTIONS(27),
    [anon_sym_PIPE_PIPE] = ACTIONS(29),
    [anon_sym_AMP_AMP] = ACTIONS(31),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_else] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [46] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(179),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(181),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(179),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(179),
    [anon_sym_LT_LT_DASH] = ACTIONS(179),
    [anon_sym_COLON_EQ] = ACTIONS(179),
    [anon_sym_DASH_GT] = ACTIONS(181),
    [anon_sym_DASH_GT_GT] = ACTIONS(179),
    [anon_sym_PIPE] = ACTIONS(25),
    [anon_sym_AMP] = ACTIONS(27),
    [anon_sym_PIPE_PIPE] = ACTIONS(29),
    [anon_sym_AMP_AMP] = ACTIONS(31),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_else] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [47] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(179),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(181),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(179),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(181),
    [anon_sym_LT_DASH] = ACTIONS(179),
    [anon_sym_LT_LT_DASH] = ACTIONS(179),
    [anon_sym_COLON_EQ] = ACTIONS(179),
    [anon_sym_DASH_GT] = ACTIONS(181),
    [anon_sym_DASH_GT_GT] = ACTIONS(179),
    [anon_sym_PIPE] = ACTIONS(181),
    [anon_sym_AMP] = ACTIONS(181),
    [anon_sym_PIPE_PIPE] = ACTIONS(179),
    [anon_sym_AMP_AMP] = ACTIONS(179),
    [anon_sym_LT] = ACTIONS(181),
    [anon_sym_LT_EQ] = ACTIONS(179),
    [anon_sym_GT] = ACTIONS(181),
    [anon_sym_GT_EQ] = ACTIONS(179),
    [anon_sym_EQ_EQ] = ACTIONS(179),
    [anon_sym_BANG_EQ] = ACTIONS(179),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_else] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [48] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(179),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(11),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(19),
    [anon_sym_LT_LT_DASH] = ACTIONS(19),
    [anon_sym_COLON_EQ] = ACTIONS(19),
    [anon_sym_DASH_GT] = ACTIONS(21),
    [anon_sym_DASH_GT_GT] = ACTIONS(23),
    [anon_sym_PIPE] = ACTIONS(25),
    [anon_sym_AMP] = ACTIONS(27),
    [anon_sym_PIPE_PIPE] = ACTIONS(29),
    [anon_sym_AMP_AMP] = ACTIONS(31),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_else] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [49] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(179),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(181),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(179),
    [anon_sym_LT_LT_DASH] = ACTIONS(179),
    [anon_sym_COLON_EQ] = ACTIONS(179),
    [anon_sym_DASH_GT] = ACTIONS(181),
    [anon_sym_DASH_GT_GT] = ACTIONS(179),
    [anon_sym_PIPE] = ACTIONS(25),
    [anon_sym_AMP] = ACTIONS(27),
    [anon_sym_PIPE_PIPE] = ACTIONS(29),
    [anon_sym_AMP_AMP] = ACTIONS(31),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_else] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [50] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(179),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(181),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(179),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(179),
    [anon_sym_LT_LT_DASH] = ACTIONS(179),
    [anon_sym_COLON_EQ] = ACTIONS(179),
    [anon_sym_DASH_GT] = ACTIONS(181),
    [anon_sym_DASH_GT_GT] = ACTIONS(179),
    [anon_sym_PIPE] = ACTIONS(181),
    [anon_sym_AMP] = ACTIONS(27),
    [anon_sym_PIPE_PIPE] = ACTIONS(179),
    [anon_sym_AMP_AMP] = ACTIONS(31),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_else] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [51] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(179),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(181),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(179),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(179),
    [anon_sym_LT_LT_DASH] = ACTIONS(179),
    [anon_sym_COLON_EQ] = ACTIONS(179),
    [anon_sym_DASH_GT] = ACTIONS(181),
    [anon_sym_DASH_GT_GT] = ACTIONS(179),
    [anon_sym_PIPE] = ACTIONS(181),
    [anon_sym_AMP] = ACTIONS(181),
    [anon_sym_PIPE_PIPE] = ACTIONS(179),
    [anon_sym_AMP_AMP] = ACTIONS(179),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_else] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [52] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(179),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(181),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(179),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(179),
    [anon_sym_LT_LT_DASH] = ACTIONS(179),
    [anon_sym_COLON_EQ] = ACTIONS(179),
    [anon_sym_DASH_GT] = ACTIONS(181),
    [anon_sym_DASH_GT_GT] = ACTIONS(179),
    [anon_sym_PIPE] = ACTIONS(181),
    [anon_sym_AMP] = ACTIONS(181),
    [anon_sym_PIPE_PIPE] = ACTIONS(179),
    [anon_sym_AMP_AMP] = ACTIONS(179),
    [anon_sym_LT] = ACTIONS(181),
    [anon_sym_LT_EQ] = ACTIONS(179),
    [anon_sym_GT] = ACTIONS(181),
    [anon_sym_GT_EQ] = ACTIONS(179),
    [anon_sym_EQ_EQ] = ACTIONS(179),
    [anon_sym_BANG_EQ] = ACTIONS(179),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_else] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [53] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(179),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(181),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(179),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(181),
    [anon_sym_LT_DASH] = ACTIONS(179),
    [anon_sym_LT_LT_DASH] = ACTIONS(179),
    [anon_sym_COLON_EQ] = ACTIONS(179),
    [anon_sym_DASH_GT] = ACTIONS(181),
    [anon_sym_DASH_GT_GT] = ACTIONS(179),
    [anon_sym_PIPE] = ACTIONS(181),
    [anon_sym_AMP] = ACTIONS(181),
    [anon_sym_PIPE_PIPE] = ACTIONS(179),
    [anon_sym_AMP_AMP] = ACTIONS(179),
    [anon_sym_LT] = ACTIONS(181),
    [anon_sym_LT_EQ] = ACTIONS(179),
    [anon_sym_GT] = ACTIONS(181),
    [anon_sym_GT_EQ] = ACTIONS(179),
    [anon_sym_EQ_EQ] = ACTIONS(179),
    [anon_sym_BANG_EQ] = ACTIONS(179),
    [anon_sym_STAR] = ACTIONS(181),
    [anon_sym_SLASH] = ACTIONS(179),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_else] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [54] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(179),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(181),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(179),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(181),
    [anon_sym_LT_DASH] = ACTIONS(179),
    [anon_sym_LT_LT_DASH] = ACTIONS(179),
    [anon_sym_COLON_EQ] = ACTIONS(179),
    [anon_sym_DASH_GT] = ACTIONS(181),
    [anon_sym_DASH_GT_GT] = ACTIONS(179),
    [anon_sym_PIPE] = ACTIONS(181),
    [anon_sym_AMP] = ACTIONS(181),
    [anon_sym_PIPE_PIPE] = ACTIONS(179),
    [anon_sym_AMP_AMP] = ACTIONS(179),
    [anon_sym_LT] = ACTIONS(181),
    [anon_sym_LT_EQ] = ACTIONS(179),
    [anon_sym_GT] = ACTIONS(181),
    [anon_sym_GT_EQ] = ACTIONS(179),
    [anon_sym_EQ_EQ] = ACTIONS(179),
    [anon_sym_BANG_EQ] = ACTIONS(179),
    [anon_sym_STAR] = ACTIONS(181),
    [anon_sym_SLASH] = ACTIONS(179),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(179),
    [anon_sym_PIPE_GT] = ACTIONS(179),
    [anon_sym_COLON] = ACTIONS(181),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_else] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [55] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(179),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(181),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(179),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(181),
    [anon_sym_LT_DASH] = ACTIONS(179),
    [anon_sym_LT_LT_DASH] = ACTIONS(179),
    [anon_sym_COLON_EQ] = ACTIONS(179),
    [anon_sym_DASH_GT] = ACTIONS(181),
    [anon_sym_DASH_GT_GT] = ACTIONS(179),
    [anon_sym_PIPE] = ACTIONS(181),
    [anon_sym_AMP] = ACTIONS(181),
    [anon_sym_PIPE_PIPE] = ACTIONS(179),
    [anon_sym_AMP_AMP] = ACTIONS(179),
    [anon_sym_LT] = ACTIONS(181),
    [anon_sym_LT_EQ] = ACTIONS(179),
    [anon_sym_GT] = ACTIONS(181),
    [anon_sym_GT_EQ] = ACTIONS(179),
    [anon_sym_EQ_EQ] = ACTIONS(179),
    [anon_sym_BANG_EQ] = ACTIONS(179),
    [anon_sym_STAR] = ACTIONS(181),
    [anon_sym_SLASH] = ACTIONS(179),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(179),
    [anon_sym_PIPE_GT] = ACTIONS(179),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_else] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [56] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(179),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(181),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(179),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(181),
    [anon_sym_LT_DASH] = ACTIONS(179),
    [anon_sym_LT_LT_DASH] = ACTIONS(179),
    [anon_sym_COLON_EQ] = ACTIONS(179),
    [anon_sym_DASH_GT] = ACTIONS(181),
    [anon_sym_DASH_GT_GT] = ACTIONS(179),
    [anon_sym_PIPE] = ACTIONS(181),
    [anon_sym_AMP] = ACTIONS(181),
    [anon_sym_PIPE_PIPE] = ACTIONS(179),
    [anon_sym_AMP_AMP] = ACTIONS(179),
    [anon_sym_LT] = ACTIONS(181),
    [anon_sym_LT_EQ] = ACTIONS(179),
    [anon_sym_GT] = ACTIONS(181),
    [anon_sym_GT_EQ] = ACTIONS(179),
    [anon_sym_EQ_EQ] = ACTIONS(179),
    [anon_sym_BANG_EQ] = ACTIONS(179),
    [anon_sym_STAR] = ACTIONS(181),
    [anon_sym_SLASH] = ACTIONS(179),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(179),
    [anon_sym_PIPE_GT] = ACTIONS(179),
    [anon_sym_COLON] = ACTIONS(181),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_else] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [57] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(183),
    [sym_identifier] = ACTIONS(185),
    [anon_sym_BSLASH] = ACTIONS(183),
    [anon_sym_function] = ACTIONS(185),
    [anon_sym_EQ] = ACTIONS(11),
    [anon_sym_if] = ACTIONS(185),
    [anon_sym_for] = ACTIONS(185),
    [anon_sym_while] = ACTIONS(185),
    [anon_sym_repeat] = ACTIONS(185),
    [anon_sym_QMARK] = ACTIONS(183),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_BANG] = ACTIONS(185),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(19),
    [anon_sym_LT_LT_DASH] = ACTIONS(19),
    [anon_sym_COLON_EQ] = ACTIONS(19),
    [anon_sym_DASH_GT] = ACTIONS(21),
    [anon_sym_DASH_GT_GT] = ACTIONS(23),
    [anon_sym_PIPE] = ACTIONS(25),
    [anon_sym_AMP] = ACTIONS(27),
    [anon_sym_PIPE_PIPE] = ACTIONS(29),
    [anon_sym_AMP_AMP] = ACTIONS(31),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(183),
    [sym__number_literal] = ACTIONS(185),
    [anon_sym_SQUOTE] = ACTIONS(183),
    [anon_sym_DQUOTE] = ACTIONS(183),
    [sym_dots] = ACTIONS(185),
    [sym_dot_dot_i] = ACTIONS(185),
    [sym_next] = ACTIONS(185),
    [sym_break] = ACTIONS(185),
    [sym_true] = ACTIONS(185),
    [sym_false] = ACTIONS(185),
    [sym_null] = ACTIONS(185),
    [sym_inf] = ACTIONS(185),
    [sym_nan] = ACTIONS(185),
    [anon_sym_NA] = ACTIONS(185),
    [anon_sym_NA_integer_] = ACTIONS(185),
    [anon_sym_NA_real_] = ACTIONS(185),
    [anon_sym_NA_complex_] = ACTIONS(185),
    [anon_sym_NA_character_] = ACTIONS(185),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(183),
    [sym__semicolon] = ACTIONS(183),
    [sym__raw_string_open] = ACTIONS(183),
    [sym__external_else] = ACTIONS(183),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(183),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [58] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(187),
    [sym_identifier] = ACTIONS(189),
    [anon_sym_BSLASH] = ACTIONS(187),
    [anon_sym_function] = ACTIONS(189),
    [anon_sym_EQ] = ACTIONS(11),
    [anon_sym_if] = ACTIONS(189),
    [anon_sym_for] = ACTIONS(189),
    [anon_sym_while] = ACTIONS(189),
    [anon_sym_repeat] = ACTIONS(189),
    [anon_sym_QMARK] = ACTIONS(187),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_BANG] = ACTIONS(189),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(19),
    [anon_sym_LT_LT_DASH] = ACTIONS(19),
    [anon_sym_COLON_EQ] = ACTIONS(19),
    [anon_sym_DASH_GT] = ACTIONS(21),
    [anon_sym_DASH_GT_GT] = ACTIONS(23),
    [anon_sym_PIPE] = ACTIONS(25),
    [anon_sym_AMP] = ACTIONS(27),
    [anon_sym_PIPE_PIPE] = ACTIONS(29),
    [anon_sym_AMP_AMP] = ACTIONS(31),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(187),
    [sym__number_literal] = ACTIONS(189),
    [anon_sym_SQUOTE] = ACTIONS(187),
    [anon_sym_DQUOTE] = ACTIONS(187),
    [sym_dots] = ACTIONS(189),
    [sym_dot_dot_i] = ACTIONS(189),
    [sym_next] = ACTIONS(189),
    [sym_break] = ACTIONS(189),
    [sym_true] = ACTIONS(189),
    [sym_false] = ACTIONS(189),
    [sym_null] = ACTIONS(189),
    [sym_inf] = ACTIONS(189),
    [sym_nan] = ACTIONS(189),
    [anon_sym_NA] = ACTIONS(189),
    [anon_sym_NA_integer_] = ACTIONS(189),
    [anon_sym_NA_real_] = ACTIONS(189),
    [anon_sym_NA_complex_] = ACTIONS(189),
    [anon_sym_NA_character_] = ACTIONS(189),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(187),
    [sym__semicolon] = ACTIONS(187),
    [sym__raw_string_open] = ACTIONS(187),
    [sym__external_else] = ACTIONS(187),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(187),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [59] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(191),
    [sym_identifier] = ACTIONS(193),
    [anon_sym_BSLASH] = ACTIONS(191),
    [anon_sym_function] = ACTIONS(193),
    [anon_sym_EQ] = ACTIONS(11),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_for] = ACTIONS(193),
    [anon_sym_while] = ACTIONS(193),
    [anon_sym_repeat] = ACTIONS(193),
    [anon_sym_QMARK] = ACTIONS(191),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_BANG] = ACTIONS(193),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(19),
    [anon_sym_LT_LT_DASH] = ACTIONS(19),
    [anon_sym_COLON_EQ] = ACTIONS(19),
    [anon_sym_DASH_GT] = ACTIONS(21),
    [anon_sym_DASH_GT_GT] = ACTIONS(23),
    [anon_sym_PIPE] = ACTIONS(25),
    [anon_sym_AMP] = ACTIONS(27),
    [anon_sym_PIPE_PIPE] = ACTIONS(29),
    [anon_sym_AMP_AMP] = ACTIONS(31),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(191),
    [sym__number_literal] = ACTIONS(193),
    [anon_sym_SQUOTE] = ACTIONS(191),
    [anon_sym_DQUOTE] = ACTIONS(191),
    [sym_dots] = ACTIONS(193),
    [sym_dot_dot_i] = ACTIONS(193),
    [sym_next] = ACTIONS(193),
    [sym_break] = ACTIONS(193),
    [sym_true] = ACTIONS(193),
    [sym_false] = ACTIONS(193),
    [sym_null] = ACTIONS(193),
    [sym_inf] = ACTIONS(193),
    [sym_nan] = ACTIONS(193),
    [anon_sym_NA] = ACTIONS(193),
    [anon_sym_NA_integer_] = ACTIONS(193),
    [anon_sym_NA_real_] = ACTIONS(193),
    [anon_sym_NA_complex_] = ACTIONS(193),
    [anon_sym_NA_character_] = ACTIONS(193),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(191),
    [sym__semicolon] = ACTIONS(191),
    [sym__raw_string_open] = ACTIONS(191),
    [sym__external_else] = ACTIONS(191),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(191),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [60] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(195),
    [sym_identifier] = ACTIONS(197),
    [anon_sym_BSLASH] = ACTIONS(195),
    [anon_sym_function] = ACTIONS(197),
    [anon_sym_EQ] = ACTIONS(11),
    [anon_sym_if] = ACTIONS(197),
    [anon_sym_for] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(197),
    [anon_sym_repeat] = ACTIONS(197),
    [anon_sym_QMARK] = ACTIONS(195),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_BANG] = ACTIONS(197),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(19),
    [anon_sym_LT_LT_DASH] = ACTIONS(19),
    [anon_sym_COLON_EQ] = ACTIONS(19),
    [anon_sym_DASH_GT] = ACTIONS(21),
    [anon_sym_DASH_GT_GT] = ACTIONS(23),
    [anon_sym_PIPE] = ACTIONS(25),
    [anon_sym_AMP] = ACTIONS(27),
    [anon_sym_PIPE_PIPE] = ACTIONS(29),
    [anon_sym_AMP_AMP] = ACTIONS(31),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(195),
    [sym__number_literal] = ACTIONS(197),
    [anon_sym_SQUOTE] = ACTIONS(195),
    [anon_sym_DQUOTE] = ACTIONS(195),
    [sym_dots] = ACTIONS(197),
    [sym_dot_dot_i] = ACTIONS(197),
    [sym_next] = ACTIONS(197),
    [sym_break] = ACTIONS(197),
    [sym_true] = ACTIONS(197),
    [sym_false] = ACTIONS(197),
    [sym_null] = ACTIONS(197),
    [sym_inf] = ACTIONS(197),
    [sym_nan] = ACTIONS(197),
    [anon_sym_NA] = ACTIONS(197),
    [anon_sym_NA_integer_] = ACTIONS(197),
    [anon_sym_NA_real_] = ACTIONS(197),
    [anon_sym_NA_complex_] = ACTIONS(197),
    [anon_sym_NA_character_] = ACTIONS(197),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(195),
    [sym__semicolon] = ACTIONS(195),
    [sym__raw_string_open] = ACTIONS(195),
    [sym__external_else] = ACTIONS(195),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(195),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [61] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(199),
    [sym_identifier] = ACTIONS(201),
    [anon_sym_BSLASH] = ACTIONS(199),
    [anon_sym_function] = ACTIONS(201),
    [anon_sym_EQ] = ACTIONS(11),
    [anon_sym_if] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(201),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_repeat] = ACTIONS(201),
    [anon_sym_QMARK] = ACTIONS(199),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_BANG] = ACTIONS(201),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(19),
    [anon_sym_LT_LT_DASH] = ACTIONS(19),
    [anon_sym_COLON_EQ] = ACTIONS(19),
    [anon_sym_DASH_GT] = ACTIONS(21),
    [anon_sym_DASH_GT_GT] = ACTIONS(23),
    [anon_sym_PIPE] = ACTIONS(25),
    [anon_sym_AMP] = ACTIONS(27),
    [anon_sym_PIPE_PIPE] = ACTIONS(29),
    [anon_sym_AMP_AMP] = ACTIONS(31),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(199),
    [sym__number_literal] = ACTIONS(201),
    [anon_sym_SQUOTE] = ACTIONS(199),
    [anon_sym_DQUOTE] = ACTIONS(199),
    [sym_dots] = ACTIONS(201),
    [sym_dot_dot_i] = ACTIONS(201),
    [sym_next] = ACTIONS(201),
    [sym_break] = ACTIONS(201),
    [sym_true] = ACTIONS(201),
    [sym_false] = ACTIONS(201),
    [sym_null] = ACTIONS(201),
    [sym_inf] = ACTIONS(201),
    [sym_nan] = ACTIONS(201),
    [anon_sym_NA] = ACTIONS(201),
    [anon_sym_NA_integer_] = ACTIONS(201),
    [anon_sym_NA_real_] = ACTIONS(201),
    [anon_sym_NA_complex_] = ACTIONS(201),
    [anon_sym_NA_character_] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(199),
    [sym__semicolon] = ACTIONS(199),
    [sym__raw_string_open] = ACTIONS(199),
    [sym__external_else] = ACTIONS(199),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(199),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [62] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(203),
    [sym_identifier] = ACTIONS(205),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_EQ] = ACTIONS(11),
    [anon_sym_if] = ACTIONS(205),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_while] = ACTIONS(205),
    [anon_sym_repeat] = ACTIONS(205),
    [anon_sym_QMARK] = ACTIONS(203),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_BANG] = ACTIONS(205),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(19),
    [anon_sym_LT_LT_DASH] = ACTIONS(19),
    [anon_sym_COLON_EQ] = ACTIONS(19),
    [anon_sym_DASH_GT] = ACTIONS(21),
    [anon_sym_DASH_GT_GT] = ACTIONS(23),
    [anon_sym_PIPE] = ACTIONS(25),
    [anon_sym_AMP] = ACTIONS(27),
    [anon_sym_PIPE_PIPE] = ACTIONS(29),
    [anon_sym_AMP_AMP] = ACTIONS(31),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(203),
    [sym__number_literal] = ACTIONS(205),
    [anon_sym_SQUOTE] = ACTIONS(203),
    [anon_sym_DQUOTE] = ACTIONS(203),
    [sym_dots] = ACTIONS(205),
    [sym_dot_dot_i] = ACTIONS(205),
    [sym_next] = ACTIONS(205),
    [sym_break] = ACTIONS(205),
    [sym_true] = ACTIONS(205),
    [sym_false] = ACTIONS(205),
    [sym_null] = ACTIONS(205),
    [sym_inf] = ACTIONS(205),
    [sym_nan] = ACTIONS(205),
    [anon_sym_NA] = ACTIONS(205),
    [anon_sym_NA_integer_] = ACTIONS(205),
    [anon_sym_NA_real_] = ACTIONS(205),
    [anon_sym_NA_complex_] = ACTIONS(205),
    [anon_sym_NA_character_] = ACTIONS(205),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(203),
    [sym__semicolon] = ACTIONS(203),
    [sym__raw_string_open] = ACTIONS(203),
    [sym__external_else] = ACTIONS(203),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(203),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [63] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(207),
    [sym_identifier] = ACTIONS(209),
    [anon_sym_BSLASH] = ACTIONS(207),
    [anon_sym_function] = ACTIONS(209),
    [anon_sym_EQ] = ACTIONS(11),
    [anon_sym_if] = ACTIONS(209),
    [anon_sym_for] = ACTIONS(209),
    [anon_sym_while] = ACTIONS(209),
    [anon_sym_repeat] = ACTIONS(209),
    [anon_sym_QMARK] = ACTIONS(207),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_BANG] = ACTIONS(209),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(19),
    [anon_sym_LT_LT_DASH] = ACTIONS(19),
    [anon_sym_COLON_EQ] = ACTIONS(19),
    [anon_sym_DASH_GT] = ACTIONS(21),
    [anon_sym_DASH_GT_GT] = ACTIONS(23),
    [anon_sym_PIPE] = ACTIONS(25),
    [anon_sym_AMP] = ACTIONS(27),
    [anon_sym_PIPE_PIPE] = ACTIONS(29),
    [anon_sym_AMP_AMP] = ACTIONS(31),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(207),
    [sym__number_literal] = ACTIONS(209),
    [anon_sym_SQUOTE] = ACTIONS(207),
    [anon_sym_DQUOTE] = ACTIONS(207),
    [sym_dots] = ACTIONS(209),
    [sym_dot_dot_i] = ACTIONS(209),
    [sym_next] = ACTIONS(209),
    [sym_break] = ACTIONS(209),
    [sym_true] = ACTIONS(209),
    [sym_false] = ACTIONS(209),
    [sym_null] = ACTIONS(209),
    [sym_inf] = ACTIONS(209),
    [sym_nan] = ACTIONS(209),
    [anon_sym_NA] = ACTIONS(209),
    [anon_sym_NA_integer_] = ACTIONS(209),
    [anon_sym_NA_real_] = ACTIONS(209),
    [anon_sym_NA_complex_] = ACTIONS(209),
    [anon_sym_NA_character_] = ACTIONS(209),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(207),
    [sym__semicolon] = ACTIONS(207),
    [sym__raw_string_open] = ACTIONS(207),
    [sym__external_else] = ACTIONS(207),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(207),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [64] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(211),
    [sym_identifier] = ACTIONS(213),
    [anon_sym_BSLASH] = ACTIONS(211),
    [anon_sym_function] = ACTIONS(213),
    [anon_sym_EQ] = ACTIONS(11),
    [anon_sym_if] = ACTIONS(213),
    [anon_sym_for] = ACTIONS(213),
    [anon_sym_while] = ACTIONS(213),
    [anon_sym_repeat] = ACTIONS(213),
    [anon_sym_QMARK] = ACTIONS(211),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_BANG] = ACTIONS(213),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(19),
    [anon_sym_LT_LT_DASH] = ACTIONS(19),
    [anon_sym_COLON_EQ] = ACTIONS(19),
    [anon_sym_DASH_GT] = ACTIONS(21),
    [anon_sym_DASH_GT_GT] = ACTIONS(23),
    [anon_sym_PIPE] = ACTIONS(25),
    [anon_sym_AMP] = ACTIONS(27),
    [anon_sym_PIPE_PIPE] = ACTIONS(29),
    [anon_sym_AMP_AMP] = ACTIONS(31),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(211),
    [sym__number_literal] = ACTIONS(213),
    [anon_sym_SQUOTE] = ACTIONS(211),
    [anon_sym_DQUOTE] = ACTIONS(211),
    [sym_dots] = ACTIONS(213),
    [sym_dot_dot_i] = ACTIONS(213),
    [sym_next] = ACTIONS(213),
    [sym_break] = ACTIONS(213),
    [sym_true] = ACTIONS(213),
    [sym_false] = ACTIONS(213),
    [sym_null] = ACTIONS(213),
    [sym_inf] = ACTIONS(213),
    [sym_nan] = ACTIONS(213),
    [anon_sym_NA] = ACTIONS(213),
    [anon_sym_NA_integer_] = ACTIONS(213),
    [anon_sym_NA_real_] = ACTIONS(213),
    [anon_sym_NA_complex_] = ACTIONS(213),
    [anon_sym_NA_character_] = ACTIONS(213),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(211),
    [sym__semicolon] = ACTIONS(211),
    [sym__raw_string_open] = ACTIONS(211),
    [sym__external_else] = ACTIONS(211),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(211),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [65] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(215),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_BSLASH] = ACTIONS(215),
    [anon_sym_function] = ACTIONS(217),
    [anon_sym_EQ] = ACTIONS(11),
    [anon_sym_if] = ACTIONS(217),
    [anon_sym_for] = ACTIONS(217),
    [anon_sym_while] = ACTIONS(217),
    [anon_sym_repeat] = ACTIONS(217),
    [anon_sym_QMARK] = ACTIONS(215),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_BANG] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(19),
    [anon_sym_LT_LT_DASH] = ACTIONS(19),
    [anon_sym_COLON_EQ] = ACTIONS(19),
    [anon_sym_DASH_GT] = ACTIONS(21),
    [anon_sym_DASH_GT_GT] = ACTIONS(23),
    [anon_sym_PIPE] = ACTIONS(25),
    [anon_sym_AMP] = ACTIONS(27),
    [anon_sym_PIPE_PIPE] = ACTIONS(29),
    [anon_sym_AMP_AMP] = ACTIONS(31),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(215),
    [sym__number_literal] = ACTIONS(217),
    [anon_sym_SQUOTE] = ACTIONS(215),
    [anon_sym_DQUOTE] = ACTIONS(215),
    [sym_dots] = ACTIONS(217),
    [sym_dot_dot_i] = ACTIONS(217),
    [sym_next] = ACTIONS(217),
    [sym_break] = ACTIONS(217),
    [sym_true] = ACTIONS(217),
    [sym_false] = ACTIONS(217),
    [sym_null] = ACTIONS(217),
    [sym_inf] = ACTIONS(217),
    [sym_nan] = ACTIONS(217),
    [anon_sym_NA] = ACTIONS(217),
    [anon_sym_NA_integer_] = ACTIONS(217),
    [anon_sym_NA_real_] = ACTIONS(217),
    [anon_sym_NA_complex_] = ACTIONS(217),
    [anon_sym_NA_character_] = ACTIONS(217),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(215),
    [sym__semicolon] = ACTIONS(215),
    [sym__raw_string_open] = ACTIONS(215),
    [sym__external_else] = ACTIONS(215),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(215),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [66] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(219),
    [sym_identifier] = ACTIONS(221),
    [anon_sym_BSLASH] = ACTIONS(219),
    [anon_sym_function] = ACTIONS(221),
    [anon_sym_EQ] = ACTIONS(11),
    [anon_sym_if] = ACTIONS(221),
    [anon_sym_for] = ACTIONS(221),
    [anon_sym_while] = ACTIONS(221),
    [anon_sym_repeat] = ACTIONS(221),
    [anon_sym_QMARK] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_BANG] = ACTIONS(221),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(19),
    [anon_sym_LT_LT_DASH] = ACTIONS(19),
    [anon_sym_COLON_EQ] = ACTIONS(19),
    [anon_sym_DASH_GT] = ACTIONS(21),
    [anon_sym_DASH_GT_GT] = ACTIONS(23),
    [anon_sym_PIPE] = ACTIONS(25),
    [anon_sym_AMP] = ACTIONS(27),
    [anon_sym_PIPE_PIPE] = ACTIONS(29),
    [anon_sym_AMP_AMP] = ACTIONS(31),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(219),
    [sym__number_literal] = ACTIONS(221),
    [anon_sym_SQUOTE] = ACTIONS(219),
    [anon_sym_DQUOTE] = ACTIONS(219),
    [sym_dots] = ACTIONS(221),
    [sym_dot_dot_i] = ACTIONS(221),
    [sym_next] = ACTIONS(221),
    [sym_break] = ACTIONS(221),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [sym_null] = ACTIONS(221),
    [sym_inf] = ACTIONS(221),
    [sym_nan] = ACTIONS(221),
    [anon_sym_NA] = ACTIONS(221),
    [anon_sym_NA_integer_] = ACTIONS(221),
    [anon_sym_NA_real_] = ACTIONS(221),
    [anon_sym_NA_complex_] = ACTIONS(221),
    [anon_sym_NA_character_] = ACTIONS(221),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(219),
    [sym__semicolon] = ACTIONS(219),
    [sym__raw_string_open] = ACTIONS(219),
    [sym__external_else] = ACTIONS(219),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(219),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [67] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(223),
    [sym_identifier] = ACTIONS(225),
    [anon_sym_BSLASH] = ACTIONS(223),
    [anon_sym_function] = ACTIONS(225),
    [anon_sym_EQ] = ACTIONS(11),
    [anon_sym_if] = ACTIONS(225),
    [anon_sym_for] = ACTIONS(225),
    [anon_sym_while] = ACTIONS(225),
    [anon_sym_repeat] = ACTIONS(225),
    [anon_sym_QMARK] = ACTIONS(223),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_BANG] = ACTIONS(225),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(19),
    [anon_sym_LT_LT_DASH] = ACTIONS(19),
    [anon_sym_COLON_EQ] = ACTIONS(19),
    [anon_sym_DASH_GT] = ACTIONS(21),
    [anon_sym_DASH_GT_GT] = ACTIONS(23),
    [anon_sym_PIPE] = ACTIONS(25),
    [anon_sym_AMP] = ACTIONS(27),
    [anon_sym_PIPE_PIPE] = ACTIONS(29),
    [anon_sym_AMP_AMP] = ACTIONS(31),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(223),
    [sym__number_literal] = ACTIONS(225),
    [anon_sym_SQUOTE] = ACTIONS(223),
    [anon_sym_DQUOTE] = ACTIONS(223),
    [sym_dots] = ACTIONS(225),
    [sym_dot_dot_i] = ACTIONS(225),
    [sym_next] = ACTIONS(225),
    [sym_break] = ACTIONS(225),
    [sym_true] = ACTIONS(225),
    [sym_false] = ACTIONS(225),
    [sym_null] = ACTIONS(225),
    [sym_inf] = ACTIONS(225),
    [sym_nan] = ACTIONS(225),
    [anon_sym_NA] = ACTIONS(225),
    [anon_sym_NA_integer_] = ACTIONS(225),
    [anon_sym_NA_real_] = ACTIONS(225),
    [anon_sym_NA_complex_] = ACTIONS(225),
    [anon_sym_NA_character_] = ACTIONS(225),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(223),
    [sym__semicolon] = ACTIONS(223),
    [sym__raw_string_open] = ACTIONS(223),
    [sym__external_else] = ACTIONS(223),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(223),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [68] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(227),
    [sym_identifier] = ACTIONS(229),
    [anon_sym_BSLASH] = ACTIONS(227),
    [anon_sym_function] = ACTIONS(229),
    [anon_sym_EQ] = ACTIONS(11),
    [anon_sym_if] = ACTIONS(229),
    [anon_sym_for] = ACTIONS(229),
    [anon_sym_while] = ACTIONS(229),
    [anon_sym_repeat] = ACTIONS(229),
    [anon_sym_QMARK] = ACTIONS(227),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_BANG] = ACTIONS(229),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(19),
    [anon_sym_LT_LT_DASH] = ACTIONS(19),
    [anon_sym_COLON_EQ] = ACTIONS(19),
    [anon_sym_DASH_GT] = ACTIONS(21),
    [anon_sym_DASH_GT_GT] = ACTIONS(23),
    [anon_sym_PIPE] = ACTIONS(25),
    [anon_sym_AMP] = ACTIONS(27),
    [anon_sym_PIPE_PIPE] = ACTIONS(29),
    [anon_sym_AMP_AMP] = ACTIONS(31),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(227),
    [sym__number_literal] = ACTIONS(229),
    [anon_sym_SQUOTE] = ACTIONS(227),
    [anon_sym_DQUOTE] = ACTIONS(227),
    [sym_dots] = ACTIONS(229),
    [sym_dot_dot_i] = ACTIONS(229),
    [sym_next] = ACTIONS(229),
    [sym_break] = ACTIONS(229),
    [sym_true] = ACTIONS(229),
    [sym_false] = ACTIONS(229),
    [sym_null] = ACTIONS(229),
    [sym_inf] = ACTIONS(229),
    [sym_nan] = ACTIONS(229),
    [anon_sym_NA] = ACTIONS(229),
    [anon_sym_NA_integer_] = ACTIONS(229),
    [anon_sym_NA_real_] = ACTIONS(229),
    [anon_sym_NA_complex_] = ACTIONS(229),
    [anon_sym_NA_character_] = ACTIONS(229),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(227),
    [sym__semicolon] = ACTIONS(227),
    [sym__raw_string_open] = ACTIONS(227),
    [sym__external_else] = ACTIONS(227),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(227),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [69] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(231),
    [sym_identifier] = ACTIONS(233),
    [anon_sym_BSLASH] = ACTIONS(231),
    [anon_sym_function] = ACTIONS(233),
    [anon_sym_EQ] = ACTIONS(11),
    [anon_sym_if] = ACTIONS(233),
    [anon_sym_for] = ACTIONS(233),
    [anon_sym_while] = ACTIONS(233),
    [anon_sym_repeat] = ACTIONS(233),
    [anon_sym_QMARK] = ACTIONS(231),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_BANG] = ACTIONS(233),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(19),
    [anon_sym_LT_LT_DASH] = ACTIONS(19),
    [anon_sym_COLON_EQ] = ACTIONS(19),
    [anon_sym_DASH_GT] = ACTIONS(21),
    [anon_sym_DASH_GT_GT] = ACTIONS(23),
    [anon_sym_PIPE] = ACTIONS(25),
    [anon_sym_AMP] = ACTIONS(27),
    [anon_sym_PIPE_PIPE] = ACTIONS(29),
    [anon_sym_AMP_AMP] = ACTIONS(31),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(231),
    [sym__number_literal] = ACTIONS(233),
    [anon_sym_SQUOTE] = ACTIONS(231),
    [anon_sym_DQUOTE] = ACTIONS(231),
    [sym_dots] = ACTIONS(233),
    [sym_dot_dot_i] = ACTIONS(233),
    [sym_next] = ACTIONS(233),
    [sym_break] = ACTIONS(233),
    [sym_true] = ACTIONS(233),
    [sym_false] = ACTIONS(233),
    [sym_null] = ACTIONS(233),
    [sym_inf] = ACTIONS(233),
    [sym_nan] = ACTIONS(233),
    [anon_sym_NA] = ACTIONS(233),
    [anon_sym_NA_integer_] = ACTIONS(233),
    [anon_sym_NA_real_] = ACTIONS(233),
    [anon_sym_NA_complex_] = ACTIONS(233),
    [anon_sym_NA_character_] = ACTIONS(233),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(231),
    [sym__semicolon] = ACTIONS(231),
    [sym__raw_string_open] = ACTIONS(231),
    [sym__external_else] = ACTIONS(231),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(231),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [70] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(235),
    [sym_identifier] = ACTIONS(237),
    [anon_sym_BSLASH] = ACTIONS(235),
    [anon_sym_function] = ACTIONS(237),
    [anon_sym_EQ] = ACTIONS(11),
    [anon_sym_if] = ACTIONS(237),
    [anon_sym_for] = ACTIONS(237),
    [anon_sym_while] = ACTIONS(237),
    [anon_sym_repeat] = ACTIONS(237),
    [anon_sym_QMARK] = ACTIONS(235),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_BANG] = ACTIONS(237),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(19),
    [anon_sym_LT_LT_DASH] = ACTIONS(19),
    [anon_sym_COLON_EQ] = ACTIONS(19),
    [anon_sym_DASH_GT] = ACTIONS(21),
    [anon_sym_DASH_GT_GT] = ACTIONS(23),
    [anon_sym_PIPE] = ACTIONS(25),
    [anon_sym_AMP] = ACTIONS(27),
    [anon_sym_PIPE_PIPE] = ACTIONS(29),
    [anon_sym_AMP_AMP] = ACTIONS(31),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(235),
    [sym__number_literal] = ACTIONS(237),
    [anon_sym_SQUOTE] = ACTIONS(235),
    [anon_sym_DQUOTE] = ACTIONS(235),
    [sym_dots] = ACTIONS(237),
    [sym_dot_dot_i] = ACTIONS(237),
    [sym_next] = ACTIONS(237),
    [sym_break] = ACTIONS(237),
    [sym_true] = ACTIONS(237),
    [sym_false] = ACTIONS(237),
    [sym_null] = ACTIONS(237),
    [sym_inf] = ACTIONS(237),
    [sym_nan] = ACTIONS(237),
    [anon_sym_NA] = ACTIONS(237),
    [anon_sym_NA_integer_] = ACTIONS(237),
    [anon_sym_NA_real_] = ACTIONS(237),
    [anon_sym_NA_complex_] = ACTIONS(237),
    [anon_sym_NA_character_] = ACTIONS(237),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(235),
    [sym__semicolon] = ACTIONS(235),
    [sym__raw_string_open] = ACTIONS(235),
    [sym__external_else] = ACTIONS(235),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(235),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [71] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(239),
    [sym_identifier] = ACTIONS(241),
    [anon_sym_BSLASH] = ACTIONS(239),
    [anon_sym_function] = ACTIONS(241),
    [anon_sym_EQ] = ACTIONS(11),
    [anon_sym_if] = ACTIONS(241),
    [anon_sym_for] = ACTIONS(241),
    [anon_sym_while] = ACTIONS(241),
    [anon_sym_repeat] = ACTIONS(241),
    [anon_sym_QMARK] = ACTIONS(239),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_BANG] = ACTIONS(241),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(19),
    [anon_sym_LT_LT_DASH] = ACTIONS(19),
    [anon_sym_COLON_EQ] = ACTIONS(19),
    [anon_sym_DASH_GT] = ACTIONS(21),
    [anon_sym_DASH_GT_GT] = ACTIONS(23),
    [anon_sym_PIPE] = ACTIONS(25),
    [anon_sym_AMP] = ACTIONS(27),
    [anon_sym_PIPE_PIPE] = ACTIONS(29),
    [anon_sym_AMP_AMP] = ACTIONS(31),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(239),
    [sym__number_literal] = ACTIONS(241),
    [anon_sym_SQUOTE] = ACTIONS(239),
    [anon_sym_DQUOTE] = ACTIONS(239),
    [sym_dots] = ACTIONS(241),
    [sym_dot_dot_i] = ACTIONS(241),
    [sym_next] = ACTIONS(241),
    [sym_break] = ACTIONS(241),
    [sym_true] = ACTIONS(241),
    [sym_false] = ACTIONS(241),
    [sym_null] = ACTIONS(241),
    [sym_inf] = ACTIONS(241),
    [sym_nan] = ACTIONS(241),
    [anon_sym_NA] = ACTIONS(241),
    [anon_sym_NA_integer_] = ACTIONS(241),
    [anon_sym_NA_real_] = ACTIONS(241),
    [anon_sym_NA_complex_] = ACTIONS(241),
    [anon_sym_NA_character_] = ACTIONS(241),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(239),
    [sym__semicolon] = ACTIONS(239),
    [sym__raw_string_open] = ACTIONS(239),
    [sym__external_else] = ACTIONS(239),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(239),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [72] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(243),
    [sym_identifier] = ACTIONS(245),
    [anon_sym_BSLASH] = ACTIONS(243),
    [anon_sym_function] = ACTIONS(245),
    [anon_sym_EQ] = ACTIONS(11),
    [anon_sym_if] = ACTIONS(245),
    [anon_sym_for] = ACTIONS(245),
    [anon_sym_while] = ACTIONS(245),
    [anon_sym_repeat] = ACTIONS(245),
    [anon_sym_QMARK] = ACTIONS(243),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_BANG] = ACTIONS(245),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(19),
    [anon_sym_LT_LT_DASH] = ACTIONS(19),
    [anon_sym_COLON_EQ] = ACTIONS(19),
    [anon_sym_DASH_GT] = ACTIONS(21),
    [anon_sym_DASH_GT_GT] = ACTIONS(23),
    [anon_sym_PIPE] = ACTIONS(25),
    [anon_sym_AMP] = ACTIONS(27),
    [anon_sym_PIPE_PIPE] = ACTIONS(29),
    [anon_sym_AMP_AMP] = ACTIONS(31),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(243),
    [sym__number_literal] = ACTIONS(245),
    [anon_sym_SQUOTE] = ACTIONS(243),
    [anon_sym_DQUOTE] = ACTIONS(243),
    [sym_dots] = ACTIONS(245),
    [sym_dot_dot_i] = ACTIONS(245),
    [sym_next] = ACTIONS(245),
    [sym_break] = ACTIONS(245),
    [sym_true] = ACTIONS(245),
    [sym_false] = ACTIONS(245),
    [sym_null] = ACTIONS(245),
    [sym_inf] = ACTIONS(245),
    [sym_nan] = ACTIONS(245),
    [anon_sym_NA] = ACTIONS(245),
    [anon_sym_NA_integer_] = ACTIONS(245),
    [anon_sym_NA_real_] = ACTIONS(245),
    [anon_sym_NA_complex_] = ACTIONS(245),
    [anon_sym_NA_character_] = ACTIONS(245),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(243),
    [sym__semicolon] = ACTIONS(243),
    [sym__raw_string_open] = ACTIONS(243),
    [sym__external_else] = ACTIONS(243),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(243),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [73] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(149),
    [sym_identifier] = ACTIONS(147),
    [anon_sym_BSLASH] = ACTIONS(149),
    [anon_sym_function] = ACTIONS(147),
    [anon_sym_EQ] = ACTIONS(11),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_for] = ACTIONS(147),
    [anon_sym_while] = ACTIONS(147),
    [anon_sym_repeat] = ACTIONS(147),
    [anon_sym_QMARK] = ACTIONS(149),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_BANG] = ACTIONS(147),
    [anon_sym_PLUS] = ACTIONS(15),
    [anon_sym_DASH] = ACTIONS(17),
    [anon_sym_LT_DASH] = ACTIONS(19),
    [anon_sym_LT_LT_DASH] = ACTIONS(19),
    [anon_sym_COLON_EQ] = ACTIONS(19),
    [anon_sym_DASH_GT] = ACTIONS(21),
    [anon_sym_DASH_GT_GT] = ACTIONS(23),
    [anon_sym_PIPE] = ACTIONS(25),
    [anon_sym_AMP] = ACTIONS(27),
    [anon_sym_PIPE_PIPE] = ACTIONS(29),
    [anon_sym_AMP_AMP] = ACTIONS(31),
    [anon_sym_LT] = ACTIONS(33),
    [anon_sym_LT_EQ] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(33),
    [anon_sym_GT_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(149),
    [sym__number_literal] = ACTIONS(147),
    [anon_sym_SQUOTE] = ACTIONS(149),
    [anon_sym_DQUOTE] = ACTIONS(149),
    [sym_dots] = ACTIONS(147),
    [sym_dot_dot_i] = ACTIONS(147),
    [sym_next] = ACTIONS(147),
    [sym_break] = ACTIONS(147),
    [sym_true] = ACTIONS(147),
    [sym_false] = ACTIONS(147),
    [sym_null] = ACTIONS(147),
    [sym_inf] = ACTIONS(147),
    [sym_nan] = ACTIONS(147),
    [anon_sym_NA] = ACTIONS(147),
    [anon_sym_NA_integer_] = ACTIONS(147),
    [anon_sym_NA_real_] = ACTIONS(147),
    [anon_sym_NA_complex_] = ACTIONS(147),
    [anon_sym_NA_character_] = ACTIONS(147),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(149),
    [sym__semicolon] = ACTIONS(149),
    [sym__raw_string_open] = ACTIONS(149),
    [sym__external_else] = ACTIONS(149),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(149),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [74] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(153),
    [anon_sym_BSLASH] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(153),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(153),
    [anon_sym_for] = ACTIONS(153),
    [anon_sym_while] = ACTIONS(153),
    [anon_sym_repeat] = ACTIONS(153),
    [anon_sym_QMARK] = ACTIONS(151),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_BANG] = ACTIONS(153),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(69),
    [anon_sym_LT_LT_DASH] = ACTIONS(69),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(71),
    [anon_sym_DASH_GT_GT] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(77),
    [anon_sym_PIPE_PIPE] = ACTIONS(79),
    [anon_sym_AMP_AMP] = ACTIONS(81),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(151),
    [sym__number_literal] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(151),
    [anon_sym_DQUOTE] = ACTIONS(151),
    [sym_dots] = ACTIONS(153),
    [sym_dot_dot_i] = ACTIONS(153),
    [sym_next] = ACTIONS(153),
    [sym_break] = ACTIONS(153),
    [sym_true] = ACTIONS(153),
    [sym_false] = ACTIONS(153),
    [sym_null] = ACTIONS(153),
    [sym_inf] = ACTIONS(153),
    [sym_nan] = ACTIONS(153),
    [anon_sym_NA] = ACTIONS(153),
    [anon_sym_NA_integer_] = ACTIONS(153),
    [anon_sym_NA_real_] = ACTIONS(153),
    [anon_sym_NA_complex_] = ACTIONS(153),
    [anon_sym_NA_character_] = ACTIONS(153),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(151),
    [sym__semicolon] = ACTIONS(151),
    [sym__raw_string_open] = ACTIONS(151),
    [sym__external_else] = ACTIONS(151),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(151),
    [sym__external_close_brace] = ACTIONS(151),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [75] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(157),
    [anon_sym_BSLASH] = ACTIONS(155),
    [anon_sym_function] = ACTIONS(157),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(157),
    [anon_sym_for] = ACTIONS(157),
    [anon_sym_while] = ACTIONS(157),
    [anon_sym_repeat] = ACTIONS(157),
    [anon_sym_QMARK] = ACTIONS(155),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_BANG] = ACTIONS(157),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(69),
    [anon_sym_LT_LT_DASH] = ACTIONS(69),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(71),
    [anon_sym_DASH_GT_GT] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(77),
    [anon_sym_PIPE_PIPE] = ACTIONS(79),
    [anon_sym_AMP_AMP] = ACTIONS(81),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(155),
    [sym__number_literal] = ACTIONS(157),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [anon_sym_DQUOTE] = ACTIONS(155),
    [sym_dots] = ACTIONS(157),
    [sym_dot_dot_i] = ACTIONS(157),
    [sym_next] = ACTIONS(157),
    [sym_break] = ACTIONS(157),
    [sym_true] = ACTIONS(157),
    [sym_false] = ACTIONS(157),
    [sym_null] = ACTIONS(157),
    [sym_inf] = ACTIONS(157),
    [sym_nan] = ACTIONS(157),
    [anon_sym_NA] = ACTIONS(157),
    [anon_sym_NA_integer_] = ACTIONS(157),
    [anon_sym_NA_real_] = ACTIONS(157),
    [anon_sym_NA_complex_] = ACTIONS(157),
    [anon_sym_NA_character_] = ACTIONS(157),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(155),
    [sym__semicolon] = ACTIONS(155),
    [sym__raw_string_open] = ACTIONS(155),
    [sym__external_else] = ACTIONS(155),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(155),
    [sym__external_close_brace] = ACTIONS(155),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [76] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(157),
    [anon_sym_BSLASH] = ACTIONS(155),
    [anon_sym_function] = ACTIONS(157),
    [anon_sym_EQ] = ACTIONS(157),
    [anon_sym_if] = ACTIONS(157),
    [anon_sym_for] = ACTIONS(157),
    [anon_sym_while] = ACTIONS(157),
    [anon_sym_repeat] = ACTIONS(157),
    [anon_sym_QMARK] = ACTIONS(155),
    [anon_sym_TILDE] = ACTIONS(155),
    [anon_sym_BANG] = ACTIONS(157),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(155),
    [anon_sym_LT_LT_DASH] = ACTIONS(155),
    [anon_sym_COLON_EQ] = ACTIONS(155),
    [anon_sym_DASH_GT] = ACTIONS(157),
    [anon_sym_DASH_GT_GT] = ACTIONS(155),
    [anon_sym_PIPE] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(77),
    [anon_sym_PIPE_PIPE] = ACTIONS(79),
    [anon_sym_AMP_AMP] = ACTIONS(81),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(155),
    [sym__number_literal] = ACTIONS(157),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [anon_sym_DQUOTE] = ACTIONS(155),
    [sym_dots] = ACTIONS(157),
    [sym_dot_dot_i] = ACTIONS(157),
    [sym_next] = ACTIONS(157),
    [sym_break] = ACTIONS(157),
    [sym_true] = ACTIONS(157),
    [sym_false] = ACTIONS(157),
    [sym_null] = ACTIONS(157),
    [sym_inf] = ACTIONS(157),
    [sym_nan] = ACTIONS(157),
    [anon_sym_NA] = ACTIONS(157),
    [anon_sym_NA_integer_] = ACTIONS(157),
    [anon_sym_NA_real_] = ACTIONS(157),
    [anon_sym_NA_complex_] = ACTIONS(157),
    [anon_sym_NA_character_] = ACTIONS(157),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(155),
    [sym__semicolon] = ACTIONS(155),
    [sym__raw_string_open] = ACTIONS(155),
    [sym__external_else] = ACTIONS(155),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(155),
    [sym__external_close_brace] = ACTIONS(155),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [77] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(157),
    [anon_sym_BSLASH] = ACTIONS(155),
    [anon_sym_function] = ACTIONS(157),
    [anon_sym_EQ] = ACTIONS(157),
    [anon_sym_if] = ACTIONS(157),
    [anon_sym_for] = ACTIONS(157),
    [anon_sym_while] = ACTIONS(157),
    [anon_sym_repeat] = ACTIONS(157),
    [anon_sym_QMARK] = ACTIONS(155),
    [anon_sym_TILDE] = ACTIONS(155),
    [anon_sym_BANG] = ACTIONS(157),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(155),
    [anon_sym_LT_LT_DASH] = ACTIONS(155),
    [anon_sym_COLON_EQ] = ACTIONS(155),
    [anon_sym_DASH_GT] = ACTIONS(157),
    [anon_sym_DASH_GT_GT] = ACTIONS(155),
    [anon_sym_PIPE] = ACTIONS(157),
    [anon_sym_AMP] = ACTIONS(157),
    [anon_sym_PIPE_PIPE] = ACTIONS(155),
    [anon_sym_AMP_AMP] = ACTIONS(155),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(155),
    [sym__number_literal] = ACTIONS(157),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [anon_sym_DQUOTE] = ACTIONS(155),
    [sym_dots] = ACTIONS(157),
    [sym_dot_dot_i] = ACTIONS(157),
    [sym_next] = ACTIONS(157),
    [sym_break] = ACTIONS(157),
    [sym_true] = ACTIONS(157),
    [sym_false] = ACTIONS(157),
    [sym_null] = ACTIONS(157),
    [sym_inf] = ACTIONS(157),
    [sym_nan] = ACTIONS(157),
    [anon_sym_NA] = ACTIONS(157),
    [anon_sym_NA_integer_] = ACTIONS(157),
    [anon_sym_NA_real_] = ACTIONS(157),
    [anon_sym_NA_complex_] = ACTIONS(157),
    [anon_sym_NA_character_] = ACTIONS(157),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(155),
    [sym__semicolon] = ACTIONS(155),
    [sym__raw_string_open] = ACTIONS(155),
    [sym__external_else] = ACTIONS(155),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(155),
    [sym__external_close_brace] = ACTIONS(155),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [78] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(157),
    [anon_sym_BSLASH] = ACTIONS(155),
    [anon_sym_function] = ACTIONS(157),
    [anon_sym_EQ] = ACTIONS(157),
    [anon_sym_if] = ACTIONS(157),
    [anon_sym_for] = ACTIONS(157),
    [anon_sym_while] = ACTIONS(157),
    [anon_sym_repeat] = ACTIONS(157),
    [anon_sym_QMARK] = ACTIONS(155),
    [anon_sym_TILDE] = ACTIONS(155),
    [anon_sym_BANG] = ACTIONS(157),
    [anon_sym_PLUS] = ACTIONS(155),
    [anon_sym_DASH] = ACTIONS(157),
    [anon_sym_LT_DASH] = ACTIONS(155),
    [anon_sym_LT_LT_DASH] = ACTIONS(155),
    [anon_sym_COLON_EQ] = ACTIONS(155),
    [anon_sym_DASH_GT] = ACTIONS(157),
    [anon_sym_DASH_GT_GT] = ACTIONS(155),
    [anon_sym_PIPE] = ACTIONS(157),
    [anon_sym_AMP] = ACTIONS(157),
    [anon_sym_PIPE_PIPE] = ACTIONS(155),
    [anon_sym_AMP_AMP] = ACTIONS(155),
    [anon_sym_LT] = ACTIONS(157),
    [anon_sym_LT_EQ] = ACTIONS(155),
    [anon_sym_GT] = ACTIONS(157),
    [anon_sym_GT_EQ] = ACTIONS(155),
    [anon_sym_EQ_EQ] = ACTIONS(155),
    [anon_sym_BANG_EQ] = ACTIONS(155),
    [anon_sym_STAR] = ACTIONS(157),
    [anon_sym_SLASH] = ACTIONS(155),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(155),
    [anon_sym_PIPE_GT] = ACTIONS(155),
    [anon_sym_COLON] = ACTIONS(157),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(155),
    [sym__number_literal] = ACTIONS(157),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [anon_sym_DQUOTE] = ACTIONS(155),
    [sym_dots] = ACTIONS(157),
    [sym_dot_dot_i] = ACTIONS(157),
    [sym_next] = ACTIONS(157),
    [sym_break] = ACTIONS(157),
    [sym_true] = ACTIONS(157),
    [sym_false] = ACTIONS(157),
    [sym_null] = ACTIONS(157),
    [sym_inf] = ACTIONS(157),
    [sym_nan] = ACTIONS(157),
    [anon_sym_NA] = ACTIONS(157),
    [anon_sym_NA_integer_] = ACTIONS(157),
    [anon_sym_NA_real_] = ACTIONS(157),
    [anon_sym_NA_complex_] = ACTIONS(157),
    [anon_sym_NA_character_] = ACTIONS(157),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(155),
    [sym__semicolon] = ACTIONS(155),
    [sym__raw_string_open] = ACTIONS(155),
    [sym__external_else] = ACTIONS(155),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(155),
    [sym__external_close_brace] = ACTIONS(155),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [79] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(161),
    [anon_sym_BSLASH] = ACTIONS(159),
    [anon_sym_function] = ACTIONS(161),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(161),
    [anon_sym_for] = ACTIONS(161),
    [anon_sym_while] = ACTIONS(161),
    [anon_sym_repeat] = ACTIONS(161),
    [anon_sym_QMARK] = ACTIONS(159),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_BANG] = ACTIONS(161),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(69),
    [anon_sym_LT_LT_DASH] = ACTIONS(69),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(71),
    [anon_sym_DASH_GT_GT] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(77),
    [anon_sym_PIPE_PIPE] = ACTIONS(79),
    [anon_sym_AMP_AMP] = ACTIONS(81),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(159),
    [sym__number_literal] = ACTIONS(161),
    [anon_sym_SQUOTE] = ACTIONS(159),
    [anon_sym_DQUOTE] = ACTIONS(159),
    [sym_dots] = ACTIONS(161),
    [sym_dot_dot_i] = ACTIONS(161),
    [sym_next] = ACTIONS(161),
    [sym_break] = ACTIONS(161),
    [sym_true] = ACTIONS(161),
    [sym_false] = ACTIONS(161),
    [sym_null] = ACTIONS(161),
    [sym_inf] = ACTIONS(161),
    [sym_nan] = ACTIONS(161),
    [anon_sym_NA] = ACTIONS(161),
    [anon_sym_NA_integer_] = ACTIONS(161),
    [anon_sym_NA_real_] = ACTIONS(161),
    [anon_sym_NA_complex_] = ACTIONS(161),
    [anon_sym_NA_character_] = ACTIONS(161),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(159),
    [sym__semicolon] = ACTIONS(159),
    [sym__raw_string_open] = ACTIONS(159),
    [sym__external_else] = ACTIONS(159),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(159),
    [sym__external_close_brace] = ACTIONS(159),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [80] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(165),
    [anon_sym_BSLASH] = ACTIONS(163),
    [anon_sym_function] = ACTIONS(165),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(165),
    [anon_sym_for] = ACTIONS(165),
    [anon_sym_while] = ACTIONS(165),
    [anon_sym_repeat] = ACTIONS(165),
    [anon_sym_QMARK] = ACTIONS(163),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_BANG] = ACTIONS(165),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(69),
    [anon_sym_LT_LT_DASH] = ACTIONS(69),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(71),
    [anon_sym_DASH_GT_GT] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(77),
    [anon_sym_PIPE_PIPE] = ACTIONS(79),
    [anon_sym_AMP_AMP] = ACTIONS(81),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(163),
    [sym__number_literal] = ACTIONS(165),
    [anon_sym_SQUOTE] = ACTIONS(163),
    [anon_sym_DQUOTE] = ACTIONS(163),
    [sym_dots] = ACTIONS(165),
    [sym_dot_dot_i] = ACTIONS(165),
    [sym_next] = ACTIONS(165),
    [sym_break] = ACTIONS(165),
    [sym_true] = ACTIONS(165),
    [sym_false] = ACTIONS(165),
    [sym_null] = ACTIONS(165),
    [sym_inf] = ACTIONS(165),
    [sym_nan] = ACTIONS(165),
    [anon_sym_NA] = ACTIONS(165),
    [anon_sym_NA_integer_] = ACTIONS(165),
    [anon_sym_NA_real_] = ACTIONS(165),
    [anon_sym_NA_complex_] = ACTIONS(165),
    [anon_sym_NA_character_] = ACTIONS(165),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(163),
    [sym__semicolon] = ACTIONS(163),
    [sym__raw_string_open] = ACTIONS(163),
    [sym__external_else] = ACTIONS(163),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(163),
    [sym__external_close_brace] = ACTIONS(163),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [81] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(169),
    [anon_sym_BSLASH] = ACTIONS(167),
    [anon_sym_function] = ACTIONS(169),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(169),
    [anon_sym_for] = ACTIONS(169),
    [anon_sym_while] = ACTIONS(169),
    [anon_sym_repeat] = ACTIONS(169),
    [anon_sym_QMARK] = ACTIONS(167),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_BANG] = ACTIONS(169),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(69),
    [anon_sym_LT_LT_DASH] = ACTIONS(69),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(71),
    [anon_sym_DASH_GT_GT] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(77),
    [anon_sym_PIPE_PIPE] = ACTIONS(79),
    [anon_sym_AMP_AMP] = ACTIONS(81),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(167),
    [sym__number_literal] = ACTIONS(169),
    [anon_sym_SQUOTE] = ACTIONS(167),
    [anon_sym_DQUOTE] = ACTIONS(167),
    [sym_dots] = ACTIONS(169),
    [sym_dot_dot_i] = ACTIONS(169),
    [sym_next] = ACTIONS(169),
    [sym_break] = ACTIONS(169),
    [sym_true] = ACTIONS(169),
    [sym_false] = ACTIONS(169),
    [sym_null] = ACTIONS(169),
    [sym_inf] = ACTIONS(169),
    [sym_nan] = ACTIONS(169),
    [anon_sym_NA] = ACTIONS(169),
    [anon_sym_NA_integer_] = ACTIONS(169),
    [anon_sym_NA_real_] = ACTIONS(169),
    [anon_sym_NA_complex_] = ACTIONS(169),
    [anon_sym_NA_character_] = ACTIONS(169),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(167),
    [sym__semicolon] = ACTIONS(167),
    [sym__raw_string_open] = ACTIONS(167),
    [sym__external_else] = ACTIONS(167),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(167),
    [sym__external_close_brace] = ACTIONS(167),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [82] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(169),
    [anon_sym_BSLASH] = ACTIONS(167),
    [anon_sym_function] = ACTIONS(169),
    [anon_sym_EQ] = ACTIONS(169),
    [anon_sym_if] = ACTIONS(169),
    [anon_sym_for] = ACTIONS(169),
    [anon_sym_while] = ACTIONS(169),
    [anon_sym_repeat] = ACTIONS(169),
    [anon_sym_QMARK] = ACTIONS(167),
    [anon_sym_TILDE] = ACTIONS(167),
    [anon_sym_BANG] = ACTIONS(169),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(167),
    [anon_sym_LT_LT_DASH] = ACTIONS(167),
    [anon_sym_COLON_EQ] = ACTIONS(167),
    [anon_sym_DASH_GT] = ACTIONS(169),
    [anon_sym_DASH_GT_GT] = ACTIONS(167),
    [anon_sym_PIPE] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(77),
    [anon_sym_PIPE_PIPE] = ACTIONS(79),
    [anon_sym_AMP_AMP] = ACTIONS(81),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(167),
    [sym__number_literal] = ACTIONS(169),
    [anon_sym_SQUOTE] = ACTIONS(167),
    [anon_sym_DQUOTE] = ACTIONS(167),
    [sym_dots] = ACTIONS(169),
    [sym_dot_dot_i] = ACTIONS(169),
    [sym_next] = ACTIONS(169),
    [sym_break] = ACTIONS(169),
    [sym_true] = ACTIONS(169),
    [sym_false] = ACTIONS(169),
    [sym_null] = ACTIONS(169),
    [sym_inf] = ACTIONS(169),
    [sym_nan] = ACTIONS(169),
    [anon_sym_NA] = ACTIONS(169),
    [anon_sym_NA_integer_] = ACTIONS(169),
    [anon_sym_NA_real_] = ACTIONS(169),
    [anon_sym_NA_complex_] = ACTIONS(169),
    [anon_sym_NA_character_] = ACTIONS(169),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(167),
    [sym__semicolon] = ACTIONS(167),
    [sym__raw_string_open] = ACTIONS(167),
    [sym__external_else] = ACTIONS(167),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(167),
    [sym__external_close_brace] = ACTIONS(167),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [83] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(169),
    [anon_sym_BSLASH] = ACTIONS(167),
    [anon_sym_function] = ACTIONS(169),
    [anon_sym_EQ] = ACTIONS(169),
    [anon_sym_if] = ACTIONS(169),
    [anon_sym_for] = ACTIONS(169),
    [anon_sym_while] = ACTIONS(169),
    [anon_sym_repeat] = ACTIONS(169),
    [anon_sym_QMARK] = ACTIONS(167),
    [anon_sym_TILDE] = ACTIONS(167),
    [anon_sym_BANG] = ACTIONS(169),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(167),
    [anon_sym_LT_LT_DASH] = ACTIONS(167),
    [anon_sym_COLON_EQ] = ACTIONS(167),
    [anon_sym_DASH_GT] = ACTIONS(169),
    [anon_sym_DASH_GT_GT] = ACTIONS(167),
    [anon_sym_PIPE] = ACTIONS(169),
    [anon_sym_AMP] = ACTIONS(169),
    [anon_sym_PIPE_PIPE] = ACTIONS(167),
    [anon_sym_AMP_AMP] = ACTIONS(167),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(167),
    [sym__number_literal] = ACTIONS(169),
    [anon_sym_SQUOTE] = ACTIONS(167),
    [anon_sym_DQUOTE] = ACTIONS(167),
    [sym_dots] = ACTIONS(169),
    [sym_dot_dot_i] = ACTIONS(169),
    [sym_next] = ACTIONS(169),
    [sym_break] = ACTIONS(169),
    [sym_true] = ACTIONS(169),
    [sym_false] = ACTIONS(169),
    [sym_null] = ACTIONS(169),
    [sym_inf] = ACTIONS(169),
    [sym_nan] = ACTIONS(169),
    [anon_sym_NA] = ACTIONS(169),
    [anon_sym_NA_integer_] = ACTIONS(169),
    [anon_sym_NA_real_] = ACTIONS(169),
    [anon_sym_NA_complex_] = ACTIONS(169),
    [anon_sym_NA_character_] = ACTIONS(169),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(167),
    [sym__semicolon] = ACTIONS(167),
    [sym__raw_string_open] = ACTIONS(167),
    [sym__external_else] = ACTIONS(167),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(167),
    [sym__external_close_brace] = ACTIONS(167),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [84] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(169),
    [anon_sym_BSLASH] = ACTIONS(167),
    [anon_sym_function] = ACTIONS(169),
    [anon_sym_EQ] = ACTIONS(169),
    [anon_sym_if] = ACTIONS(169),
    [anon_sym_for] = ACTIONS(169),
    [anon_sym_while] = ACTIONS(169),
    [anon_sym_repeat] = ACTIONS(169),
    [anon_sym_QMARK] = ACTIONS(167),
    [anon_sym_TILDE] = ACTIONS(167),
    [anon_sym_BANG] = ACTIONS(169),
    [anon_sym_PLUS] = ACTIONS(167),
    [anon_sym_DASH] = ACTIONS(169),
    [anon_sym_LT_DASH] = ACTIONS(167),
    [anon_sym_LT_LT_DASH] = ACTIONS(167),
    [anon_sym_COLON_EQ] = ACTIONS(167),
    [anon_sym_DASH_GT] = ACTIONS(169),
    [anon_sym_DASH_GT_GT] = ACTIONS(167),
    [anon_sym_PIPE] = ACTIONS(169),
    [anon_sym_AMP] = ACTIONS(169),
    [anon_sym_PIPE_PIPE] = ACTIONS(167),
    [anon_sym_AMP_AMP] = ACTIONS(167),
    [anon_sym_LT] = ACTIONS(169),
    [anon_sym_LT_EQ] = ACTIONS(167),
    [anon_sym_GT] = ACTIONS(169),
    [anon_sym_GT_EQ] = ACTIONS(167),
    [anon_sym_EQ_EQ] = ACTIONS(167),
    [anon_sym_BANG_EQ] = ACTIONS(167),
    [anon_sym_STAR] = ACTIONS(169),
    [anon_sym_SLASH] = ACTIONS(167),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(167),
    [anon_sym_PIPE_GT] = ACTIONS(167),
    [anon_sym_COLON] = ACTIONS(169),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(167),
    [sym__number_literal] = ACTIONS(169),
    [anon_sym_SQUOTE] = ACTIONS(167),
    [anon_sym_DQUOTE] = ACTIONS(167),
    [sym_dots] = ACTIONS(169),
    [sym_dot_dot_i] = ACTIONS(169),
    [sym_next] = ACTIONS(169),
    [sym_break] = ACTIONS(169),
    [sym_true] = ACTIONS(169),
    [sym_false] = ACTIONS(169),
    [sym_null] = ACTIONS(169),
    [sym_inf] = ACTIONS(169),
    [sym_nan] = ACTIONS(169),
    [anon_sym_NA] = ACTIONS(169),
    [anon_sym_NA_integer_] = ACTIONS(169),
    [anon_sym_NA_real_] = ACTIONS(169),
    [anon_sym_NA_complex_] = ACTIONS(169),
    [anon_sym_NA_character_] = ACTIONS(169),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(167),
    [sym__semicolon] = ACTIONS(167),
    [sym__raw_string_open] = ACTIONS(167),
    [sym__external_else] = ACTIONS(167),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(167),
    [sym__external_close_brace] = ACTIONS(167),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [85] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(143),
    [anon_sym_LT_LT_DASH] = ACTIONS(143),
    [anon_sym_COLON_EQ] = ACTIONS(143),
    [anon_sym_DASH_GT] = ACTIONS(71),
    [anon_sym_DASH_GT_GT] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(77),
    [anon_sym_PIPE_PIPE] = ACTIONS(79),
    [anon_sym_AMP_AMP] = ACTIONS(81),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_else] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_close_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [86] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(69),
    [anon_sym_LT_LT_DASH] = ACTIONS(69),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(71),
    [anon_sym_DASH_GT_GT] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(77),
    [anon_sym_PIPE_PIPE] = ACTIONS(79),
    [anon_sym_AMP_AMP] = ACTIONS(81),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_else] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_close_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [87] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(143),
    [anon_sym_LT_LT_DASH] = ACTIONS(143),
    [anon_sym_COLON_EQ] = ACTIONS(143),
    [anon_sym_DASH_GT] = ACTIONS(145),
    [anon_sym_DASH_GT_GT] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(77),
    [anon_sym_PIPE_PIPE] = ACTIONS(79),
    [anon_sym_AMP_AMP] = ACTIONS(81),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_else] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_close_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [88] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_LT_DASH] = ACTIONS(143),
    [anon_sym_LT_LT_DASH] = ACTIONS(143),
    [anon_sym_COLON_EQ] = ACTIONS(143),
    [anon_sym_DASH_GT] = ACTIONS(145),
    [anon_sym_DASH_GT_GT] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(145),
    [anon_sym_PIPE_PIPE] = ACTIONS(143),
    [anon_sym_AMP_AMP] = ACTIONS(143),
    [anon_sym_LT] = ACTIONS(145),
    [anon_sym_LT_EQ] = ACTIONS(143),
    [anon_sym_GT] = ACTIONS(145),
    [anon_sym_GT_EQ] = ACTIONS(143),
    [anon_sym_EQ_EQ] = ACTIONS(143),
    [anon_sym_BANG_EQ] = ACTIONS(143),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_else] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_close_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [89] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(69),
    [anon_sym_LT_LT_DASH] = ACTIONS(69),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(71),
    [anon_sym_DASH_GT_GT] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(77),
    [anon_sym_PIPE_PIPE] = ACTIONS(79),
    [anon_sym_AMP_AMP] = ACTIONS(81),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_else] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_close_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [90] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(143),
    [anon_sym_LT_LT_DASH] = ACTIONS(143),
    [anon_sym_COLON_EQ] = ACTIONS(143),
    [anon_sym_DASH_GT] = ACTIONS(145),
    [anon_sym_DASH_GT_GT] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(77),
    [anon_sym_PIPE_PIPE] = ACTIONS(79),
    [anon_sym_AMP_AMP] = ACTIONS(81),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_else] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_close_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [91] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(143),
    [anon_sym_LT_LT_DASH] = ACTIONS(143),
    [anon_sym_COLON_EQ] = ACTIONS(143),
    [anon_sym_DASH_GT] = ACTIONS(145),
    [anon_sym_DASH_GT_GT] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(77),
    [anon_sym_PIPE_PIPE] = ACTIONS(143),
    [anon_sym_AMP_AMP] = ACTIONS(81),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_else] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_close_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [92] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(143),
    [anon_sym_LT_LT_DASH] = ACTIONS(143),
    [anon_sym_COLON_EQ] = ACTIONS(143),
    [anon_sym_DASH_GT] = ACTIONS(145),
    [anon_sym_DASH_GT_GT] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(145),
    [anon_sym_PIPE_PIPE] = ACTIONS(143),
    [anon_sym_AMP_AMP] = ACTIONS(143),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_else] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_close_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [93] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(143),
    [anon_sym_LT_LT_DASH] = ACTIONS(143),
    [anon_sym_COLON_EQ] = ACTIONS(143),
    [anon_sym_DASH_GT] = ACTIONS(145),
    [anon_sym_DASH_GT_GT] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(145),
    [anon_sym_PIPE_PIPE] = ACTIONS(143),
    [anon_sym_AMP_AMP] = ACTIONS(143),
    [anon_sym_LT] = ACTIONS(145),
    [anon_sym_LT_EQ] = ACTIONS(143),
    [anon_sym_GT] = ACTIONS(145),
    [anon_sym_GT_EQ] = ACTIONS(143),
    [anon_sym_EQ_EQ] = ACTIONS(143),
    [anon_sym_BANG_EQ] = ACTIONS(143),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_else] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_close_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [94] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_LT_DASH] = ACTIONS(143),
    [anon_sym_LT_LT_DASH] = ACTIONS(143),
    [anon_sym_COLON_EQ] = ACTIONS(143),
    [anon_sym_DASH_GT] = ACTIONS(145),
    [anon_sym_DASH_GT_GT] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(145),
    [anon_sym_PIPE_PIPE] = ACTIONS(143),
    [anon_sym_AMP_AMP] = ACTIONS(143),
    [anon_sym_LT] = ACTIONS(145),
    [anon_sym_LT_EQ] = ACTIONS(143),
    [anon_sym_GT] = ACTIONS(145),
    [anon_sym_GT_EQ] = ACTIONS(143),
    [anon_sym_EQ_EQ] = ACTIONS(143),
    [anon_sym_BANG_EQ] = ACTIONS(143),
    [anon_sym_STAR] = ACTIONS(145),
    [anon_sym_SLASH] = ACTIONS(143),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_else] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_close_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [95] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_LT_DASH] = ACTIONS(143),
    [anon_sym_LT_LT_DASH] = ACTIONS(143),
    [anon_sym_COLON_EQ] = ACTIONS(143),
    [anon_sym_DASH_GT] = ACTIONS(145),
    [anon_sym_DASH_GT_GT] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(145),
    [anon_sym_PIPE_PIPE] = ACTIONS(143),
    [anon_sym_AMP_AMP] = ACTIONS(143),
    [anon_sym_LT] = ACTIONS(145),
    [anon_sym_LT_EQ] = ACTIONS(143),
    [anon_sym_GT] = ACTIONS(145),
    [anon_sym_GT_EQ] = ACTIONS(143),
    [anon_sym_EQ_EQ] = ACTIONS(143),
    [anon_sym_BANG_EQ] = ACTIONS(143),
    [anon_sym_STAR] = ACTIONS(145),
    [anon_sym_SLASH] = ACTIONS(143),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(143),
    [anon_sym_PIPE_GT] = ACTIONS(143),
    [anon_sym_COLON] = ACTIONS(145),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_else] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_close_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [96] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_LT_DASH] = ACTIONS(143),
    [anon_sym_LT_LT_DASH] = ACTIONS(143),
    [anon_sym_COLON_EQ] = ACTIONS(143),
    [anon_sym_DASH_GT] = ACTIONS(145),
    [anon_sym_DASH_GT_GT] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(145),
    [anon_sym_PIPE_PIPE] = ACTIONS(143),
    [anon_sym_AMP_AMP] = ACTIONS(143),
    [anon_sym_LT] = ACTIONS(145),
    [anon_sym_LT_EQ] = ACTIONS(143),
    [anon_sym_GT] = ACTIONS(145),
    [anon_sym_GT_EQ] = ACTIONS(143),
    [anon_sym_EQ_EQ] = ACTIONS(143),
    [anon_sym_BANG_EQ] = ACTIONS(143),
    [anon_sym_STAR] = ACTIONS(145),
    [anon_sym_SLASH] = ACTIONS(143),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(143),
    [anon_sym_PIPE_GT] = ACTIONS(143),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_else] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_close_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [97] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_LT_DASH] = ACTIONS(143),
    [anon_sym_LT_LT_DASH] = ACTIONS(143),
    [anon_sym_COLON_EQ] = ACTIONS(143),
    [anon_sym_DASH_GT] = ACTIONS(145),
    [anon_sym_DASH_GT_GT] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(145),
    [anon_sym_PIPE_PIPE] = ACTIONS(143),
    [anon_sym_AMP_AMP] = ACTIONS(143),
    [anon_sym_LT] = ACTIONS(145),
    [anon_sym_LT_EQ] = ACTIONS(143),
    [anon_sym_GT] = ACTIONS(145),
    [anon_sym_GT_EQ] = ACTIONS(143),
    [anon_sym_EQ_EQ] = ACTIONS(143),
    [anon_sym_BANG_EQ] = ACTIONS(143),
    [anon_sym_STAR] = ACTIONS(145),
    [anon_sym_SLASH] = ACTIONS(143),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(143),
    [anon_sym_PIPE_GT] = ACTIONS(143),
    [anon_sym_COLON] = ACTIONS(145),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_else] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_close_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [98] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(173),
    [anon_sym_BSLASH] = ACTIONS(171),
    [anon_sym_function] = ACTIONS(173),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(173),
    [anon_sym_for] = ACTIONS(173),
    [anon_sym_while] = ACTIONS(173),
    [anon_sym_repeat] = ACTIONS(173),
    [anon_sym_QMARK] = ACTIONS(171),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_BANG] = ACTIONS(173),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(69),
    [anon_sym_LT_LT_DASH] = ACTIONS(69),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(71),
    [anon_sym_DASH_GT_GT] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(77),
    [anon_sym_PIPE_PIPE] = ACTIONS(79),
    [anon_sym_AMP_AMP] = ACTIONS(81),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(171),
    [sym__number_literal] = ACTIONS(173),
    [anon_sym_SQUOTE] = ACTIONS(171),
    [anon_sym_DQUOTE] = ACTIONS(171),
    [sym_dots] = ACTIONS(173),
    [sym_dot_dot_i] = ACTIONS(173),
    [sym_next] = ACTIONS(173),
    [sym_break] = ACTIONS(173),
    [sym_true] = ACTIONS(173),
    [sym_false] = ACTIONS(173),
    [sym_null] = ACTIONS(173),
    [sym_inf] = ACTIONS(173),
    [sym_nan] = ACTIONS(173),
    [anon_sym_NA] = ACTIONS(173),
    [anon_sym_NA_integer_] = ACTIONS(173),
    [anon_sym_NA_real_] = ACTIONS(173),
    [anon_sym_NA_complex_] = ACTIONS(173),
    [anon_sym_NA_character_] = ACTIONS(173),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(171),
    [sym__semicolon] = ACTIONS(171),
    [sym__raw_string_open] = ACTIONS(171),
    [sym__external_else] = ACTIONS(171),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(171),
    [sym__external_close_brace] = ACTIONS(171),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [99] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(177),
    [anon_sym_BSLASH] = ACTIONS(175),
    [anon_sym_function] = ACTIONS(177),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(177),
    [anon_sym_for] = ACTIONS(177),
    [anon_sym_while] = ACTIONS(177),
    [anon_sym_repeat] = ACTIONS(177),
    [anon_sym_QMARK] = ACTIONS(175),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_BANG] = ACTIONS(177),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(69),
    [anon_sym_LT_LT_DASH] = ACTIONS(69),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(71),
    [anon_sym_DASH_GT_GT] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(77),
    [anon_sym_PIPE_PIPE] = ACTIONS(79),
    [anon_sym_AMP_AMP] = ACTIONS(81),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(175),
    [sym__number_literal] = ACTIONS(177),
    [anon_sym_SQUOTE] = ACTIONS(175),
    [anon_sym_DQUOTE] = ACTIONS(175),
    [sym_dots] = ACTIONS(177),
    [sym_dot_dot_i] = ACTIONS(177),
    [sym_next] = ACTIONS(177),
    [sym_break] = ACTIONS(177),
    [sym_true] = ACTIONS(177),
    [sym_false] = ACTIONS(177),
    [sym_null] = ACTIONS(177),
    [sym_inf] = ACTIONS(177),
    [sym_nan] = ACTIONS(177),
    [anon_sym_NA] = ACTIONS(177),
    [anon_sym_NA_integer_] = ACTIONS(177),
    [anon_sym_NA_real_] = ACTIONS(177),
    [anon_sym_NA_complex_] = ACTIONS(177),
    [anon_sym_NA_character_] = ACTIONS(177),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(175),
    [sym__semicolon] = ACTIONS(175),
    [sym__raw_string_open] = ACTIONS(175),
    [sym__external_else] = ACTIONS(175),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(175),
    [sym__external_close_brace] = ACTIONS(175),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [100] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(179),
    [anon_sym_LT_LT_DASH] = ACTIONS(179),
    [anon_sym_COLON_EQ] = ACTIONS(179),
    [anon_sym_DASH_GT] = ACTIONS(71),
    [anon_sym_DASH_GT_GT] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(77),
    [anon_sym_PIPE_PIPE] = ACTIONS(79),
    [anon_sym_AMP_AMP] = ACTIONS(81),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_else] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_close_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [101] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(69),
    [anon_sym_LT_LT_DASH] = ACTIONS(69),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(71),
    [anon_sym_DASH_GT_GT] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(77),
    [anon_sym_PIPE_PIPE] = ACTIONS(79),
    [anon_sym_AMP_AMP] = ACTIONS(81),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_else] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_close_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [102] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(181),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(179),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(179),
    [anon_sym_LT_LT_DASH] = ACTIONS(179),
    [anon_sym_COLON_EQ] = ACTIONS(179),
    [anon_sym_DASH_GT] = ACTIONS(181),
    [anon_sym_DASH_GT_GT] = ACTIONS(179),
    [anon_sym_PIPE] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(77),
    [anon_sym_PIPE_PIPE] = ACTIONS(79),
    [anon_sym_AMP_AMP] = ACTIONS(81),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_else] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_close_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [103] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(181),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(179),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(181),
    [anon_sym_LT_DASH] = ACTIONS(179),
    [anon_sym_LT_LT_DASH] = ACTIONS(179),
    [anon_sym_COLON_EQ] = ACTIONS(179),
    [anon_sym_DASH_GT] = ACTIONS(181),
    [anon_sym_DASH_GT_GT] = ACTIONS(179),
    [anon_sym_PIPE] = ACTIONS(181),
    [anon_sym_AMP] = ACTIONS(181),
    [anon_sym_PIPE_PIPE] = ACTIONS(179),
    [anon_sym_AMP_AMP] = ACTIONS(179),
    [anon_sym_LT] = ACTIONS(181),
    [anon_sym_LT_EQ] = ACTIONS(179),
    [anon_sym_GT] = ACTIONS(181),
    [anon_sym_GT_EQ] = ACTIONS(179),
    [anon_sym_EQ_EQ] = ACTIONS(179),
    [anon_sym_BANG_EQ] = ACTIONS(179),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_else] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_close_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [104] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(69),
    [anon_sym_LT_LT_DASH] = ACTIONS(69),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(71),
    [anon_sym_DASH_GT_GT] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(77),
    [anon_sym_PIPE_PIPE] = ACTIONS(79),
    [anon_sym_AMP_AMP] = ACTIONS(81),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_else] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_close_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [105] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(181),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(179),
    [anon_sym_LT_LT_DASH] = ACTIONS(179),
    [anon_sym_COLON_EQ] = ACTIONS(179),
    [anon_sym_DASH_GT] = ACTIONS(181),
    [anon_sym_DASH_GT_GT] = ACTIONS(179),
    [anon_sym_PIPE] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(77),
    [anon_sym_PIPE_PIPE] = ACTIONS(79),
    [anon_sym_AMP_AMP] = ACTIONS(81),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_else] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_close_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [106] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(181),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(179),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(179),
    [anon_sym_LT_LT_DASH] = ACTIONS(179),
    [anon_sym_COLON_EQ] = ACTIONS(179),
    [anon_sym_DASH_GT] = ACTIONS(181),
    [anon_sym_DASH_GT_GT] = ACTIONS(179),
    [anon_sym_PIPE] = ACTIONS(181),
    [anon_sym_AMP] = ACTIONS(77),
    [anon_sym_PIPE_PIPE] = ACTIONS(179),
    [anon_sym_AMP_AMP] = ACTIONS(81),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_else] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_close_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [107] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(181),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(179),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(179),
    [anon_sym_LT_LT_DASH] = ACTIONS(179),
    [anon_sym_COLON_EQ] = ACTIONS(179),
    [anon_sym_DASH_GT] = ACTIONS(181),
    [anon_sym_DASH_GT_GT] = ACTIONS(179),
    [anon_sym_PIPE] = ACTIONS(181),
    [anon_sym_AMP] = ACTIONS(181),
    [anon_sym_PIPE_PIPE] = ACTIONS(179),
    [anon_sym_AMP_AMP] = ACTIONS(179),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_else] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_close_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [108] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(181),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(179),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(179),
    [anon_sym_LT_LT_DASH] = ACTIONS(179),
    [anon_sym_COLON_EQ] = ACTIONS(179),
    [anon_sym_DASH_GT] = ACTIONS(181),
    [anon_sym_DASH_GT_GT] = ACTIONS(179),
    [anon_sym_PIPE] = ACTIONS(181),
    [anon_sym_AMP] = ACTIONS(181),
    [anon_sym_PIPE_PIPE] = ACTIONS(179),
    [anon_sym_AMP_AMP] = ACTIONS(179),
    [anon_sym_LT] = ACTIONS(181),
    [anon_sym_LT_EQ] = ACTIONS(179),
    [anon_sym_GT] = ACTIONS(181),
    [anon_sym_GT_EQ] = ACTIONS(179),
    [anon_sym_EQ_EQ] = ACTIONS(179),
    [anon_sym_BANG_EQ] = ACTIONS(179),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_else] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_close_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [109] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(181),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(179),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(181),
    [anon_sym_LT_DASH] = ACTIONS(179),
    [anon_sym_LT_LT_DASH] = ACTIONS(179),
    [anon_sym_COLON_EQ] = ACTIONS(179),
    [anon_sym_DASH_GT] = ACTIONS(181),
    [anon_sym_DASH_GT_GT] = ACTIONS(179),
    [anon_sym_PIPE] = ACTIONS(181),
    [anon_sym_AMP] = ACTIONS(181),
    [anon_sym_PIPE_PIPE] = ACTIONS(179),
    [anon_sym_AMP_AMP] = ACTIONS(179),
    [anon_sym_LT] = ACTIONS(181),
    [anon_sym_LT_EQ] = ACTIONS(179),
    [anon_sym_GT] = ACTIONS(181),
    [anon_sym_GT_EQ] = ACTIONS(179),
    [anon_sym_EQ_EQ] = ACTIONS(179),
    [anon_sym_BANG_EQ] = ACTIONS(179),
    [anon_sym_STAR] = ACTIONS(181),
    [anon_sym_SLASH] = ACTIONS(179),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_else] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_close_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [110] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(181),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(179),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(181),
    [anon_sym_LT_DASH] = ACTIONS(179),
    [anon_sym_LT_LT_DASH] = ACTIONS(179),
    [anon_sym_COLON_EQ] = ACTIONS(179),
    [anon_sym_DASH_GT] = ACTIONS(181),
    [anon_sym_DASH_GT_GT] = ACTIONS(179),
    [anon_sym_PIPE] = ACTIONS(181),
    [anon_sym_AMP] = ACTIONS(181),
    [anon_sym_PIPE_PIPE] = ACTIONS(179),
    [anon_sym_AMP_AMP] = ACTIONS(179),
    [anon_sym_LT] = ACTIONS(181),
    [anon_sym_LT_EQ] = ACTIONS(179),
    [anon_sym_GT] = ACTIONS(181),
    [anon_sym_GT_EQ] = ACTIONS(179),
    [anon_sym_EQ_EQ] = ACTIONS(179),
    [anon_sym_BANG_EQ] = ACTIONS(179),
    [anon_sym_STAR] = ACTIONS(181),
    [anon_sym_SLASH] = ACTIONS(179),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(179),
    [anon_sym_PIPE_GT] = ACTIONS(179),
    [anon_sym_COLON] = ACTIONS(181),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_else] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_close_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [111] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(181),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(179),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(181),
    [anon_sym_LT_DASH] = ACTIONS(179),
    [anon_sym_LT_LT_DASH] = ACTIONS(179),
    [anon_sym_COLON_EQ] = ACTIONS(179),
    [anon_sym_DASH_GT] = ACTIONS(181),
    [anon_sym_DASH_GT_GT] = ACTIONS(179),
    [anon_sym_PIPE] = ACTIONS(181),
    [anon_sym_AMP] = ACTIONS(181),
    [anon_sym_PIPE_PIPE] = ACTIONS(179),
    [anon_sym_AMP_AMP] = ACTIONS(179),
    [anon_sym_LT] = ACTIONS(181),
    [anon_sym_LT_EQ] = ACTIONS(179),
    [anon_sym_GT] = ACTIONS(181),
    [anon_sym_GT_EQ] = ACTIONS(179),
    [anon_sym_EQ_EQ] = ACTIONS(179),
    [anon_sym_BANG_EQ] = ACTIONS(179),
    [anon_sym_STAR] = ACTIONS(181),
    [anon_sym_SLASH] = ACTIONS(179),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(179),
    [anon_sym_PIPE_GT] = ACTIONS(179),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_else] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_close_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [112] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(181),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(179),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(181),
    [anon_sym_LT_DASH] = ACTIONS(179),
    [anon_sym_LT_LT_DASH] = ACTIONS(179),
    [anon_sym_COLON_EQ] = ACTIONS(179),
    [anon_sym_DASH_GT] = ACTIONS(181),
    [anon_sym_DASH_GT_GT] = ACTIONS(179),
    [anon_sym_PIPE] = ACTIONS(181),
    [anon_sym_AMP] = ACTIONS(181),
    [anon_sym_PIPE_PIPE] = ACTIONS(179),
    [anon_sym_AMP_AMP] = ACTIONS(179),
    [anon_sym_LT] = ACTIONS(181),
    [anon_sym_LT_EQ] = ACTIONS(179),
    [anon_sym_GT] = ACTIONS(181),
    [anon_sym_GT_EQ] = ACTIONS(179),
    [anon_sym_EQ_EQ] = ACTIONS(179),
    [anon_sym_BANG_EQ] = ACTIONS(179),
    [anon_sym_STAR] = ACTIONS(181),
    [anon_sym_SLASH] = ACTIONS(179),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(179),
    [anon_sym_PIPE_GT] = ACTIONS(179),
    [anon_sym_COLON] = ACTIONS(181),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_else] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_close_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [113] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(185),
    [anon_sym_BSLASH] = ACTIONS(183),
    [anon_sym_function] = ACTIONS(185),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(185),
    [anon_sym_for] = ACTIONS(185),
    [anon_sym_while] = ACTIONS(185),
    [anon_sym_repeat] = ACTIONS(185),
    [anon_sym_QMARK] = ACTIONS(183),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_BANG] = ACTIONS(185),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(69),
    [anon_sym_LT_LT_DASH] = ACTIONS(69),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(71),
    [anon_sym_DASH_GT_GT] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(77),
    [anon_sym_PIPE_PIPE] = ACTIONS(79),
    [anon_sym_AMP_AMP] = ACTIONS(81),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(183),
    [sym__number_literal] = ACTIONS(185),
    [anon_sym_SQUOTE] = ACTIONS(183),
    [anon_sym_DQUOTE] = ACTIONS(183),
    [sym_dots] = ACTIONS(185),
    [sym_dot_dot_i] = ACTIONS(185),
    [sym_next] = ACTIONS(185),
    [sym_break] = ACTIONS(185),
    [sym_true] = ACTIONS(185),
    [sym_false] = ACTIONS(185),
    [sym_null] = ACTIONS(185),
    [sym_inf] = ACTIONS(185),
    [sym_nan] = ACTIONS(185),
    [anon_sym_NA] = ACTIONS(185),
    [anon_sym_NA_integer_] = ACTIONS(185),
    [anon_sym_NA_real_] = ACTIONS(185),
    [anon_sym_NA_complex_] = ACTIONS(185),
    [anon_sym_NA_character_] = ACTIONS(185),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(183),
    [sym__semicolon] = ACTIONS(183),
    [sym__raw_string_open] = ACTIONS(183),
    [sym__external_else] = ACTIONS(183),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(183),
    [sym__external_close_brace] = ACTIONS(183),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [114] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(189),
    [anon_sym_BSLASH] = ACTIONS(187),
    [anon_sym_function] = ACTIONS(189),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(189),
    [anon_sym_for] = ACTIONS(189),
    [anon_sym_while] = ACTIONS(189),
    [anon_sym_repeat] = ACTIONS(189),
    [anon_sym_QMARK] = ACTIONS(187),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_BANG] = ACTIONS(189),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(69),
    [anon_sym_LT_LT_DASH] = ACTIONS(69),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(71),
    [anon_sym_DASH_GT_GT] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(77),
    [anon_sym_PIPE_PIPE] = ACTIONS(79),
    [anon_sym_AMP_AMP] = ACTIONS(81),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(187),
    [sym__number_literal] = ACTIONS(189),
    [anon_sym_SQUOTE] = ACTIONS(187),
    [anon_sym_DQUOTE] = ACTIONS(187),
    [sym_dots] = ACTIONS(189),
    [sym_dot_dot_i] = ACTIONS(189),
    [sym_next] = ACTIONS(189),
    [sym_break] = ACTIONS(189),
    [sym_true] = ACTIONS(189),
    [sym_false] = ACTIONS(189),
    [sym_null] = ACTIONS(189),
    [sym_inf] = ACTIONS(189),
    [sym_nan] = ACTIONS(189),
    [anon_sym_NA] = ACTIONS(189),
    [anon_sym_NA_integer_] = ACTIONS(189),
    [anon_sym_NA_real_] = ACTIONS(189),
    [anon_sym_NA_complex_] = ACTIONS(189),
    [anon_sym_NA_character_] = ACTIONS(189),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(187),
    [sym__semicolon] = ACTIONS(187),
    [sym__raw_string_open] = ACTIONS(187),
    [sym__external_else] = ACTIONS(187),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(187),
    [sym__external_close_brace] = ACTIONS(187),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [115] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(193),
    [anon_sym_BSLASH] = ACTIONS(191),
    [anon_sym_function] = ACTIONS(193),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_for] = ACTIONS(193),
    [anon_sym_while] = ACTIONS(193),
    [anon_sym_repeat] = ACTIONS(193),
    [anon_sym_QMARK] = ACTIONS(191),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_BANG] = ACTIONS(193),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(69),
    [anon_sym_LT_LT_DASH] = ACTIONS(69),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(71),
    [anon_sym_DASH_GT_GT] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(77),
    [anon_sym_PIPE_PIPE] = ACTIONS(79),
    [anon_sym_AMP_AMP] = ACTIONS(81),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(191),
    [sym__number_literal] = ACTIONS(193),
    [anon_sym_SQUOTE] = ACTIONS(191),
    [anon_sym_DQUOTE] = ACTIONS(191),
    [sym_dots] = ACTIONS(193),
    [sym_dot_dot_i] = ACTIONS(193),
    [sym_next] = ACTIONS(193),
    [sym_break] = ACTIONS(193),
    [sym_true] = ACTIONS(193),
    [sym_false] = ACTIONS(193),
    [sym_null] = ACTIONS(193),
    [sym_inf] = ACTIONS(193),
    [sym_nan] = ACTIONS(193),
    [anon_sym_NA] = ACTIONS(193),
    [anon_sym_NA_integer_] = ACTIONS(193),
    [anon_sym_NA_real_] = ACTIONS(193),
    [anon_sym_NA_complex_] = ACTIONS(193),
    [anon_sym_NA_character_] = ACTIONS(193),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(191),
    [sym__semicolon] = ACTIONS(191),
    [sym__raw_string_open] = ACTIONS(191),
    [sym__external_else] = ACTIONS(191),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(191),
    [sym__external_close_brace] = ACTIONS(191),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [116] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(197),
    [anon_sym_BSLASH] = ACTIONS(195),
    [anon_sym_function] = ACTIONS(197),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(197),
    [anon_sym_for] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(197),
    [anon_sym_repeat] = ACTIONS(197),
    [anon_sym_QMARK] = ACTIONS(195),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_BANG] = ACTIONS(197),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(69),
    [anon_sym_LT_LT_DASH] = ACTIONS(69),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(71),
    [anon_sym_DASH_GT_GT] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(77),
    [anon_sym_PIPE_PIPE] = ACTIONS(79),
    [anon_sym_AMP_AMP] = ACTIONS(81),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(195),
    [sym__number_literal] = ACTIONS(197),
    [anon_sym_SQUOTE] = ACTIONS(195),
    [anon_sym_DQUOTE] = ACTIONS(195),
    [sym_dots] = ACTIONS(197),
    [sym_dot_dot_i] = ACTIONS(197),
    [sym_next] = ACTIONS(197),
    [sym_break] = ACTIONS(197),
    [sym_true] = ACTIONS(197),
    [sym_false] = ACTIONS(197),
    [sym_null] = ACTIONS(197),
    [sym_inf] = ACTIONS(197),
    [sym_nan] = ACTIONS(197),
    [anon_sym_NA] = ACTIONS(197),
    [anon_sym_NA_integer_] = ACTIONS(197),
    [anon_sym_NA_real_] = ACTIONS(197),
    [anon_sym_NA_complex_] = ACTIONS(197),
    [anon_sym_NA_character_] = ACTIONS(197),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(195),
    [sym__semicolon] = ACTIONS(195),
    [sym__raw_string_open] = ACTIONS(195),
    [sym__external_else] = ACTIONS(195),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(195),
    [sym__external_close_brace] = ACTIONS(195),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [117] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(201),
    [anon_sym_BSLASH] = ACTIONS(199),
    [anon_sym_function] = ACTIONS(201),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(201),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_repeat] = ACTIONS(201),
    [anon_sym_QMARK] = ACTIONS(199),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_BANG] = ACTIONS(201),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(69),
    [anon_sym_LT_LT_DASH] = ACTIONS(69),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(71),
    [anon_sym_DASH_GT_GT] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(77),
    [anon_sym_PIPE_PIPE] = ACTIONS(79),
    [anon_sym_AMP_AMP] = ACTIONS(81),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(199),
    [sym__number_literal] = ACTIONS(201),
    [anon_sym_SQUOTE] = ACTIONS(199),
    [anon_sym_DQUOTE] = ACTIONS(199),
    [sym_dots] = ACTIONS(201),
    [sym_dot_dot_i] = ACTIONS(201),
    [sym_next] = ACTIONS(201),
    [sym_break] = ACTIONS(201),
    [sym_true] = ACTIONS(201),
    [sym_false] = ACTIONS(201),
    [sym_null] = ACTIONS(201),
    [sym_inf] = ACTIONS(201),
    [sym_nan] = ACTIONS(201),
    [anon_sym_NA] = ACTIONS(201),
    [anon_sym_NA_integer_] = ACTIONS(201),
    [anon_sym_NA_real_] = ACTIONS(201),
    [anon_sym_NA_complex_] = ACTIONS(201),
    [anon_sym_NA_character_] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(199),
    [sym__semicolon] = ACTIONS(199),
    [sym__raw_string_open] = ACTIONS(199),
    [sym__external_else] = ACTIONS(199),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(199),
    [sym__external_close_brace] = ACTIONS(199),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [118] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(205),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(205),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_while] = ACTIONS(205),
    [anon_sym_repeat] = ACTIONS(205),
    [anon_sym_QMARK] = ACTIONS(203),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_BANG] = ACTIONS(205),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(69),
    [anon_sym_LT_LT_DASH] = ACTIONS(69),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(71),
    [anon_sym_DASH_GT_GT] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(77),
    [anon_sym_PIPE_PIPE] = ACTIONS(79),
    [anon_sym_AMP_AMP] = ACTIONS(81),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(203),
    [sym__number_literal] = ACTIONS(205),
    [anon_sym_SQUOTE] = ACTIONS(203),
    [anon_sym_DQUOTE] = ACTIONS(203),
    [sym_dots] = ACTIONS(205),
    [sym_dot_dot_i] = ACTIONS(205),
    [sym_next] = ACTIONS(205),
    [sym_break] = ACTIONS(205),
    [sym_true] = ACTIONS(205),
    [sym_false] = ACTIONS(205),
    [sym_null] = ACTIONS(205),
    [sym_inf] = ACTIONS(205),
    [sym_nan] = ACTIONS(205),
    [anon_sym_NA] = ACTIONS(205),
    [anon_sym_NA_integer_] = ACTIONS(205),
    [anon_sym_NA_real_] = ACTIONS(205),
    [anon_sym_NA_complex_] = ACTIONS(205),
    [anon_sym_NA_character_] = ACTIONS(205),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(203),
    [sym__semicolon] = ACTIONS(203),
    [sym__raw_string_open] = ACTIONS(203),
    [sym__external_else] = ACTIONS(203),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(203),
    [sym__external_close_brace] = ACTIONS(203),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [119] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(209),
    [anon_sym_BSLASH] = ACTIONS(207),
    [anon_sym_function] = ACTIONS(209),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(209),
    [anon_sym_for] = ACTIONS(209),
    [anon_sym_while] = ACTIONS(209),
    [anon_sym_repeat] = ACTIONS(209),
    [anon_sym_QMARK] = ACTIONS(207),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_BANG] = ACTIONS(209),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(69),
    [anon_sym_LT_LT_DASH] = ACTIONS(69),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(71),
    [anon_sym_DASH_GT_GT] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(77),
    [anon_sym_PIPE_PIPE] = ACTIONS(79),
    [anon_sym_AMP_AMP] = ACTIONS(81),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(207),
    [sym__number_literal] = ACTIONS(209),
    [anon_sym_SQUOTE] = ACTIONS(207),
    [anon_sym_DQUOTE] = ACTIONS(207),
    [sym_dots] = ACTIONS(209),
    [sym_dot_dot_i] = ACTIONS(209),
    [sym_next] = ACTIONS(209),
    [sym_break] = ACTIONS(209),
    [sym_true] = ACTIONS(209),
    [sym_false] = ACTIONS(209),
    [sym_null] = ACTIONS(209),
    [sym_inf] = ACTIONS(209),
    [sym_nan] = ACTIONS(209),
    [anon_sym_NA] = ACTIONS(209),
    [anon_sym_NA_integer_] = ACTIONS(209),
    [anon_sym_NA_real_] = ACTIONS(209),
    [anon_sym_NA_complex_] = ACTIONS(209),
    [anon_sym_NA_character_] = ACTIONS(209),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(207),
    [sym__semicolon] = ACTIONS(207),
    [sym__raw_string_open] = ACTIONS(207),
    [sym__external_else] = ACTIONS(207),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(207),
    [sym__external_close_brace] = ACTIONS(207),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [120] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(213),
    [anon_sym_BSLASH] = ACTIONS(211),
    [anon_sym_function] = ACTIONS(213),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(213),
    [anon_sym_for] = ACTIONS(213),
    [anon_sym_while] = ACTIONS(213),
    [anon_sym_repeat] = ACTIONS(213),
    [anon_sym_QMARK] = ACTIONS(211),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_BANG] = ACTIONS(213),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(69),
    [anon_sym_LT_LT_DASH] = ACTIONS(69),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(71),
    [anon_sym_DASH_GT_GT] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(77),
    [anon_sym_PIPE_PIPE] = ACTIONS(79),
    [anon_sym_AMP_AMP] = ACTIONS(81),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(211),
    [sym__number_literal] = ACTIONS(213),
    [anon_sym_SQUOTE] = ACTIONS(211),
    [anon_sym_DQUOTE] = ACTIONS(211),
    [sym_dots] = ACTIONS(213),
    [sym_dot_dot_i] = ACTIONS(213),
    [sym_next] = ACTIONS(213),
    [sym_break] = ACTIONS(213),
    [sym_true] = ACTIONS(213),
    [sym_false] = ACTIONS(213),
    [sym_null] = ACTIONS(213),
    [sym_inf] = ACTIONS(213),
    [sym_nan] = ACTIONS(213),
    [anon_sym_NA] = ACTIONS(213),
    [anon_sym_NA_integer_] = ACTIONS(213),
    [anon_sym_NA_real_] = ACTIONS(213),
    [anon_sym_NA_complex_] = ACTIONS(213),
    [anon_sym_NA_character_] = ACTIONS(213),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(211),
    [sym__semicolon] = ACTIONS(211),
    [sym__raw_string_open] = ACTIONS(211),
    [sym__external_else] = ACTIONS(211),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(211),
    [sym__external_close_brace] = ACTIONS(211),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [121] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_BSLASH] = ACTIONS(215),
    [anon_sym_function] = ACTIONS(217),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(217),
    [anon_sym_for] = ACTIONS(217),
    [anon_sym_while] = ACTIONS(217),
    [anon_sym_repeat] = ACTIONS(217),
    [anon_sym_QMARK] = ACTIONS(215),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_BANG] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(69),
    [anon_sym_LT_LT_DASH] = ACTIONS(69),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(71),
    [anon_sym_DASH_GT_GT] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(77),
    [anon_sym_PIPE_PIPE] = ACTIONS(79),
    [anon_sym_AMP_AMP] = ACTIONS(81),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(215),
    [sym__number_literal] = ACTIONS(217),
    [anon_sym_SQUOTE] = ACTIONS(215),
    [anon_sym_DQUOTE] = ACTIONS(215),
    [sym_dots] = ACTIONS(217),
    [sym_dot_dot_i] = ACTIONS(217),
    [sym_next] = ACTIONS(217),
    [sym_break] = ACTIONS(217),
    [sym_true] = ACTIONS(217),
    [sym_false] = ACTIONS(217),
    [sym_null] = ACTIONS(217),
    [sym_inf] = ACTIONS(217),
    [sym_nan] = ACTIONS(217),
    [anon_sym_NA] = ACTIONS(217),
    [anon_sym_NA_integer_] = ACTIONS(217),
    [anon_sym_NA_real_] = ACTIONS(217),
    [anon_sym_NA_complex_] = ACTIONS(217),
    [anon_sym_NA_character_] = ACTIONS(217),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(215),
    [sym__semicolon] = ACTIONS(215),
    [sym__raw_string_open] = ACTIONS(215),
    [sym__external_else] = ACTIONS(215),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(215),
    [sym__external_close_brace] = ACTIONS(215),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [122] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(221),
    [anon_sym_BSLASH] = ACTIONS(219),
    [anon_sym_function] = ACTIONS(221),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(221),
    [anon_sym_for] = ACTIONS(221),
    [anon_sym_while] = ACTIONS(221),
    [anon_sym_repeat] = ACTIONS(221),
    [anon_sym_QMARK] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_BANG] = ACTIONS(221),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(69),
    [anon_sym_LT_LT_DASH] = ACTIONS(69),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(71),
    [anon_sym_DASH_GT_GT] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(77),
    [anon_sym_PIPE_PIPE] = ACTIONS(79),
    [anon_sym_AMP_AMP] = ACTIONS(81),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(219),
    [sym__number_literal] = ACTIONS(221),
    [anon_sym_SQUOTE] = ACTIONS(219),
    [anon_sym_DQUOTE] = ACTIONS(219),
    [sym_dots] = ACTIONS(221),
    [sym_dot_dot_i] = ACTIONS(221),
    [sym_next] = ACTIONS(221),
    [sym_break] = ACTIONS(221),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [sym_null] = ACTIONS(221),
    [sym_inf] = ACTIONS(221),
    [sym_nan] = ACTIONS(221),
    [anon_sym_NA] = ACTIONS(221),
    [anon_sym_NA_integer_] = ACTIONS(221),
    [anon_sym_NA_real_] = ACTIONS(221),
    [anon_sym_NA_complex_] = ACTIONS(221),
    [anon_sym_NA_character_] = ACTIONS(221),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(219),
    [sym__semicolon] = ACTIONS(219),
    [sym__raw_string_open] = ACTIONS(219),
    [sym__external_else] = ACTIONS(219),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(219),
    [sym__external_close_brace] = ACTIONS(219),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [123] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(225),
    [anon_sym_BSLASH] = ACTIONS(223),
    [anon_sym_function] = ACTIONS(225),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(225),
    [anon_sym_for] = ACTIONS(225),
    [anon_sym_while] = ACTIONS(225),
    [anon_sym_repeat] = ACTIONS(225),
    [anon_sym_QMARK] = ACTIONS(223),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_BANG] = ACTIONS(225),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(69),
    [anon_sym_LT_LT_DASH] = ACTIONS(69),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(71),
    [anon_sym_DASH_GT_GT] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(77),
    [anon_sym_PIPE_PIPE] = ACTIONS(79),
    [anon_sym_AMP_AMP] = ACTIONS(81),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(223),
    [sym__number_literal] = ACTIONS(225),
    [anon_sym_SQUOTE] = ACTIONS(223),
    [anon_sym_DQUOTE] = ACTIONS(223),
    [sym_dots] = ACTIONS(225),
    [sym_dot_dot_i] = ACTIONS(225),
    [sym_next] = ACTIONS(225),
    [sym_break] = ACTIONS(225),
    [sym_true] = ACTIONS(225),
    [sym_false] = ACTIONS(225),
    [sym_null] = ACTIONS(225),
    [sym_inf] = ACTIONS(225),
    [sym_nan] = ACTIONS(225),
    [anon_sym_NA] = ACTIONS(225),
    [anon_sym_NA_integer_] = ACTIONS(225),
    [anon_sym_NA_real_] = ACTIONS(225),
    [anon_sym_NA_complex_] = ACTIONS(225),
    [anon_sym_NA_character_] = ACTIONS(225),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(223),
    [sym__semicolon] = ACTIONS(223),
    [sym__raw_string_open] = ACTIONS(223),
    [sym__external_else] = ACTIONS(223),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(223),
    [sym__external_close_brace] = ACTIONS(223),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [124] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(229),
    [anon_sym_BSLASH] = ACTIONS(227),
    [anon_sym_function] = ACTIONS(229),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(229),
    [anon_sym_for] = ACTIONS(229),
    [anon_sym_while] = ACTIONS(229),
    [anon_sym_repeat] = ACTIONS(229),
    [anon_sym_QMARK] = ACTIONS(227),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_BANG] = ACTIONS(229),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(69),
    [anon_sym_LT_LT_DASH] = ACTIONS(69),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(71),
    [anon_sym_DASH_GT_GT] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(77),
    [anon_sym_PIPE_PIPE] = ACTIONS(79),
    [anon_sym_AMP_AMP] = ACTIONS(81),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(227),
    [sym__number_literal] = ACTIONS(229),
    [anon_sym_SQUOTE] = ACTIONS(227),
    [anon_sym_DQUOTE] = ACTIONS(227),
    [sym_dots] = ACTIONS(229),
    [sym_dot_dot_i] = ACTIONS(229),
    [sym_next] = ACTIONS(229),
    [sym_break] = ACTIONS(229),
    [sym_true] = ACTIONS(229),
    [sym_false] = ACTIONS(229),
    [sym_null] = ACTIONS(229),
    [sym_inf] = ACTIONS(229),
    [sym_nan] = ACTIONS(229),
    [anon_sym_NA] = ACTIONS(229),
    [anon_sym_NA_integer_] = ACTIONS(229),
    [anon_sym_NA_real_] = ACTIONS(229),
    [anon_sym_NA_complex_] = ACTIONS(229),
    [anon_sym_NA_character_] = ACTIONS(229),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(227),
    [sym__semicolon] = ACTIONS(227),
    [sym__raw_string_open] = ACTIONS(227),
    [sym__external_else] = ACTIONS(227),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(227),
    [sym__external_close_brace] = ACTIONS(227),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [125] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(233),
    [anon_sym_BSLASH] = ACTIONS(231),
    [anon_sym_function] = ACTIONS(233),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(233),
    [anon_sym_for] = ACTIONS(233),
    [anon_sym_while] = ACTIONS(233),
    [anon_sym_repeat] = ACTIONS(233),
    [anon_sym_QMARK] = ACTIONS(231),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_BANG] = ACTIONS(233),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(69),
    [anon_sym_LT_LT_DASH] = ACTIONS(69),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(71),
    [anon_sym_DASH_GT_GT] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(77),
    [anon_sym_PIPE_PIPE] = ACTIONS(79),
    [anon_sym_AMP_AMP] = ACTIONS(81),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(231),
    [sym__number_literal] = ACTIONS(233),
    [anon_sym_SQUOTE] = ACTIONS(231),
    [anon_sym_DQUOTE] = ACTIONS(231),
    [sym_dots] = ACTIONS(233),
    [sym_dot_dot_i] = ACTIONS(233),
    [sym_next] = ACTIONS(233),
    [sym_break] = ACTIONS(233),
    [sym_true] = ACTIONS(233),
    [sym_false] = ACTIONS(233),
    [sym_null] = ACTIONS(233),
    [sym_inf] = ACTIONS(233),
    [sym_nan] = ACTIONS(233),
    [anon_sym_NA] = ACTIONS(233),
    [anon_sym_NA_integer_] = ACTIONS(233),
    [anon_sym_NA_real_] = ACTIONS(233),
    [anon_sym_NA_complex_] = ACTIONS(233),
    [anon_sym_NA_character_] = ACTIONS(233),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(231),
    [sym__semicolon] = ACTIONS(231),
    [sym__raw_string_open] = ACTIONS(231),
    [sym__external_else] = ACTIONS(231),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(231),
    [sym__external_close_brace] = ACTIONS(231),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [126] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(237),
    [anon_sym_BSLASH] = ACTIONS(235),
    [anon_sym_function] = ACTIONS(237),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(237),
    [anon_sym_for] = ACTIONS(237),
    [anon_sym_while] = ACTIONS(237),
    [anon_sym_repeat] = ACTIONS(237),
    [anon_sym_QMARK] = ACTIONS(235),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_BANG] = ACTIONS(237),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(69),
    [anon_sym_LT_LT_DASH] = ACTIONS(69),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(71),
    [anon_sym_DASH_GT_GT] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(77),
    [anon_sym_PIPE_PIPE] = ACTIONS(79),
    [anon_sym_AMP_AMP] = ACTIONS(81),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(235),
    [sym__number_literal] = ACTIONS(237),
    [anon_sym_SQUOTE] = ACTIONS(235),
    [anon_sym_DQUOTE] = ACTIONS(235),
    [sym_dots] = ACTIONS(237),
    [sym_dot_dot_i] = ACTIONS(237),
    [sym_next] = ACTIONS(237),
    [sym_break] = ACTIONS(237),
    [sym_true] = ACTIONS(237),
    [sym_false] = ACTIONS(237),
    [sym_null] = ACTIONS(237),
    [sym_inf] = ACTIONS(237),
    [sym_nan] = ACTIONS(237),
    [anon_sym_NA] = ACTIONS(237),
    [anon_sym_NA_integer_] = ACTIONS(237),
    [anon_sym_NA_real_] = ACTIONS(237),
    [anon_sym_NA_complex_] = ACTIONS(237),
    [anon_sym_NA_character_] = ACTIONS(237),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(235),
    [sym__semicolon] = ACTIONS(235),
    [sym__raw_string_open] = ACTIONS(235),
    [sym__external_else] = ACTIONS(235),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(235),
    [sym__external_close_brace] = ACTIONS(235),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [127] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(241),
    [anon_sym_BSLASH] = ACTIONS(239),
    [anon_sym_function] = ACTIONS(241),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(241),
    [anon_sym_for] = ACTIONS(241),
    [anon_sym_while] = ACTIONS(241),
    [anon_sym_repeat] = ACTIONS(241),
    [anon_sym_QMARK] = ACTIONS(239),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_BANG] = ACTIONS(241),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(69),
    [anon_sym_LT_LT_DASH] = ACTIONS(69),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(71),
    [anon_sym_DASH_GT_GT] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(77),
    [anon_sym_PIPE_PIPE] = ACTIONS(79),
    [anon_sym_AMP_AMP] = ACTIONS(81),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(239),
    [sym__number_literal] = ACTIONS(241),
    [anon_sym_SQUOTE] = ACTIONS(239),
    [anon_sym_DQUOTE] = ACTIONS(239),
    [sym_dots] = ACTIONS(241),
    [sym_dot_dot_i] = ACTIONS(241),
    [sym_next] = ACTIONS(241),
    [sym_break] = ACTIONS(241),
    [sym_true] = ACTIONS(241),
    [sym_false] = ACTIONS(241),
    [sym_null] = ACTIONS(241),
    [sym_inf] = ACTIONS(241),
    [sym_nan] = ACTIONS(241),
    [anon_sym_NA] = ACTIONS(241),
    [anon_sym_NA_integer_] = ACTIONS(241),
    [anon_sym_NA_real_] = ACTIONS(241),
    [anon_sym_NA_complex_] = ACTIONS(241),
    [anon_sym_NA_character_] = ACTIONS(241),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(239),
    [sym__semicolon] = ACTIONS(239),
    [sym__raw_string_open] = ACTIONS(239),
    [sym__external_else] = ACTIONS(239),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(239),
    [sym__external_close_brace] = ACTIONS(239),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [128] = {
    [sym_call_arguments] = STATE(402),
    [sym_subset_arguments] = STATE(403),
    [sym_subset2_arguments] = STATE(371),
    [sym__open_parenthesis] = STATE(276),
    [sym__open_bracket] = STATE(277),
    [sym__open_bracket2] = STATE(278),
    [sym_identifier] = ACTIONS(245),
    [anon_sym_BSLASH] = ACTIONS(243),
    [anon_sym_function] = ACTIONS(245),
    [anon_sym_EQ] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(245),
    [anon_sym_for] = ACTIONS(245),
    [anon_sym_while] = ACTIONS(245),
    [anon_sym_repeat] = ACTIONS(245),
    [anon_sym_QMARK] = ACTIONS(243),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_BANG] = ACTIONS(245),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_LT_DASH] = ACTIONS(69),
    [anon_sym_LT_LT_DASH] = ACTIONS(69),
    [anon_sym_COLON_EQ] = ACTIONS(69),
    [anon_sym_DASH_GT] = ACTIONS(71),
    [anon_sym_DASH_GT_GT] = ACTIONS(73),
    [anon_sym_PIPE] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(77),
    [anon_sym_PIPE_PIPE] = ACTIONS(79),
    [anon_sym_AMP_AMP] = ACTIONS(81),
    [anon_sym_LT] = ACTIONS(83),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(83),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_SLASH] = ACTIONS(89),
    [anon_sym_STAR_STAR] = ACTIONS(91),
    [anon_sym_CARET] = ACTIONS(91),
    [aux_sym_binary_operator_token1] = ACTIONS(93),
    [anon_sym_PIPE_GT] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(97),
    [anon_sym_AT] = ACTIONS(97),
    [sym__hex_literal] = ACTIONS(243),
    [sym__number_literal] = ACTIONS(245),
    [anon_sym_SQUOTE] = ACTIONS(243),
    [anon_sym_DQUOTE] = ACTIONS(243),
    [sym_dots] = ACTIONS(245),
    [sym_dot_dot_i] = ACTIONS(245),
    [sym_next] = ACTIONS(245),
    [sym_break] = ACTIONS(245),
    [sym_true] = ACTIONS(245),
    [sym_false] = ACTIONS(245),
    [sym_null] = ACTIONS(245),
    [sym_inf] = ACTIONS(245),
    [sym_nan] = ACTIONS(245),
    [anon_sym_NA] = ACTIONS(245),
    [anon_sym_NA_integer_] = ACTIONS(245),
    [anon_sym_NA_real_] = ACTIONS(245),
    [anon_sym_NA_complex_] = ACTIONS(245),
    [anon_sym_NA_character_] = ACTIONS(245),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(243),
    [sym__semicolon] = ACTIONS(243),
    [sym__raw_string_open] = ACTIONS(243),
    [sym__external_else] = ACTIONS(243),
    [sym__external_open_parenthesis] = ACTIONS(101),
    [sym__external_open_brace] = ACTIONS(243),
    [sym__external_close_brace] = ACTIONS(243),
    [sym__external_open_bracket] = ACTIONS(103),
    [sym__external_open_bracket2] = ACTIONS(105),
  },
  [129] = {
    [sym_call_arguments] = STATE(374),
    [sym_subset_arguments] = STATE(375),
    [sym_subset2_arguments] = STATE(376),
    [sym__open_parenthesis] = STATE(271),
    [sym__open_bracket] = STATE(272),
    [sym__open_bracket2] = STATE(273),
    [ts_builtin_sym_end] = ACTIONS(143),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_LT_DASH] = ACTIONS(143),
    [anon_sym_LT_LT_DASH] = ACTIONS(143),
    [anon_sym_COLON_EQ] = ACTIONS(143),
    [anon_sym_DASH_GT] = ACTIONS(145),
    [anon_sym_DASH_GT_GT] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(145),
    [anon_sym_PIPE_PIPE] = ACTIONS(143),
    [anon_sym_AMP_AMP] = ACTIONS(143),
    [anon_sym_LT] = ACTIONS(145),
    [anon_sym_LT_EQ] = ACTIONS(143),
    [anon_sym_GT] = ACTIONS(145),
    [anon_sym_GT_EQ] = ACTIONS(143),
    [anon_sym_EQ_EQ] = ACTIONS(143),
    [anon_sym_BANG_EQ] = ACTIONS(143),
    [anon_sym_STAR] = ACTIONS(37),
    [anon_sym_SLASH] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(41),
    [anon_sym_CARET] = ACTIONS(41),
    [aux_sym_binary_operator_token1] = ACTIONS(43),
    [anon_sym_PIPE_GT] = ACTIONS(43),
    [anon_sym_COLON] = ACTIONS(45),
    [anon_sym_DOLLAR] = ACTIONS(47),
    [anon_sym_AT] = ACTIONS(47),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_else] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(51),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(53),
    [sym__external_open_bracket2] = ACTIONS(55),
  },
  [130] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(169),
    [anon_sym_BSLASH] = ACTIONS(167),
    [anon_sym_function] = ACTIONS(169),
    [anon_sym_EQ] = ACTIONS(247),
    [anon_sym_if] = ACTIONS(169),
    [anon_sym_for] = ACTIONS(169),
    [anon_sym_while] = ACTIONS(169),
    [anon_sym_repeat] = ACTIONS(169),
    [anon_sym_QMARK] = ACTIONS(167),
    [anon_sym_TILDE] = ACTIONS(249),
    [anon_sym_BANG] = ACTIONS(169),
    [anon_sym_PLUS] = ACTIONS(251),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_LT_DASH] = ACTIONS(255),
    [anon_sym_LT_LT_DASH] = ACTIONS(255),
    [anon_sym_COLON_EQ] = ACTIONS(255),
    [anon_sym_DASH_GT] = ACTIONS(257),
    [anon_sym_DASH_GT_GT] = ACTIONS(259),
    [anon_sym_PIPE] = ACTIONS(261),
    [anon_sym_AMP] = ACTIONS(263),
    [anon_sym_PIPE_PIPE] = ACTIONS(265),
    [anon_sym_AMP_AMP] = ACTIONS(267),
    [anon_sym_LT] = ACTIONS(269),
    [anon_sym_LT_EQ] = ACTIONS(271),
    [anon_sym_GT] = ACTIONS(269),
    [anon_sym_GT_EQ] = ACTIONS(271),
    [anon_sym_EQ_EQ] = ACTIONS(271),
    [anon_sym_BANG_EQ] = ACTIONS(271),
    [anon_sym_STAR] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(279),
    [anon_sym_PIPE_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(167),
    [sym__number_literal] = ACTIONS(169),
    [anon_sym_SQUOTE] = ACTIONS(167),
    [anon_sym_DQUOTE] = ACTIONS(167),
    [sym_dots] = ACTIONS(169),
    [sym_dot_dot_i] = ACTIONS(169),
    [sym_next] = ACTIONS(169),
    [sym_break] = ACTIONS(169),
    [sym_true] = ACTIONS(169),
    [sym_false] = ACTIONS(169),
    [sym_null] = ACTIONS(169),
    [sym_inf] = ACTIONS(169),
    [sym_nan] = ACTIONS(169),
    [anon_sym_NA] = ACTIONS(169),
    [anon_sym_NA_integer_] = ACTIONS(169),
    [anon_sym_NA_real_] = ACTIONS(169),
    [anon_sym_NA_complex_] = ACTIONS(169),
    [anon_sym_NA_character_] = ACTIONS(169),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(167),
    [sym__semicolon] = ACTIONS(167),
    [sym__raw_string_open] = ACTIONS(167),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(167),
    [sym__external_close_brace] = ACTIONS(167),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [131] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(167),
    [sym_identifier] = ACTIONS(169),
    [anon_sym_BSLASH] = ACTIONS(167),
    [anon_sym_function] = ACTIONS(169),
    [anon_sym_EQ] = ACTIONS(169),
    [anon_sym_if] = ACTIONS(169),
    [anon_sym_for] = ACTIONS(169),
    [anon_sym_while] = ACTIONS(169),
    [anon_sym_repeat] = ACTIONS(169),
    [anon_sym_QMARK] = ACTIONS(167),
    [anon_sym_TILDE] = ACTIONS(167),
    [anon_sym_BANG] = ACTIONS(169),
    [anon_sym_PLUS] = ACTIONS(291),
    [anon_sym_DASH] = ACTIONS(293),
    [anon_sym_LT_DASH] = ACTIONS(167),
    [anon_sym_LT_LT_DASH] = ACTIONS(167),
    [anon_sym_COLON_EQ] = ACTIONS(167),
    [anon_sym_DASH_GT] = ACTIONS(169),
    [anon_sym_DASH_GT_GT] = ACTIONS(167),
    [anon_sym_PIPE] = ACTIONS(295),
    [anon_sym_AMP] = ACTIONS(297),
    [anon_sym_PIPE_PIPE] = ACTIONS(299),
    [anon_sym_AMP_AMP] = ACTIONS(301),
    [anon_sym_LT] = ACTIONS(303),
    [anon_sym_LT_EQ] = ACTIONS(305),
    [anon_sym_GT] = ACTIONS(303),
    [anon_sym_GT_EQ] = ACTIONS(305),
    [anon_sym_EQ_EQ] = ACTIONS(305),
    [anon_sym_BANG_EQ] = ACTIONS(305),
    [anon_sym_STAR] = ACTIONS(307),
    [anon_sym_SLASH] = ACTIONS(309),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(313),
    [anon_sym_PIPE_GT] = ACTIONS(313),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(167),
    [sym__number_literal] = ACTIONS(169),
    [anon_sym_SQUOTE] = ACTIONS(167),
    [anon_sym_DQUOTE] = ACTIONS(167),
    [sym_dots] = ACTIONS(169),
    [sym_dot_dot_i] = ACTIONS(169),
    [sym_next] = ACTIONS(169),
    [sym_break] = ACTIONS(169),
    [sym_true] = ACTIONS(169),
    [sym_false] = ACTIONS(169),
    [sym_null] = ACTIONS(169),
    [sym_inf] = ACTIONS(169),
    [sym_nan] = ACTIONS(169),
    [anon_sym_NA] = ACTIONS(169),
    [anon_sym_NA_integer_] = ACTIONS(169),
    [anon_sym_NA_real_] = ACTIONS(169),
    [anon_sym_NA_complex_] = ACTIONS(169),
    [anon_sym_NA_character_] = ACTIONS(169),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(167),
    [sym__semicolon] = ACTIONS(167),
    [sym__raw_string_open] = ACTIONS(167),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(167),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [132] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(167),
    [sym_identifier] = ACTIONS(169),
    [anon_sym_BSLASH] = ACTIONS(167),
    [anon_sym_function] = ACTIONS(169),
    [anon_sym_EQ] = ACTIONS(169),
    [anon_sym_if] = ACTIONS(169),
    [anon_sym_for] = ACTIONS(169),
    [anon_sym_while] = ACTIONS(169),
    [anon_sym_repeat] = ACTIONS(169),
    [anon_sym_QMARK] = ACTIONS(167),
    [anon_sym_TILDE] = ACTIONS(167),
    [anon_sym_BANG] = ACTIONS(169),
    [anon_sym_PLUS] = ACTIONS(291),
    [anon_sym_DASH] = ACTIONS(293),
    [anon_sym_LT_DASH] = ACTIONS(167),
    [anon_sym_LT_LT_DASH] = ACTIONS(167),
    [anon_sym_COLON_EQ] = ACTIONS(167),
    [anon_sym_DASH_GT] = ACTIONS(169),
    [anon_sym_DASH_GT_GT] = ACTIONS(167),
    [anon_sym_PIPE] = ACTIONS(169),
    [anon_sym_AMP] = ACTIONS(169),
    [anon_sym_PIPE_PIPE] = ACTIONS(167),
    [anon_sym_AMP_AMP] = ACTIONS(167),
    [anon_sym_LT] = ACTIONS(303),
    [anon_sym_LT_EQ] = ACTIONS(305),
    [anon_sym_GT] = ACTIONS(303),
    [anon_sym_GT_EQ] = ACTIONS(305),
    [anon_sym_EQ_EQ] = ACTIONS(305),
    [anon_sym_BANG_EQ] = ACTIONS(305),
    [anon_sym_STAR] = ACTIONS(307),
    [anon_sym_SLASH] = ACTIONS(309),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(313),
    [anon_sym_PIPE_GT] = ACTIONS(313),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(167),
    [sym__number_literal] = ACTIONS(169),
    [anon_sym_SQUOTE] = ACTIONS(167),
    [anon_sym_DQUOTE] = ACTIONS(167),
    [sym_dots] = ACTIONS(169),
    [sym_dot_dot_i] = ACTIONS(169),
    [sym_next] = ACTIONS(169),
    [sym_break] = ACTIONS(169),
    [sym_true] = ACTIONS(169),
    [sym_false] = ACTIONS(169),
    [sym_null] = ACTIONS(169),
    [sym_inf] = ACTIONS(169),
    [sym_nan] = ACTIONS(169),
    [anon_sym_NA] = ACTIONS(169),
    [anon_sym_NA_integer_] = ACTIONS(169),
    [anon_sym_NA_real_] = ACTIONS(169),
    [anon_sym_NA_complex_] = ACTIONS(169),
    [anon_sym_NA_character_] = ACTIONS(169),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(167),
    [sym__semicolon] = ACTIONS(167),
    [sym__raw_string_open] = ACTIONS(167),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(167),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [133] = {
    [sym_string] = STATE(387),
    [sym__raw_string] = STATE(290),
    [sym__single_quoted_string] = STATE(291),
    [sym__double_quoted_string] = STATE(286),
    [aux_sym_function_definition_repeat1] = STATE(152),
    [ts_builtin_sym_end] = ACTIONS(325),
    [sym_identifier] = ACTIONS(327),
    [anon_sym_BSLASH] = ACTIONS(325),
    [anon_sym_function] = ACTIONS(329),
    [anon_sym_EQ] = ACTIONS(329),
    [anon_sym_if] = ACTIONS(329),
    [anon_sym_for] = ACTIONS(329),
    [anon_sym_while] = ACTIONS(329),
    [anon_sym_repeat] = ACTIONS(329),
    [anon_sym_QMARK] = ACTIONS(325),
    [anon_sym_TILDE] = ACTIONS(325),
    [anon_sym_BANG] = ACTIONS(329),
    [anon_sym_PLUS] = ACTIONS(325),
    [anon_sym_DASH] = ACTIONS(329),
    [anon_sym_LT_DASH] = ACTIONS(325),
    [anon_sym_LT_LT_DASH] = ACTIONS(325),
    [anon_sym_COLON_EQ] = ACTIONS(325),
    [anon_sym_DASH_GT] = ACTIONS(329),
    [anon_sym_DASH_GT_GT] = ACTIONS(325),
    [anon_sym_PIPE] = ACTIONS(329),
    [anon_sym_AMP] = ACTIONS(329),
    [anon_sym_PIPE_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(325),
    [anon_sym_LT] = ACTIONS(329),
    [anon_sym_LT_EQ] = ACTIONS(325),
    [anon_sym_GT] = ACTIONS(329),
    [anon_sym_GT_EQ] = ACTIONS(325),
    [anon_sym_EQ_EQ] = ACTIONS(325),
    [anon_sym_BANG_EQ] = ACTIONS(325),
    [anon_sym_STAR] = ACTIONS(329),
    [anon_sym_SLASH] = ACTIONS(325),
    [anon_sym_STAR_STAR] = ACTIONS(325),
    [anon_sym_CARET] = ACTIONS(325),
    [aux_sym_binary_operator_token1] = ACTIONS(325),
    [anon_sym_PIPE_GT] = ACTIONS(325),
    [anon_sym_COLON] = ACTIONS(329),
    [anon_sym_DOLLAR] = ACTIONS(325),
    [anon_sym_AT] = ACTIONS(325),
    [sym__hex_literal] = ACTIONS(325),
    [sym__number_literal] = ACTIONS(329),
    [anon_sym_SQUOTE] = ACTIONS(331),
    [anon_sym_DQUOTE] = ACTIONS(333),
    [sym_dots] = ACTIONS(327),
    [sym_dot_dot_i] = ACTIONS(327),
    [sym_next] = ACTIONS(329),
    [sym_break] = ACTIONS(329),
    [sym_true] = ACTIONS(329),
    [sym_false] = ACTIONS(329),
    [sym_null] = ACTIONS(329),
    [sym_inf] = ACTIONS(329),
    [sym_nan] = ACTIONS(329),
    [anon_sym_NA] = ACTIONS(329),
    [anon_sym_NA_integer_] = ACTIONS(329),
    [anon_sym_NA_real_] = ACTIONS(329),
    [anon_sym_NA_complex_] = ACTIONS(329),
    [anon_sym_NA_character_] = ACTIONS(329),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(335),
    [sym__semicolon] = ACTIONS(325),
    [sym__raw_string_open] = ACTIONS(337),
    [sym__external_else] = ACTIONS(325),
    [sym__external_open_parenthesis] = ACTIONS(325),
    [sym__external_open_brace] = ACTIONS(325),
    [sym__external_open_bracket] = ACTIONS(325),
    [sym__external_open_bracket2] = ACTIONS(325),
  },
  [134] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(167),
    [sym_identifier] = ACTIONS(169),
    [anon_sym_BSLASH] = ACTIONS(167),
    [anon_sym_function] = ACTIONS(169),
    [anon_sym_EQ] = ACTIONS(169),
    [anon_sym_if] = ACTIONS(169),
    [anon_sym_for] = ACTIONS(169),
    [anon_sym_while] = ACTIONS(169),
    [anon_sym_repeat] = ACTIONS(169),
    [anon_sym_QMARK] = ACTIONS(167),
    [anon_sym_TILDE] = ACTIONS(167),
    [anon_sym_BANG] = ACTIONS(169),
    [anon_sym_PLUS] = ACTIONS(167),
    [anon_sym_DASH] = ACTIONS(169),
    [anon_sym_LT_DASH] = ACTIONS(167),
    [anon_sym_LT_LT_DASH] = ACTIONS(167),
    [anon_sym_COLON_EQ] = ACTIONS(167),
    [anon_sym_DASH_GT] = ACTIONS(169),
    [anon_sym_DASH_GT_GT] = ACTIONS(167),
    [anon_sym_PIPE] = ACTIONS(169),
    [anon_sym_AMP] = ACTIONS(169),
    [anon_sym_PIPE_PIPE] = ACTIONS(167),
    [anon_sym_AMP_AMP] = ACTIONS(167),
    [anon_sym_LT] = ACTIONS(169),
    [anon_sym_LT_EQ] = ACTIONS(167),
    [anon_sym_GT] = ACTIONS(169),
    [anon_sym_GT_EQ] = ACTIONS(167),
    [anon_sym_EQ_EQ] = ACTIONS(167),
    [anon_sym_BANG_EQ] = ACTIONS(167),
    [anon_sym_STAR] = ACTIONS(169),
    [anon_sym_SLASH] = ACTIONS(167),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(167),
    [anon_sym_PIPE_GT] = ACTIONS(167),
    [anon_sym_COLON] = ACTIONS(169),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(167),
    [sym__number_literal] = ACTIONS(169),
    [anon_sym_SQUOTE] = ACTIONS(167),
    [anon_sym_DQUOTE] = ACTIONS(167),
    [sym_dots] = ACTIONS(169),
    [sym_dot_dot_i] = ACTIONS(169),
    [sym_next] = ACTIONS(169),
    [sym_break] = ACTIONS(169),
    [sym_true] = ACTIONS(169),
    [sym_false] = ACTIONS(169),
    [sym_null] = ACTIONS(169),
    [sym_inf] = ACTIONS(169),
    [sym_nan] = ACTIONS(169),
    [anon_sym_NA] = ACTIONS(169),
    [anon_sym_NA_integer_] = ACTIONS(169),
    [anon_sym_NA_real_] = ACTIONS(169),
    [anon_sym_NA_complex_] = ACTIONS(169),
    [anon_sym_NA_character_] = ACTIONS(169),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(167),
    [sym__semicolon] = ACTIONS(167),
    [sym__raw_string_open] = ACTIONS(167),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(167),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [135] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(143),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(339),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(341),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(291),
    [anon_sym_DASH] = ACTIONS(293),
    [anon_sym_LT_DASH] = ACTIONS(143),
    [anon_sym_LT_LT_DASH] = ACTIONS(143),
    [anon_sym_COLON_EQ] = ACTIONS(143),
    [anon_sym_DASH_GT] = ACTIONS(343),
    [anon_sym_DASH_GT_GT] = ACTIONS(345),
    [anon_sym_PIPE] = ACTIONS(295),
    [anon_sym_AMP] = ACTIONS(297),
    [anon_sym_PIPE_PIPE] = ACTIONS(299),
    [anon_sym_AMP_AMP] = ACTIONS(301),
    [anon_sym_LT] = ACTIONS(303),
    [anon_sym_LT_EQ] = ACTIONS(305),
    [anon_sym_GT] = ACTIONS(303),
    [anon_sym_GT_EQ] = ACTIONS(305),
    [anon_sym_EQ_EQ] = ACTIONS(305),
    [anon_sym_BANG_EQ] = ACTIONS(305),
    [anon_sym_STAR] = ACTIONS(307),
    [anon_sym_SLASH] = ACTIONS(309),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(313),
    [anon_sym_PIPE_GT] = ACTIONS(313),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [136] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(143),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(339),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(341),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(291),
    [anon_sym_DASH] = ACTIONS(293),
    [anon_sym_LT_DASH] = ACTIONS(347),
    [anon_sym_LT_LT_DASH] = ACTIONS(347),
    [anon_sym_COLON_EQ] = ACTIONS(347),
    [anon_sym_DASH_GT] = ACTIONS(343),
    [anon_sym_DASH_GT_GT] = ACTIONS(345),
    [anon_sym_PIPE] = ACTIONS(295),
    [anon_sym_AMP] = ACTIONS(297),
    [anon_sym_PIPE_PIPE] = ACTIONS(299),
    [anon_sym_AMP_AMP] = ACTIONS(301),
    [anon_sym_LT] = ACTIONS(303),
    [anon_sym_LT_EQ] = ACTIONS(305),
    [anon_sym_GT] = ACTIONS(303),
    [anon_sym_GT_EQ] = ACTIONS(305),
    [anon_sym_EQ_EQ] = ACTIONS(305),
    [anon_sym_BANG_EQ] = ACTIONS(305),
    [anon_sym_STAR] = ACTIONS(307),
    [anon_sym_SLASH] = ACTIONS(309),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(313),
    [anon_sym_PIPE_GT] = ACTIONS(313),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [137] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(143),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(291),
    [anon_sym_DASH] = ACTIONS(293),
    [anon_sym_LT_DASH] = ACTIONS(143),
    [anon_sym_LT_LT_DASH] = ACTIONS(143),
    [anon_sym_COLON_EQ] = ACTIONS(143),
    [anon_sym_DASH_GT] = ACTIONS(145),
    [anon_sym_DASH_GT_GT] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(295),
    [anon_sym_AMP] = ACTIONS(297),
    [anon_sym_PIPE_PIPE] = ACTIONS(299),
    [anon_sym_AMP_AMP] = ACTIONS(301),
    [anon_sym_LT] = ACTIONS(303),
    [anon_sym_LT_EQ] = ACTIONS(305),
    [anon_sym_GT] = ACTIONS(303),
    [anon_sym_GT_EQ] = ACTIONS(305),
    [anon_sym_EQ_EQ] = ACTIONS(305),
    [anon_sym_BANG_EQ] = ACTIONS(305),
    [anon_sym_STAR] = ACTIONS(307),
    [anon_sym_SLASH] = ACTIONS(309),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(313),
    [anon_sym_PIPE_GT] = ACTIONS(313),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [138] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(143),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_LT_DASH] = ACTIONS(143),
    [anon_sym_LT_LT_DASH] = ACTIONS(143),
    [anon_sym_COLON_EQ] = ACTIONS(143),
    [anon_sym_DASH_GT] = ACTIONS(145),
    [anon_sym_DASH_GT_GT] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(145),
    [anon_sym_PIPE_PIPE] = ACTIONS(143),
    [anon_sym_AMP_AMP] = ACTIONS(143),
    [anon_sym_LT] = ACTIONS(145),
    [anon_sym_LT_EQ] = ACTIONS(143),
    [anon_sym_GT] = ACTIONS(145),
    [anon_sym_GT_EQ] = ACTIONS(143),
    [anon_sym_EQ_EQ] = ACTIONS(143),
    [anon_sym_BANG_EQ] = ACTIONS(143),
    [anon_sym_STAR] = ACTIONS(307),
    [anon_sym_SLASH] = ACTIONS(309),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(313),
    [anon_sym_PIPE_GT] = ACTIONS(313),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [139] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(143),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(339),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(341),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(291),
    [anon_sym_DASH] = ACTIONS(293),
    [anon_sym_LT_DASH] = ACTIONS(347),
    [anon_sym_LT_LT_DASH] = ACTIONS(347),
    [anon_sym_COLON_EQ] = ACTIONS(347),
    [anon_sym_DASH_GT] = ACTIONS(343),
    [anon_sym_DASH_GT_GT] = ACTIONS(345),
    [anon_sym_PIPE] = ACTIONS(295),
    [anon_sym_AMP] = ACTIONS(297),
    [anon_sym_PIPE_PIPE] = ACTIONS(299),
    [anon_sym_AMP_AMP] = ACTIONS(301),
    [anon_sym_LT] = ACTIONS(303),
    [anon_sym_LT_EQ] = ACTIONS(305),
    [anon_sym_GT] = ACTIONS(303),
    [anon_sym_GT_EQ] = ACTIONS(305),
    [anon_sym_EQ_EQ] = ACTIONS(305),
    [anon_sym_BANG_EQ] = ACTIONS(305),
    [anon_sym_STAR] = ACTIONS(307),
    [anon_sym_SLASH] = ACTIONS(309),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(313),
    [anon_sym_PIPE_GT] = ACTIONS(313),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [140] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(143),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(341),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(291),
    [anon_sym_DASH] = ACTIONS(293),
    [anon_sym_LT_DASH] = ACTIONS(143),
    [anon_sym_LT_LT_DASH] = ACTIONS(143),
    [anon_sym_COLON_EQ] = ACTIONS(143),
    [anon_sym_DASH_GT] = ACTIONS(145),
    [anon_sym_DASH_GT_GT] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(295),
    [anon_sym_AMP] = ACTIONS(297),
    [anon_sym_PIPE_PIPE] = ACTIONS(299),
    [anon_sym_AMP_AMP] = ACTIONS(301),
    [anon_sym_LT] = ACTIONS(303),
    [anon_sym_LT_EQ] = ACTIONS(305),
    [anon_sym_GT] = ACTIONS(303),
    [anon_sym_GT_EQ] = ACTIONS(305),
    [anon_sym_EQ_EQ] = ACTIONS(305),
    [anon_sym_BANG_EQ] = ACTIONS(305),
    [anon_sym_STAR] = ACTIONS(307),
    [anon_sym_SLASH] = ACTIONS(309),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(313),
    [anon_sym_PIPE_GT] = ACTIONS(313),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [141] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(143),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(291),
    [anon_sym_DASH] = ACTIONS(293),
    [anon_sym_LT_DASH] = ACTIONS(143),
    [anon_sym_LT_LT_DASH] = ACTIONS(143),
    [anon_sym_COLON_EQ] = ACTIONS(143),
    [anon_sym_DASH_GT] = ACTIONS(145),
    [anon_sym_DASH_GT_GT] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(297),
    [anon_sym_PIPE_PIPE] = ACTIONS(143),
    [anon_sym_AMP_AMP] = ACTIONS(301),
    [anon_sym_LT] = ACTIONS(303),
    [anon_sym_LT_EQ] = ACTIONS(305),
    [anon_sym_GT] = ACTIONS(303),
    [anon_sym_GT_EQ] = ACTIONS(305),
    [anon_sym_EQ_EQ] = ACTIONS(305),
    [anon_sym_BANG_EQ] = ACTIONS(305),
    [anon_sym_STAR] = ACTIONS(307),
    [anon_sym_SLASH] = ACTIONS(309),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(313),
    [anon_sym_PIPE_GT] = ACTIONS(313),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [142] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(155),
    [sym_identifier] = ACTIONS(157),
    [anon_sym_BSLASH] = ACTIONS(155),
    [anon_sym_function] = ACTIONS(157),
    [anon_sym_EQ] = ACTIONS(157),
    [anon_sym_if] = ACTIONS(157),
    [anon_sym_for] = ACTIONS(157),
    [anon_sym_while] = ACTIONS(157),
    [anon_sym_repeat] = ACTIONS(157),
    [anon_sym_QMARK] = ACTIONS(155),
    [anon_sym_TILDE] = ACTIONS(155),
    [anon_sym_BANG] = ACTIONS(157),
    [anon_sym_PLUS] = ACTIONS(155),
    [anon_sym_DASH] = ACTIONS(157),
    [anon_sym_LT_DASH] = ACTIONS(155),
    [anon_sym_LT_LT_DASH] = ACTIONS(155),
    [anon_sym_COLON_EQ] = ACTIONS(155),
    [anon_sym_DASH_GT] = ACTIONS(157),
    [anon_sym_DASH_GT_GT] = ACTIONS(155),
    [anon_sym_PIPE] = ACTIONS(157),
    [anon_sym_AMP] = ACTIONS(157),
    [anon_sym_PIPE_PIPE] = ACTIONS(155),
    [anon_sym_AMP_AMP] = ACTIONS(155),
    [anon_sym_LT] = ACTIONS(157),
    [anon_sym_LT_EQ] = ACTIONS(155),
    [anon_sym_GT] = ACTIONS(157),
    [anon_sym_GT_EQ] = ACTIONS(155),
    [anon_sym_EQ_EQ] = ACTIONS(155),
    [anon_sym_BANG_EQ] = ACTIONS(155),
    [anon_sym_STAR] = ACTIONS(157),
    [anon_sym_SLASH] = ACTIONS(155),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(155),
    [anon_sym_PIPE_GT] = ACTIONS(155),
    [anon_sym_COLON] = ACTIONS(157),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(155),
    [sym__number_literal] = ACTIONS(157),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [anon_sym_DQUOTE] = ACTIONS(155),
    [sym_dots] = ACTIONS(157),
    [sym_dot_dot_i] = ACTIONS(157),
    [sym_next] = ACTIONS(157),
    [sym_break] = ACTIONS(157),
    [sym_true] = ACTIONS(157),
    [sym_false] = ACTIONS(157),
    [sym_null] = ACTIONS(157),
    [sym_inf] = ACTIONS(157),
    [sym_nan] = ACTIONS(157),
    [anon_sym_NA] = ACTIONS(157),
    [anon_sym_NA_integer_] = ACTIONS(157),
    [anon_sym_NA_real_] = ACTIONS(157),
    [anon_sym_NA_complex_] = ACTIONS(157),
    [anon_sym_NA_character_] = ACTIONS(157),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(155),
    [sym__semicolon] = ACTIONS(155),
    [sym__raw_string_open] = ACTIONS(155),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(155),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [143] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(143),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(291),
    [anon_sym_DASH] = ACTIONS(293),
    [anon_sym_LT_DASH] = ACTIONS(143),
    [anon_sym_LT_LT_DASH] = ACTIONS(143),
    [anon_sym_COLON_EQ] = ACTIONS(143),
    [anon_sym_DASH_GT] = ACTIONS(145),
    [anon_sym_DASH_GT_GT] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(145),
    [anon_sym_PIPE_PIPE] = ACTIONS(143),
    [anon_sym_AMP_AMP] = ACTIONS(143),
    [anon_sym_LT] = ACTIONS(303),
    [anon_sym_LT_EQ] = ACTIONS(305),
    [anon_sym_GT] = ACTIONS(303),
    [anon_sym_GT_EQ] = ACTIONS(305),
    [anon_sym_EQ_EQ] = ACTIONS(305),
    [anon_sym_BANG_EQ] = ACTIONS(305),
    [anon_sym_STAR] = ACTIONS(307),
    [anon_sym_SLASH] = ACTIONS(309),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(313),
    [anon_sym_PIPE_GT] = ACTIONS(313),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [144] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(143),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(291),
    [anon_sym_DASH] = ACTIONS(293),
    [anon_sym_LT_DASH] = ACTIONS(143),
    [anon_sym_LT_LT_DASH] = ACTIONS(143),
    [anon_sym_COLON_EQ] = ACTIONS(143),
    [anon_sym_DASH_GT] = ACTIONS(145),
    [anon_sym_DASH_GT_GT] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(145),
    [anon_sym_PIPE_PIPE] = ACTIONS(143),
    [anon_sym_AMP_AMP] = ACTIONS(143),
    [anon_sym_LT] = ACTIONS(145),
    [anon_sym_LT_EQ] = ACTIONS(143),
    [anon_sym_GT] = ACTIONS(145),
    [anon_sym_GT_EQ] = ACTIONS(143),
    [anon_sym_EQ_EQ] = ACTIONS(143),
    [anon_sym_BANG_EQ] = ACTIONS(143),
    [anon_sym_STAR] = ACTIONS(307),
    [anon_sym_SLASH] = ACTIONS(309),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(313),
    [anon_sym_PIPE_GT] = ACTIONS(313),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [145] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(143),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_LT_DASH] = ACTIONS(143),
    [anon_sym_LT_LT_DASH] = ACTIONS(143),
    [anon_sym_COLON_EQ] = ACTIONS(143),
    [anon_sym_DASH_GT] = ACTIONS(145),
    [anon_sym_DASH_GT_GT] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(145),
    [anon_sym_PIPE_PIPE] = ACTIONS(143),
    [anon_sym_AMP_AMP] = ACTIONS(143),
    [anon_sym_LT] = ACTIONS(145),
    [anon_sym_LT_EQ] = ACTIONS(143),
    [anon_sym_GT] = ACTIONS(145),
    [anon_sym_GT_EQ] = ACTIONS(143),
    [anon_sym_EQ_EQ] = ACTIONS(143),
    [anon_sym_BANG_EQ] = ACTIONS(143),
    [anon_sym_STAR] = ACTIONS(145),
    [anon_sym_SLASH] = ACTIONS(143),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(313),
    [anon_sym_PIPE_GT] = ACTIONS(313),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [146] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(143),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_LT_DASH] = ACTIONS(143),
    [anon_sym_LT_LT_DASH] = ACTIONS(143),
    [anon_sym_COLON_EQ] = ACTIONS(143),
    [anon_sym_DASH_GT] = ACTIONS(145),
    [anon_sym_DASH_GT_GT] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(145),
    [anon_sym_PIPE_PIPE] = ACTIONS(143),
    [anon_sym_AMP_AMP] = ACTIONS(143),
    [anon_sym_LT] = ACTIONS(145),
    [anon_sym_LT_EQ] = ACTIONS(143),
    [anon_sym_GT] = ACTIONS(145),
    [anon_sym_GT_EQ] = ACTIONS(143),
    [anon_sym_EQ_EQ] = ACTIONS(143),
    [anon_sym_BANG_EQ] = ACTIONS(143),
    [anon_sym_STAR] = ACTIONS(145),
    [anon_sym_SLASH] = ACTIONS(143),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(143),
    [anon_sym_PIPE_GT] = ACTIONS(143),
    [anon_sym_COLON] = ACTIONS(145),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [147] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(143),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_LT_DASH] = ACTIONS(143),
    [anon_sym_LT_LT_DASH] = ACTIONS(143),
    [anon_sym_COLON_EQ] = ACTIONS(143),
    [anon_sym_DASH_GT] = ACTIONS(145),
    [anon_sym_DASH_GT_GT] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(145),
    [anon_sym_PIPE_PIPE] = ACTIONS(143),
    [anon_sym_AMP_AMP] = ACTIONS(143),
    [anon_sym_LT] = ACTIONS(145),
    [anon_sym_LT_EQ] = ACTIONS(143),
    [anon_sym_GT] = ACTIONS(145),
    [anon_sym_GT_EQ] = ACTIONS(143),
    [anon_sym_EQ_EQ] = ACTIONS(143),
    [anon_sym_BANG_EQ] = ACTIONS(143),
    [anon_sym_STAR] = ACTIONS(145),
    [anon_sym_SLASH] = ACTIONS(143),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(143),
    [anon_sym_PIPE_GT] = ACTIONS(143),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [148] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(143),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_LT_DASH] = ACTIONS(143),
    [anon_sym_LT_LT_DASH] = ACTIONS(143),
    [anon_sym_COLON_EQ] = ACTIONS(143),
    [anon_sym_DASH_GT] = ACTIONS(145),
    [anon_sym_DASH_GT_GT] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(145),
    [anon_sym_PIPE_PIPE] = ACTIONS(143),
    [anon_sym_AMP_AMP] = ACTIONS(143),
    [anon_sym_LT] = ACTIONS(145),
    [anon_sym_LT_EQ] = ACTIONS(143),
    [anon_sym_GT] = ACTIONS(145),
    [anon_sym_GT_EQ] = ACTIONS(143),
    [anon_sym_EQ_EQ] = ACTIONS(143),
    [anon_sym_BANG_EQ] = ACTIONS(143),
    [anon_sym_STAR] = ACTIONS(145),
    [anon_sym_SLASH] = ACTIONS(143),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(143),
    [anon_sym_PIPE_GT] = ACTIONS(143),
    [anon_sym_COLON] = ACTIONS(145),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [149] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(171),
    [sym_identifier] = ACTIONS(173),
    [anon_sym_BSLASH] = ACTIONS(171),
    [anon_sym_function] = ACTIONS(173),
    [anon_sym_EQ] = ACTIONS(339),
    [anon_sym_if] = ACTIONS(173),
    [anon_sym_for] = ACTIONS(173),
    [anon_sym_while] = ACTIONS(173),
    [anon_sym_repeat] = ACTIONS(173),
    [anon_sym_QMARK] = ACTIONS(171),
    [anon_sym_TILDE] = ACTIONS(341),
    [anon_sym_BANG] = ACTIONS(173),
    [anon_sym_PLUS] = ACTIONS(291),
    [anon_sym_DASH] = ACTIONS(293),
    [anon_sym_LT_DASH] = ACTIONS(347),
    [anon_sym_LT_LT_DASH] = ACTIONS(347),
    [anon_sym_COLON_EQ] = ACTIONS(347),
    [anon_sym_DASH_GT] = ACTIONS(343),
    [anon_sym_DASH_GT_GT] = ACTIONS(345),
    [anon_sym_PIPE] = ACTIONS(295),
    [anon_sym_AMP] = ACTIONS(297),
    [anon_sym_PIPE_PIPE] = ACTIONS(299),
    [anon_sym_AMP_AMP] = ACTIONS(301),
    [anon_sym_LT] = ACTIONS(303),
    [anon_sym_LT_EQ] = ACTIONS(305),
    [anon_sym_GT] = ACTIONS(303),
    [anon_sym_GT_EQ] = ACTIONS(305),
    [anon_sym_EQ_EQ] = ACTIONS(305),
    [anon_sym_BANG_EQ] = ACTIONS(305),
    [anon_sym_STAR] = ACTIONS(307),
    [anon_sym_SLASH] = ACTIONS(309),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(313),
    [anon_sym_PIPE_GT] = ACTIONS(313),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(171),
    [sym__number_literal] = ACTIONS(173),
    [anon_sym_SQUOTE] = ACTIONS(171),
    [anon_sym_DQUOTE] = ACTIONS(171),
    [sym_dots] = ACTIONS(173),
    [sym_dot_dot_i] = ACTIONS(173),
    [sym_next] = ACTIONS(173),
    [sym_break] = ACTIONS(173),
    [sym_true] = ACTIONS(173),
    [sym_false] = ACTIONS(173),
    [sym_null] = ACTIONS(173),
    [sym_inf] = ACTIONS(173),
    [sym_nan] = ACTIONS(173),
    [anon_sym_NA] = ACTIONS(173),
    [anon_sym_NA_integer_] = ACTIONS(173),
    [anon_sym_NA_real_] = ACTIONS(173),
    [anon_sym_NA_complex_] = ACTIONS(173),
    [anon_sym_NA_character_] = ACTIONS(173),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(171),
    [sym__semicolon] = ACTIONS(171),
    [sym__raw_string_open] = ACTIONS(171),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(171),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [150] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(175),
    [sym_identifier] = ACTIONS(177),
    [anon_sym_BSLASH] = ACTIONS(175),
    [anon_sym_function] = ACTIONS(177),
    [anon_sym_EQ] = ACTIONS(339),
    [anon_sym_if] = ACTIONS(177),
    [anon_sym_for] = ACTIONS(177),
    [anon_sym_while] = ACTIONS(177),
    [anon_sym_repeat] = ACTIONS(177),
    [anon_sym_QMARK] = ACTIONS(175),
    [anon_sym_TILDE] = ACTIONS(341),
    [anon_sym_BANG] = ACTIONS(177),
    [anon_sym_PLUS] = ACTIONS(291),
    [anon_sym_DASH] = ACTIONS(293),
    [anon_sym_LT_DASH] = ACTIONS(347),
    [anon_sym_LT_LT_DASH] = ACTIONS(347),
    [anon_sym_COLON_EQ] = ACTIONS(347),
    [anon_sym_DASH_GT] = ACTIONS(343),
    [anon_sym_DASH_GT_GT] = ACTIONS(345),
    [anon_sym_PIPE] = ACTIONS(295),
    [anon_sym_AMP] = ACTIONS(297),
    [anon_sym_PIPE_PIPE] = ACTIONS(299),
    [anon_sym_AMP_AMP] = ACTIONS(301),
    [anon_sym_LT] = ACTIONS(303),
    [anon_sym_LT_EQ] = ACTIONS(305),
    [anon_sym_GT] = ACTIONS(303),
    [anon_sym_GT_EQ] = ACTIONS(305),
    [anon_sym_EQ_EQ] = ACTIONS(305),
    [anon_sym_BANG_EQ] = ACTIONS(305),
    [anon_sym_STAR] = ACTIONS(307),
    [anon_sym_SLASH] = ACTIONS(309),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(313),
    [anon_sym_PIPE_GT] = ACTIONS(313),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(175),
    [sym__number_literal] = ACTIONS(177),
    [anon_sym_SQUOTE] = ACTIONS(175),
    [anon_sym_DQUOTE] = ACTIONS(175),
    [sym_dots] = ACTIONS(177),
    [sym_dot_dot_i] = ACTIONS(177),
    [sym_next] = ACTIONS(177),
    [sym_break] = ACTIONS(177),
    [sym_true] = ACTIONS(177),
    [sym_false] = ACTIONS(177),
    [sym_null] = ACTIONS(177),
    [sym_inf] = ACTIONS(177),
    [sym_nan] = ACTIONS(177),
    [anon_sym_NA] = ACTIONS(177),
    [anon_sym_NA_integer_] = ACTIONS(177),
    [anon_sym_NA_real_] = ACTIONS(177),
    [anon_sym_NA_complex_] = ACTIONS(177),
    [anon_sym_NA_character_] = ACTIONS(177),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(175),
    [sym__semicolon] = ACTIONS(175),
    [sym__raw_string_open] = ACTIONS(175),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(175),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [151] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(179),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(339),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(341),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(291),
    [anon_sym_DASH] = ACTIONS(293),
    [anon_sym_LT_DASH] = ACTIONS(179),
    [anon_sym_LT_LT_DASH] = ACTIONS(179),
    [anon_sym_COLON_EQ] = ACTIONS(179),
    [anon_sym_DASH_GT] = ACTIONS(343),
    [anon_sym_DASH_GT_GT] = ACTIONS(345),
    [anon_sym_PIPE] = ACTIONS(295),
    [anon_sym_AMP] = ACTIONS(297),
    [anon_sym_PIPE_PIPE] = ACTIONS(299),
    [anon_sym_AMP_AMP] = ACTIONS(301),
    [anon_sym_LT] = ACTIONS(303),
    [anon_sym_LT_EQ] = ACTIONS(305),
    [anon_sym_GT] = ACTIONS(303),
    [anon_sym_GT_EQ] = ACTIONS(305),
    [anon_sym_EQ_EQ] = ACTIONS(305),
    [anon_sym_BANG_EQ] = ACTIONS(305),
    [anon_sym_STAR] = ACTIONS(307),
    [anon_sym_SLASH] = ACTIONS(309),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(313),
    [anon_sym_PIPE_GT] = ACTIONS(313),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [152] = {
    [sym_string] = STATE(341),
    [sym__raw_string] = STATE(290),
    [sym__single_quoted_string] = STATE(291),
    [sym__double_quoted_string] = STATE(286),
    [aux_sym_function_definition_repeat1] = STATE(323),
    [ts_builtin_sym_end] = ACTIONS(349),
    [sym_identifier] = ACTIONS(351),
    [anon_sym_BSLASH] = ACTIONS(349),
    [anon_sym_function] = ACTIONS(353),
    [anon_sym_EQ] = ACTIONS(353),
    [anon_sym_if] = ACTIONS(353),
    [anon_sym_for] = ACTIONS(353),
    [anon_sym_while] = ACTIONS(353),
    [anon_sym_repeat] = ACTIONS(353),
    [anon_sym_QMARK] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(349),
    [anon_sym_BANG] = ACTIONS(353),
    [anon_sym_PLUS] = ACTIONS(349),
    [anon_sym_DASH] = ACTIONS(353),
    [anon_sym_LT_DASH] = ACTIONS(349),
    [anon_sym_LT_LT_DASH] = ACTIONS(349),
    [anon_sym_COLON_EQ] = ACTIONS(349),
    [anon_sym_DASH_GT] = ACTIONS(353),
    [anon_sym_DASH_GT_GT] = ACTIONS(349),
    [anon_sym_PIPE] = ACTIONS(353),
    [anon_sym_AMP] = ACTIONS(353),
    [anon_sym_PIPE_PIPE] = ACTIONS(349),
    [anon_sym_AMP_AMP] = ACTIONS(349),
    [anon_sym_LT] = ACTIONS(353),
    [anon_sym_LT_EQ] = ACTIONS(349),
    [anon_sym_GT] = ACTIONS(353),
    [anon_sym_GT_EQ] = ACTIONS(349),
    [anon_sym_EQ_EQ] = ACTIONS(349),
    [anon_sym_BANG_EQ] = ACTIONS(349),
    [anon_sym_STAR] = ACTIONS(353),
    [anon_sym_SLASH] = ACTIONS(349),
    [anon_sym_STAR_STAR] = ACTIONS(349),
    [anon_sym_CARET] = ACTIONS(349),
    [aux_sym_binary_operator_token1] = ACTIONS(349),
    [anon_sym_PIPE_GT] = ACTIONS(349),
    [anon_sym_COLON] = ACTIONS(353),
    [anon_sym_DOLLAR] = ACTIONS(349),
    [anon_sym_AT] = ACTIONS(349),
    [sym__hex_literal] = ACTIONS(349),
    [sym__number_literal] = ACTIONS(353),
    [anon_sym_SQUOTE] = ACTIONS(331),
    [anon_sym_DQUOTE] = ACTIONS(333),
    [sym_dots] = ACTIONS(351),
    [sym_dot_dot_i] = ACTIONS(351),
    [sym_next] = ACTIONS(353),
    [sym_break] = ACTIONS(353),
    [sym_true] = ACTIONS(353),
    [sym_false] = ACTIONS(353),
    [sym_null] = ACTIONS(353),
    [sym_inf] = ACTIONS(353),
    [sym_nan] = ACTIONS(353),
    [anon_sym_NA] = ACTIONS(353),
    [anon_sym_NA_integer_] = ACTIONS(353),
    [anon_sym_NA_real_] = ACTIONS(353),
    [anon_sym_NA_complex_] = ACTIONS(353),
    [anon_sym_NA_character_] = ACTIONS(353),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(349),
    [sym__semicolon] = ACTIONS(349),
    [sym__raw_string_open] = ACTIONS(337),
    [sym__external_else] = ACTIONS(349),
    [sym__external_open_parenthesis] = ACTIONS(349),
    [sym__external_open_brace] = ACTIONS(349),
    [sym__external_open_bracket] = ACTIONS(349),
    [sym__external_open_bracket2] = ACTIONS(349),
  },
  [153] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(179),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(339),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(341),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(291),
    [anon_sym_DASH] = ACTIONS(293),
    [anon_sym_LT_DASH] = ACTIONS(347),
    [anon_sym_LT_LT_DASH] = ACTIONS(347),
    [anon_sym_COLON_EQ] = ACTIONS(347),
    [anon_sym_DASH_GT] = ACTIONS(343),
    [anon_sym_DASH_GT_GT] = ACTIONS(345),
    [anon_sym_PIPE] = ACTIONS(295),
    [anon_sym_AMP] = ACTIONS(297),
    [anon_sym_PIPE_PIPE] = ACTIONS(299),
    [anon_sym_AMP_AMP] = ACTIONS(301),
    [anon_sym_LT] = ACTIONS(303),
    [anon_sym_LT_EQ] = ACTIONS(305),
    [anon_sym_GT] = ACTIONS(303),
    [anon_sym_GT_EQ] = ACTIONS(305),
    [anon_sym_EQ_EQ] = ACTIONS(305),
    [anon_sym_BANG_EQ] = ACTIONS(305),
    [anon_sym_STAR] = ACTIONS(307),
    [anon_sym_SLASH] = ACTIONS(309),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(313),
    [anon_sym_PIPE_GT] = ACTIONS(313),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [154] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(179),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(181),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(179),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(291),
    [anon_sym_DASH] = ACTIONS(293),
    [anon_sym_LT_DASH] = ACTIONS(179),
    [anon_sym_LT_LT_DASH] = ACTIONS(179),
    [anon_sym_COLON_EQ] = ACTIONS(179),
    [anon_sym_DASH_GT] = ACTIONS(181),
    [anon_sym_DASH_GT_GT] = ACTIONS(179),
    [anon_sym_PIPE] = ACTIONS(295),
    [anon_sym_AMP] = ACTIONS(297),
    [anon_sym_PIPE_PIPE] = ACTIONS(299),
    [anon_sym_AMP_AMP] = ACTIONS(301),
    [anon_sym_LT] = ACTIONS(303),
    [anon_sym_LT_EQ] = ACTIONS(305),
    [anon_sym_GT] = ACTIONS(303),
    [anon_sym_GT_EQ] = ACTIONS(305),
    [anon_sym_EQ_EQ] = ACTIONS(305),
    [anon_sym_BANG_EQ] = ACTIONS(305),
    [anon_sym_STAR] = ACTIONS(307),
    [anon_sym_SLASH] = ACTIONS(309),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(313),
    [anon_sym_PIPE_GT] = ACTIONS(313),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [155] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(179),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(181),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(179),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(181),
    [anon_sym_LT_DASH] = ACTIONS(179),
    [anon_sym_LT_LT_DASH] = ACTIONS(179),
    [anon_sym_COLON_EQ] = ACTIONS(179),
    [anon_sym_DASH_GT] = ACTIONS(181),
    [anon_sym_DASH_GT_GT] = ACTIONS(179),
    [anon_sym_PIPE] = ACTIONS(181),
    [anon_sym_AMP] = ACTIONS(181),
    [anon_sym_PIPE_PIPE] = ACTIONS(179),
    [anon_sym_AMP_AMP] = ACTIONS(179),
    [anon_sym_LT] = ACTIONS(181),
    [anon_sym_LT_EQ] = ACTIONS(179),
    [anon_sym_GT] = ACTIONS(181),
    [anon_sym_GT_EQ] = ACTIONS(179),
    [anon_sym_EQ_EQ] = ACTIONS(179),
    [anon_sym_BANG_EQ] = ACTIONS(179),
    [anon_sym_STAR] = ACTIONS(307),
    [anon_sym_SLASH] = ACTIONS(309),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(313),
    [anon_sym_PIPE_GT] = ACTIONS(313),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [156] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(179),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(339),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(341),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(291),
    [anon_sym_DASH] = ACTIONS(293),
    [anon_sym_LT_DASH] = ACTIONS(347),
    [anon_sym_LT_LT_DASH] = ACTIONS(347),
    [anon_sym_COLON_EQ] = ACTIONS(347),
    [anon_sym_DASH_GT] = ACTIONS(343),
    [anon_sym_DASH_GT_GT] = ACTIONS(345),
    [anon_sym_PIPE] = ACTIONS(295),
    [anon_sym_AMP] = ACTIONS(297),
    [anon_sym_PIPE_PIPE] = ACTIONS(299),
    [anon_sym_AMP_AMP] = ACTIONS(301),
    [anon_sym_LT] = ACTIONS(303),
    [anon_sym_LT_EQ] = ACTIONS(305),
    [anon_sym_GT] = ACTIONS(303),
    [anon_sym_GT_EQ] = ACTIONS(305),
    [anon_sym_EQ_EQ] = ACTIONS(305),
    [anon_sym_BANG_EQ] = ACTIONS(305),
    [anon_sym_STAR] = ACTIONS(307),
    [anon_sym_SLASH] = ACTIONS(309),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(313),
    [anon_sym_PIPE_GT] = ACTIONS(313),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [157] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(179),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(181),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(341),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(291),
    [anon_sym_DASH] = ACTIONS(293),
    [anon_sym_LT_DASH] = ACTIONS(179),
    [anon_sym_LT_LT_DASH] = ACTIONS(179),
    [anon_sym_COLON_EQ] = ACTIONS(179),
    [anon_sym_DASH_GT] = ACTIONS(181),
    [anon_sym_DASH_GT_GT] = ACTIONS(179),
    [anon_sym_PIPE] = ACTIONS(295),
    [anon_sym_AMP] = ACTIONS(297),
    [anon_sym_PIPE_PIPE] = ACTIONS(299),
    [anon_sym_AMP_AMP] = ACTIONS(301),
    [anon_sym_LT] = ACTIONS(303),
    [anon_sym_LT_EQ] = ACTIONS(305),
    [anon_sym_GT] = ACTIONS(303),
    [anon_sym_GT_EQ] = ACTIONS(305),
    [anon_sym_EQ_EQ] = ACTIONS(305),
    [anon_sym_BANG_EQ] = ACTIONS(305),
    [anon_sym_STAR] = ACTIONS(307),
    [anon_sym_SLASH] = ACTIONS(309),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(313),
    [anon_sym_PIPE_GT] = ACTIONS(313),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [158] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(179),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(181),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(179),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(291),
    [anon_sym_DASH] = ACTIONS(293),
    [anon_sym_LT_DASH] = ACTIONS(179),
    [anon_sym_LT_LT_DASH] = ACTIONS(179),
    [anon_sym_COLON_EQ] = ACTIONS(179),
    [anon_sym_DASH_GT] = ACTIONS(181),
    [anon_sym_DASH_GT_GT] = ACTIONS(179),
    [anon_sym_PIPE] = ACTIONS(181),
    [anon_sym_AMP] = ACTIONS(297),
    [anon_sym_PIPE_PIPE] = ACTIONS(179),
    [anon_sym_AMP_AMP] = ACTIONS(301),
    [anon_sym_LT] = ACTIONS(303),
    [anon_sym_LT_EQ] = ACTIONS(305),
    [anon_sym_GT] = ACTIONS(303),
    [anon_sym_GT_EQ] = ACTIONS(305),
    [anon_sym_EQ_EQ] = ACTIONS(305),
    [anon_sym_BANG_EQ] = ACTIONS(305),
    [anon_sym_STAR] = ACTIONS(307),
    [anon_sym_SLASH] = ACTIONS(309),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(313),
    [anon_sym_PIPE_GT] = ACTIONS(313),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [159] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(179),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(181),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(179),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(291),
    [anon_sym_DASH] = ACTIONS(293),
    [anon_sym_LT_DASH] = ACTIONS(179),
    [anon_sym_LT_LT_DASH] = ACTIONS(179),
    [anon_sym_COLON_EQ] = ACTIONS(179),
    [anon_sym_DASH_GT] = ACTIONS(181),
    [anon_sym_DASH_GT_GT] = ACTIONS(179),
    [anon_sym_PIPE] = ACTIONS(181),
    [anon_sym_AMP] = ACTIONS(181),
    [anon_sym_PIPE_PIPE] = ACTIONS(179),
    [anon_sym_AMP_AMP] = ACTIONS(179),
    [anon_sym_LT] = ACTIONS(303),
    [anon_sym_LT_EQ] = ACTIONS(305),
    [anon_sym_GT] = ACTIONS(303),
    [anon_sym_GT_EQ] = ACTIONS(305),
    [anon_sym_EQ_EQ] = ACTIONS(305),
    [anon_sym_BANG_EQ] = ACTIONS(305),
    [anon_sym_STAR] = ACTIONS(307),
    [anon_sym_SLASH] = ACTIONS(309),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(313),
    [anon_sym_PIPE_GT] = ACTIONS(313),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [160] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(179),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(181),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(179),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(291),
    [anon_sym_DASH] = ACTIONS(293),
    [anon_sym_LT_DASH] = ACTIONS(179),
    [anon_sym_LT_LT_DASH] = ACTIONS(179),
    [anon_sym_COLON_EQ] = ACTIONS(179),
    [anon_sym_DASH_GT] = ACTIONS(181),
    [anon_sym_DASH_GT_GT] = ACTIONS(179),
    [anon_sym_PIPE] = ACTIONS(181),
    [anon_sym_AMP] = ACTIONS(181),
    [anon_sym_PIPE_PIPE] = ACTIONS(179),
    [anon_sym_AMP_AMP] = ACTIONS(179),
    [anon_sym_LT] = ACTIONS(181),
    [anon_sym_LT_EQ] = ACTIONS(179),
    [anon_sym_GT] = ACTIONS(181),
    [anon_sym_GT_EQ] = ACTIONS(179),
    [anon_sym_EQ_EQ] = ACTIONS(179),
    [anon_sym_BANG_EQ] = ACTIONS(179),
    [anon_sym_STAR] = ACTIONS(307),
    [anon_sym_SLASH] = ACTIONS(309),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(313),
    [anon_sym_PIPE_GT] = ACTIONS(313),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [161] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(179),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(181),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(179),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(181),
    [anon_sym_LT_DASH] = ACTIONS(179),
    [anon_sym_LT_LT_DASH] = ACTIONS(179),
    [anon_sym_COLON_EQ] = ACTIONS(179),
    [anon_sym_DASH_GT] = ACTIONS(181),
    [anon_sym_DASH_GT_GT] = ACTIONS(179),
    [anon_sym_PIPE] = ACTIONS(181),
    [anon_sym_AMP] = ACTIONS(181),
    [anon_sym_PIPE_PIPE] = ACTIONS(179),
    [anon_sym_AMP_AMP] = ACTIONS(179),
    [anon_sym_LT] = ACTIONS(181),
    [anon_sym_LT_EQ] = ACTIONS(179),
    [anon_sym_GT] = ACTIONS(181),
    [anon_sym_GT_EQ] = ACTIONS(179),
    [anon_sym_EQ_EQ] = ACTIONS(179),
    [anon_sym_BANG_EQ] = ACTIONS(179),
    [anon_sym_STAR] = ACTIONS(181),
    [anon_sym_SLASH] = ACTIONS(179),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(313),
    [anon_sym_PIPE_GT] = ACTIONS(313),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [162] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(179),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(181),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(179),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(181),
    [anon_sym_LT_DASH] = ACTIONS(179),
    [anon_sym_LT_LT_DASH] = ACTIONS(179),
    [anon_sym_COLON_EQ] = ACTIONS(179),
    [anon_sym_DASH_GT] = ACTIONS(181),
    [anon_sym_DASH_GT_GT] = ACTIONS(179),
    [anon_sym_PIPE] = ACTIONS(181),
    [anon_sym_AMP] = ACTIONS(181),
    [anon_sym_PIPE_PIPE] = ACTIONS(179),
    [anon_sym_AMP_AMP] = ACTIONS(179),
    [anon_sym_LT] = ACTIONS(181),
    [anon_sym_LT_EQ] = ACTIONS(179),
    [anon_sym_GT] = ACTIONS(181),
    [anon_sym_GT_EQ] = ACTIONS(179),
    [anon_sym_EQ_EQ] = ACTIONS(179),
    [anon_sym_BANG_EQ] = ACTIONS(179),
    [anon_sym_STAR] = ACTIONS(181),
    [anon_sym_SLASH] = ACTIONS(179),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(179),
    [anon_sym_PIPE_GT] = ACTIONS(179),
    [anon_sym_COLON] = ACTIONS(181),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [163] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(179),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(181),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(179),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(181),
    [anon_sym_LT_DASH] = ACTIONS(179),
    [anon_sym_LT_LT_DASH] = ACTIONS(179),
    [anon_sym_COLON_EQ] = ACTIONS(179),
    [anon_sym_DASH_GT] = ACTIONS(181),
    [anon_sym_DASH_GT_GT] = ACTIONS(179),
    [anon_sym_PIPE] = ACTIONS(181),
    [anon_sym_AMP] = ACTIONS(181),
    [anon_sym_PIPE_PIPE] = ACTIONS(179),
    [anon_sym_AMP_AMP] = ACTIONS(179),
    [anon_sym_LT] = ACTIONS(181),
    [anon_sym_LT_EQ] = ACTIONS(179),
    [anon_sym_GT] = ACTIONS(181),
    [anon_sym_GT_EQ] = ACTIONS(179),
    [anon_sym_EQ_EQ] = ACTIONS(179),
    [anon_sym_BANG_EQ] = ACTIONS(179),
    [anon_sym_STAR] = ACTIONS(181),
    [anon_sym_SLASH] = ACTIONS(179),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(179),
    [anon_sym_PIPE_GT] = ACTIONS(179),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [164] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(179),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(181),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(179),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(181),
    [anon_sym_LT_DASH] = ACTIONS(179),
    [anon_sym_LT_LT_DASH] = ACTIONS(179),
    [anon_sym_COLON_EQ] = ACTIONS(179),
    [anon_sym_DASH_GT] = ACTIONS(181),
    [anon_sym_DASH_GT_GT] = ACTIONS(179),
    [anon_sym_PIPE] = ACTIONS(181),
    [anon_sym_AMP] = ACTIONS(181),
    [anon_sym_PIPE_PIPE] = ACTIONS(179),
    [anon_sym_AMP_AMP] = ACTIONS(179),
    [anon_sym_LT] = ACTIONS(181),
    [anon_sym_LT_EQ] = ACTIONS(179),
    [anon_sym_GT] = ACTIONS(181),
    [anon_sym_GT_EQ] = ACTIONS(179),
    [anon_sym_EQ_EQ] = ACTIONS(179),
    [anon_sym_BANG_EQ] = ACTIONS(179),
    [anon_sym_STAR] = ACTIONS(181),
    [anon_sym_SLASH] = ACTIONS(179),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(179),
    [anon_sym_PIPE_GT] = ACTIONS(179),
    [anon_sym_COLON] = ACTIONS(181),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [165] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(183),
    [sym_identifier] = ACTIONS(185),
    [anon_sym_BSLASH] = ACTIONS(183),
    [anon_sym_function] = ACTIONS(185),
    [anon_sym_EQ] = ACTIONS(339),
    [anon_sym_if] = ACTIONS(185),
    [anon_sym_for] = ACTIONS(185),
    [anon_sym_while] = ACTIONS(185),
    [anon_sym_repeat] = ACTIONS(185),
    [anon_sym_QMARK] = ACTIONS(183),
    [anon_sym_TILDE] = ACTIONS(341),
    [anon_sym_BANG] = ACTIONS(185),
    [anon_sym_PLUS] = ACTIONS(291),
    [anon_sym_DASH] = ACTIONS(293),
    [anon_sym_LT_DASH] = ACTIONS(347),
    [anon_sym_LT_LT_DASH] = ACTIONS(347),
    [anon_sym_COLON_EQ] = ACTIONS(347),
    [anon_sym_DASH_GT] = ACTIONS(343),
    [anon_sym_DASH_GT_GT] = ACTIONS(345),
    [anon_sym_PIPE] = ACTIONS(295),
    [anon_sym_AMP] = ACTIONS(297),
    [anon_sym_PIPE_PIPE] = ACTIONS(299),
    [anon_sym_AMP_AMP] = ACTIONS(301),
    [anon_sym_LT] = ACTIONS(303),
    [anon_sym_LT_EQ] = ACTIONS(305),
    [anon_sym_GT] = ACTIONS(303),
    [anon_sym_GT_EQ] = ACTIONS(305),
    [anon_sym_EQ_EQ] = ACTIONS(305),
    [anon_sym_BANG_EQ] = ACTIONS(305),
    [anon_sym_STAR] = ACTIONS(307),
    [anon_sym_SLASH] = ACTIONS(309),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(313),
    [anon_sym_PIPE_GT] = ACTIONS(313),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(183),
    [sym__number_literal] = ACTIONS(185),
    [anon_sym_SQUOTE] = ACTIONS(183),
    [anon_sym_DQUOTE] = ACTIONS(183),
    [sym_dots] = ACTIONS(185),
    [sym_dot_dot_i] = ACTIONS(185),
    [sym_next] = ACTIONS(185),
    [sym_break] = ACTIONS(185),
    [sym_true] = ACTIONS(185),
    [sym_false] = ACTIONS(185),
    [sym_null] = ACTIONS(185),
    [sym_inf] = ACTIONS(185),
    [sym_nan] = ACTIONS(185),
    [anon_sym_NA] = ACTIONS(185),
    [anon_sym_NA_integer_] = ACTIONS(185),
    [anon_sym_NA_real_] = ACTIONS(185),
    [anon_sym_NA_complex_] = ACTIONS(185),
    [anon_sym_NA_character_] = ACTIONS(185),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(183),
    [sym__semicolon] = ACTIONS(183),
    [sym__raw_string_open] = ACTIONS(183),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(183),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [166] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(187),
    [sym_identifier] = ACTIONS(189),
    [anon_sym_BSLASH] = ACTIONS(187),
    [anon_sym_function] = ACTIONS(189),
    [anon_sym_EQ] = ACTIONS(339),
    [anon_sym_if] = ACTIONS(189),
    [anon_sym_for] = ACTIONS(189),
    [anon_sym_while] = ACTIONS(189),
    [anon_sym_repeat] = ACTIONS(189),
    [anon_sym_QMARK] = ACTIONS(187),
    [anon_sym_TILDE] = ACTIONS(341),
    [anon_sym_BANG] = ACTIONS(189),
    [anon_sym_PLUS] = ACTIONS(291),
    [anon_sym_DASH] = ACTIONS(293),
    [anon_sym_LT_DASH] = ACTIONS(347),
    [anon_sym_LT_LT_DASH] = ACTIONS(347),
    [anon_sym_COLON_EQ] = ACTIONS(347),
    [anon_sym_DASH_GT] = ACTIONS(343),
    [anon_sym_DASH_GT_GT] = ACTIONS(345),
    [anon_sym_PIPE] = ACTIONS(295),
    [anon_sym_AMP] = ACTIONS(297),
    [anon_sym_PIPE_PIPE] = ACTIONS(299),
    [anon_sym_AMP_AMP] = ACTIONS(301),
    [anon_sym_LT] = ACTIONS(303),
    [anon_sym_LT_EQ] = ACTIONS(305),
    [anon_sym_GT] = ACTIONS(303),
    [anon_sym_GT_EQ] = ACTIONS(305),
    [anon_sym_EQ_EQ] = ACTIONS(305),
    [anon_sym_BANG_EQ] = ACTIONS(305),
    [anon_sym_STAR] = ACTIONS(307),
    [anon_sym_SLASH] = ACTIONS(309),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(313),
    [anon_sym_PIPE_GT] = ACTIONS(313),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(187),
    [sym__number_literal] = ACTIONS(189),
    [anon_sym_SQUOTE] = ACTIONS(187),
    [anon_sym_DQUOTE] = ACTIONS(187),
    [sym_dots] = ACTIONS(189),
    [sym_dot_dot_i] = ACTIONS(189),
    [sym_next] = ACTIONS(189),
    [sym_break] = ACTIONS(189),
    [sym_true] = ACTIONS(189),
    [sym_false] = ACTIONS(189),
    [sym_null] = ACTIONS(189),
    [sym_inf] = ACTIONS(189),
    [sym_nan] = ACTIONS(189),
    [anon_sym_NA] = ACTIONS(189),
    [anon_sym_NA_integer_] = ACTIONS(189),
    [anon_sym_NA_real_] = ACTIONS(189),
    [anon_sym_NA_complex_] = ACTIONS(189),
    [anon_sym_NA_character_] = ACTIONS(189),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(187),
    [sym__semicolon] = ACTIONS(187),
    [sym__raw_string_open] = ACTIONS(187),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(187),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [167] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(191),
    [sym_identifier] = ACTIONS(193),
    [anon_sym_BSLASH] = ACTIONS(191),
    [anon_sym_function] = ACTIONS(193),
    [anon_sym_EQ] = ACTIONS(339),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_for] = ACTIONS(193),
    [anon_sym_while] = ACTIONS(193),
    [anon_sym_repeat] = ACTIONS(193),
    [anon_sym_QMARK] = ACTIONS(191),
    [anon_sym_TILDE] = ACTIONS(341),
    [anon_sym_BANG] = ACTIONS(193),
    [anon_sym_PLUS] = ACTIONS(291),
    [anon_sym_DASH] = ACTIONS(293),
    [anon_sym_LT_DASH] = ACTIONS(347),
    [anon_sym_LT_LT_DASH] = ACTIONS(347),
    [anon_sym_COLON_EQ] = ACTIONS(347),
    [anon_sym_DASH_GT] = ACTIONS(343),
    [anon_sym_DASH_GT_GT] = ACTIONS(345),
    [anon_sym_PIPE] = ACTIONS(295),
    [anon_sym_AMP] = ACTIONS(297),
    [anon_sym_PIPE_PIPE] = ACTIONS(299),
    [anon_sym_AMP_AMP] = ACTIONS(301),
    [anon_sym_LT] = ACTIONS(303),
    [anon_sym_LT_EQ] = ACTIONS(305),
    [anon_sym_GT] = ACTIONS(303),
    [anon_sym_GT_EQ] = ACTIONS(305),
    [anon_sym_EQ_EQ] = ACTIONS(305),
    [anon_sym_BANG_EQ] = ACTIONS(305),
    [anon_sym_STAR] = ACTIONS(307),
    [anon_sym_SLASH] = ACTIONS(309),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(313),
    [anon_sym_PIPE_GT] = ACTIONS(313),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(191),
    [sym__number_literal] = ACTIONS(193),
    [anon_sym_SQUOTE] = ACTIONS(191),
    [anon_sym_DQUOTE] = ACTIONS(191),
    [sym_dots] = ACTIONS(193),
    [sym_dot_dot_i] = ACTIONS(193),
    [sym_next] = ACTIONS(193),
    [sym_break] = ACTIONS(193),
    [sym_true] = ACTIONS(193),
    [sym_false] = ACTIONS(193),
    [sym_null] = ACTIONS(193),
    [sym_inf] = ACTIONS(193),
    [sym_nan] = ACTIONS(193),
    [anon_sym_NA] = ACTIONS(193),
    [anon_sym_NA_integer_] = ACTIONS(193),
    [anon_sym_NA_real_] = ACTIONS(193),
    [anon_sym_NA_complex_] = ACTIONS(193),
    [anon_sym_NA_character_] = ACTIONS(193),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(191),
    [sym__semicolon] = ACTIONS(191),
    [sym__raw_string_open] = ACTIONS(191),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(191),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [168] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(195),
    [sym_identifier] = ACTIONS(197),
    [anon_sym_BSLASH] = ACTIONS(195),
    [anon_sym_function] = ACTIONS(197),
    [anon_sym_EQ] = ACTIONS(339),
    [anon_sym_if] = ACTIONS(197),
    [anon_sym_for] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(197),
    [anon_sym_repeat] = ACTIONS(197),
    [anon_sym_QMARK] = ACTIONS(195),
    [anon_sym_TILDE] = ACTIONS(341),
    [anon_sym_BANG] = ACTIONS(197),
    [anon_sym_PLUS] = ACTIONS(291),
    [anon_sym_DASH] = ACTIONS(293),
    [anon_sym_LT_DASH] = ACTIONS(347),
    [anon_sym_LT_LT_DASH] = ACTIONS(347),
    [anon_sym_COLON_EQ] = ACTIONS(347),
    [anon_sym_DASH_GT] = ACTIONS(343),
    [anon_sym_DASH_GT_GT] = ACTIONS(345),
    [anon_sym_PIPE] = ACTIONS(295),
    [anon_sym_AMP] = ACTIONS(297),
    [anon_sym_PIPE_PIPE] = ACTIONS(299),
    [anon_sym_AMP_AMP] = ACTIONS(301),
    [anon_sym_LT] = ACTIONS(303),
    [anon_sym_LT_EQ] = ACTIONS(305),
    [anon_sym_GT] = ACTIONS(303),
    [anon_sym_GT_EQ] = ACTIONS(305),
    [anon_sym_EQ_EQ] = ACTIONS(305),
    [anon_sym_BANG_EQ] = ACTIONS(305),
    [anon_sym_STAR] = ACTIONS(307),
    [anon_sym_SLASH] = ACTIONS(309),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(313),
    [anon_sym_PIPE_GT] = ACTIONS(313),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(195),
    [sym__number_literal] = ACTIONS(197),
    [anon_sym_SQUOTE] = ACTIONS(195),
    [anon_sym_DQUOTE] = ACTIONS(195),
    [sym_dots] = ACTIONS(197),
    [sym_dot_dot_i] = ACTIONS(197),
    [sym_next] = ACTIONS(197),
    [sym_break] = ACTIONS(197),
    [sym_true] = ACTIONS(197),
    [sym_false] = ACTIONS(197),
    [sym_null] = ACTIONS(197),
    [sym_inf] = ACTIONS(197),
    [sym_nan] = ACTIONS(197),
    [anon_sym_NA] = ACTIONS(197),
    [anon_sym_NA_integer_] = ACTIONS(197),
    [anon_sym_NA_real_] = ACTIONS(197),
    [anon_sym_NA_complex_] = ACTIONS(197),
    [anon_sym_NA_character_] = ACTIONS(197),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(195),
    [sym__semicolon] = ACTIONS(195),
    [sym__raw_string_open] = ACTIONS(195),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(195),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [169] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(199),
    [sym_identifier] = ACTIONS(201),
    [anon_sym_BSLASH] = ACTIONS(199),
    [anon_sym_function] = ACTIONS(201),
    [anon_sym_EQ] = ACTIONS(339),
    [anon_sym_if] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(201),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_repeat] = ACTIONS(201),
    [anon_sym_QMARK] = ACTIONS(199),
    [anon_sym_TILDE] = ACTIONS(341),
    [anon_sym_BANG] = ACTIONS(201),
    [anon_sym_PLUS] = ACTIONS(291),
    [anon_sym_DASH] = ACTIONS(293),
    [anon_sym_LT_DASH] = ACTIONS(347),
    [anon_sym_LT_LT_DASH] = ACTIONS(347),
    [anon_sym_COLON_EQ] = ACTIONS(347),
    [anon_sym_DASH_GT] = ACTIONS(343),
    [anon_sym_DASH_GT_GT] = ACTIONS(345),
    [anon_sym_PIPE] = ACTIONS(295),
    [anon_sym_AMP] = ACTIONS(297),
    [anon_sym_PIPE_PIPE] = ACTIONS(299),
    [anon_sym_AMP_AMP] = ACTIONS(301),
    [anon_sym_LT] = ACTIONS(303),
    [anon_sym_LT_EQ] = ACTIONS(305),
    [anon_sym_GT] = ACTIONS(303),
    [anon_sym_GT_EQ] = ACTIONS(305),
    [anon_sym_EQ_EQ] = ACTIONS(305),
    [anon_sym_BANG_EQ] = ACTIONS(305),
    [anon_sym_STAR] = ACTIONS(307),
    [anon_sym_SLASH] = ACTIONS(309),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(313),
    [anon_sym_PIPE_GT] = ACTIONS(313),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(199),
    [sym__number_literal] = ACTIONS(201),
    [anon_sym_SQUOTE] = ACTIONS(199),
    [anon_sym_DQUOTE] = ACTIONS(199),
    [sym_dots] = ACTIONS(201),
    [sym_dot_dot_i] = ACTIONS(201),
    [sym_next] = ACTIONS(201),
    [sym_break] = ACTIONS(201),
    [sym_true] = ACTIONS(201),
    [sym_false] = ACTIONS(201),
    [sym_null] = ACTIONS(201),
    [sym_inf] = ACTIONS(201),
    [sym_nan] = ACTIONS(201),
    [anon_sym_NA] = ACTIONS(201),
    [anon_sym_NA_integer_] = ACTIONS(201),
    [anon_sym_NA_real_] = ACTIONS(201),
    [anon_sym_NA_complex_] = ACTIONS(201),
    [anon_sym_NA_character_] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(199),
    [sym__semicolon] = ACTIONS(199),
    [sym__raw_string_open] = ACTIONS(199),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(199),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [170] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(203),
    [sym_identifier] = ACTIONS(205),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_EQ] = ACTIONS(339),
    [anon_sym_if] = ACTIONS(205),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_while] = ACTIONS(205),
    [anon_sym_repeat] = ACTIONS(205),
    [anon_sym_QMARK] = ACTIONS(203),
    [anon_sym_TILDE] = ACTIONS(341),
    [anon_sym_BANG] = ACTIONS(205),
    [anon_sym_PLUS] = ACTIONS(291),
    [anon_sym_DASH] = ACTIONS(293),
    [anon_sym_LT_DASH] = ACTIONS(347),
    [anon_sym_LT_LT_DASH] = ACTIONS(347),
    [anon_sym_COLON_EQ] = ACTIONS(347),
    [anon_sym_DASH_GT] = ACTIONS(343),
    [anon_sym_DASH_GT_GT] = ACTIONS(345),
    [anon_sym_PIPE] = ACTIONS(295),
    [anon_sym_AMP] = ACTIONS(297),
    [anon_sym_PIPE_PIPE] = ACTIONS(299),
    [anon_sym_AMP_AMP] = ACTIONS(301),
    [anon_sym_LT] = ACTIONS(303),
    [anon_sym_LT_EQ] = ACTIONS(305),
    [anon_sym_GT] = ACTIONS(303),
    [anon_sym_GT_EQ] = ACTIONS(305),
    [anon_sym_EQ_EQ] = ACTIONS(305),
    [anon_sym_BANG_EQ] = ACTIONS(305),
    [anon_sym_STAR] = ACTIONS(307),
    [anon_sym_SLASH] = ACTIONS(309),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(313),
    [anon_sym_PIPE_GT] = ACTIONS(313),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(203),
    [sym__number_literal] = ACTIONS(205),
    [anon_sym_SQUOTE] = ACTIONS(203),
    [anon_sym_DQUOTE] = ACTIONS(203),
    [sym_dots] = ACTIONS(205),
    [sym_dot_dot_i] = ACTIONS(205),
    [sym_next] = ACTIONS(205),
    [sym_break] = ACTIONS(205),
    [sym_true] = ACTIONS(205),
    [sym_false] = ACTIONS(205),
    [sym_null] = ACTIONS(205),
    [sym_inf] = ACTIONS(205),
    [sym_nan] = ACTIONS(205),
    [anon_sym_NA] = ACTIONS(205),
    [anon_sym_NA_integer_] = ACTIONS(205),
    [anon_sym_NA_real_] = ACTIONS(205),
    [anon_sym_NA_complex_] = ACTIONS(205),
    [anon_sym_NA_character_] = ACTIONS(205),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(203),
    [sym__semicolon] = ACTIONS(203),
    [sym__raw_string_open] = ACTIONS(203),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(203),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [171] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(207),
    [sym_identifier] = ACTIONS(209),
    [anon_sym_BSLASH] = ACTIONS(207),
    [anon_sym_function] = ACTIONS(209),
    [anon_sym_EQ] = ACTIONS(339),
    [anon_sym_if] = ACTIONS(209),
    [anon_sym_for] = ACTIONS(209),
    [anon_sym_while] = ACTIONS(209),
    [anon_sym_repeat] = ACTIONS(209),
    [anon_sym_QMARK] = ACTIONS(207),
    [anon_sym_TILDE] = ACTIONS(341),
    [anon_sym_BANG] = ACTIONS(209),
    [anon_sym_PLUS] = ACTIONS(291),
    [anon_sym_DASH] = ACTIONS(293),
    [anon_sym_LT_DASH] = ACTIONS(347),
    [anon_sym_LT_LT_DASH] = ACTIONS(347),
    [anon_sym_COLON_EQ] = ACTIONS(347),
    [anon_sym_DASH_GT] = ACTIONS(343),
    [anon_sym_DASH_GT_GT] = ACTIONS(345),
    [anon_sym_PIPE] = ACTIONS(295),
    [anon_sym_AMP] = ACTIONS(297),
    [anon_sym_PIPE_PIPE] = ACTIONS(299),
    [anon_sym_AMP_AMP] = ACTIONS(301),
    [anon_sym_LT] = ACTIONS(303),
    [anon_sym_LT_EQ] = ACTIONS(305),
    [anon_sym_GT] = ACTIONS(303),
    [anon_sym_GT_EQ] = ACTIONS(305),
    [anon_sym_EQ_EQ] = ACTIONS(305),
    [anon_sym_BANG_EQ] = ACTIONS(305),
    [anon_sym_STAR] = ACTIONS(307),
    [anon_sym_SLASH] = ACTIONS(309),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(313),
    [anon_sym_PIPE_GT] = ACTIONS(313),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(207),
    [sym__number_literal] = ACTIONS(209),
    [anon_sym_SQUOTE] = ACTIONS(207),
    [anon_sym_DQUOTE] = ACTIONS(207),
    [sym_dots] = ACTIONS(209),
    [sym_dot_dot_i] = ACTIONS(209),
    [sym_next] = ACTIONS(209),
    [sym_break] = ACTIONS(209),
    [sym_true] = ACTIONS(209),
    [sym_false] = ACTIONS(209),
    [sym_null] = ACTIONS(209),
    [sym_inf] = ACTIONS(209),
    [sym_nan] = ACTIONS(209),
    [anon_sym_NA] = ACTIONS(209),
    [anon_sym_NA_integer_] = ACTIONS(209),
    [anon_sym_NA_real_] = ACTIONS(209),
    [anon_sym_NA_complex_] = ACTIONS(209),
    [anon_sym_NA_character_] = ACTIONS(209),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(207),
    [sym__semicolon] = ACTIONS(207),
    [sym__raw_string_open] = ACTIONS(207),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(207),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [172] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(211),
    [sym_identifier] = ACTIONS(213),
    [anon_sym_BSLASH] = ACTIONS(211),
    [anon_sym_function] = ACTIONS(213),
    [anon_sym_EQ] = ACTIONS(339),
    [anon_sym_if] = ACTIONS(213),
    [anon_sym_for] = ACTIONS(213),
    [anon_sym_while] = ACTIONS(213),
    [anon_sym_repeat] = ACTIONS(213),
    [anon_sym_QMARK] = ACTIONS(211),
    [anon_sym_TILDE] = ACTIONS(341),
    [anon_sym_BANG] = ACTIONS(213),
    [anon_sym_PLUS] = ACTIONS(291),
    [anon_sym_DASH] = ACTIONS(293),
    [anon_sym_LT_DASH] = ACTIONS(347),
    [anon_sym_LT_LT_DASH] = ACTIONS(347),
    [anon_sym_COLON_EQ] = ACTIONS(347),
    [anon_sym_DASH_GT] = ACTIONS(343),
    [anon_sym_DASH_GT_GT] = ACTIONS(345),
    [anon_sym_PIPE] = ACTIONS(295),
    [anon_sym_AMP] = ACTIONS(297),
    [anon_sym_PIPE_PIPE] = ACTIONS(299),
    [anon_sym_AMP_AMP] = ACTIONS(301),
    [anon_sym_LT] = ACTIONS(303),
    [anon_sym_LT_EQ] = ACTIONS(305),
    [anon_sym_GT] = ACTIONS(303),
    [anon_sym_GT_EQ] = ACTIONS(305),
    [anon_sym_EQ_EQ] = ACTIONS(305),
    [anon_sym_BANG_EQ] = ACTIONS(305),
    [anon_sym_STAR] = ACTIONS(307),
    [anon_sym_SLASH] = ACTIONS(309),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(313),
    [anon_sym_PIPE_GT] = ACTIONS(313),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(211),
    [sym__number_literal] = ACTIONS(213),
    [anon_sym_SQUOTE] = ACTIONS(211),
    [anon_sym_DQUOTE] = ACTIONS(211),
    [sym_dots] = ACTIONS(213),
    [sym_dot_dot_i] = ACTIONS(213),
    [sym_next] = ACTIONS(213),
    [sym_break] = ACTIONS(213),
    [sym_true] = ACTIONS(213),
    [sym_false] = ACTIONS(213),
    [sym_null] = ACTIONS(213),
    [sym_inf] = ACTIONS(213),
    [sym_nan] = ACTIONS(213),
    [anon_sym_NA] = ACTIONS(213),
    [anon_sym_NA_integer_] = ACTIONS(213),
    [anon_sym_NA_real_] = ACTIONS(213),
    [anon_sym_NA_complex_] = ACTIONS(213),
    [anon_sym_NA_character_] = ACTIONS(213),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(211),
    [sym__semicolon] = ACTIONS(211),
    [sym__raw_string_open] = ACTIONS(211),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(211),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [173] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(215),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_BSLASH] = ACTIONS(215),
    [anon_sym_function] = ACTIONS(217),
    [anon_sym_EQ] = ACTIONS(339),
    [anon_sym_if] = ACTIONS(217),
    [anon_sym_for] = ACTIONS(217),
    [anon_sym_while] = ACTIONS(217),
    [anon_sym_repeat] = ACTIONS(217),
    [anon_sym_QMARK] = ACTIONS(215),
    [anon_sym_TILDE] = ACTIONS(341),
    [anon_sym_BANG] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(291),
    [anon_sym_DASH] = ACTIONS(293),
    [anon_sym_LT_DASH] = ACTIONS(347),
    [anon_sym_LT_LT_DASH] = ACTIONS(347),
    [anon_sym_COLON_EQ] = ACTIONS(347),
    [anon_sym_DASH_GT] = ACTIONS(343),
    [anon_sym_DASH_GT_GT] = ACTIONS(345),
    [anon_sym_PIPE] = ACTIONS(295),
    [anon_sym_AMP] = ACTIONS(297),
    [anon_sym_PIPE_PIPE] = ACTIONS(299),
    [anon_sym_AMP_AMP] = ACTIONS(301),
    [anon_sym_LT] = ACTIONS(303),
    [anon_sym_LT_EQ] = ACTIONS(305),
    [anon_sym_GT] = ACTIONS(303),
    [anon_sym_GT_EQ] = ACTIONS(305),
    [anon_sym_EQ_EQ] = ACTIONS(305),
    [anon_sym_BANG_EQ] = ACTIONS(305),
    [anon_sym_STAR] = ACTIONS(307),
    [anon_sym_SLASH] = ACTIONS(309),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(313),
    [anon_sym_PIPE_GT] = ACTIONS(313),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(215),
    [sym__number_literal] = ACTIONS(217),
    [anon_sym_SQUOTE] = ACTIONS(215),
    [anon_sym_DQUOTE] = ACTIONS(215),
    [sym_dots] = ACTIONS(217),
    [sym_dot_dot_i] = ACTIONS(217),
    [sym_next] = ACTIONS(217),
    [sym_break] = ACTIONS(217),
    [sym_true] = ACTIONS(217),
    [sym_false] = ACTIONS(217),
    [sym_null] = ACTIONS(217),
    [sym_inf] = ACTIONS(217),
    [sym_nan] = ACTIONS(217),
    [anon_sym_NA] = ACTIONS(217),
    [anon_sym_NA_integer_] = ACTIONS(217),
    [anon_sym_NA_real_] = ACTIONS(217),
    [anon_sym_NA_complex_] = ACTIONS(217),
    [anon_sym_NA_character_] = ACTIONS(217),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(215),
    [sym__semicolon] = ACTIONS(215),
    [sym__raw_string_open] = ACTIONS(215),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(215),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [174] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(219),
    [sym_identifier] = ACTIONS(221),
    [anon_sym_BSLASH] = ACTIONS(219),
    [anon_sym_function] = ACTIONS(221),
    [anon_sym_EQ] = ACTIONS(339),
    [anon_sym_if] = ACTIONS(221),
    [anon_sym_for] = ACTIONS(221),
    [anon_sym_while] = ACTIONS(221),
    [anon_sym_repeat] = ACTIONS(221),
    [anon_sym_QMARK] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(341),
    [anon_sym_BANG] = ACTIONS(221),
    [anon_sym_PLUS] = ACTIONS(291),
    [anon_sym_DASH] = ACTIONS(293),
    [anon_sym_LT_DASH] = ACTIONS(347),
    [anon_sym_LT_LT_DASH] = ACTIONS(347),
    [anon_sym_COLON_EQ] = ACTIONS(347),
    [anon_sym_DASH_GT] = ACTIONS(343),
    [anon_sym_DASH_GT_GT] = ACTIONS(345),
    [anon_sym_PIPE] = ACTIONS(295),
    [anon_sym_AMP] = ACTIONS(297),
    [anon_sym_PIPE_PIPE] = ACTIONS(299),
    [anon_sym_AMP_AMP] = ACTIONS(301),
    [anon_sym_LT] = ACTIONS(303),
    [anon_sym_LT_EQ] = ACTIONS(305),
    [anon_sym_GT] = ACTIONS(303),
    [anon_sym_GT_EQ] = ACTIONS(305),
    [anon_sym_EQ_EQ] = ACTIONS(305),
    [anon_sym_BANG_EQ] = ACTIONS(305),
    [anon_sym_STAR] = ACTIONS(307),
    [anon_sym_SLASH] = ACTIONS(309),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(313),
    [anon_sym_PIPE_GT] = ACTIONS(313),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(219),
    [sym__number_literal] = ACTIONS(221),
    [anon_sym_SQUOTE] = ACTIONS(219),
    [anon_sym_DQUOTE] = ACTIONS(219),
    [sym_dots] = ACTIONS(221),
    [sym_dot_dot_i] = ACTIONS(221),
    [sym_next] = ACTIONS(221),
    [sym_break] = ACTIONS(221),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [sym_null] = ACTIONS(221),
    [sym_inf] = ACTIONS(221),
    [sym_nan] = ACTIONS(221),
    [anon_sym_NA] = ACTIONS(221),
    [anon_sym_NA_integer_] = ACTIONS(221),
    [anon_sym_NA_real_] = ACTIONS(221),
    [anon_sym_NA_complex_] = ACTIONS(221),
    [anon_sym_NA_character_] = ACTIONS(221),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(219),
    [sym__semicolon] = ACTIONS(219),
    [sym__raw_string_open] = ACTIONS(219),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(219),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [175] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(223),
    [sym_identifier] = ACTIONS(225),
    [anon_sym_BSLASH] = ACTIONS(223),
    [anon_sym_function] = ACTIONS(225),
    [anon_sym_EQ] = ACTIONS(339),
    [anon_sym_if] = ACTIONS(225),
    [anon_sym_for] = ACTIONS(225),
    [anon_sym_while] = ACTIONS(225),
    [anon_sym_repeat] = ACTIONS(225),
    [anon_sym_QMARK] = ACTIONS(223),
    [anon_sym_TILDE] = ACTIONS(341),
    [anon_sym_BANG] = ACTIONS(225),
    [anon_sym_PLUS] = ACTIONS(291),
    [anon_sym_DASH] = ACTIONS(293),
    [anon_sym_LT_DASH] = ACTIONS(347),
    [anon_sym_LT_LT_DASH] = ACTIONS(347),
    [anon_sym_COLON_EQ] = ACTIONS(347),
    [anon_sym_DASH_GT] = ACTIONS(343),
    [anon_sym_DASH_GT_GT] = ACTIONS(345),
    [anon_sym_PIPE] = ACTIONS(295),
    [anon_sym_AMP] = ACTIONS(297),
    [anon_sym_PIPE_PIPE] = ACTIONS(299),
    [anon_sym_AMP_AMP] = ACTIONS(301),
    [anon_sym_LT] = ACTIONS(303),
    [anon_sym_LT_EQ] = ACTIONS(305),
    [anon_sym_GT] = ACTIONS(303),
    [anon_sym_GT_EQ] = ACTIONS(305),
    [anon_sym_EQ_EQ] = ACTIONS(305),
    [anon_sym_BANG_EQ] = ACTIONS(305),
    [anon_sym_STAR] = ACTIONS(307),
    [anon_sym_SLASH] = ACTIONS(309),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(313),
    [anon_sym_PIPE_GT] = ACTIONS(313),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(223),
    [sym__number_literal] = ACTIONS(225),
    [anon_sym_SQUOTE] = ACTIONS(223),
    [anon_sym_DQUOTE] = ACTIONS(223),
    [sym_dots] = ACTIONS(225),
    [sym_dot_dot_i] = ACTIONS(225),
    [sym_next] = ACTIONS(225),
    [sym_break] = ACTIONS(225),
    [sym_true] = ACTIONS(225),
    [sym_false] = ACTIONS(225),
    [sym_null] = ACTIONS(225),
    [sym_inf] = ACTIONS(225),
    [sym_nan] = ACTIONS(225),
    [anon_sym_NA] = ACTIONS(225),
    [anon_sym_NA_integer_] = ACTIONS(225),
    [anon_sym_NA_real_] = ACTIONS(225),
    [anon_sym_NA_complex_] = ACTIONS(225),
    [anon_sym_NA_character_] = ACTIONS(225),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(223),
    [sym__semicolon] = ACTIONS(223),
    [sym__raw_string_open] = ACTIONS(223),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(223),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [176] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(227),
    [sym_identifier] = ACTIONS(229),
    [anon_sym_BSLASH] = ACTIONS(227),
    [anon_sym_function] = ACTIONS(229),
    [anon_sym_EQ] = ACTIONS(339),
    [anon_sym_if] = ACTIONS(229),
    [anon_sym_for] = ACTIONS(229),
    [anon_sym_while] = ACTIONS(229),
    [anon_sym_repeat] = ACTIONS(229),
    [anon_sym_QMARK] = ACTIONS(227),
    [anon_sym_TILDE] = ACTIONS(341),
    [anon_sym_BANG] = ACTIONS(229),
    [anon_sym_PLUS] = ACTIONS(291),
    [anon_sym_DASH] = ACTIONS(293),
    [anon_sym_LT_DASH] = ACTIONS(347),
    [anon_sym_LT_LT_DASH] = ACTIONS(347),
    [anon_sym_COLON_EQ] = ACTIONS(347),
    [anon_sym_DASH_GT] = ACTIONS(343),
    [anon_sym_DASH_GT_GT] = ACTIONS(345),
    [anon_sym_PIPE] = ACTIONS(295),
    [anon_sym_AMP] = ACTIONS(297),
    [anon_sym_PIPE_PIPE] = ACTIONS(299),
    [anon_sym_AMP_AMP] = ACTIONS(301),
    [anon_sym_LT] = ACTIONS(303),
    [anon_sym_LT_EQ] = ACTIONS(305),
    [anon_sym_GT] = ACTIONS(303),
    [anon_sym_GT_EQ] = ACTIONS(305),
    [anon_sym_EQ_EQ] = ACTIONS(305),
    [anon_sym_BANG_EQ] = ACTIONS(305),
    [anon_sym_STAR] = ACTIONS(307),
    [anon_sym_SLASH] = ACTIONS(309),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(313),
    [anon_sym_PIPE_GT] = ACTIONS(313),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(227),
    [sym__number_literal] = ACTIONS(229),
    [anon_sym_SQUOTE] = ACTIONS(227),
    [anon_sym_DQUOTE] = ACTIONS(227),
    [sym_dots] = ACTIONS(229),
    [sym_dot_dot_i] = ACTIONS(229),
    [sym_next] = ACTIONS(229),
    [sym_break] = ACTIONS(229),
    [sym_true] = ACTIONS(229),
    [sym_false] = ACTIONS(229),
    [sym_null] = ACTIONS(229),
    [sym_inf] = ACTIONS(229),
    [sym_nan] = ACTIONS(229),
    [anon_sym_NA] = ACTIONS(229),
    [anon_sym_NA_integer_] = ACTIONS(229),
    [anon_sym_NA_real_] = ACTIONS(229),
    [anon_sym_NA_complex_] = ACTIONS(229),
    [anon_sym_NA_character_] = ACTIONS(229),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(227),
    [sym__semicolon] = ACTIONS(227),
    [sym__raw_string_open] = ACTIONS(227),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(227),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [177] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(231),
    [sym_identifier] = ACTIONS(233),
    [anon_sym_BSLASH] = ACTIONS(231),
    [anon_sym_function] = ACTIONS(233),
    [anon_sym_EQ] = ACTIONS(339),
    [anon_sym_if] = ACTIONS(233),
    [anon_sym_for] = ACTIONS(233),
    [anon_sym_while] = ACTIONS(233),
    [anon_sym_repeat] = ACTIONS(233),
    [anon_sym_QMARK] = ACTIONS(231),
    [anon_sym_TILDE] = ACTIONS(341),
    [anon_sym_BANG] = ACTIONS(233),
    [anon_sym_PLUS] = ACTIONS(291),
    [anon_sym_DASH] = ACTIONS(293),
    [anon_sym_LT_DASH] = ACTIONS(347),
    [anon_sym_LT_LT_DASH] = ACTIONS(347),
    [anon_sym_COLON_EQ] = ACTIONS(347),
    [anon_sym_DASH_GT] = ACTIONS(343),
    [anon_sym_DASH_GT_GT] = ACTIONS(345),
    [anon_sym_PIPE] = ACTIONS(295),
    [anon_sym_AMP] = ACTIONS(297),
    [anon_sym_PIPE_PIPE] = ACTIONS(299),
    [anon_sym_AMP_AMP] = ACTIONS(301),
    [anon_sym_LT] = ACTIONS(303),
    [anon_sym_LT_EQ] = ACTIONS(305),
    [anon_sym_GT] = ACTIONS(303),
    [anon_sym_GT_EQ] = ACTIONS(305),
    [anon_sym_EQ_EQ] = ACTIONS(305),
    [anon_sym_BANG_EQ] = ACTIONS(305),
    [anon_sym_STAR] = ACTIONS(307),
    [anon_sym_SLASH] = ACTIONS(309),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(313),
    [anon_sym_PIPE_GT] = ACTIONS(313),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(231),
    [sym__number_literal] = ACTIONS(233),
    [anon_sym_SQUOTE] = ACTIONS(231),
    [anon_sym_DQUOTE] = ACTIONS(231),
    [sym_dots] = ACTIONS(233),
    [sym_dot_dot_i] = ACTIONS(233),
    [sym_next] = ACTIONS(233),
    [sym_break] = ACTIONS(233),
    [sym_true] = ACTIONS(233),
    [sym_false] = ACTIONS(233),
    [sym_null] = ACTIONS(233),
    [sym_inf] = ACTIONS(233),
    [sym_nan] = ACTIONS(233),
    [anon_sym_NA] = ACTIONS(233),
    [anon_sym_NA_integer_] = ACTIONS(233),
    [anon_sym_NA_real_] = ACTIONS(233),
    [anon_sym_NA_complex_] = ACTIONS(233),
    [anon_sym_NA_character_] = ACTIONS(233),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(231),
    [sym__semicolon] = ACTIONS(231),
    [sym__raw_string_open] = ACTIONS(231),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(231),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [178] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(235),
    [sym_identifier] = ACTIONS(237),
    [anon_sym_BSLASH] = ACTIONS(235),
    [anon_sym_function] = ACTIONS(237),
    [anon_sym_EQ] = ACTIONS(339),
    [anon_sym_if] = ACTIONS(237),
    [anon_sym_for] = ACTIONS(237),
    [anon_sym_while] = ACTIONS(237),
    [anon_sym_repeat] = ACTIONS(237),
    [anon_sym_QMARK] = ACTIONS(235),
    [anon_sym_TILDE] = ACTIONS(341),
    [anon_sym_BANG] = ACTIONS(237),
    [anon_sym_PLUS] = ACTIONS(291),
    [anon_sym_DASH] = ACTIONS(293),
    [anon_sym_LT_DASH] = ACTIONS(347),
    [anon_sym_LT_LT_DASH] = ACTIONS(347),
    [anon_sym_COLON_EQ] = ACTIONS(347),
    [anon_sym_DASH_GT] = ACTIONS(343),
    [anon_sym_DASH_GT_GT] = ACTIONS(345),
    [anon_sym_PIPE] = ACTIONS(295),
    [anon_sym_AMP] = ACTIONS(297),
    [anon_sym_PIPE_PIPE] = ACTIONS(299),
    [anon_sym_AMP_AMP] = ACTIONS(301),
    [anon_sym_LT] = ACTIONS(303),
    [anon_sym_LT_EQ] = ACTIONS(305),
    [anon_sym_GT] = ACTIONS(303),
    [anon_sym_GT_EQ] = ACTIONS(305),
    [anon_sym_EQ_EQ] = ACTIONS(305),
    [anon_sym_BANG_EQ] = ACTIONS(305),
    [anon_sym_STAR] = ACTIONS(307),
    [anon_sym_SLASH] = ACTIONS(309),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(313),
    [anon_sym_PIPE_GT] = ACTIONS(313),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(235),
    [sym__number_literal] = ACTIONS(237),
    [anon_sym_SQUOTE] = ACTIONS(235),
    [anon_sym_DQUOTE] = ACTIONS(235),
    [sym_dots] = ACTIONS(237),
    [sym_dot_dot_i] = ACTIONS(237),
    [sym_next] = ACTIONS(237),
    [sym_break] = ACTIONS(237),
    [sym_true] = ACTIONS(237),
    [sym_false] = ACTIONS(237),
    [sym_null] = ACTIONS(237),
    [sym_inf] = ACTIONS(237),
    [sym_nan] = ACTIONS(237),
    [anon_sym_NA] = ACTIONS(237),
    [anon_sym_NA_integer_] = ACTIONS(237),
    [anon_sym_NA_real_] = ACTIONS(237),
    [anon_sym_NA_complex_] = ACTIONS(237),
    [anon_sym_NA_character_] = ACTIONS(237),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(235),
    [sym__semicolon] = ACTIONS(235),
    [sym__raw_string_open] = ACTIONS(235),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(235),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [179] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(239),
    [sym_identifier] = ACTIONS(241),
    [anon_sym_BSLASH] = ACTIONS(239),
    [anon_sym_function] = ACTIONS(241),
    [anon_sym_EQ] = ACTIONS(339),
    [anon_sym_if] = ACTIONS(241),
    [anon_sym_for] = ACTIONS(241),
    [anon_sym_while] = ACTIONS(241),
    [anon_sym_repeat] = ACTIONS(241),
    [anon_sym_QMARK] = ACTIONS(239),
    [anon_sym_TILDE] = ACTIONS(341),
    [anon_sym_BANG] = ACTIONS(241),
    [anon_sym_PLUS] = ACTIONS(291),
    [anon_sym_DASH] = ACTIONS(293),
    [anon_sym_LT_DASH] = ACTIONS(347),
    [anon_sym_LT_LT_DASH] = ACTIONS(347),
    [anon_sym_COLON_EQ] = ACTIONS(347),
    [anon_sym_DASH_GT] = ACTIONS(343),
    [anon_sym_DASH_GT_GT] = ACTIONS(345),
    [anon_sym_PIPE] = ACTIONS(295),
    [anon_sym_AMP] = ACTIONS(297),
    [anon_sym_PIPE_PIPE] = ACTIONS(299),
    [anon_sym_AMP_AMP] = ACTIONS(301),
    [anon_sym_LT] = ACTIONS(303),
    [anon_sym_LT_EQ] = ACTIONS(305),
    [anon_sym_GT] = ACTIONS(303),
    [anon_sym_GT_EQ] = ACTIONS(305),
    [anon_sym_EQ_EQ] = ACTIONS(305),
    [anon_sym_BANG_EQ] = ACTIONS(305),
    [anon_sym_STAR] = ACTIONS(307),
    [anon_sym_SLASH] = ACTIONS(309),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(313),
    [anon_sym_PIPE_GT] = ACTIONS(313),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(239),
    [sym__number_literal] = ACTIONS(241),
    [anon_sym_SQUOTE] = ACTIONS(239),
    [anon_sym_DQUOTE] = ACTIONS(239),
    [sym_dots] = ACTIONS(241),
    [sym_dot_dot_i] = ACTIONS(241),
    [sym_next] = ACTIONS(241),
    [sym_break] = ACTIONS(241),
    [sym_true] = ACTIONS(241),
    [sym_false] = ACTIONS(241),
    [sym_null] = ACTIONS(241),
    [sym_inf] = ACTIONS(241),
    [sym_nan] = ACTIONS(241),
    [anon_sym_NA] = ACTIONS(241),
    [anon_sym_NA_integer_] = ACTIONS(241),
    [anon_sym_NA_real_] = ACTIONS(241),
    [anon_sym_NA_complex_] = ACTIONS(241),
    [anon_sym_NA_character_] = ACTIONS(241),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(239),
    [sym__semicolon] = ACTIONS(239),
    [sym__raw_string_open] = ACTIONS(239),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(239),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [180] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(243),
    [sym_identifier] = ACTIONS(245),
    [anon_sym_BSLASH] = ACTIONS(243),
    [anon_sym_function] = ACTIONS(245),
    [anon_sym_EQ] = ACTIONS(339),
    [anon_sym_if] = ACTIONS(245),
    [anon_sym_for] = ACTIONS(245),
    [anon_sym_while] = ACTIONS(245),
    [anon_sym_repeat] = ACTIONS(245),
    [anon_sym_QMARK] = ACTIONS(243),
    [anon_sym_TILDE] = ACTIONS(341),
    [anon_sym_BANG] = ACTIONS(245),
    [anon_sym_PLUS] = ACTIONS(291),
    [anon_sym_DASH] = ACTIONS(293),
    [anon_sym_LT_DASH] = ACTIONS(347),
    [anon_sym_LT_LT_DASH] = ACTIONS(347),
    [anon_sym_COLON_EQ] = ACTIONS(347),
    [anon_sym_DASH_GT] = ACTIONS(343),
    [anon_sym_DASH_GT_GT] = ACTIONS(345),
    [anon_sym_PIPE] = ACTIONS(295),
    [anon_sym_AMP] = ACTIONS(297),
    [anon_sym_PIPE_PIPE] = ACTIONS(299),
    [anon_sym_AMP_AMP] = ACTIONS(301),
    [anon_sym_LT] = ACTIONS(303),
    [anon_sym_LT_EQ] = ACTIONS(305),
    [anon_sym_GT] = ACTIONS(303),
    [anon_sym_GT_EQ] = ACTIONS(305),
    [anon_sym_EQ_EQ] = ACTIONS(305),
    [anon_sym_BANG_EQ] = ACTIONS(305),
    [anon_sym_STAR] = ACTIONS(307),
    [anon_sym_SLASH] = ACTIONS(309),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(313),
    [anon_sym_PIPE_GT] = ACTIONS(313),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(243),
    [sym__number_literal] = ACTIONS(245),
    [anon_sym_SQUOTE] = ACTIONS(243),
    [anon_sym_DQUOTE] = ACTIONS(243),
    [sym_dots] = ACTIONS(245),
    [sym_dot_dot_i] = ACTIONS(245),
    [sym_next] = ACTIONS(245),
    [sym_break] = ACTIONS(245),
    [sym_true] = ACTIONS(245),
    [sym_false] = ACTIONS(245),
    [sym_null] = ACTIONS(245),
    [sym_inf] = ACTIONS(245),
    [sym_nan] = ACTIONS(245),
    [anon_sym_NA] = ACTIONS(245),
    [anon_sym_NA_integer_] = ACTIONS(245),
    [anon_sym_NA_real_] = ACTIONS(245),
    [anon_sym_NA_complex_] = ACTIONS(245),
    [anon_sym_NA_character_] = ACTIONS(245),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(243),
    [sym__semicolon] = ACTIONS(243),
    [sym__raw_string_open] = ACTIONS(243),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(243),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [181] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(149),
    [sym_identifier] = ACTIONS(147),
    [anon_sym_BSLASH] = ACTIONS(149),
    [anon_sym_function] = ACTIONS(147),
    [anon_sym_EQ] = ACTIONS(339),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_for] = ACTIONS(147),
    [anon_sym_while] = ACTIONS(147),
    [anon_sym_repeat] = ACTIONS(147),
    [anon_sym_QMARK] = ACTIONS(149),
    [anon_sym_TILDE] = ACTIONS(341),
    [anon_sym_BANG] = ACTIONS(147),
    [anon_sym_PLUS] = ACTIONS(291),
    [anon_sym_DASH] = ACTIONS(293),
    [anon_sym_LT_DASH] = ACTIONS(347),
    [anon_sym_LT_LT_DASH] = ACTIONS(347),
    [anon_sym_COLON_EQ] = ACTIONS(347),
    [anon_sym_DASH_GT] = ACTIONS(343),
    [anon_sym_DASH_GT_GT] = ACTIONS(345),
    [anon_sym_PIPE] = ACTIONS(295),
    [anon_sym_AMP] = ACTIONS(297),
    [anon_sym_PIPE_PIPE] = ACTIONS(299),
    [anon_sym_AMP_AMP] = ACTIONS(301),
    [anon_sym_LT] = ACTIONS(303),
    [anon_sym_LT_EQ] = ACTIONS(305),
    [anon_sym_GT] = ACTIONS(303),
    [anon_sym_GT_EQ] = ACTIONS(305),
    [anon_sym_EQ_EQ] = ACTIONS(305),
    [anon_sym_BANG_EQ] = ACTIONS(305),
    [anon_sym_STAR] = ACTIONS(307),
    [anon_sym_SLASH] = ACTIONS(309),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(313),
    [anon_sym_PIPE_GT] = ACTIONS(313),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(149),
    [sym__number_literal] = ACTIONS(147),
    [anon_sym_SQUOTE] = ACTIONS(149),
    [anon_sym_DQUOTE] = ACTIONS(149),
    [sym_dots] = ACTIONS(147),
    [sym_dot_dot_i] = ACTIONS(147),
    [sym_next] = ACTIONS(147),
    [sym_break] = ACTIONS(147),
    [sym_true] = ACTIONS(147),
    [sym_false] = ACTIONS(147),
    [sym_null] = ACTIONS(147),
    [sym_inf] = ACTIONS(147),
    [sym_nan] = ACTIONS(147),
    [anon_sym_NA] = ACTIONS(147),
    [anon_sym_NA_integer_] = ACTIONS(147),
    [anon_sym_NA_real_] = ACTIONS(147),
    [anon_sym_NA_complex_] = ACTIONS(147),
    [anon_sym_NA_character_] = ACTIONS(147),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(149),
    [sym__semicolon] = ACTIONS(149),
    [sym__raw_string_open] = ACTIONS(149),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(149),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [182] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(153),
    [anon_sym_BSLASH] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(153),
    [anon_sym_EQ] = ACTIONS(247),
    [anon_sym_if] = ACTIONS(153),
    [anon_sym_for] = ACTIONS(153),
    [anon_sym_while] = ACTIONS(153),
    [anon_sym_repeat] = ACTIONS(153),
    [anon_sym_QMARK] = ACTIONS(151),
    [anon_sym_TILDE] = ACTIONS(249),
    [anon_sym_BANG] = ACTIONS(153),
    [anon_sym_PLUS] = ACTIONS(251),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_LT_DASH] = ACTIONS(255),
    [anon_sym_LT_LT_DASH] = ACTIONS(255),
    [anon_sym_COLON_EQ] = ACTIONS(255),
    [anon_sym_DASH_GT] = ACTIONS(257),
    [anon_sym_DASH_GT_GT] = ACTIONS(259),
    [anon_sym_PIPE] = ACTIONS(261),
    [anon_sym_AMP] = ACTIONS(263),
    [anon_sym_PIPE_PIPE] = ACTIONS(265),
    [anon_sym_AMP_AMP] = ACTIONS(267),
    [anon_sym_LT] = ACTIONS(269),
    [anon_sym_LT_EQ] = ACTIONS(271),
    [anon_sym_GT] = ACTIONS(269),
    [anon_sym_GT_EQ] = ACTIONS(271),
    [anon_sym_EQ_EQ] = ACTIONS(271),
    [anon_sym_BANG_EQ] = ACTIONS(271),
    [anon_sym_STAR] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(279),
    [anon_sym_PIPE_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(151),
    [sym__number_literal] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(151),
    [anon_sym_DQUOTE] = ACTIONS(151),
    [sym_dots] = ACTIONS(153),
    [sym_dot_dot_i] = ACTIONS(153),
    [sym_next] = ACTIONS(153),
    [sym_break] = ACTIONS(153),
    [sym_true] = ACTIONS(153),
    [sym_false] = ACTIONS(153),
    [sym_null] = ACTIONS(153),
    [sym_inf] = ACTIONS(153),
    [sym_nan] = ACTIONS(153),
    [anon_sym_NA] = ACTIONS(153),
    [anon_sym_NA_integer_] = ACTIONS(153),
    [anon_sym_NA_real_] = ACTIONS(153),
    [anon_sym_NA_complex_] = ACTIONS(153),
    [anon_sym_NA_character_] = ACTIONS(153),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(151),
    [sym__semicolon] = ACTIONS(151),
    [sym__raw_string_open] = ACTIONS(151),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(151),
    [sym__external_close_brace] = ACTIONS(151),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [183] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(157),
    [anon_sym_BSLASH] = ACTIONS(155),
    [anon_sym_function] = ACTIONS(157),
    [anon_sym_EQ] = ACTIONS(247),
    [anon_sym_if] = ACTIONS(157),
    [anon_sym_for] = ACTIONS(157),
    [anon_sym_while] = ACTIONS(157),
    [anon_sym_repeat] = ACTIONS(157),
    [anon_sym_QMARK] = ACTIONS(155),
    [anon_sym_TILDE] = ACTIONS(249),
    [anon_sym_BANG] = ACTIONS(157),
    [anon_sym_PLUS] = ACTIONS(251),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_LT_DASH] = ACTIONS(255),
    [anon_sym_LT_LT_DASH] = ACTIONS(255),
    [anon_sym_COLON_EQ] = ACTIONS(255),
    [anon_sym_DASH_GT] = ACTIONS(257),
    [anon_sym_DASH_GT_GT] = ACTIONS(259),
    [anon_sym_PIPE] = ACTIONS(261),
    [anon_sym_AMP] = ACTIONS(263),
    [anon_sym_PIPE_PIPE] = ACTIONS(265),
    [anon_sym_AMP_AMP] = ACTIONS(267),
    [anon_sym_LT] = ACTIONS(269),
    [anon_sym_LT_EQ] = ACTIONS(271),
    [anon_sym_GT] = ACTIONS(269),
    [anon_sym_GT_EQ] = ACTIONS(271),
    [anon_sym_EQ_EQ] = ACTIONS(271),
    [anon_sym_BANG_EQ] = ACTIONS(271),
    [anon_sym_STAR] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(279),
    [anon_sym_PIPE_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(155),
    [sym__number_literal] = ACTIONS(157),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [anon_sym_DQUOTE] = ACTIONS(155),
    [sym_dots] = ACTIONS(157),
    [sym_dot_dot_i] = ACTIONS(157),
    [sym_next] = ACTIONS(157),
    [sym_break] = ACTIONS(157),
    [sym_true] = ACTIONS(157),
    [sym_false] = ACTIONS(157),
    [sym_null] = ACTIONS(157),
    [sym_inf] = ACTIONS(157),
    [sym_nan] = ACTIONS(157),
    [anon_sym_NA] = ACTIONS(157),
    [anon_sym_NA_integer_] = ACTIONS(157),
    [anon_sym_NA_real_] = ACTIONS(157),
    [anon_sym_NA_complex_] = ACTIONS(157),
    [anon_sym_NA_character_] = ACTIONS(157),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(155),
    [sym__semicolon] = ACTIONS(155),
    [sym__raw_string_open] = ACTIONS(155),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(155),
    [sym__external_close_brace] = ACTIONS(155),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [184] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(157),
    [anon_sym_BSLASH] = ACTIONS(155),
    [anon_sym_function] = ACTIONS(157),
    [anon_sym_EQ] = ACTIONS(157),
    [anon_sym_if] = ACTIONS(157),
    [anon_sym_for] = ACTIONS(157),
    [anon_sym_while] = ACTIONS(157),
    [anon_sym_repeat] = ACTIONS(157),
    [anon_sym_QMARK] = ACTIONS(155),
    [anon_sym_TILDE] = ACTIONS(155),
    [anon_sym_BANG] = ACTIONS(157),
    [anon_sym_PLUS] = ACTIONS(251),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_LT_DASH] = ACTIONS(155),
    [anon_sym_LT_LT_DASH] = ACTIONS(155),
    [anon_sym_COLON_EQ] = ACTIONS(155),
    [anon_sym_DASH_GT] = ACTIONS(157),
    [anon_sym_DASH_GT_GT] = ACTIONS(155),
    [anon_sym_PIPE] = ACTIONS(261),
    [anon_sym_AMP] = ACTIONS(263),
    [anon_sym_PIPE_PIPE] = ACTIONS(265),
    [anon_sym_AMP_AMP] = ACTIONS(267),
    [anon_sym_LT] = ACTIONS(269),
    [anon_sym_LT_EQ] = ACTIONS(271),
    [anon_sym_GT] = ACTIONS(269),
    [anon_sym_GT_EQ] = ACTIONS(271),
    [anon_sym_EQ_EQ] = ACTIONS(271),
    [anon_sym_BANG_EQ] = ACTIONS(271),
    [anon_sym_STAR] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(279),
    [anon_sym_PIPE_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(155),
    [sym__number_literal] = ACTIONS(157),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [anon_sym_DQUOTE] = ACTIONS(155),
    [sym_dots] = ACTIONS(157),
    [sym_dot_dot_i] = ACTIONS(157),
    [sym_next] = ACTIONS(157),
    [sym_break] = ACTIONS(157),
    [sym_true] = ACTIONS(157),
    [sym_false] = ACTIONS(157),
    [sym_null] = ACTIONS(157),
    [sym_inf] = ACTIONS(157),
    [sym_nan] = ACTIONS(157),
    [anon_sym_NA] = ACTIONS(157),
    [anon_sym_NA_integer_] = ACTIONS(157),
    [anon_sym_NA_real_] = ACTIONS(157),
    [anon_sym_NA_complex_] = ACTIONS(157),
    [anon_sym_NA_character_] = ACTIONS(157),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(155),
    [sym__semicolon] = ACTIONS(155),
    [sym__raw_string_open] = ACTIONS(155),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(155),
    [sym__external_close_brace] = ACTIONS(155),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [185] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(157),
    [anon_sym_BSLASH] = ACTIONS(155),
    [anon_sym_function] = ACTIONS(157),
    [anon_sym_EQ] = ACTIONS(157),
    [anon_sym_if] = ACTIONS(157),
    [anon_sym_for] = ACTIONS(157),
    [anon_sym_while] = ACTIONS(157),
    [anon_sym_repeat] = ACTIONS(157),
    [anon_sym_QMARK] = ACTIONS(155),
    [anon_sym_TILDE] = ACTIONS(155),
    [anon_sym_BANG] = ACTIONS(157),
    [anon_sym_PLUS] = ACTIONS(251),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_LT_DASH] = ACTIONS(155),
    [anon_sym_LT_LT_DASH] = ACTIONS(155),
    [anon_sym_COLON_EQ] = ACTIONS(155),
    [anon_sym_DASH_GT] = ACTIONS(157),
    [anon_sym_DASH_GT_GT] = ACTIONS(155),
    [anon_sym_PIPE] = ACTIONS(157),
    [anon_sym_AMP] = ACTIONS(157),
    [anon_sym_PIPE_PIPE] = ACTIONS(155),
    [anon_sym_AMP_AMP] = ACTIONS(155),
    [anon_sym_LT] = ACTIONS(269),
    [anon_sym_LT_EQ] = ACTIONS(271),
    [anon_sym_GT] = ACTIONS(269),
    [anon_sym_GT_EQ] = ACTIONS(271),
    [anon_sym_EQ_EQ] = ACTIONS(271),
    [anon_sym_BANG_EQ] = ACTIONS(271),
    [anon_sym_STAR] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(279),
    [anon_sym_PIPE_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(155),
    [sym__number_literal] = ACTIONS(157),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [anon_sym_DQUOTE] = ACTIONS(155),
    [sym_dots] = ACTIONS(157),
    [sym_dot_dot_i] = ACTIONS(157),
    [sym_next] = ACTIONS(157),
    [sym_break] = ACTIONS(157),
    [sym_true] = ACTIONS(157),
    [sym_false] = ACTIONS(157),
    [sym_null] = ACTIONS(157),
    [sym_inf] = ACTIONS(157),
    [sym_nan] = ACTIONS(157),
    [anon_sym_NA] = ACTIONS(157),
    [anon_sym_NA_integer_] = ACTIONS(157),
    [anon_sym_NA_real_] = ACTIONS(157),
    [anon_sym_NA_complex_] = ACTIONS(157),
    [anon_sym_NA_character_] = ACTIONS(157),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(155),
    [sym__semicolon] = ACTIONS(155),
    [sym__raw_string_open] = ACTIONS(155),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(155),
    [sym__external_close_brace] = ACTIONS(155),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [186] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(157),
    [anon_sym_BSLASH] = ACTIONS(155),
    [anon_sym_function] = ACTIONS(157),
    [anon_sym_EQ] = ACTIONS(157),
    [anon_sym_if] = ACTIONS(157),
    [anon_sym_for] = ACTIONS(157),
    [anon_sym_while] = ACTIONS(157),
    [anon_sym_repeat] = ACTIONS(157),
    [anon_sym_QMARK] = ACTIONS(155),
    [anon_sym_TILDE] = ACTIONS(155),
    [anon_sym_BANG] = ACTIONS(157),
    [anon_sym_PLUS] = ACTIONS(155),
    [anon_sym_DASH] = ACTIONS(157),
    [anon_sym_LT_DASH] = ACTIONS(155),
    [anon_sym_LT_LT_DASH] = ACTIONS(155),
    [anon_sym_COLON_EQ] = ACTIONS(155),
    [anon_sym_DASH_GT] = ACTIONS(157),
    [anon_sym_DASH_GT_GT] = ACTIONS(155),
    [anon_sym_PIPE] = ACTIONS(157),
    [anon_sym_AMP] = ACTIONS(157),
    [anon_sym_PIPE_PIPE] = ACTIONS(155),
    [anon_sym_AMP_AMP] = ACTIONS(155),
    [anon_sym_LT] = ACTIONS(157),
    [anon_sym_LT_EQ] = ACTIONS(155),
    [anon_sym_GT] = ACTIONS(157),
    [anon_sym_GT_EQ] = ACTIONS(155),
    [anon_sym_EQ_EQ] = ACTIONS(155),
    [anon_sym_BANG_EQ] = ACTIONS(155),
    [anon_sym_STAR] = ACTIONS(157),
    [anon_sym_SLASH] = ACTIONS(155),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(155),
    [anon_sym_PIPE_GT] = ACTIONS(155),
    [anon_sym_COLON] = ACTIONS(157),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(155),
    [sym__number_literal] = ACTIONS(157),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [anon_sym_DQUOTE] = ACTIONS(155),
    [sym_dots] = ACTIONS(157),
    [sym_dot_dot_i] = ACTIONS(157),
    [sym_next] = ACTIONS(157),
    [sym_break] = ACTIONS(157),
    [sym_true] = ACTIONS(157),
    [sym_false] = ACTIONS(157),
    [sym_null] = ACTIONS(157),
    [sym_inf] = ACTIONS(157),
    [sym_nan] = ACTIONS(157),
    [anon_sym_NA] = ACTIONS(157),
    [anon_sym_NA_integer_] = ACTIONS(157),
    [anon_sym_NA_real_] = ACTIONS(157),
    [anon_sym_NA_complex_] = ACTIONS(157),
    [anon_sym_NA_character_] = ACTIONS(157),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(155),
    [sym__semicolon] = ACTIONS(155),
    [sym__raw_string_open] = ACTIONS(155),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(155),
    [sym__external_close_brace] = ACTIONS(155),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [187] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(161),
    [anon_sym_BSLASH] = ACTIONS(159),
    [anon_sym_function] = ACTIONS(161),
    [anon_sym_EQ] = ACTIONS(247),
    [anon_sym_if] = ACTIONS(161),
    [anon_sym_for] = ACTIONS(161),
    [anon_sym_while] = ACTIONS(161),
    [anon_sym_repeat] = ACTIONS(161),
    [anon_sym_QMARK] = ACTIONS(159),
    [anon_sym_TILDE] = ACTIONS(249),
    [anon_sym_BANG] = ACTIONS(161),
    [anon_sym_PLUS] = ACTIONS(251),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_LT_DASH] = ACTIONS(255),
    [anon_sym_LT_LT_DASH] = ACTIONS(255),
    [anon_sym_COLON_EQ] = ACTIONS(255),
    [anon_sym_DASH_GT] = ACTIONS(257),
    [anon_sym_DASH_GT_GT] = ACTIONS(259),
    [anon_sym_PIPE] = ACTIONS(261),
    [anon_sym_AMP] = ACTIONS(263),
    [anon_sym_PIPE_PIPE] = ACTIONS(265),
    [anon_sym_AMP_AMP] = ACTIONS(267),
    [anon_sym_LT] = ACTIONS(269),
    [anon_sym_LT_EQ] = ACTIONS(271),
    [anon_sym_GT] = ACTIONS(269),
    [anon_sym_GT_EQ] = ACTIONS(271),
    [anon_sym_EQ_EQ] = ACTIONS(271),
    [anon_sym_BANG_EQ] = ACTIONS(271),
    [anon_sym_STAR] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(279),
    [anon_sym_PIPE_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(159),
    [sym__number_literal] = ACTIONS(161),
    [anon_sym_SQUOTE] = ACTIONS(159),
    [anon_sym_DQUOTE] = ACTIONS(159),
    [sym_dots] = ACTIONS(161),
    [sym_dot_dot_i] = ACTIONS(161),
    [sym_next] = ACTIONS(161),
    [sym_break] = ACTIONS(161),
    [sym_true] = ACTIONS(161),
    [sym_false] = ACTIONS(161),
    [sym_null] = ACTIONS(161),
    [sym_inf] = ACTIONS(161),
    [sym_nan] = ACTIONS(161),
    [anon_sym_NA] = ACTIONS(161),
    [anon_sym_NA_integer_] = ACTIONS(161),
    [anon_sym_NA_real_] = ACTIONS(161),
    [anon_sym_NA_complex_] = ACTIONS(161),
    [anon_sym_NA_character_] = ACTIONS(161),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(159),
    [sym__semicolon] = ACTIONS(159),
    [sym__raw_string_open] = ACTIONS(159),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(159),
    [sym__external_close_brace] = ACTIONS(159),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [188] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(165),
    [anon_sym_BSLASH] = ACTIONS(163),
    [anon_sym_function] = ACTIONS(165),
    [anon_sym_EQ] = ACTIONS(247),
    [anon_sym_if] = ACTIONS(165),
    [anon_sym_for] = ACTIONS(165),
    [anon_sym_while] = ACTIONS(165),
    [anon_sym_repeat] = ACTIONS(165),
    [anon_sym_QMARK] = ACTIONS(163),
    [anon_sym_TILDE] = ACTIONS(249),
    [anon_sym_BANG] = ACTIONS(165),
    [anon_sym_PLUS] = ACTIONS(251),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_LT_DASH] = ACTIONS(255),
    [anon_sym_LT_LT_DASH] = ACTIONS(255),
    [anon_sym_COLON_EQ] = ACTIONS(255),
    [anon_sym_DASH_GT] = ACTIONS(257),
    [anon_sym_DASH_GT_GT] = ACTIONS(259),
    [anon_sym_PIPE] = ACTIONS(261),
    [anon_sym_AMP] = ACTIONS(263),
    [anon_sym_PIPE_PIPE] = ACTIONS(265),
    [anon_sym_AMP_AMP] = ACTIONS(267),
    [anon_sym_LT] = ACTIONS(269),
    [anon_sym_LT_EQ] = ACTIONS(271),
    [anon_sym_GT] = ACTIONS(269),
    [anon_sym_GT_EQ] = ACTIONS(271),
    [anon_sym_EQ_EQ] = ACTIONS(271),
    [anon_sym_BANG_EQ] = ACTIONS(271),
    [anon_sym_STAR] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(279),
    [anon_sym_PIPE_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(163),
    [sym__number_literal] = ACTIONS(165),
    [anon_sym_SQUOTE] = ACTIONS(163),
    [anon_sym_DQUOTE] = ACTIONS(163),
    [sym_dots] = ACTIONS(165),
    [sym_dot_dot_i] = ACTIONS(165),
    [sym_next] = ACTIONS(165),
    [sym_break] = ACTIONS(165),
    [sym_true] = ACTIONS(165),
    [sym_false] = ACTIONS(165),
    [sym_null] = ACTIONS(165),
    [sym_inf] = ACTIONS(165),
    [sym_nan] = ACTIONS(165),
    [anon_sym_NA] = ACTIONS(165),
    [anon_sym_NA_integer_] = ACTIONS(165),
    [anon_sym_NA_real_] = ACTIONS(165),
    [anon_sym_NA_complex_] = ACTIONS(165),
    [anon_sym_NA_character_] = ACTIONS(165),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(163),
    [sym__semicolon] = ACTIONS(163),
    [sym__raw_string_open] = ACTIONS(163),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(163),
    [sym__external_close_brace] = ACTIONS(163),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [189] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(355),
    [anon_sym_BSLASH] = ACTIONS(357),
    [anon_sym_function] = ACTIONS(355),
    [anon_sym_EQ] = ACTIONS(247),
    [anon_sym_if] = ACTIONS(355),
    [anon_sym_for] = ACTIONS(355),
    [anon_sym_while] = ACTIONS(355),
    [anon_sym_repeat] = ACTIONS(355),
    [anon_sym_QMARK] = ACTIONS(359),
    [anon_sym_TILDE] = ACTIONS(249),
    [anon_sym_BANG] = ACTIONS(355),
    [anon_sym_PLUS] = ACTIONS(251),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_LT_DASH] = ACTIONS(255),
    [anon_sym_LT_LT_DASH] = ACTIONS(255),
    [anon_sym_COLON_EQ] = ACTIONS(255),
    [anon_sym_DASH_GT] = ACTIONS(257),
    [anon_sym_DASH_GT_GT] = ACTIONS(259),
    [anon_sym_PIPE] = ACTIONS(261),
    [anon_sym_AMP] = ACTIONS(263),
    [anon_sym_PIPE_PIPE] = ACTIONS(265),
    [anon_sym_AMP_AMP] = ACTIONS(267),
    [anon_sym_LT] = ACTIONS(269),
    [anon_sym_LT_EQ] = ACTIONS(271),
    [anon_sym_GT] = ACTIONS(269),
    [anon_sym_GT_EQ] = ACTIONS(271),
    [anon_sym_EQ_EQ] = ACTIONS(271),
    [anon_sym_BANG_EQ] = ACTIONS(271),
    [anon_sym_STAR] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(279),
    [anon_sym_PIPE_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(357),
    [sym__number_literal] = ACTIONS(355),
    [anon_sym_SQUOTE] = ACTIONS(357),
    [anon_sym_DQUOTE] = ACTIONS(357),
    [sym_dots] = ACTIONS(355),
    [sym_dot_dot_i] = ACTIONS(355),
    [sym_next] = ACTIONS(355),
    [sym_break] = ACTIONS(355),
    [sym_true] = ACTIONS(355),
    [sym_false] = ACTIONS(355),
    [sym_null] = ACTIONS(355),
    [sym_inf] = ACTIONS(355),
    [sym_nan] = ACTIONS(355),
    [anon_sym_NA] = ACTIONS(355),
    [anon_sym_NA_integer_] = ACTIONS(355),
    [anon_sym_NA_real_] = ACTIONS(355),
    [anon_sym_NA_complex_] = ACTIONS(355),
    [anon_sym_NA_character_] = ACTIONS(355),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(357),
    [sym__semicolon] = ACTIONS(357),
    [sym__raw_string_open] = ACTIONS(357),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(357),
    [sym__external_close_brace] = ACTIONS(357),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [190] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(167),
    [sym_identifier] = ACTIONS(169),
    [anon_sym_BSLASH] = ACTIONS(167),
    [anon_sym_function] = ACTIONS(169),
    [anon_sym_EQ] = ACTIONS(339),
    [anon_sym_if] = ACTIONS(169),
    [anon_sym_for] = ACTIONS(169),
    [anon_sym_while] = ACTIONS(169),
    [anon_sym_repeat] = ACTIONS(169),
    [anon_sym_QMARK] = ACTIONS(167),
    [anon_sym_TILDE] = ACTIONS(341),
    [anon_sym_BANG] = ACTIONS(169),
    [anon_sym_PLUS] = ACTIONS(291),
    [anon_sym_DASH] = ACTIONS(293),
    [anon_sym_LT_DASH] = ACTIONS(347),
    [anon_sym_LT_LT_DASH] = ACTIONS(347),
    [anon_sym_COLON_EQ] = ACTIONS(347),
    [anon_sym_DASH_GT] = ACTIONS(343),
    [anon_sym_DASH_GT_GT] = ACTIONS(345),
    [anon_sym_PIPE] = ACTIONS(295),
    [anon_sym_AMP] = ACTIONS(297),
    [anon_sym_PIPE_PIPE] = ACTIONS(299),
    [anon_sym_AMP_AMP] = ACTIONS(301),
    [anon_sym_LT] = ACTIONS(303),
    [anon_sym_LT_EQ] = ACTIONS(305),
    [anon_sym_GT] = ACTIONS(303),
    [anon_sym_GT_EQ] = ACTIONS(305),
    [anon_sym_EQ_EQ] = ACTIONS(305),
    [anon_sym_BANG_EQ] = ACTIONS(305),
    [anon_sym_STAR] = ACTIONS(307),
    [anon_sym_SLASH] = ACTIONS(309),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(313),
    [anon_sym_PIPE_GT] = ACTIONS(313),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(167),
    [sym__number_literal] = ACTIONS(169),
    [anon_sym_SQUOTE] = ACTIONS(167),
    [anon_sym_DQUOTE] = ACTIONS(167),
    [sym_dots] = ACTIONS(169),
    [sym_dot_dot_i] = ACTIONS(169),
    [sym_next] = ACTIONS(169),
    [sym_break] = ACTIONS(169),
    [sym_true] = ACTIONS(169),
    [sym_false] = ACTIONS(169),
    [sym_null] = ACTIONS(169),
    [sym_inf] = ACTIONS(169),
    [sym_nan] = ACTIONS(169),
    [anon_sym_NA] = ACTIONS(169),
    [anon_sym_NA_integer_] = ACTIONS(169),
    [anon_sym_NA_real_] = ACTIONS(169),
    [anon_sym_NA_complex_] = ACTIONS(169),
    [anon_sym_NA_character_] = ACTIONS(169),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(167),
    [sym__semicolon] = ACTIONS(167),
    [sym__raw_string_open] = ACTIONS(167),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(167),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [191] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(169),
    [anon_sym_BSLASH] = ACTIONS(167),
    [anon_sym_function] = ACTIONS(169),
    [anon_sym_EQ] = ACTIONS(169),
    [anon_sym_if] = ACTIONS(169),
    [anon_sym_for] = ACTIONS(169),
    [anon_sym_while] = ACTIONS(169),
    [anon_sym_repeat] = ACTIONS(169),
    [anon_sym_QMARK] = ACTIONS(167),
    [anon_sym_TILDE] = ACTIONS(167),
    [anon_sym_BANG] = ACTIONS(169),
    [anon_sym_PLUS] = ACTIONS(251),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_LT_DASH] = ACTIONS(167),
    [anon_sym_LT_LT_DASH] = ACTIONS(167),
    [anon_sym_COLON_EQ] = ACTIONS(167),
    [anon_sym_DASH_GT] = ACTIONS(169),
    [anon_sym_DASH_GT_GT] = ACTIONS(167),
    [anon_sym_PIPE] = ACTIONS(261),
    [anon_sym_AMP] = ACTIONS(263),
    [anon_sym_PIPE_PIPE] = ACTIONS(265),
    [anon_sym_AMP_AMP] = ACTIONS(267),
    [anon_sym_LT] = ACTIONS(269),
    [anon_sym_LT_EQ] = ACTIONS(271),
    [anon_sym_GT] = ACTIONS(269),
    [anon_sym_GT_EQ] = ACTIONS(271),
    [anon_sym_EQ_EQ] = ACTIONS(271),
    [anon_sym_BANG_EQ] = ACTIONS(271),
    [anon_sym_STAR] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(279),
    [anon_sym_PIPE_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(167),
    [sym__number_literal] = ACTIONS(169),
    [anon_sym_SQUOTE] = ACTIONS(167),
    [anon_sym_DQUOTE] = ACTIONS(167),
    [sym_dots] = ACTIONS(169),
    [sym_dot_dot_i] = ACTIONS(169),
    [sym_next] = ACTIONS(169),
    [sym_break] = ACTIONS(169),
    [sym_true] = ACTIONS(169),
    [sym_false] = ACTIONS(169),
    [sym_null] = ACTIONS(169),
    [sym_inf] = ACTIONS(169),
    [sym_nan] = ACTIONS(169),
    [anon_sym_NA] = ACTIONS(169),
    [anon_sym_NA_integer_] = ACTIONS(169),
    [anon_sym_NA_real_] = ACTIONS(169),
    [anon_sym_NA_complex_] = ACTIONS(169),
    [anon_sym_NA_character_] = ACTIONS(169),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(167),
    [sym__semicolon] = ACTIONS(167),
    [sym__raw_string_open] = ACTIONS(167),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(167),
    [sym__external_close_brace] = ACTIONS(167),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [192] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(169),
    [anon_sym_BSLASH] = ACTIONS(167),
    [anon_sym_function] = ACTIONS(169),
    [anon_sym_EQ] = ACTIONS(169),
    [anon_sym_if] = ACTIONS(169),
    [anon_sym_for] = ACTIONS(169),
    [anon_sym_while] = ACTIONS(169),
    [anon_sym_repeat] = ACTIONS(169),
    [anon_sym_QMARK] = ACTIONS(167),
    [anon_sym_TILDE] = ACTIONS(167),
    [anon_sym_BANG] = ACTIONS(169),
    [anon_sym_PLUS] = ACTIONS(251),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_LT_DASH] = ACTIONS(167),
    [anon_sym_LT_LT_DASH] = ACTIONS(167),
    [anon_sym_COLON_EQ] = ACTIONS(167),
    [anon_sym_DASH_GT] = ACTIONS(169),
    [anon_sym_DASH_GT_GT] = ACTIONS(167),
    [anon_sym_PIPE] = ACTIONS(169),
    [anon_sym_AMP] = ACTIONS(169),
    [anon_sym_PIPE_PIPE] = ACTIONS(167),
    [anon_sym_AMP_AMP] = ACTIONS(167),
    [anon_sym_LT] = ACTIONS(269),
    [anon_sym_LT_EQ] = ACTIONS(271),
    [anon_sym_GT] = ACTIONS(269),
    [anon_sym_GT_EQ] = ACTIONS(271),
    [anon_sym_EQ_EQ] = ACTIONS(271),
    [anon_sym_BANG_EQ] = ACTIONS(271),
    [anon_sym_STAR] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(279),
    [anon_sym_PIPE_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(167),
    [sym__number_literal] = ACTIONS(169),
    [anon_sym_SQUOTE] = ACTIONS(167),
    [anon_sym_DQUOTE] = ACTIONS(167),
    [sym_dots] = ACTIONS(169),
    [sym_dot_dot_i] = ACTIONS(169),
    [sym_next] = ACTIONS(169),
    [sym_break] = ACTIONS(169),
    [sym_true] = ACTIONS(169),
    [sym_false] = ACTIONS(169),
    [sym_null] = ACTIONS(169),
    [sym_inf] = ACTIONS(169),
    [sym_nan] = ACTIONS(169),
    [anon_sym_NA] = ACTIONS(169),
    [anon_sym_NA_integer_] = ACTIONS(169),
    [anon_sym_NA_real_] = ACTIONS(169),
    [anon_sym_NA_complex_] = ACTIONS(169),
    [anon_sym_NA_character_] = ACTIONS(169),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(167),
    [sym__semicolon] = ACTIONS(167),
    [sym__raw_string_open] = ACTIONS(167),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(167),
    [sym__external_close_brace] = ACTIONS(167),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [193] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(169),
    [anon_sym_BSLASH] = ACTIONS(167),
    [anon_sym_function] = ACTIONS(169),
    [anon_sym_EQ] = ACTIONS(169),
    [anon_sym_if] = ACTIONS(169),
    [anon_sym_for] = ACTIONS(169),
    [anon_sym_while] = ACTIONS(169),
    [anon_sym_repeat] = ACTIONS(169),
    [anon_sym_QMARK] = ACTIONS(167),
    [anon_sym_TILDE] = ACTIONS(167),
    [anon_sym_BANG] = ACTIONS(169),
    [anon_sym_PLUS] = ACTIONS(167),
    [anon_sym_DASH] = ACTIONS(169),
    [anon_sym_LT_DASH] = ACTIONS(167),
    [anon_sym_LT_LT_DASH] = ACTIONS(167),
    [anon_sym_COLON_EQ] = ACTIONS(167),
    [anon_sym_DASH_GT] = ACTIONS(169),
    [anon_sym_DASH_GT_GT] = ACTIONS(167),
    [anon_sym_PIPE] = ACTIONS(169),
    [anon_sym_AMP] = ACTIONS(169),
    [anon_sym_PIPE_PIPE] = ACTIONS(167),
    [anon_sym_AMP_AMP] = ACTIONS(167),
    [anon_sym_LT] = ACTIONS(169),
    [anon_sym_LT_EQ] = ACTIONS(167),
    [anon_sym_GT] = ACTIONS(169),
    [anon_sym_GT_EQ] = ACTIONS(167),
    [anon_sym_EQ_EQ] = ACTIONS(167),
    [anon_sym_BANG_EQ] = ACTIONS(167),
    [anon_sym_STAR] = ACTIONS(169),
    [anon_sym_SLASH] = ACTIONS(167),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(167),
    [anon_sym_PIPE_GT] = ACTIONS(167),
    [anon_sym_COLON] = ACTIONS(169),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(167),
    [sym__number_literal] = ACTIONS(169),
    [anon_sym_SQUOTE] = ACTIONS(167),
    [anon_sym_DQUOTE] = ACTIONS(167),
    [sym_dots] = ACTIONS(169),
    [sym_dot_dot_i] = ACTIONS(169),
    [sym_next] = ACTIONS(169),
    [sym_break] = ACTIONS(169),
    [sym_true] = ACTIONS(169),
    [sym_false] = ACTIONS(169),
    [sym_null] = ACTIONS(169),
    [sym_inf] = ACTIONS(169),
    [sym_nan] = ACTIONS(169),
    [anon_sym_NA] = ACTIONS(169),
    [anon_sym_NA_integer_] = ACTIONS(169),
    [anon_sym_NA_real_] = ACTIONS(169),
    [anon_sym_NA_complex_] = ACTIONS(169),
    [anon_sym_NA_character_] = ACTIONS(169),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(167),
    [sym__semicolon] = ACTIONS(167),
    [sym__raw_string_open] = ACTIONS(167),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(167),
    [sym__external_close_brace] = ACTIONS(167),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [194] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(247),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(249),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(251),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_LT_DASH] = ACTIONS(143),
    [anon_sym_LT_LT_DASH] = ACTIONS(143),
    [anon_sym_COLON_EQ] = ACTIONS(143),
    [anon_sym_DASH_GT] = ACTIONS(257),
    [anon_sym_DASH_GT_GT] = ACTIONS(259),
    [anon_sym_PIPE] = ACTIONS(261),
    [anon_sym_AMP] = ACTIONS(263),
    [anon_sym_PIPE_PIPE] = ACTIONS(265),
    [anon_sym_AMP_AMP] = ACTIONS(267),
    [anon_sym_LT] = ACTIONS(269),
    [anon_sym_LT_EQ] = ACTIONS(271),
    [anon_sym_GT] = ACTIONS(269),
    [anon_sym_GT_EQ] = ACTIONS(271),
    [anon_sym_EQ_EQ] = ACTIONS(271),
    [anon_sym_BANG_EQ] = ACTIONS(271),
    [anon_sym_STAR] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(279),
    [anon_sym_PIPE_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_close_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [195] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(247),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(249),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(251),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_LT_DASH] = ACTIONS(255),
    [anon_sym_LT_LT_DASH] = ACTIONS(255),
    [anon_sym_COLON_EQ] = ACTIONS(255),
    [anon_sym_DASH_GT] = ACTIONS(257),
    [anon_sym_DASH_GT_GT] = ACTIONS(259),
    [anon_sym_PIPE] = ACTIONS(261),
    [anon_sym_AMP] = ACTIONS(263),
    [anon_sym_PIPE_PIPE] = ACTIONS(265),
    [anon_sym_AMP_AMP] = ACTIONS(267),
    [anon_sym_LT] = ACTIONS(269),
    [anon_sym_LT_EQ] = ACTIONS(271),
    [anon_sym_GT] = ACTIONS(269),
    [anon_sym_GT_EQ] = ACTIONS(271),
    [anon_sym_EQ_EQ] = ACTIONS(271),
    [anon_sym_BANG_EQ] = ACTIONS(271),
    [anon_sym_STAR] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(279),
    [anon_sym_PIPE_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_close_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [196] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(251),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_LT_DASH] = ACTIONS(143),
    [anon_sym_LT_LT_DASH] = ACTIONS(143),
    [anon_sym_COLON_EQ] = ACTIONS(143),
    [anon_sym_DASH_GT] = ACTIONS(145),
    [anon_sym_DASH_GT_GT] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(261),
    [anon_sym_AMP] = ACTIONS(263),
    [anon_sym_PIPE_PIPE] = ACTIONS(265),
    [anon_sym_AMP_AMP] = ACTIONS(267),
    [anon_sym_LT] = ACTIONS(269),
    [anon_sym_LT_EQ] = ACTIONS(271),
    [anon_sym_GT] = ACTIONS(269),
    [anon_sym_GT_EQ] = ACTIONS(271),
    [anon_sym_EQ_EQ] = ACTIONS(271),
    [anon_sym_BANG_EQ] = ACTIONS(271),
    [anon_sym_STAR] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(279),
    [anon_sym_PIPE_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_close_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [197] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_LT_DASH] = ACTIONS(143),
    [anon_sym_LT_LT_DASH] = ACTIONS(143),
    [anon_sym_COLON_EQ] = ACTIONS(143),
    [anon_sym_DASH_GT] = ACTIONS(145),
    [anon_sym_DASH_GT_GT] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(145),
    [anon_sym_PIPE_PIPE] = ACTIONS(143),
    [anon_sym_AMP_AMP] = ACTIONS(143),
    [anon_sym_LT] = ACTIONS(145),
    [anon_sym_LT_EQ] = ACTIONS(143),
    [anon_sym_GT] = ACTIONS(145),
    [anon_sym_GT_EQ] = ACTIONS(143),
    [anon_sym_EQ_EQ] = ACTIONS(143),
    [anon_sym_BANG_EQ] = ACTIONS(143),
    [anon_sym_STAR] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(279),
    [anon_sym_PIPE_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_close_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [198] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(247),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(249),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(251),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_LT_DASH] = ACTIONS(255),
    [anon_sym_LT_LT_DASH] = ACTIONS(255),
    [anon_sym_COLON_EQ] = ACTIONS(255),
    [anon_sym_DASH_GT] = ACTIONS(257),
    [anon_sym_DASH_GT_GT] = ACTIONS(259),
    [anon_sym_PIPE] = ACTIONS(261),
    [anon_sym_AMP] = ACTIONS(263),
    [anon_sym_PIPE_PIPE] = ACTIONS(265),
    [anon_sym_AMP_AMP] = ACTIONS(267),
    [anon_sym_LT] = ACTIONS(269),
    [anon_sym_LT_EQ] = ACTIONS(271),
    [anon_sym_GT] = ACTIONS(269),
    [anon_sym_GT_EQ] = ACTIONS(271),
    [anon_sym_EQ_EQ] = ACTIONS(271),
    [anon_sym_BANG_EQ] = ACTIONS(271),
    [anon_sym_STAR] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(279),
    [anon_sym_PIPE_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_close_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [199] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(249),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(251),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_LT_DASH] = ACTIONS(143),
    [anon_sym_LT_LT_DASH] = ACTIONS(143),
    [anon_sym_COLON_EQ] = ACTIONS(143),
    [anon_sym_DASH_GT] = ACTIONS(145),
    [anon_sym_DASH_GT_GT] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(261),
    [anon_sym_AMP] = ACTIONS(263),
    [anon_sym_PIPE_PIPE] = ACTIONS(265),
    [anon_sym_AMP_AMP] = ACTIONS(267),
    [anon_sym_LT] = ACTIONS(269),
    [anon_sym_LT_EQ] = ACTIONS(271),
    [anon_sym_GT] = ACTIONS(269),
    [anon_sym_GT_EQ] = ACTIONS(271),
    [anon_sym_EQ_EQ] = ACTIONS(271),
    [anon_sym_BANG_EQ] = ACTIONS(271),
    [anon_sym_STAR] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(279),
    [anon_sym_PIPE_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_close_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [200] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(251),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_LT_DASH] = ACTIONS(143),
    [anon_sym_LT_LT_DASH] = ACTIONS(143),
    [anon_sym_COLON_EQ] = ACTIONS(143),
    [anon_sym_DASH_GT] = ACTIONS(145),
    [anon_sym_DASH_GT_GT] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(263),
    [anon_sym_PIPE_PIPE] = ACTIONS(143),
    [anon_sym_AMP_AMP] = ACTIONS(267),
    [anon_sym_LT] = ACTIONS(269),
    [anon_sym_LT_EQ] = ACTIONS(271),
    [anon_sym_GT] = ACTIONS(269),
    [anon_sym_GT_EQ] = ACTIONS(271),
    [anon_sym_EQ_EQ] = ACTIONS(271),
    [anon_sym_BANG_EQ] = ACTIONS(271),
    [anon_sym_STAR] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(279),
    [anon_sym_PIPE_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_close_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [201] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(251),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_LT_DASH] = ACTIONS(143),
    [anon_sym_LT_LT_DASH] = ACTIONS(143),
    [anon_sym_COLON_EQ] = ACTIONS(143),
    [anon_sym_DASH_GT] = ACTIONS(145),
    [anon_sym_DASH_GT_GT] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(145),
    [anon_sym_PIPE_PIPE] = ACTIONS(143),
    [anon_sym_AMP_AMP] = ACTIONS(143),
    [anon_sym_LT] = ACTIONS(269),
    [anon_sym_LT_EQ] = ACTIONS(271),
    [anon_sym_GT] = ACTIONS(269),
    [anon_sym_GT_EQ] = ACTIONS(271),
    [anon_sym_EQ_EQ] = ACTIONS(271),
    [anon_sym_BANG_EQ] = ACTIONS(271),
    [anon_sym_STAR] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(279),
    [anon_sym_PIPE_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_close_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [202] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(251),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_LT_DASH] = ACTIONS(143),
    [anon_sym_LT_LT_DASH] = ACTIONS(143),
    [anon_sym_COLON_EQ] = ACTIONS(143),
    [anon_sym_DASH_GT] = ACTIONS(145),
    [anon_sym_DASH_GT_GT] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(145),
    [anon_sym_PIPE_PIPE] = ACTIONS(143),
    [anon_sym_AMP_AMP] = ACTIONS(143),
    [anon_sym_LT] = ACTIONS(145),
    [anon_sym_LT_EQ] = ACTIONS(143),
    [anon_sym_GT] = ACTIONS(145),
    [anon_sym_GT_EQ] = ACTIONS(143),
    [anon_sym_EQ_EQ] = ACTIONS(143),
    [anon_sym_BANG_EQ] = ACTIONS(143),
    [anon_sym_STAR] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(279),
    [anon_sym_PIPE_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_close_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [203] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_LT_DASH] = ACTIONS(143),
    [anon_sym_LT_LT_DASH] = ACTIONS(143),
    [anon_sym_COLON_EQ] = ACTIONS(143),
    [anon_sym_DASH_GT] = ACTIONS(145),
    [anon_sym_DASH_GT_GT] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(145),
    [anon_sym_PIPE_PIPE] = ACTIONS(143),
    [anon_sym_AMP_AMP] = ACTIONS(143),
    [anon_sym_LT] = ACTIONS(145),
    [anon_sym_LT_EQ] = ACTIONS(143),
    [anon_sym_GT] = ACTIONS(145),
    [anon_sym_GT_EQ] = ACTIONS(143),
    [anon_sym_EQ_EQ] = ACTIONS(143),
    [anon_sym_BANG_EQ] = ACTIONS(143),
    [anon_sym_STAR] = ACTIONS(145),
    [anon_sym_SLASH] = ACTIONS(143),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(279),
    [anon_sym_PIPE_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_close_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [204] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_LT_DASH] = ACTIONS(143),
    [anon_sym_LT_LT_DASH] = ACTIONS(143),
    [anon_sym_COLON_EQ] = ACTIONS(143),
    [anon_sym_DASH_GT] = ACTIONS(145),
    [anon_sym_DASH_GT_GT] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(145),
    [anon_sym_PIPE_PIPE] = ACTIONS(143),
    [anon_sym_AMP_AMP] = ACTIONS(143),
    [anon_sym_LT] = ACTIONS(145),
    [anon_sym_LT_EQ] = ACTIONS(143),
    [anon_sym_GT] = ACTIONS(145),
    [anon_sym_GT_EQ] = ACTIONS(143),
    [anon_sym_EQ_EQ] = ACTIONS(143),
    [anon_sym_BANG_EQ] = ACTIONS(143),
    [anon_sym_STAR] = ACTIONS(145),
    [anon_sym_SLASH] = ACTIONS(143),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(143),
    [anon_sym_PIPE_GT] = ACTIONS(143),
    [anon_sym_COLON] = ACTIONS(145),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_close_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [205] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_LT_DASH] = ACTIONS(143),
    [anon_sym_LT_LT_DASH] = ACTIONS(143),
    [anon_sym_COLON_EQ] = ACTIONS(143),
    [anon_sym_DASH_GT] = ACTIONS(145),
    [anon_sym_DASH_GT_GT] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(145),
    [anon_sym_PIPE_PIPE] = ACTIONS(143),
    [anon_sym_AMP_AMP] = ACTIONS(143),
    [anon_sym_LT] = ACTIONS(145),
    [anon_sym_LT_EQ] = ACTIONS(143),
    [anon_sym_GT] = ACTIONS(145),
    [anon_sym_GT_EQ] = ACTIONS(143),
    [anon_sym_EQ_EQ] = ACTIONS(143),
    [anon_sym_BANG_EQ] = ACTIONS(143),
    [anon_sym_STAR] = ACTIONS(145),
    [anon_sym_SLASH] = ACTIONS(143),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(143),
    [anon_sym_PIPE_GT] = ACTIONS(143),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_close_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [206] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(145),
    [anon_sym_BSLASH] = ACTIONS(143),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_repeat] = ACTIONS(145),
    [anon_sym_QMARK] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_LT_DASH] = ACTIONS(143),
    [anon_sym_LT_LT_DASH] = ACTIONS(143),
    [anon_sym_COLON_EQ] = ACTIONS(143),
    [anon_sym_DASH_GT] = ACTIONS(145),
    [anon_sym_DASH_GT_GT] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(145),
    [anon_sym_AMP] = ACTIONS(145),
    [anon_sym_PIPE_PIPE] = ACTIONS(143),
    [anon_sym_AMP_AMP] = ACTIONS(143),
    [anon_sym_LT] = ACTIONS(145),
    [anon_sym_LT_EQ] = ACTIONS(143),
    [anon_sym_GT] = ACTIONS(145),
    [anon_sym_GT_EQ] = ACTIONS(143),
    [anon_sym_EQ_EQ] = ACTIONS(143),
    [anon_sym_BANG_EQ] = ACTIONS(143),
    [anon_sym_STAR] = ACTIONS(145),
    [anon_sym_SLASH] = ACTIONS(143),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(143),
    [anon_sym_PIPE_GT] = ACTIONS(143),
    [anon_sym_COLON] = ACTIONS(145),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(143),
    [sym__number_literal] = ACTIONS(145),
    [anon_sym_SQUOTE] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(143),
    [sym_dots] = ACTIONS(145),
    [sym_dot_dot_i] = ACTIONS(145),
    [sym_next] = ACTIONS(145),
    [sym_break] = ACTIONS(145),
    [sym_true] = ACTIONS(145),
    [sym_false] = ACTIONS(145),
    [sym_null] = ACTIONS(145),
    [sym_inf] = ACTIONS(145),
    [sym_nan] = ACTIONS(145),
    [anon_sym_NA] = ACTIONS(145),
    [anon_sym_NA_integer_] = ACTIONS(145),
    [anon_sym_NA_real_] = ACTIONS(145),
    [anon_sym_NA_complex_] = ACTIONS(145),
    [anon_sym_NA_character_] = ACTIONS(145),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(143),
    [sym__semicolon] = ACTIONS(143),
    [sym__raw_string_open] = ACTIONS(143),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(143),
    [sym__external_close_brace] = ACTIONS(143),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [207] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(173),
    [anon_sym_BSLASH] = ACTIONS(171),
    [anon_sym_function] = ACTIONS(173),
    [anon_sym_EQ] = ACTIONS(247),
    [anon_sym_if] = ACTIONS(173),
    [anon_sym_for] = ACTIONS(173),
    [anon_sym_while] = ACTIONS(173),
    [anon_sym_repeat] = ACTIONS(173),
    [anon_sym_QMARK] = ACTIONS(171),
    [anon_sym_TILDE] = ACTIONS(249),
    [anon_sym_BANG] = ACTIONS(173),
    [anon_sym_PLUS] = ACTIONS(251),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_LT_DASH] = ACTIONS(255),
    [anon_sym_LT_LT_DASH] = ACTIONS(255),
    [anon_sym_COLON_EQ] = ACTIONS(255),
    [anon_sym_DASH_GT] = ACTIONS(257),
    [anon_sym_DASH_GT_GT] = ACTIONS(259),
    [anon_sym_PIPE] = ACTIONS(261),
    [anon_sym_AMP] = ACTIONS(263),
    [anon_sym_PIPE_PIPE] = ACTIONS(265),
    [anon_sym_AMP_AMP] = ACTIONS(267),
    [anon_sym_LT] = ACTIONS(269),
    [anon_sym_LT_EQ] = ACTIONS(271),
    [anon_sym_GT] = ACTIONS(269),
    [anon_sym_GT_EQ] = ACTIONS(271),
    [anon_sym_EQ_EQ] = ACTIONS(271),
    [anon_sym_BANG_EQ] = ACTIONS(271),
    [anon_sym_STAR] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(279),
    [anon_sym_PIPE_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(171),
    [sym__number_literal] = ACTIONS(173),
    [anon_sym_SQUOTE] = ACTIONS(171),
    [anon_sym_DQUOTE] = ACTIONS(171),
    [sym_dots] = ACTIONS(173),
    [sym_dot_dot_i] = ACTIONS(173),
    [sym_next] = ACTIONS(173),
    [sym_break] = ACTIONS(173),
    [sym_true] = ACTIONS(173),
    [sym_false] = ACTIONS(173),
    [sym_null] = ACTIONS(173),
    [sym_inf] = ACTIONS(173),
    [sym_nan] = ACTIONS(173),
    [anon_sym_NA] = ACTIONS(173),
    [anon_sym_NA_integer_] = ACTIONS(173),
    [anon_sym_NA_real_] = ACTIONS(173),
    [anon_sym_NA_complex_] = ACTIONS(173),
    [anon_sym_NA_character_] = ACTIONS(173),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(171),
    [sym__semicolon] = ACTIONS(171),
    [sym__raw_string_open] = ACTIONS(171),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(171),
    [sym__external_close_brace] = ACTIONS(171),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [208] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(177),
    [anon_sym_BSLASH] = ACTIONS(175),
    [anon_sym_function] = ACTIONS(177),
    [anon_sym_EQ] = ACTIONS(247),
    [anon_sym_if] = ACTIONS(177),
    [anon_sym_for] = ACTIONS(177),
    [anon_sym_while] = ACTIONS(177),
    [anon_sym_repeat] = ACTIONS(177),
    [anon_sym_QMARK] = ACTIONS(175),
    [anon_sym_TILDE] = ACTIONS(249),
    [anon_sym_BANG] = ACTIONS(177),
    [anon_sym_PLUS] = ACTIONS(251),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_LT_DASH] = ACTIONS(255),
    [anon_sym_LT_LT_DASH] = ACTIONS(255),
    [anon_sym_COLON_EQ] = ACTIONS(255),
    [anon_sym_DASH_GT] = ACTIONS(257),
    [anon_sym_DASH_GT_GT] = ACTIONS(259),
    [anon_sym_PIPE] = ACTIONS(261),
    [anon_sym_AMP] = ACTIONS(263),
    [anon_sym_PIPE_PIPE] = ACTIONS(265),
    [anon_sym_AMP_AMP] = ACTIONS(267),
    [anon_sym_LT] = ACTIONS(269),
    [anon_sym_LT_EQ] = ACTIONS(271),
    [anon_sym_GT] = ACTIONS(269),
    [anon_sym_GT_EQ] = ACTIONS(271),
    [anon_sym_EQ_EQ] = ACTIONS(271),
    [anon_sym_BANG_EQ] = ACTIONS(271),
    [anon_sym_STAR] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(279),
    [anon_sym_PIPE_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(175),
    [sym__number_literal] = ACTIONS(177),
    [anon_sym_SQUOTE] = ACTIONS(175),
    [anon_sym_DQUOTE] = ACTIONS(175),
    [sym_dots] = ACTIONS(177),
    [sym_dot_dot_i] = ACTIONS(177),
    [sym_next] = ACTIONS(177),
    [sym_break] = ACTIONS(177),
    [sym_true] = ACTIONS(177),
    [sym_false] = ACTIONS(177),
    [sym_null] = ACTIONS(177),
    [sym_inf] = ACTIONS(177),
    [sym_nan] = ACTIONS(177),
    [anon_sym_NA] = ACTIONS(177),
    [anon_sym_NA_integer_] = ACTIONS(177),
    [anon_sym_NA_real_] = ACTIONS(177),
    [anon_sym_NA_complex_] = ACTIONS(177),
    [anon_sym_NA_character_] = ACTIONS(177),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(175),
    [sym__semicolon] = ACTIONS(175),
    [sym__raw_string_open] = ACTIONS(175),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(175),
    [sym__external_close_brace] = ACTIONS(175),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [209] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(247),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(249),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(251),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_LT_DASH] = ACTIONS(179),
    [anon_sym_LT_LT_DASH] = ACTIONS(179),
    [anon_sym_COLON_EQ] = ACTIONS(179),
    [anon_sym_DASH_GT] = ACTIONS(257),
    [anon_sym_DASH_GT_GT] = ACTIONS(259),
    [anon_sym_PIPE] = ACTIONS(261),
    [anon_sym_AMP] = ACTIONS(263),
    [anon_sym_PIPE_PIPE] = ACTIONS(265),
    [anon_sym_AMP_AMP] = ACTIONS(267),
    [anon_sym_LT] = ACTIONS(269),
    [anon_sym_LT_EQ] = ACTIONS(271),
    [anon_sym_GT] = ACTIONS(269),
    [anon_sym_GT_EQ] = ACTIONS(271),
    [anon_sym_EQ_EQ] = ACTIONS(271),
    [anon_sym_BANG_EQ] = ACTIONS(271),
    [anon_sym_STAR] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(279),
    [anon_sym_PIPE_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_close_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [210] = {
    [sym_string] = STATE(359),
    [sym__raw_string] = STATE(301),
    [sym__single_quoted_string] = STATE(302),
    [sym__double_quoted_string] = STATE(303),
    [aux_sym_function_definition_repeat1] = STATE(317),
    [sym_identifier] = ACTIONS(361),
    [anon_sym_BSLASH] = ACTIONS(349),
    [anon_sym_function] = ACTIONS(353),
    [anon_sym_EQ] = ACTIONS(353),
    [anon_sym_if] = ACTIONS(353),
    [anon_sym_for] = ACTIONS(353),
    [anon_sym_while] = ACTIONS(353),
    [anon_sym_repeat] = ACTIONS(353),
    [anon_sym_QMARK] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(349),
    [anon_sym_BANG] = ACTIONS(353),
    [anon_sym_PLUS] = ACTIONS(349),
    [anon_sym_DASH] = ACTIONS(353),
    [anon_sym_LT_DASH] = ACTIONS(349),
    [anon_sym_LT_LT_DASH] = ACTIONS(349),
    [anon_sym_COLON_EQ] = ACTIONS(349),
    [anon_sym_DASH_GT] = ACTIONS(353),
    [anon_sym_DASH_GT_GT] = ACTIONS(349),
    [anon_sym_PIPE] = ACTIONS(353),
    [anon_sym_AMP] = ACTIONS(353),
    [anon_sym_PIPE_PIPE] = ACTIONS(349),
    [anon_sym_AMP_AMP] = ACTIONS(349),
    [anon_sym_LT] = ACTIONS(353),
    [anon_sym_LT_EQ] = ACTIONS(349),
    [anon_sym_GT] = ACTIONS(353),
    [anon_sym_GT_EQ] = ACTIONS(349),
    [anon_sym_EQ_EQ] = ACTIONS(349),
    [anon_sym_BANG_EQ] = ACTIONS(349),
    [anon_sym_STAR] = ACTIONS(353),
    [anon_sym_SLASH] = ACTIONS(349),
    [anon_sym_STAR_STAR] = ACTIONS(349),
    [anon_sym_CARET] = ACTIONS(349),
    [aux_sym_binary_operator_token1] = ACTIONS(349),
    [anon_sym_PIPE_GT] = ACTIONS(349),
    [anon_sym_COLON] = ACTIONS(353),
    [anon_sym_DOLLAR] = ACTIONS(349),
    [anon_sym_AT] = ACTIONS(349),
    [sym__hex_literal] = ACTIONS(349),
    [sym__number_literal] = ACTIONS(353),
    [anon_sym_SQUOTE] = ACTIONS(363),
    [anon_sym_DQUOTE] = ACTIONS(365),
    [sym_dots] = ACTIONS(361),
    [sym_dot_dot_i] = ACTIONS(361),
    [sym_next] = ACTIONS(353),
    [sym_break] = ACTIONS(353),
    [sym_true] = ACTIONS(353),
    [sym_false] = ACTIONS(353),
    [sym_null] = ACTIONS(353),
    [sym_inf] = ACTIONS(353),
    [sym_nan] = ACTIONS(353),
    [anon_sym_NA] = ACTIONS(353),
    [anon_sym_NA_integer_] = ACTIONS(353),
    [anon_sym_NA_real_] = ACTIONS(353),
    [anon_sym_NA_complex_] = ACTIONS(353),
    [anon_sym_NA_character_] = ACTIONS(353),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(349),
    [sym__semicolon] = ACTIONS(349),
    [sym__raw_string_open] = ACTIONS(367),
    [sym__external_else] = ACTIONS(349),
    [sym__external_open_parenthesis] = ACTIONS(349),
    [sym__external_open_brace] = ACTIONS(349),
    [sym__external_close_brace] = ACTIONS(349),
    [sym__external_open_bracket] = ACTIONS(349),
    [sym__external_open_bracket2] = ACTIONS(349),
  },
  [211] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(247),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(249),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(251),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_LT_DASH] = ACTIONS(255),
    [anon_sym_LT_LT_DASH] = ACTIONS(255),
    [anon_sym_COLON_EQ] = ACTIONS(255),
    [anon_sym_DASH_GT] = ACTIONS(257),
    [anon_sym_DASH_GT_GT] = ACTIONS(259),
    [anon_sym_PIPE] = ACTIONS(261),
    [anon_sym_AMP] = ACTIONS(263),
    [anon_sym_PIPE_PIPE] = ACTIONS(265),
    [anon_sym_AMP_AMP] = ACTIONS(267),
    [anon_sym_LT] = ACTIONS(269),
    [anon_sym_LT_EQ] = ACTIONS(271),
    [anon_sym_GT] = ACTIONS(269),
    [anon_sym_GT_EQ] = ACTIONS(271),
    [anon_sym_EQ_EQ] = ACTIONS(271),
    [anon_sym_BANG_EQ] = ACTIONS(271),
    [anon_sym_STAR] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(279),
    [anon_sym_PIPE_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_close_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [212] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(181),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(179),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(251),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_LT_DASH] = ACTIONS(179),
    [anon_sym_LT_LT_DASH] = ACTIONS(179),
    [anon_sym_COLON_EQ] = ACTIONS(179),
    [anon_sym_DASH_GT] = ACTIONS(181),
    [anon_sym_DASH_GT_GT] = ACTIONS(179),
    [anon_sym_PIPE] = ACTIONS(261),
    [anon_sym_AMP] = ACTIONS(263),
    [anon_sym_PIPE_PIPE] = ACTIONS(265),
    [anon_sym_AMP_AMP] = ACTIONS(267),
    [anon_sym_LT] = ACTIONS(269),
    [anon_sym_LT_EQ] = ACTIONS(271),
    [anon_sym_GT] = ACTIONS(269),
    [anon_sym_GT_EQ] = ACTIONS(271),
    [anon_sym_EQ_EQ] = ACTIONS(271),
    [anon_sym_BANG_EQ] = ACTIONS(271),
    [anon_sym_STAR] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(279),
    [anon_sym_PIPE_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_close_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [213] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(181),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(179),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(181),
    [anon_sym_LT_DASH] = ACTIONS(179),
    [anon_sym_LT_LT_DASH] = ACTIONS(179),
    [anon_sym_COLON_EQ] = ACTIONS(179),
    [anon_sym_DASH_GT] = ACTIONS(181),
    [anon_sym_DASH_GT_GT] = ACTIONS(179),
    [anon_sym_PIPE] = ACTIONS(181),
    [anon_sym_AMP] = ACTIONS(181),
    [anon_sym_PIPE_PIPE] = ACTIONS(179),
    [anon_sym_AMP_AMP] = ACTIONS(179),
    [anon_sym_LT] = ACTIONS(181),
    [anon_sym_LT_EQ] = ACTIONS(179),
    [anon_sym_GT] = ACTIONS(181),
    [anon_sym_GT_EQ] = ACTIONS(179),
    [anon_sym_EQ_EQ] = ACTIONS(179),
    [anon_sym_BANG_EQ] = ACTIONS(179),
    [anon_sym_STAR] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(279),
    [anon_sym_PIPE_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_close_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [214] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(247),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(249),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(251),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_LT_DASH] = ACTIONS(255),
    [anon_sym_LT_LT_DASH] = ACTIONS(255),
    [anon_sym_COLON_EQ] = ACTIONS(255),
    [anon_sym_DASH_GT] = ACTIONS(257),
    [anon_sym_DASH_GT_GT] = ACTIONS(259),
    [anon_sym_PIPE] = ACTIONS(261),
    [anon_sym_AMP] = ACTIONS(263),
    [anon_sym_PIPE_PIPE] = ACTIONS(265),
    [anon_sym_AMP_AMP] = ACTIONS(267),
    [anon_sym_LT] = ACTIONS(269),
    [anon_sym_LT_EQ] = ACTIONS(271),
    [anon_sym_GT] = ACTIONS(269),
    [anon_sym_GT_EQ] = ACTIONS(271),
    [anon_sym_EQ_EQ] = ACTIONS(271),
    [anon_sym_BANG_EQ] = ACTIONS(271),
    [anon_sym_STAR] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(279),
    [anon_sym_PIPE_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_close_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [215] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(181),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(249),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(251),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_LT_DASH] = ACTIONS(179),
    [anon_sym_LT_LT_DASH] = ACTIONS(179),
    [anon_sym_COLON_EQ] = ACTIONS(179),
    [anon_sym_DASH_GT] = ACTIONS(181),
    [anon_sym_DASH_GT_GT] = ACTIONS(179),
    [anon_sym_PIPE] = ACTIONS(261),
    [anon_sym_AMP] = ACTIONS(263),
    [anon_sym_PIPE_PIPE] = ACTIONS(265),
    [anon_sym_AMP_AMP] = ACTIONS(267),
    [anon_sym_LT] = ACTIONS(269),
    [anon_sym_LT_EQ] = ACTIONS(271),
    [anon_sym_GT] = ACTIONS(269),
    [anon_sym_GT_EQ] = ACTIONS(271),
    [anon_sym_EQ_EQ] = ACTIONS(271),
    [anon_sym_BANG_EQ] = ACTIONS(271),
    [anon_sym_STAR] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(279),
    [anon_sym_PIPE_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_close_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [216] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(181),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(179),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(251),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_LT_DASH] = ACTIONS(179),
    [anon_sym_LT_LT_DASH] = ACTIONS(179),
    [anon_sym_COLON_EQ] = ACTIONS(179),
    [anon_sym_DASH_GT] = ACTIONS(181),
    [anon_sym_DASH_GT_GT] = ACTIONS(179),
    [anon_sym_PIPE] = ACTIONS(181),
    [anon_sym_AMP] = ACTIONS(263),
    [anon_sym_PIPE_PIPE] = ACTIONS(179),
    [anon_sym_AMP_AMP] = ACTIONS(267),
    [anon_sym_LT] = ACTIONS(269),
    [anon_sym_LT_EQ] = ACTIONS(271),
    [anon_sym_GT] = ACTIONS(269),
    [anon_sym_GT_EQ] = ACTIONS(271),
    [anon_sym_EQ_EQ] = ACTIONS(271),
    [anon_sym_BANG_EQ] = ACTIONS(271),
    [anon_sym_STAR] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(279),
    [anon_sym_PIPE_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_close_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [217] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(181),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(179),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(251),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_LT_DASH] = ACTIONS(179),
    [anon_sym_LT_LT_DASH] = ACTIONS(179),
    [anon_sym_COLON_EQ] = ACTIONS(179),
    [anon_sym_DASH_GT] = ACTIONS(181),
    [anon_sym_DASH_GT_GT] = ACTIONS(179),
    [anon_sym_PIPE] = ACTIONS(181),
    [anon_sym_AMP] = ACTIONS(181),
    [anon_sym_PIPE_PIPE] = ACTIONS(179),
    [anon_sym_AMP_AMP] = ACTIONS(179),
    [anon_sym_LT] = ACTIONS(269),
    [anon_sym_LT_EQ] = ACTIONS(271),
    [anon_sym_GT] = ACTIONS(269),
    [anon_sym_GT_EQ] = ACTIONS(271),
    [anon_sym_EQ_EQ] = ACTIONS(271),
    [anon_sym_BANG_EQ] = ACTIONS(271),
    [anon_sym_STAR] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(279),
    [anon_sym_PIPE_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_close_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [218] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(181),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(179),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(251),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_LT_DASH] = ACTIONS(179),
    [anon_sym_LT_LT_DASH] = ACTIONS(179),
    [anon_sym_COLON_EQ] = ACTIONS(179),
    [anon_sym_DASH_GT] = ACTIONS(181),
    [anon_sym_DASH_GT_GT] = ACTIONS(179),
    [anon_sym_PIPE] = ACTIONS(181),
    [anon_sym_AMP] = ACTIONS(181),
    [anon_sym_PIPE_PIPE] = ACTIONS(179),
    [anon_sym_AMP_AMP] = ACTIONS(179),
    [anon_sym_LT] = ACTIONS(181),
    [anon_sym_LT_EQ] = ACTIONS(179),
    [anon_sym_GT] = ACTIONS(181),
    [anon_sym_GT_EQ] = ACTIONS(179),
    [anon_sym_EQ_EQ] = ACTIONS(179),
    [anon_sym_BANG_EQ] = ACTIONS(179),
    [anon_sym_STAR] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(279),
    [anon_sym_PIPE_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_close_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [219] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(181),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(179),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(181),
    [anon_sym_LT_DASH] = ACTIONS(179),
    [anon_sym_LT_LT_DASH] = ACTIONS(179),
    [anon_sym_COLON_EQ] = ACTIONS(179),
    [anon_sym_DASH_GT] = ACTIONS(181),
    [anon_sym_DASH_GT_GT] = ACTIONS(179),
    [anon_sym_PIPE] = ACTIONS(181),
    [anon_sym_AMP] = ACTIONS(181),
    [anon_sym_PIPE_PIPE] = ACTIONS(179),
    [anon_sym_AMP_AMP] = ACTIONS(179),
    [anon_sym_LT] = ACTIONS(181),
    [anon_sym_LT_EQ] = ACTIONS(179),
    [anon_sym_GT] = ACTIONS(181),
    [anon_sym_GT_EQ] = ACTIONS(179),
    [anon_sym_EQ_EQ] = ACTIONS(179),
    [anon_sym_BANG_EQ] = ACTIONS(179),
    [anon_sym_STAR] = ACTIONS(181),
    [anon_sym_SLASH] = ACTIONS(179),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(279),
    [anon_sym_PIPE_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_close_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [220] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(181),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(179),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(181),
    [anon_sym_LT_DASH] = ACTIONS(179),
    [anon_sym_LT_LT_DASH] = ACTIONS(179),
    [anon_sym_COLON_EQ] = ACTIONS(179),
    [anon_sym_DASH_GT] = ACTIONS(181),
    [anon_sym_DASH_GT_GT] = ACTIONS(179),
    [anon_sym_PIPE] = ACTIONS(181),
    [anon_sym_AMP] = ACTIONS(181),
    [anon_sym_PIPE_PIPE] = ACTIONS(179),
    [anon_sym_AMP_AMP] = ACTIONS(179),
    [anon_sym_LT] = ACTIONS(181),
    [anon_sym_LT_EQ] = ACTIONS(179),
    [anon_sym_GT] = ACTIONS(181),
    [anon_sym_GT_EQ] = ACTIONS(179),
    [anon_sym_EQ_EQ] = ACTIONS(179),
    [anon_sym_BANG_EQ] = ACTIONS(179),
    [anon_sym_STAR] = ACTIONS(181),
    [anon_sym_SLASH] = ACTIONS(179),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(179),
    [anon_sym_PIPE_GT] = ACTIONS(179),
    [anon_sym_COLON] = ACTIONS(181),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_close_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [221] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(181),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(179),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(181),
    [anon_sym_LT_DASH] = ACTIONS(179),
    [anon_sym_LT_LT_DASH] = ACTIONS(179),
    [anon_sym_COLON_EQ] = ACTIONS(179),
    [anon_sym_DASH_GT] = ACTIONS(181),
    [anon_sym_DASH_GT_GT] = ACTIONS(179),
    [anon_sym_PIPE] = ACTIONS(181),
    [anon_sym_AMP] = ACTIONS(181),
    [anon_sym_PIPE_PIPE] = ACTIONS(179),
    [anon_sym_AMP_AMP] = ACTIONS(179),
    [anon_sym_LT] = ACTIONS(181),
    [anon_sym_LT_EQ] = ACTIONS(179),
    [anon_sym_GT] = ACTIONS(181),
    [anon_sym_GT_EQ] = ACTIONS(179),
    [anon_sym_EQ_EQ] = ACTIONS(179),
    [anon_sym_BANG_EQ] = ACTIONS(179),
    [anon_sym_STAR] = ACTIONS(181),
    [anon_sym_SLASH] = ACTIONS(179),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(179),
    [anon_sym_PIPE_GT] = ACTIONS(179),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_close_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [222] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_BSLASH] = ACTIONS(179),
    [anon_sym_function] = ACTIONS(181),
    [anon_sym_EQ] = ACTIONS(181),
    [anon_sym_if] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(181),
    [anon_sym_while] = ACTIONS(181),
    [anon_sym_repeat] = ACTIONS(181),
    [anon_sym_QMARK] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(179),
    [anon_sym_BANG] = ACTIONS(181),
    [anon_sym_PLUS] = ACTIONS(179),
    [anon_sym_DASH] = ACTIONS(181),
    [anon_sym_LT_DASH] = ACTIONS(179),
    [anon_sym_LT_LT_DASH] = ACTIONS(179),
    [anon_sym_COLON_EQ] = ACTIONS(179),
    [anon_sym_DASH_GT] = ACTIONS(181),
    [anon_sym_DASH_GT_GT] = ACTIONS(179),
    [anon_sym_PIPE] = ACTIONS(181),
    [anon_sym_AMP] = ACTIONS(181),
    [anon_sym_PIPE_PIPE] = ACTIONS(179),
    [anon_sym_AMP_AMP] = ACTIONS(179),
    [anon_sym_LT] = ACTIONS(181),
    [anon_sym_LT_EQ] = ACTIONS(179),
    [anon_sym_GT] = ACTIONS(181),
    [anon_sym_GT_EQ] = ACTIONS(179),
    [anon_sym_EQ_EQ] = ACTIONS(179),
    [anon_sym_BANG_EQ] = ACTIONS(179),
    [anon_sym_STAR] = ACTIONS(181),
    [anon_sym_SLASH] = ACTIONS(179),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(179),
    [anon_sym_PIPE_GT] = ACTIONS(179),
    [anon_sym_COLON] = ACTIONS(181),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(179),
    [sym__number_literal] = ACTIONS(181),
    [anon_sym_SQUOTE] = ACTIONS(179),
    [anon_sym_DQUOTE] = ACTIONS(179),
    [sym_dots] = ACTIONS(181),
    [sym_dot_dot_i] = ACTIONS(181),
    [sym_next] = ACTIONS(181),
    [sym_break] = ACTIONS(181),
    [sym_true] = ACTIONS(181),
    [sym_false] = ACTIONS(181),
    [sym_null] = ACTIONS(181),
    [sym_inf] = ACTIONS(181),
    [sym_nan] = ACTIONS(181),
    [anon_sym_NA] = ACTIONS(181),
    [anon_sym_NA_integer_] = ACTIONS(181),
    [anon_sym_NA_real_] = ACTIONS(181),
    [anon_sym_NA_complex_] = ACTIONS(181),
    [anon_sym_NA_character_] = ACTIONS(181),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(179),
    [sym__semicolon] = ACTIONS(179),
    [sym__raw_string_open] = ACTIONS(179),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(179),
    [sym__external_close_brace] = ACTIONS(179),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [223] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(185),
    [anon_sym_BSLASH] = ACTIONS(183),
    [anon_sym_function] = ACTIONS(185),
    [anon_sym_EQ] = ACTIONS(247),
    [anon_sym_if] = ACTIONS(185),
    [anon_sym_for] = ACTIONS(185),
    [anon_sym_while] = ACTIONS(185),
    [anon_sym_repeat] = ACTIONS(185),
    [anon_sym_QMARK] = ACTIONS(183),
    [anon_sym_TILDE] = ACTIONS(249),
    [anon_sym_BANG] = ACTIONS(185),
    [anon_sym_PLUS] = ACTIONS(251),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_LT_DASH] = ACTIONS(255),
    [anon_sym_LT_LT_DASH] = ACTIONS(255),
    [anon_sym_COLON_EQ] = ACTIONS(255),
    [anon_sym_DASH_GT] = ACTIONS(257),
    [anon_sym_DASH_GT_GT] = ACTIONS(259),
    [anon_sym_PIPE] = ACTIONS(261),
    [anon_sym_AMP] = ACTIONS(263),
    [anon_sym_PIPE_PIPE] = ACTIONS(265),
    [anon_sym_AMP_AMP] = ACTIONS(267),
    [anon_sym_LT] = ACTIONS(269),
    [anon_sym_LT_EQ] = ACTIONS(271),
    [anon_sym_GT] = ACTIONS(269),
    [anon_sym_GT_EQ] = ACTIONS(271),
    [anon_sym_EQ_EQ] = ACTIONS(271),
    [anon_sym_BANG_EQ] = ACTIONS(271),
    [anon_sym_STAR] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(279),
    [anon_sym_PIPE_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(183),
    [sym__number_literal] = ACTIONS(185),
    [anon_sym_SQUOTE] = ACTIONS(183),
    [anon_sym_DQUOTE] = ACTIONS(183),
    [sym_dots] = ACTIONS(185),
    [sym_dot_dot_i] = ACTIONS(185),
    [sym_next] = ACTIONS(185),
    [sym_break] = ACTIONS(185),
    [sym_true] = ACTIONS(185),
    [sym_false] = ACTIONS(185),
    [sym_null] = ACTIONS(185),
    [sym_inf] = ACTIONS(185),
    [sym_nan] = ACTIONS(185),
    [anon_sym_NA] = ACTIONS(185),
    [anon_sym_NA_integer_] = ACTIONS(185),
    [anon_sym_NA_real_] = ACTIONS(185),
    [anon_sym_NA_complex_] = ACTIONS(185),
    [anon_sym_NA_character_] = ACTIONS(185),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(183),
    [sym__semicolon] = ACTIONS(183),
    [sym__raw_string_open] = ACTIONS(183),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(183),
    [sym__external_close_brace] = ACTIONS(183),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [224] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(189),
    [anon_sym_BSLASH] = ACTIONS(187),
    [anon_sym_function] = ACTIONS(189),
    [anon_sym_EQ] = ACTIONS(247),
    [anon_sym_if] = ACTIONS(189),
    [anon_sym_for] = ACTIONS(189),
    [anon_sym_while] = ACTIONS(189),
    [anon_sym_repeat] = ACTIONS(189),
    [anon_sym_QMARK] = ACTIONS(187),
    [anon_sym_TILDE] = ACTIONS(249),
    [anon_sym_BANG] = ACTIONS(189),
    [anon_sym_PLUS] = ACTIONS(251),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_LT_DASH] = ACTIONS(255),
    [anon_sym_LT_LT_DASH] = ACTIONS(255),
    [anon_sym_COLON_EQ] = ACTIONS(255),
    [anon_sym_DASH_GT] = ACTIONS(257),
    [anon_sym_DASH_GT_GT] = ACTIONS(259),
    [anon_sym_PIPE] = ACTIONS(261),
    [anon_sym_AMP] = ACTIONS(263),
    [anon_sym_PIPE_PIPE] = ACTIONS(265),
    [anon_sym_AMP_AMP] = ACTIONS(267),
    [anon_sym_LT] = ACTIONS(269),
    [anon_sym_LT_EQ] = ACTIONS(271),
    [anon_sym_GT] = ACTIONS(269),
    [anon_sym_GT_EQ] = ACTIONS(271),
    [anon_sym_EQ_EQ] = ACTIONS(271),
    [anon_sym_BANG_EQ] = ACTIONS(271),
    [anon_sym_STAR] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(279),
    [anon_sym_PIPE_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(187),
    [sym__number_literal] = ACTIONS(189),
    [anon_sym_SQUOTE] = ACTIONS(187),
    [anon_sym_DQUOTE] = ACTIONS(187),
    [sym_dots] = ACTIONS(189),
    [sym_dot_dot_i] = ACTIONS(189),
    [sym_next] = ACTIONS(189),
    [sym_break] = ACTIONS(189),
    [sym_true] = ACTIONS(189),
    [sym_false] = ACTIONS(189),
    [sym_null] = ACTIONS(189),
    [sym_inf] = ACTIONS(189),
    [sym_nan] = ACTIONS(189),
    [anon_sym_NA] = ACTIONS(189),
    [anon_sym_NA_integer_] = ACTIONS(189),
    [anon_sym_NA_real_] = ACTIONS(189),
    [anon_sym_NA_complex_] = ACTIONS(189),
    [anon_sym_NA_character_] = ACTIONS(189),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(187),
    [sym__semicolon] = ACTIONS(187),
    [sym__raw_string_open] = ACTIONS(187),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(187),
    [sym__external_close_brace] = ACTIONS(187),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [225] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(369),
    [sym_identifier] = ACTIONS(371),
    [anon_sym_BSLASH] = ACTIONS(369),
    [anon_sym_function] = ACTIONS(371),
    [anon_sym_EQ] = ACTIONS(339),
    [anon_sym_if] = ACTIONS(371),
    [anon_sym_for] = ACTIONS(371),
    [anon_sym_while] = ACTIONS(371),
    [anon_sym_repeat] = ACTIONS(371),
    [anon_sym_QMARK] = ACTIONS(373),
    [anon_sym_TILDE] = ACTIONS(341),
    [anon_sym_BANG] = ACTIONS(371),
    [anon_sym_PLUS] = ACTIONS(291),
    [anon_sym_DASH] = ACTIONS(293),
    [anon_sym_LT_DASH] = ACTIONS(347),
    [anon_sym_LT_LT_DASH] = ACTIONS(347),
    [anon_sym_COLON_EQ] = ACTIONS(347),
    [anon_sym_DASH_GT] = ACTIONS(343),
    [anon_sym_DASH_GT_GT] = ACTIONS(345),
    [anon_sym_PIPE] = ACTIONS(295),
    [anon_sym_AMP] = ACTIONS(297),
    [anon_sym_PIPE_PIPE] = ACTIONS(299),
    [anon_sym_AMP_AMP] = ACTIONS(301),
    [anon_sym_LT] = ACTIONS(303),
    [anon_sym_LT_EQ] = ACTIONS(305),
    [anon_sym_GT] = ACTIONS(303),
    [anon_sym_GT_EQ] = ACTIONS(305),
    [anon_sym_EQ_EQ] = ACTIONS(305),
    [anon_sym_BANG_EQ] = ACTIONS(305),
    [anon_sym_STAR] = ACTIONS(307),
    [anon_sym_SLASH] = ACTIONS(309),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(313),
    [anon_sym_PIPE_GT] = ACTIONS(313),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(369),
    [sym__number_literal] = ACTIONS(371),
    [anon_sym_SQUOTE] = ACTIONS(369),
    [anon_sym_DQUOTE] = ACTIONS(369),
    [sym_dots] = ACTIONS(371),
    [sym_dot_dot_i] = ACTIONS(371),
    [sym_next] = ACTIONS(371),
    [sym_break] = ACTIONS(371),
    [sym_true] = ACTIONS(371),
    [sym_false] = ACTIONS(371),
    [sym_null] = ACTIONS(371),
    [sym_inf] = ACTIONS(371),
    [sym_nan] = ACTIONS(371),
    [anon_sym_NA] = ACTIONS(371),
    [anon_sym_NA_integer_] = ACTIONS(371),
    [anon_sym_NA_real_] = ACTIONS(371),
    [anon_sym_NA_complex_] = ACTIONS(371),
    [anon_sym_NA_character_] = ACTIONS(371),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(369),
    [sym__semicolon] = ACTIONS(369),
    [sym__raw_string_open] = ACTIONS(369),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(369),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [226] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(193),
    [anon_sym_BSLASH] = ACTIONS(191),
    [anon_sym_function] = ACTIONS(193),
    [anon_sym_EQ] = ACTIONS(247),
    [anon_sym_if] = ACTIONS(193),
    [anon_sym_for] = ACTIONS(193),
    [anon_sym_while] = ACTIONS(193),
    [anon_sym_repeat] = ACTIONS(193),
    [anon_sym_QMARK] = ACTIONS(191),
    [anon_sym_TILDE] = ACTIONS(249),
    [anon_sym_BANG] = ACTIONS(193),
    [anon_sym_PLUS] = ACTIONS(251),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_LT_DASH] = ACTIONS(255),
    [anon_sym_LT_LT_DASH] = ACTIONS(255),
    [anon_sym_COLON_EQ] = ACTIONS(255),
    [anon_sym_DASH_GT] = ACTIONS(257),
    [anon_sym_DASH_GT_GT] = ACTIONS(259),
    [anon_sym_PIPE] = ACTIONS(261),
    [anon_sym_AMP] = ACTIONS(263),
    [anon_sym_PIPE_PIPE] = ACTIONS(265),
    [anon_sym_AMP_AMP] = ACTIONS(267),
    [anon_sym_LT] = ACTIONS(269),
    [anon_sym_LT_EQ] = ACTIONS(271),
    [anon_sym_GT] = ACTIONS(269),
    [anon_sym_GT_EQ] = ACTIONS(271),
    [anon_sym_EQ_EQ] = ACTIONS(271),
    [anon_sym_BANG_EQ] = ACTIONS(271),
    [anon_sym_STAR] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(279),
    [anon_sym_PIPE_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(191),
    [sym__number_literal] = ACTIONS(193),
    [anon_sym_SQUOTE] = ACTIONS(191),
    [anon_sym_DQUOTE] = ACTIONS(191),
    [sym_dots] = ACTIONS(193),
    [sym_dot_dot_i] = ACTIONS(193),
    [sym_next] = ACTIONS(193),
    [sym_break] = ACTIONS(193),
    [sym_true] = ACTIONS(193),
    [sym_false] = ACTIONS(193),
    [sym_null] = ACTIONS(193),
    [sym_inf] = ACTIONS(193),
    [sym_nan] = ACTIONS(193),
    [anon_sym_NA] = ACTIONS(193),
    [anon_sym_NA_integer_] = ACTIONS(193),
    [anon_sym_NA_real_] = ACTIONS(193),
    [anon_sym_NA_complex_] = ACTIONS(193),
    [anon_sym_NA_character_] = ACTIONS(193),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(191),
    [sym__semicolon] = ACTIONS(191),
    [sym__raw_string_open] = ACTIONS(191),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(191),
    [sym__external_close_brace] = ACTIONS(191),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [227] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(197),
    [anon_sym_BSLASH] = ACTIONS(195),
    [anon_sym_function] = ACTIONS(197),
    [anon_sym_EQ] = ACTIONS(247),
    [anon_sym_if] = ACTIONS(197),
    [anon_sym_for] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(197),
    [anon_sym_repeat] = ACTIONS(197),
    [anon_sym_QMARK] = ACTIONS(195),
    [anon_sym_TILDE] = ACTIONS(249),
    [anon_sym_BANG] = ACTIONS(197),
    [anon_sym_PLUS] = ACTIONS(251),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_LT_DASH] = ACTIONS(255),
    [anon_sym_LT_LT_DASH] = ACTIONS(255),
    [anon_sym_COLON_EQ] = ACTIONS(255),
    [anon_sym_DASH_GT] = ACTIONS(257),
    [anon_sym_DASH_GT_GT] = ACTIONS(259),
    [anon_sym_PIPE] = ACTIONS(261),
    [anon_sym_AMP] = ACTIONS(263),
    [anon_sym_PIPE_PIPE] = ACTIONS(265),
    [anon_sym_AMP_AMP] = ACTIONS(267),
    [anon_sym_LT] = ACTIONS(269),
    [anon_sym_LT_EQ] = ACTIONS(271),
    [anon_sym_GT] = ACTIONS(269),
    [anon_sym_GT_EQ] = ACTIONS(271),
    [anon_sym_EQ_EQ] = ACTIONS(271),
    [anon_sym_BANG_EQ] = ACTIONS(271),
    [anon_sym_STAR] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(279),
    [anon_sym_PIPE_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(195),
    [sym__number_literal] = ACTIONS(197),
    [anon_sym_SQUOTE] = ACTIONS(195),
    [anon_sym_DQUOTE] = ACTIONS(195),
    [sym_dots] = ACTIONS(197),
    [sym_dot_dot_i] = ACTIONS(197),
    [sym_next] = ACTIONS(197),
    [sym_break] = ACTIONS(197),
    [sym_true] = ACTIONS(197),
    [sym_false] = ACTIONS(197),
    [sym_null] = ACTIONS(197),
    [sym_inf] = ACTIONS(197),
    [sym_nan] = ACTIONS(197),
    [anon_sym_NA] = ACTIONS(197),
    [anon_sym_NA_integer_] = ACTIONS(197),
    [anon_sym_NA_real_] = ACTIONS(197),
    [anon_sym_NA_complex_] = ACTIONS(197),
    [anon_sym_NA_character_] = ACTIONS(197),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(195),
    [sym__semicolon] = ACTIONS(195),
    [sym__raw_string_open] = ACTIONS(195),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(195),
    [sym__external_close_brace] = ACTIONS(195),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [228] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(201),
    [anon_sym_BSLASH] = ACTIONS(199),
    [anon_sym_function] = ACTIONS(201),
    [anon_sym_EQ] = ACTIONS(247),
    [anon_sym_if] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(201),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_repeat] = ACTIONS(201),
    [anon_sym_QMARK] = ACTIONS(199),
    [anon_sym_TILDE] = ACTIONS(249),
    [anon_sym_BANG] = ACTIONS(201),
    [anon_sym_PLUS] = ACTIONS(251),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_LT_DASH] = ACTIONS(255),
    [anon_sym_LT_LT_DASH] = ACTIONS(255),
    [anon_sym_COLON_EQ] = ACTIONS(255),
    [anon_sym_DASH_GT] = ACTIONS(257),
    [anon_sym_DASH_GT_GT] = ACTIONS(259),
    [anon_sym_PIPE] = ACTIONS(261),
    [anon_sym_AMP] = ACTIONS(263),
    [anon_sym_PIPE_PIPE] = ACTIONS(265),
    [anon_sym_AMP_AMP] = ACTIONS(267),
    [anon_sym_LT] = ACTIONS(269),
    [anon_sym_LT_EQ] = ACTIONS(271),
    [anon_sym_GT] = ACTIONS(269),
    [anon_sym_GT_EQ] = ACTIONS(271),
    [anon_sym_EQ_EQ] = ACTIONS(271),
    [anon_sym_BANG_EQ] = ACTIONS(271),
    [anon_sym_STAR] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(279),
    [anon_sym_PIPE_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(199),
    [sym__number_literal] = ACTIONS(201),
    [anon_sym_SQUOTE] = ACTIONS(199),
    [anon_sym_DQUOTE] = ACTIONS(199),
    [sym_dots] = ACTIONS(201),
    [sym_dot_dot_i] = ACTIONS(201),
    [sym_next] = ACTIONS(201),
    [sym_break] = ACTIONS(201),
    [sym_true] = ACTIONS(201),
    [sym_false] = ACTIONS(201),
    [sym_null] = ACTIONS(201),
    [sym_inf] = ACTIONS(201),
    [sym_nan] = ACTIONS(201),
    [anon_sym_NA] = ACTIONS(201),
    [anon_sym_NA_integer_] = ACTIONS(201),
    [anon_sym_NA_real_] = ACTIONS(201),
    [anon_sym_NA_complex_] = ACTIONS(201),
    [anon_sym_NA_character_] = ACTIONS(201),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(199),
    [sym__semicolon] = ACTIONS(199),
    [sym__raw_string_open] = ACTIONS(199),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(199),
    [sym__external_close_brace] = ACTIONS(199),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [229] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(205),
    [anon_sym_BSLASH] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_EQ] = ACTIONS(247),
    [anon_sym_if] = ACTIONS(205),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_while] = ACTIONS(205),
    [anon_sym_repeat] = ACTIONS(205),
    [anon_sym_QMARK] = ACTIONS(203),
    [anon_sym_TILDE] = ACTIONS(249),
    [anon_sym_BANG] = ACTIONS(205),
    [anon_sym_PLUS] = ACTIONS(251),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_LT_DASH] = ACTIONS(255),
    [anon_sym_LT_LT_DASH] = ACTIONS(255),
    [anon_sym_COLON_EQ] = ACTIONS(255),
    [anon_sym_DASH_GT] = ACTIONS(257),
    [anon_sym_DASH_GT_GT] = ACTIONS(259),
    [anon_sym_PIPE] = ACTIONS(261),
    [anon_sym_AMP] = ACTIONS(263),
    [anon_sym_PIPE_PIPE] = ACTIONS(265),
    [anon_sym_AMP_AMP] = ACTIONS(267),
    [anon_sym_LT] = ACTIONS(269),
    [anon_sym_LT_EQ] = ACTIONS(271),
    [anon_sym_GT] = ACTIONS(269),
    [anon_sym_GT_EQ] = ACTIONS(271),
    [anon_sym_EQ_EQ] = ACTIONS(271),
    [anon_sym_BANG_EQ] = ACTIONS(271),
    [anon_sym_STAR] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(279),
    [anon_sym_PIPE_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(203),
    [sym__number_literal] = ACTIONS(205),
    [anon_sym_SQUOTE] = ACTIONS(203),
    [anon_sym_DQUOTE] = ACTIONS(203),
    [sym_dots] = ACTIONS(205),
    [sym_dot_dot_i] = ACTIONS(205),
    [sym_next] = ACTIONS(205),
    [sym_break] = ACTIONS(205),
    [sym_true] = ACTIONS(205),
    [sym_false] = ACTIONS(205),
    [sym_null] = ACTIONS(205),
    [sym_inf] = ACTIONS(205),
    [sym_nan] = ACTIONS(205),
    [anon_sym_NA] = ACTIONS(205),
    [anon_sym_NA_integer_] = ACTIONS(205),
    [anon_sym_NA_real_] = ACTIONS(205),
    [anon_sym_NA_complex_] = ACTIONS(205),
    [anon_sym_NA_character_] = ACTIONS(205),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(203),
    [sym__semicolon] = ACTIONS(203),
    [sym__raw_string_open] = ACTIONS(203),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(203),
    [sym__external_close_brace] = ACTIONS(203),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [230] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(209),
    [anon_sym_BSLASH] = ACTIONS(207),
    [anon_sym_function] = ACTIONS(209),
    [anon_sym_EQ] = ACTIONS(247),
    [anon_sym_if] = ACTIONS(209),
    [anon_sym_for] = ACTIONS(209),
    [anon_sym_while] = ACTIONS(209),
    [anon_sym_repeat] = ACTIONS(209),
    [anon_sym_QMARK] = ACTIONS(207),
    [anon_sym_TILDE] = ACTIONS(249),
    [anon_sym_BANG] = ACTIONS(209),
    [anon_sym_PLUS] = ACTIONS(251),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_LT_DASH] = ACTIONS(255),
    [anon_sym_LT_LT_DASH] = ACTIONS(255),
    [anon_sym_COLON_EQ] = ACTIONS(255),
    [anon_sym_DASH_GT] = ACTIONS(257),
    [anon_sym_DASH_GT_GT] = ACTIONS(259),
    [anon_sym_PIPE] = ACTIONS(261),
    [anon_sym_AMP] = ACTIONS(263),
    [anon_sym_PIPE_PIPE] = ACTIONS(265),
    [anon_sym_AMP_AMP] = ACTIONS(267),
    [anon_sym_LT] = ACTIONS(269),
    [anon_sym_LT_EQ] = ACTIONS(271),
    [anon_sym_GT] = ACTIONS(269),
    [anon_sym_GT_EQ] = ACTIONS(271),
    [anon_sym_EQ_EQ] = ACTIONS(271),
    [anon_sym_BANG_EQ] = ACTIONS(271),
    [anon_sym_STAR] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(279),
    [anon_sym_PIPE_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(207),
    [sym__number_literal] = ACTIONS(209),
    [anon_sym_SQUOTE] = ACTIONS(207),
    [anon_sym_DQUOTE] = ACTIONS(207),
    [sym_dots] = ACTIONS(209),
    [sym_dot_dot_i] = ACTIONS(209),
    [sym_next] = ACTIONS(209),
    [sym_break] = ACTIONS(209),
    [sym_true] = ACTIONS(209),
    [sym_false] = ACTIONS(209),
    [sym_null] = ACTIONS(209),
    [sym_inf] = ACTIONS(209),
    [sym_nan] = ACTIONS(209),
    [anon_sym_NA] = ACTIONS(209),
    [anon_sym_NA_integer_] = ACTIONS(209),
    [anon_sym_NA_real_] = ACTIONS(209),
    [anon_sym_NA_complex_] = ACTIONS(209),
    [anon_sym_NA_character_] = ACTIONS(209),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(207),
    [sym__semicolon] = ACTIONS(207),
    [sym__raw_string_open] = ACTIONS(207),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(207),
    [sym__external_close_brace] = ACTIONS(207),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [231] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(213),
    [anon_sym_BSLASH] = ACTIONS(211),
    [anon_sym_function] = ACTIONS(213),
    [anon_sym_EQ] = ACTIONS(247),
    [anon_sym_if] = ACTIONS(213),
    [anon_sym_for] = ACTIONS(213),
    [anon_sym_while] = ACTIONS(213),
    [anon_sym_repeat] = ACTIONS(213),
    [anon_sym_QMARK] = ACTIONS(211),
    [anon_sym_TILDE] = ACTIONS(249),
    [anon_sym_BANG] = ACTIONS(213),
    [anon_sym_PLUS] = ACTIONS(251),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_LT_DASH] = ACTIONS(255),
    [anon_sym_LT_LT_DASH] = ACTIONS(255),
    [anon_sym_COLON_EQ] = ACTIONS(255),
    [anon_sym_DASH_GT] = ACTIONS(257),
    [anon_sym_DASH_GT_GT] = ACTIONS(259),
    [anon_sym_PIPE] = ACTIONS(261),
    [anon_sym_AMP] = ACTIONS(263),
    [anon_sym_PIPE_PIPE] = ACTIONS(265),
    [anon_sym_AMP_AMP] = ACTIONS(267),
    [anon_sym_LT] = ACTIONS(269),
    [anon_sym_LT_EQ] = ACTIONS(271),
    [anon_sym_GT] = ACTIONS(269),
    [anon_sym_GT_EQ] = ACTIONS(271),
    [anon_sym_EQ_EQ] = ACTIONS(271),
    [anon_sym_BANG_EQ] = ACTIONS(271),
    [anon_sym_STAR] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(279),
    [anon_sym_PIPE_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(211),
    [sym__number_literal] = ACTIONS(213),
    [anon_sym_SQUOTE] = ACTIONS(211),
    [anon_sym_DQUOTE] = ACTIONS(211),
    [sym_dots] = ACTIONS(213),
    [sym_dot_dot_i] = ACTIONS(213),
    [sym_next] = ACTIONS(213),
    [sym_break] = ACTIONS(213),
    [sym_true] = ACTIONS(213),
    [sym_false] = ACTIONS(213),
    [sym_null] = ACTIONS(213),
    [sym_inf] = ACTIONS(213),
    [sym_nan] = ACTIONS(213),
    [anon_sym_NA] = ACTIONS(213),
    [anon_sym_NA_integer_] = ACTIONS(213),
    [anon_sym_NA_real_] = ACTIONS(213),
    [anon_sym_NA_complex_] = ACTIONS(213),
    [anon_sym_NA_character_] = ACTIONS(213),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(211),
    [sym__semicolon] = ACTIONS(211),
    [sym__raw_string_open] = ACTIONS(211),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(211),
    [sym__external_close_brace] = ACTIONS(211),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [232] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(217),
    [anon_sym_BSLASH] = ACTIONS(215),
    [anon_sym_function] = ACTIONS(217),
    [anon_sym_EQ] = ACTIONS(247),
    [anon_sym_if] = ACTIONS(217),
    [anon_sym_for] = ACTIONS(217),
    [anon_sym_while] = ACTIONS(217),
    [anon_sym_repeat] = ACTIONS(217),
    [anon_sym_QMARK] = ACTIONS(215),
    [anon_sym_TILDE] = ACTIONS(249),
    [anon_sym_BANG] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(251),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_LT_DASH] = ACTIONS(255),
    [anon_sym_LT_LT_DASH] = ACTIONS(255),
    [anon_sym_COLON_EQ] = ACTIONS(255),
    [anon_sym_DASH_GT] = ACTIONS(257),
    [anon_sym_DASH_GT_GT] = ACTIONS(259),
    [anon_sym_PIPE] = ACTIONS(261),
    [anon_sym_AMP] = ACTIONS(263),
    [anon_sym_PIPE_PIPE] = ACTIONS(265),
    [anon_sym_AMP_AMP] = ACTIONS(267),
    [anon_sym_LT] = ACTIONS(269),
    [anon_sym_LT_EQ] = ACTIONS(271),
    [anon_sym_GT] = ACTIONS(269),
    [anon_sym_GT_EQ] = ACTIONS(271),
    [anon_sym_EQ_EQ] = ACTIONS(271),
    [anon_sym_BANG_EQ] = ACTIONS(271),
    [anon_sym_STAR] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(279),
    [anon_sym_PIPE_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(215),
    [sym__number_literal] = ACTIONS(217),
    [anon_sym_SQUOTE] = ACTIONS(215),
    [anon_sym_DQUOTE] = ACTIONS(215),
    [sym_dots] = ACTIONS(217),
    [sym_dot_dot_i] = ACTIONS(217),
    [sym_next] = ACTIONS(217),
    [sym_break] = ACTIONS(217),
    [sym_true] = ACTIONS(217),
    [sym_false] = ACTIONS(217),
    [sym_null] = ACTIONS(217),
    [sym_inf] = ACTIONS(217),
    [sym_nan] = ACTIONS(217),
    [anon_sym_NA] = ACTIONS(217),
    [anon_sym_NA_integer_] = ACTIONS(217),
    [anon_sym_NA_real_] = ACTIONS(217),
    [anon_sym_NA_complex_] = ACTIONS(217),
    [anon_sym_NA_character_] = ACTIONS(217),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(215),
    [sym__semicolon] = ACTIONS(215),
    [sym__raw_string_open] = ACTIONS(215),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(215),
    [sym__external_close_brace] = ACTIONS(215),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [233] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(221),
    [anon_sym_BSLASH] = ACTIONS(219),
    [anon_sym_function] = ACTIONS(221),
    [anon_sym_EQ] = ACTIONS(247),
    [anon_sym_if] = ACTIONS(221),
    [anon_sym_for] = ACTIONS(221),
    [anon_sym_while] = ACTIONS(221),
    [anon_sym_repeat] = ACTIONS(221),
    [anon_sym_QMARK] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(249),
    [anon_sym_BANG] = ACTIONS(221),
    [anon_sym_PLUS] = ACTIONS(251),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_LT_DASH] = ACTIONS(255),
    [anon_sym_LT_LT_DASH] = ACTIONS(255),
    [anon_sym_COLON_EQ] = ACTIONS(255),
    [anon_sym_DASH_GT] = ACTIONS(257),
    [anon_sym_DASH_GT_GT] = ACTIONS(259),
    [anon_sym_PIPE] = ACTIONS(261),
    [anon_sym_AMP] = ACTIONS(263),
    [anon_sym_PIPE_PIPE] = ACTIONS(265),
    [anon_sym_AMP_AMP] = ACTIONS(267),
    [anon_sym_LT] = ACTIONS(269),
    [anon_sym_LT_EQ] = ACTIONS(271),
    [anon_sym_GT] = ACTIONS(269),
    [anon_sym_GT_EQ] = ACTIONS(271),
    [anon_sym_EQ_EQ] = ACTIONS(271),
    [anon_sym_BANG_EQ] = ACTIONS(271),
    [anon_sym_STAR] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(279),
    [anon_sym_PIPE_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(219),
    [sym__number_literal] = ACTIONS(221),
    [anon_sym_SQUOTE] = ACTIONS(219),
    [anon_sym_DQUOTE] = ACTIONS(219),
    [sym_dots] = ACTIONS(221),
    [sym_dot_dot_i] = ACTIONS(221),
    [sym_next] = ACTIONS(221),
    [sym_break] = ACTIONS(221),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [sym_null] = ACTIONS(221),
    [sym_inf] = ACTIONS(221),
    [sym_nan] = ACTIONS(221),
    [anon_sym_NA] = ACTIONS(221),
    [anon_sym_NA_integer_] = ACTIONS(221),
    [anon_sym_NA_real_] = ACTIONS(221),
    [anon_sym_NA_complex_] = ACTIONS(221),
    [anon_sym_NA_character_] = ACTIONS(221),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(219),
    [sym__semicolon] = ACTIONS(219),
    [sym__raw_string_open] = ACTIONS(219),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(219),
    [sym__external_close_brace] = ACTIONS(219),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [234] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(225),
    [anon_sym_BSLASH] = ACTIONS(223),
    [anon_sym_function] = ACTIONS(225),
    [anon_sym_EQ] = ACTIONS(247),
    [anon_sym_if] = ACTIONS(225),
    [anon_sym_for] = ACTIONS(225),
    [anon_sym_while] = ACTIONS(225),
    [anon_sym_repeat] = ACTIONS(225),
    [anon_sym_QMARK] = ACTIONS(223),
    [anon_sym_TILDE] = ACTIONS(249),
    [anon_sym_BANG] = ACTIONS(225),
    [anon_sym_PLUS] = ACTIONS(251),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_LT_DASH] = ACTIONS(255),
    [anon_sym_LT_LT_DASH] = ACTIONS(255),
    [anon_sym_COLON_EQ] = ACTIONS(255),
    [anon_sym_DASH_GT] = ACTIONS(257),
    [anon_sym_DASH_GT_GT] = ACTIONS(259),
    [anon_sym_PIPE] = ACTIONS(261),
    [anon_sym_AMP] = ACTIONS(263),
    [anon_sym_PIPE_PIPE] = ACTIONS(265),
    [anon_sym_AMP_AMP] = ACTIONS(267),
    [anon_sym_LT] = ACTIONS(269),
    [anon_sym_LT_EQ] = ACTIONS(271),
    [anon_sym_GT] = ACTIONS(269),
    [anon_sym_GT_EQ] = ACTIONS(271),
    [anon_sym_EQ_EQ] = ACTIONS(271),
    [anon_sym_BANG_EQ] = ACTIONS(271),
    [anon_sym_STAR] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(279),
    [anon_sym_PIPE_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(223),
    [sym__number_literal] = ACTIONS(225),
    [anon_sym_SQUOTE] = ACTIONS(223),
    [anon_sym_DQUOTE] = ACTIONS(223),
    [sym_dots] = ACTIONS(225),
    [sym_dot_dot_i] = ACTIONS(225),
    [sym_next] = ACTIONS(225),
    [sym_break] = ACTIONS(225),
    [sym_true] = ACTIONS(225),
    [sym_false] = ACTIONS(225),
    [sym_null] = ACTIONS(225),
    [sym_inf] = ACTIONS(225),
    [sym_nan] = ACTIONS(225),
    [anon_sym_NA] = ACTIONS(225),
    [anon_sym_NA_integer_] = ACTIONS(225),
    [anon_sym_NA_real_] = ACTIONS(225),
    [anon_sym_NA_complex_] = ACTIONS(225),
    [anon_sym_NA_character_] = ACTIONS(225),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(223),
    [sym__semicolon] = ACTIONS(223),
    [sym__raw_string_open] = ACTIONS(223),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(223),
    [sym__external_close_brace] = ACTIONS(223),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [235] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(229),
    [anon_sym_BSLASH] = ACTIONS(227),
    [anon_sym_function] = ACTIONS(229),
    [anon_sym_EQ] = ACTIONS(247),
    [anon_sym_if] = ACTIONS(229),
    [anon_sym_for] = ACTIONS(229),
    [anon_sym_while] = ACTIONS(229),
    [anon_sym_repeat] = ACTIONS(229),
    [anon_sym_QMARK] = ACTIONS(227),
    [anon_sym_TILDE] = ACTIONS(249),
    [anon_sym_BANG] = ACTIONS(229),
    [anon_sym_PLUS] = ACTIONS(251),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_LT_DASH] = ACTIONS(255),
    [anon_sym_LT_LT_DASH] = ACTIONS(255),
    [anon_sym_COLON_EQ] = ACTIONS(255),
    [anon_sym_DASH_GT] = ACTIONS(257),
    [anon_sym_DASH_GT_GT] = ACTIONS(259),
    [anon_sym_PIPE] = ACTIONS(261),
    [anon_sym_AMP] = ACTIONS(263),
    [anon_sym_PIPE_PIPE] = ACTIONS(265),
    [anon_sym_AMP_AMP] = ACTIONS(267),
    [anon_sym_LT] = ACTIONS(269),
    [anon_sym_LT_EQ] = ACTIONS(271),
    [anon_sym_GT] = ACTIONS(269),
    [anon_sym_GT_EQ] = ACTIONS(271),
    [anon_sym_EQ_EQ] = ACTIONS(271),
    [anon_sym_BANG_EQ] = ACTIONS(271),
    [anon_sym_STAR] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(279),
    [anon_sym_PIPE_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(227),
    [sym__number_literal] = ACTIONS(229),
    [anon_sym_SQUOTE] = ACTIONS(227),
    [anon_sym_DQUOTE] = ACTIONS(227),
    [sym_dots] = ACTIONS(229),
    [sym_dot_dot_i] = ACTIONS(229),
    [sym_next] = ACTIONS(229),
    [sym_break] = ACTIONS(229),
    [sym_true] = ACTIONS(229),
    [sym_false] = ACTIONS(229),
    [sym_null] = ACTIONS(229),
    [sym_inf] = ACTIONS(229),
    [sym_nan] = ACTIONS(229),
    [anon_sym_NA] = ACTIONS(229),
    [anon_sym_NA_integer_] = ACTIONS(229),
    [anon_sym_NA_real_] = ACTIONS(229),
    [anon_sym_NA_complex_] = ACTIONS(229),
    [anon_sym_NA_character_] = ACTIONS(229),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(227),
    [sym__semicolon] = ACTIONS(227),
    [sym__raw_string_open] = ACTIONS(227),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(227),
    [sym__external_close_brace] = ACTIONS(227),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [236] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(233),
    [anon_sym_BSLASH] = ACTIONS(231),
    [anon_sym_function] = ACTIONS(233),
    [anon_sym_EQ] = ACTIONS(247),
    [anon_sym_if] = ACTIONS(233),
    [anon_sym_for] = ACTIONS(233),
    [anon_sym_while] = ACTIONS(233),
    [anon_sym_repeat] = ACTIONS(233),
    [anon_sym_QMARK] = ACTIONS(231),
    [anon_sym_TILDE] = ACTIONS(249),
    [anon_sym_BANG] = ACTIONS(233),
    [anon_sym_PLUS] = ACTIONS(251),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_LT_DASH] = ACTIONS(255),
    [anon_sym_LT_LT_DASH] = ACTIONS(255),
    [anon_sym_COLON_EQ] = ACTIONS(255),
    [anon_sym_DASH_GT] = ACTIONS(257),
    [anon_sym_DASH_GT_GT] = ACTIONS(259),
    [anon_sym_PIPE] = ACTIONS(261),
    [anon_sym_AMP] = ACTIONS(263),
    [anon_sym_PIPE_PIPE] = ACTIONS(265),
    [anon_sym_AMP_AMP] = ACTIONS(267),
    [anon_sym_LT] = ACTIONS(269),
    [anon_sym_LT_EQ] = ACTIONS(271),
    [anon_sym_GT] = ACTIONS(269),
    [anon_sym_GT_EQ] = ACTIONS(271),
    [anon_sym_EQ_EQ] = ACTIONS(271),
    [anon_sym_BANG_EQ] = ACTIONS(271),
    [anon_sym_STAR] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(279),
    [anon_sym_PIPE_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(231),
    [sym__number_literal] = ACTIONS(233),
    [anon_sym_SQUOTE] = ACTIONS(231),
    [anon_sym_DQUOTE] = ACTIONS(231),
    [sym_dots] = ACTIONS(233),
    [sym_dot_dot_i] = ACTIONS(233),
    [sym_next] = ACTIONS(233),
    [sym_break] = ACTIONS(233),
    [sym_true] = ACTIONS(233),
    [sym_false] = ACTIONS(233),
    [sym_null] = ACTIONS(233),
    [sym_inf] = ACTIONS(233),
    [sym_nan] = ACTIONS(233),
    [anon_sym_NA] = ACTIONS(233),
    [anon_sym_NA_integer_] = ACTIONS(233),
    [anon_sym_NA_real_] = ACTIONS(233),
    [anon_sym_NA_complex_] = ACTIONS(233),
    [anon_sym_NA_character_] = ACTIONS(233),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(231),
    [sym__semicolon] = ACTIONS(231),
    [sym__raw_string_open] = ACTIONS(231),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(231),
    [sym__external_close_brace] = ACTIONS(231),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [237] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(237),
    [anon_sym_BSLASH] = ACTIONS(235),
    [anon_sym_function] = ACTIONS(237),
    [anon_sym_EQ] = ACTIONS(247),
    [anon_sym_if] = ACTIONS(237),
    [anon_sym_for] = ACTIONS(237),
    [anon_sym_while] = ACTIONS(237),
    [anon_sym_repeat] = ACTIONS(237),
    [anon_sym_QMARK] = ACTIONS(235),
    [anon_sym_TILDE] = ACTIONS(249),
    [anon_sym_BANG] = ACTIONS(237),
    [anon_sym_PLUS] = ACTIONS(251),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_LT_DASH] = ACTIONS(255),
    [anon_sym_LT_LT_DASH] = ACTIONS(255),
    [anon_sym_COLON_EQ] = ACTIONS(255),
    [anon_sym_DASH_GT] = ACTIONS(257),
    [anon_sym_DASH_GT_GT] = ACTIONS(259),
    [anon_sym_PIPE] = ACTIONS(261),
    [anon_sym_AMP] = ACTIONS(263),
    [anon_sym_PIPE_PIPE] = ACTIONS(265),
    [anon_sym_AMP_AMP] = ACTIONS(267),
    [anon_sym_LT] = ACTIONS(269),
    [anon_sym_LT_EQ] = ACTIONS(271),
    [anon_sym_GT] = ACTIONS(269),
    [anon_sym_GT_EQ] = ACTIONS(271),
    [anon_sym_EQ_EQ] = ACTIONS(271),
    [anon_sym_BANG_EQ] = ACTIONS(271),
    [anon_sym_STAR] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(279),
    [anon_sym_PIPE_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(235),
    [sym__number_literal] = ACTIONS(237),
    [anon_sym_SQUOTE] = ACTIONS(235),
    [anon_sym_DQUOTE] = ACTIONS(235),
    [sym_dots] = ACTIONS(237),
    [sym_dot_dot_i] = ACTIONS(237),
    [sym_next] = ACTIONS(237),
    [sym_break] = ACTIONS(237),
    [sym_true] = ACTIONS(237),
    [sym_false] = ACTIONS(237),
    [sym_null] = ACTIONS(237),
    [sym_inf] = ACTIONS(237),
    [sym_nan] = ACTIONS(237),
    [anon_sym_NA] = ACTIONS(237),
    [anon_sym_NA_integer_] = ACTIONS(237),
    [anon_sym_NA_real_] = ACTIONS(237),
    [anon_sym_NA_complex_] = ACTIONS(237),
    [anon_sym_NA_character_] = ACTIONS(237),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(235),
    [sym__semicolon] = ACTIONS(235),
    [sym__raw_string_open] = ACTIONS(235),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(235),
    [sym__external_close_brace] = ACTIONS(235),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [238] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(241),
    [anon_sym_BSLASH] = ACTIONS(239),
    [anon_sym_function] = ACTIONS(241),
    [anon_sym_EQ] = ACTIONS(247),
    [anon_sym_if] = ACTIONS(241),
    [anon_sym_for] = ACTIONS(241),
    [anon_sym_while] = ACTIONS(241),
    [anon_sym_repeat] = ACTIONS(241),
    [anon_sym_QMARK] = ACTIONS(239),
    [anon_sym_TILDE] = ACTIONS(249),
    [anon_sym_BANG] = ACTIONS(241),
    [anon_sym_PLUS] = ACTIONS(251),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_LT_DASH] = ACTIONS(255),
    [anon_sym_LT_LT_DASH] = ACTIONS(255),
    [anon_sym_COLON_EQ] = ACTIONS(255),
    [anon_sym_DASH_GT] = ACTIONS(257),
    [anon_sym_DASH_GT_GT] = ACTIONS(259),
    [anon_sym_PIPE] = ACTIONS(261),
    [anon_sym_AMP] = ACTIONS(263),
    [anon_sym_PIPE_PIPE] = ACTIONS(265),
    [anon_sym_AMP_AMP] = ACTIONS(267),
    [anon_sym_LT] = ACTIONS(269),
    [anon_sym_LT_EQ] = ACTIONS(271),
    [anon_sym_GT] = ACTIONS(269),
    [anon_sym_GT_EQ] = ACTIONS(271),
    [anon_sym_EQ_EQ] = ACTIONS(271),
    [anon_sym_BANG_EQ] = ACTIONS(271),
    [anon_sym_STAR] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(279),
    [anon_sym_PIPE_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(239),
    [sym__number_literal] = ACTIONS(241),
    [anon_sym_SQUOTE] = ACTIONS(239),
    [anon_sym_DQUOTE] = ACTIONS(239),
    [sym_dots] = ACTIONS(241),
    [sym_dot_dot_i] = ACTIONS(241),
    [sym_next] = ACTIONS(241),
    [sym_break] = ACTIONS(241),
    [sym_true] = ACTIONS(241),
    [sym_false] = ACTIONS(241),
    [sym_null] = ACTIONS(241),
    [sym_inf] = ACTIONS(241),
    [sym_nan] = ACTIONS(241),
    [anon_sym_NA] = ACTIONS(241),
    [anon_sym_NA_integer_] = ACTIONS(241),
    [anon_sym_NA_real_] = ACTIONS(241),
    [anon_sym_NA_complex_] = ACTIONS(241),
    [anon_sym_NA_character_] = ACTIONS(241),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(239),
    [sym__semicolon] = ACTIONS(239),
    [sym__raw_string_open] = ACTIONS(239),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(239),
    [sym__external_close_brace] = ACTIONS(239),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [239] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(245),
    [anon_sym_BSLASH] = ACTIONS(243),
    [anon_sym_function] = ACTIONS(245),
    [anon_sym_EQ] = ACTIONS(247),
    [anon_sym_if] = ACTIONS(245),
    [anon_sym_for] = ACTIONS(245),
    [anon_sym_while] = ACTIONS(245),
    [anon_sym_repeat] = ACTIONS(245),
    [anon_sym_QMARK] = ACTIONS(243),
    [anon_sym_TILDE] = ACTIONS(249),
    [anon_sym_BANG] = ACTIONS(245),
    [anon_sym_PLUS] = ACTIONS(251),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_LT_DASH] = ACTIONS(255),
    [anon_sym_LT_LT_DASH] = ACTIONS(255),
    [anon_sym_COLON_EQ] = ACTIONS(255),
    [anon_sym_DASH_GT] = ACTIONS(257),
    [anon_sym_DASH_GT_GT] = ACTIONS(259),
    [anon_sym_PIPE] = ACTIONS(261),
    [anon_sym_AMP] = ACTIONS(263),
    [anon_sym_PIPE_PIPE] = ACTIONS(265),
    [anon_sym_AMP_AMP] = ACTIONS(267),
    [anon_sym_LT] = ACTIONS(269),
    [anon_sym_LT_EQ] = ACTIONS(271),
    [anon_sym_GT] = ACTIONS(269),
    [anon_sym_GT_EQ] = ACTIONS(271),
    [anon_sym_EQ_EQ] = ACTIONS(271),
    [anon_sym_BANG_EQ] = ACTIONS(271),
    [anon_sym_STAR] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(279),
    [anon_sym_PIPE_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(243),
    [sym__number_literal] = ACTIONS(245),
    [anon_sym_SQUOTE] = ACTIONS(243),
    [anon_sym_DQUOTE] = ACTIONS(243),
    [sym_dots] = ACTIONS(245),
    [sym_dot_dot_i] = ACTIONS(245),
    [sym_next] = ACTIONS(245),
    [sym_break] = ACTIONS(245),
    [sym_true] = ACTIONS(245),
    [sym_false] = ACTIONS(245),
    [sym_null] = ACTIONS(245),
    [sym_inf] = ACTIONS(245),
    [sym_nan] = ACTIONS(245),
    [anon_sym_NA] = ACTIONS(245),
    [anon_sym_NA_integer_] = ACTIONS(245),
    [anon_sym_NA_real_] = ACTIONS(245),
    [anon_sym_NA_complex_] = ACTIONS(245),
    [anon_sym_NA_character_] = ACTIONS(245),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(243),
    [sym__semicolon] = ACTIONS(243),
    [sym__raw_string_open] = ACTIONS(243),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(243),
    [sym__external_close_brace] = ACTIONS(243),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [240] = {
    [sym_call_arguments] = STATE(449),
    [sym_subset_arguments] = STATE(428),
    [sym_subset2_arguments] = STATE(418),
    [sym__open_parenthesis] = STATE(283),
    [sym__open_bracket] = STATE(263),
    [sym__open_bracket2] = STATE(264),
    [sym_identifier] = ACTIONS(147),
    [anon_sym_BSLASH] = ACTIONS(149),
    [anon_sym_function] = ACTIONS(147),
    [anon_sym_EQ] = ACTIONS(247),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_for] = ACTIONS(147),
    [anon_sym_while] = ACTIONS(147),
    [anon_sym_repeat] = ACTIONS(147),
    [anon_sym_QMARK] = ACTIONS(149),
    [anon_sym_TILDE] = ACTIONS(249),
    [anon_sym_BANG] = ACTIONS(147),
    [anon_sym_PLUS] = ACTIONS(251),
    [anon_sym_DASH] = ACTIONS(253),
    [anon_sym_LT_DASH] = ACTIONS(255),
    [anon_sym_LT_LT_DASH] = ACTIONS(255),
    [anon_sym_COLON_EQ] = ACTIONS(255),
    [anon_sym_DASH_GT] = ACTIONS(257),
    [anon_sym_DASH_GT_GT] = ACTIONS(259),
    [anon_sym_PIPE] = ACTIONS(261),
    [anon_sym_AMP] = ACTIONS(263),
    [anon_sym_PIPE_PIPE] = ACTIONS(265),
    [anon_sym_AMP_AMP] = ACTIONS(267),
    [anon_sym_LT] = ACTIONS(269),
    [anon_sym_LT_EQ] = ACTIONS(271),
    [anon_sym_GT] = ACTIONS(269),
    [anon_sym_GT_EQ] = ACTIONS(271),
    [anon_sym_EQ_EQ] = ACTIONS(271),
    [anon_sym_BANG_EQ] = ACTIONS(271),
    [anon_sym_STAR] = ACTIONS(273),
    [anon_sym_SLASH] = ACTIONS(275),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [aux_sym_binary_operator_token1] = ACTIONS(279),
    [anon_sym_PIPE_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(281),
    [anon_sym_DOLLAR] = ACTIONS(283),
    [anon_sym_AT] = ACTIONS(283),
    [sym__hex_literal] = ACTIONS(149),
    [sym__number_literal] = ACTIONS(147),
    [anon_sym_SQUOTE] = ACTIONS(149),
    [anon_sym_DQUOTE] = ACTIONS(149),
    [sym_dots] = ACTIONS(147),
    [sym_dot_dot_i] = ACTIONS(147),
    [sym_next] = ACTIONS(147),
    [sym_break] = ACTIONS(147),
    [sym_true] = ACTIONS(147),
    [sym_false] = ACTIONS(147),
    [sym_null] = ACTIONS(147),
    [sym_inf] = ACTIONS(147),
    [sym_nan] = ACTIONS(147),
    [anon_sym_NA] = ACTIONS(147),
    [anon_sym_NA_integer_] = ACTIONS(147),
    [anon_sym_NA_real_] = ACTIONS(147),
    [anon_sym_NA_complex_] = ACTIONS(147),
    [anon_sym_NA_character_] = ACTIONS(147),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(149),
    [sym__semicolon] = ACTIONS(149),
    [sym__raw_string_open] = ACTIONS(149),
    [sym__external_open_parenthesis] = ACTIONS(285),
    [sym__external_open_brace] = ACTIONS(149),
    [sym__external_close_brace] = ACTIONS(149),
    [sym__external_open_bracket] = ACTIONS(287),
    [sym__external_open_bracket2] = ACTIONS(289),
  },
  [241] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(159),
    [sym_identifier] = ACTIONS(161),
    [anon_sym_BSLASH] = ACTIONS(159),
    [anon_sym_function] = ACTIONS(161),
    [anon_sym_EQ] = ACTIONS(339),
    [anon_sym_if] = ACTIONS(161),
    [anon_sym_for] = ACTIONS(161),
    [anon_sym_while] = ACTIONS(161),
    [anon_sym_repeat] = ACTIONS(161),
    [anon_sym_QMARK] = ACTIONS(159),
    [anon_sym_TILDE] = ACTIONS(341),
    [anon_sym_BANG] = ACTIONS(161),
    [anon_sym_PLUS] = ACTIONS(291),
    [anon_sym_DASH] = ACTIONS(293),
    [anon_sym_LT_DASH] = ACTIONS(347),
    [anon_sym_LT_LT_DASH] = ACTIONS(347),
    [anon_sym_COLON_EQ] = ACTIONS(347),
    [anon_sym_DASH_GT] = ACTIONS(343),
    [anon_sym_DASH_GT_GT] = ACTIONS(345),
    [anon_sym_PIPE] = ACTIONS(295),
    [anon_sym_AMP] = ACTIONS(297),
    [anon_sym_PIPE_PIPE] = ACTIONS(299),
    [anon_sym_AMP_AMP] = ACTIONS(301),
    [anon_sym_LT] = ACTIONS(303),
    [anon_sym_LT_EQ] = ACTIONS(305),
    [anon_sym_GT] = ACTIONS(303),
    [anon_sym_GT_EQ] = ACTIONS(305),
    [anon_sym_EQ_EQ] = ACTIONS(305),
    [anon_sym_BANG_EQ] = ACTIONS(305),
    [anon_sym_STAR] = ACTIONS(307),
    [anon_sym_SLASH] = ACTIONS(309),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(313),
    [anon_sym_PIPE_GT] = ACTIONS(313),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(159),
    [sym__number_literal] = ACTIONS(161),
    [anon_sym_SQUOTE] = ACTIONS(159),
    [anon_sym_DQUOTE] = ACTIONS(159),
    [sym_dots] = ACTIONS(161),
    [sym_dot_dot_i] = ACTIONS(161),
    [sym_next] = ACTIONS(161),
    [sym_break] = ACTIONS(161),
    [sym_true] = ACTIONS(161),
    [sym_false] = ACTIONS(161),
    [sym_null] = ACTIONS(161),
    [sym_inf] = ACTIONS(161),
    [sym_nan] = ACTIONS(161),
    [anon_sym_NA] = ACTIONS(161),
    [anon_sym_NA_integer_] = ACTIONS(161),
    [anon_sym_NA_real_] = ACTIONS(161),
    [anon_sym_NA_complex_] = ACTIONS(161),
    [anon_sym_NA_character_] = ACTIONS(161),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(159),
    [sym__semicolon] = ACTIONS(159),
    [sym__raw_string_open] = ACTIONS(159),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(159),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [242] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(163),
    [sym_identifier] = ACTIONS(165),
    [anon_sym_BSLASH] = ACTIONS(163),
    [anon_sym_function] = ACTIONS(165),
    [anon_sym_EQ] = ACTIONS(339),
    [anon_sym_if] = ACTIONS(165),
    [anon_sym_for] = ACTIONS(165),
    [anon_sym_while] = ACTIONS(165),
    [anon_sym_repeat] = ACTIONS(165),
    [anon_sym_QMARK] = ACTIONS(163),
    [anon_sym_TILDE] = ACTIONS(341),
    [anon_sym_BANG] = ACTIONS(165),
    [anon_sym_PLUS] = ACTIONS(291),
    [anon_sym_DASH] = ACTIONS(293),
    [anon_sym_LT_DASH] = ACTIONS(347),
    [anon_sym_LT_LT_DASH] = ACTIONS(347),
    [anon_sym_COLON_EQ] = ACTIONS(347),
    [anon_sym_DASH_GT] = ACTIONS(343),
    [anon_sym_DASH_GT_GT] = ACTIONS(345),
    [anon_sym_PIPE] = ACTIONS(295),
    [anon_sym_AMP] = ACTIONS(297),
    [anon_sym_PIPE_PIPE] = ACTIONS(299),
    [anon_sym_AMP_AMP] = ACTIONS(301),
    [anon_sym_LT] = ACTIONS(303),
    [anon_sym_LT_EQ] = ACTIONS(305),
    [anon_sym_GT] = ACTIONS(303),
    [anon_sym_GT_EQ] = ACTIONS(305),
    [anon_sym_EQ_EQ] = ACTIONS(305),
    [anon_sym_BANG_EQ] = ACTIONS(305),
    [anon_sym_STAR] = ACTIONS(307),
    [anon_sym_SLASH] = ACTIONS(309),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(313),
    [anon_sym_PIPE_GT] = ACTIONS(313),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(163),
    [sym__number_literal] = ACTIONS(165),
    [anon_sym_SQUOTE] = ACTIONS(163),
    [anon_sym_DQUOTE] = ACTIONS(163),
    [sym_dots] = ACTIONS(165),
    [sym_dot_dot_i] = ACTIONS(165),
    [sym_next] = ACTIONS(165),
    [sym_break] = ACTIONS(165),
    [sym_true] = ACTIONS(165),
    [sym_false] = ACTIONS(165),
    [sym_null] = ACTIONS(165),
    [sym_inf] = ACTIONS(165),
    [sym_nan] = ACTIONS(165),
    [anon_sym_NA] = ACTIONS(165),
    [anon_sym_NA_integer_] = ACTIONS(165),
    [anon_sym_NA_real_] = ACTIONS(165),
    [anon_sym_NA_complex_] = ACTIONS(165),
    [anon_sym_NA_character_] = ACTIONS(165),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(163),
    [sym__semicolon] = ACTIONS(163),
    [sym__raw_string_open] = ACTIONS(163),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(163),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [243] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(151),
    [sym_identifier] = ACTIONS(153),
    [anon_sym_BSLASH] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(153),
    [anon_sym_EQ] = ACTIONS(339),
    [anon_sym_if] = ACTIONS(153),
    [anon_sym_for] = ACTIONS(153),
    [anon_sym_while] = ACTIONS(153),
    [anon_sym_repeat] = ACTIONS(153),
    [anon_sym_QMARK] = ACTIONS(151),
    [anon_sym_TILDE] = ACTIONS(341),
    [anon_sym_BANG] = ACTIONS(153),
    [anon_sym_PLUS] = ACTIONS(291),
    [anon_sym_DASH] = ACTIONS(293),
    [anon_sym_LT_DASH] = ACTIONS(347),
    [anon_sym_LT_LT_DASH] = ACTIONS(347),
    [anon_sym_COLON_EQ] = ACTIONS(347),
    [anon_sym_DASH_GT] = ACTIONS(343),
    [anon_sym_DASH_GT_GT] = ACTIONS(345),
    [anon_sym_PIPE] = ACTIONS(295),
    [anon_sym_AMP] = ACTIONS(297),
    [anon_sym_PIPE_PIPE] = ACTIONS(299),
    [anon_sym_AMP_AMP] = ACTIONS(301),
    [anon_sym_LT] = ACTIONS(303),
    [anon_sym_LT_EQ] = ACTIONS(305),
    [anon_sym_GT] = ACTIONS(303),
    [anon_sym_GT_EQ] = ACTIONS(305),
    [anon_sym_EQ_EQ] = ACTIONS(305),
    [anon_sym_BANG_EQ] = ACTIONS(305),
    [anon_sym_STAR] = ACTIONS(307),
    [anon_sym_SLASH] = ACTIONS(309),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(313),
    [anon_sym_PIPE_GT] = ACTIONS(313),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(151),
    [sym__number_literal] = ACTIONS(153),
    [anon_sym_SQUOTE] = ACTIONS(151),
    [anon_sym_DQUOTE] = ACTIONS(151),
    [sym_dots] = ACTIONS(153),
    [sym_dot_dot_i] = ACTIONS(153),
    [sym_next] = ACTIONS(153),
    [sym_break] = ACTIONS(153),
    [sym_true] = ACTIONS(153),
    [sym_false] = ACTIONS(153),
    [sym_null] = ACTIONS(153),
    [sym_inf] = ACTIONS(153),
    [sym_nan] = ACTIONS(153),
    [anon_sym_NA] = ACTIONS(153),
    [anon_sym_NA_integer_] = ACTIONS(153),
    [anon_sym_NA_real_] = ACTIONS(153),
    [anon_sym_NA_complex_] = ACTIONS(153),
    [anon_sym_NA_character_] = ACTIONS(153),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(151),
    [sym__semicolon] = ACTIONS(151),
    [sym__raw_string_open] = ACTIONS(151),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(151),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [244] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(155),
    [sym_identifier] = ACTIONS(157),
    [anon_sym_BSLASH] = ACTIONS(155),
    [anon_sym_function] = ACTIONS(157),
    [anon_sym_EQ] = ACTIONS(339),
    [anon_sym_if] = ACTIONS(157),
    [anon_sym_for] = ACTIONS(157),
    [anon_sym_while] = ACTIONS(157),
    [anon_sym_repeat] = ACTIONS(157),
    [anon_sym_QMARK] = ACTIONS(155),
    [anon_sym_TILDE] = ACTIONS(341),
    [anon_sym_BANG] = ACTIONS(157),
    [anon_sym_PLUS] = ACTIONS(291),
    [anon_sym_DASH] = ACTIONS(293),
    [anon_sym_LT_DASH] = ACTIONS(347),
    [anon_sym_LT_LT_DASH] = ACTIONS(347),
    [anon_sym_COLON_EQ] = ACTIONS(347),
    [anon_sym_DASH_GT] = ACTIONS(343),
    [anon_sym_DASH_GT_GT] = ACTIONS(345),
    [anon_sym_PIPE] = ACTIONS(295),
    [anon_sym_AMP] = ACTIONS(297),
    [anon_sym_PIPE_PIPE] = ACTIONS(299),
    [anon_sym_AMP_AMP] = ACTIONS(301),
    [anon_sym_LT] = ACTIONS(303),
    [anon_sym_LT_EQ] = ACTIONS(305),
    [anon_sym_GT] = ACTIONS(303),
    [anon_sym_GT_EQ] = ACTIONS(305),
    [anon_sym_EQ_EQ] = ACTIONS(305),
    [anon_sym_BANG_EQ] = ACTIONS(305),
    [anon_sym_STAR] = ACTIONS(307),
    [anon_sym_SLASH] = ACTIONS(309),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(313),
    [anon_sym_PIPE_GT] = ACTIONS(313),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(155),
    [sym__number_literal] = ACTIONS(157),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [anon_sym_DQUOTE] = ACTIONS(155),
    [sym_dots] = ACTIONS(157),
    [sym_dot_dot_i] = ACTIONS(157),
    [sym_next] = ACTIONS(157),
    [sym_break] = ACTIONS(157),
    [sym_true] = ACTIONS(157),
    [sym_false] = ACTIONS(157),
    [sym_null] = ACTIONS(157),
    [sym_inf] = ACTIONS(157),
    [sym_nan] = ACTIONS(157),
    [anon_sym_NA] = ACTIONS(157),
    [anon_sym_NA_integer_] = ACTIONS(157),
    [anon_sym_NA_real_] = ACTIONS(157),
    [anon_sym_NA_complex_] = ACTIONS(157),
    [anon_sym_NA_character_] = ACTIONS(157),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(155),
    [sym__semicolon] = ACTIONS(155),
    [sym__raw_string_open] = ACTIONS(155),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(155),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [245] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(155),
    [sym_identifier] = ACTIONS(157),
    [anon_sym_BSLASH] = ACTIONS(155),
    [anon_sym_function] = ACTIONS(157),
    [anon_sym_EQ] = ACTIONS(157),
    [anon_sym_if] = ACTIONS(157),
    [anon_sym_for] = ACTIONS(157),
    [anon_sym_while] = ACTIONS(157),
    [anon_sym_repeat] = ACTIONS(157),
    [anon_sym_QMARK] = ACTIONS(155),
    [anon_sym_TILDE] = ACTIONS(155),
    [anon_sym_BANG] = ACTIONS(157),
    [anon_sym_PLUS] = ACTIONS(291),
    [anon_sym_DASH] = ACTIONS(293),
    [anon_sym_LT_DASH] = ACTIONS(155),
    [anon_sym_LT_LT_DASH] = ACTIONS(155),
    [anon_sym_COLON_EQ] = ACTIONS(155),
    [anon_sym_DASH_GT] = ACTIONS(157),
    [anon_sym_DASH_GT_GT] = ACTIONS(155),
    [anon_sym_PIPE] = ACTIONS(295),
    [anon_sym_AMP] = ACTIONS(297),
    [anon_sym_PIPE_PIPE] = ACTIONS(299),
    [anon_sym_AMP_AMP] = ACTIONS(301),
    [anon_sym_LT] = ACTIONS(303),
    [anon_sym_LT_EQ] = ACTIONS(305),
    [anon_sym_GT] = ACTIONS(303),
    [anon_sym_GT_EQ] = ACTIONS(305),
    [anon_sym_EQ_EQ] = ACTIONS(305),
    [anon_sym_BANG_EQ] = ACTIONS(305),
    [anon_sym_STAR] = ACTIONS(307),
    [anon_sym_SLASH] = ACTIONS(309),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(313),
    [anon_sym_PIPE_GT] = ACTIONS(313),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(155),
    [sym__number_literal] = ACTIONS(157),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [anon_sym_DQUOTE] = ACTIONS(155),
    [sym_dots] = ACTIONS(157),
    [sym_dot_dot_i] = ACTIONS(157),
    [sym_next] = ACTIONS(157),
    [sym_break] = ACTIONS(157),
    [sym_true] = ACTIONS(157),
    [sym_false] = ACTIONS(157),
    [sym_null] = ACTIONS(157),
    [sym_inf] = ACTIONS(157),
    [sym_nan] = ACTIONS(157),
    [anon_sym_NA] = ACTIONS(157),
    [anon_sym_NA_integer_] = ACTIONS(157),
    [anon_sym_NA_real_] = ACTIONS(157),
    [anon_sym_NA_complex_] = ACTIONS(157),
    [anon_sym_NA_character_] = ACTIONS(157),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(155),
    [sym__semicolon] = ACTIONS(155),
    [sym__raw_string_open] = ACTIONS(155),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(155),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [246] = {
    [sym_call_arguments] = STATE(432),
    [sym_subset_arguments] = STATE(441),
    [sym_subset2_arguments] = STATE(447),
    [sym__open_parenthesis] = STATE(254),
    [sym__open_bracket] = STATE(261),
    [sym__open_bracket2] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(155),
    [sym_identifier] = ACTIONS(157),
    [anon_sym_BSLASH] = ACTIONS(155),
    [anon_sym_function] = ACTIONS(157),
    [anon_sym_EQ] = ACTIONS(157),
    [anon_sym_if] = ACTIONS(157),
    [anon_sym_for] = ACTIONS(157),
    [anon_sym_while] = ACTIONS(157),
    [anon_sym_repeat] = ACTIONS(157),
    [anon_sym_QMARK] = ACTIONS(155),
    [anon_sym_TILDE] = ACTIONS(155),
    [anon_sym_BANG] = ACTIONS(157),
    [anon_sym_PLUS] = ACTIONS(291),
    [anon_sym_DASH] = ACTIONS(293),
    [anon_sym_LT_DASH] = ACTIONS(155),
    [anon_sym_LT_LT_DASH] = ACTIONS(155),
    [anon_sym_COLON_EQ] = ACTIONS(155),
    [anon_sym_DASH_GT] = ACTIONS(157),
    [anon_sym_DASH_GT_GT] = ACTIONS(155),
    [anon_sym_PIPE] = ACTIONS(157),
    [anon_sym_AMP] = ACTIONS(157),
    [anon_sym_PIPE_PIPE] = ACTIONS(155),
    [anon_sym_AMP_AMP] = ACTIONS(155),
    [anon_sym_LT] = ACTIONS(303),
    [anon_sym_LT_EQ] = ACTIONS(305),
    [anon_sym_GT] = ACTIONS(303),
    [anon_sym_GT_EQ] = ACTIONS(305),
    [anon_sym_EQ_EQ] = ACTIONS(305),
    [anon_sym_BANG_EQ] = ACTIONS(305),
    [anon_sym_STAR] = ACTIONS(307),
    [anon_sym_SLASH] = ACTIONS(309),
    [anon_sym_STAR_STAR] = ACTIONS(311),
    [anon_sym_CARET] = ACTIONS(311),
    [aux_sym_binary_operator_token1] = ACTIONS(313),
    [anon_sym_PIPE_GT] = ACTIONS(313),
    [anon_sym_COLON] = ACTIONS(315),
    [anon_sym_DOLLAR] = ACTIONS(317),
    [anon_sym_AT] = ACTIONS(317),
    [sym__hex_literal] = ACTIONS(155),
    [sym__number_literal] = ACTIONS(157),
    [anon_sym_SQUOTE] = ACTIONS(155),
    [anon_sym_DQUOTE] = ACTIONS(155),
    [sym_dots] = ACTIONS(157),
    [sym_dot_dot_i] = ACTIONS(157),
    [sym_next] = ACTIONS(157),
    [sym_break] = ACTIONS(157),
    [sym_true] = ACTIONS(157),
    [sym_false] = ACTIONS(157),
    [sym_null] = ACTIONS(157),
    [sym_inf] = ACTIONS(157),
    [sym_nan] = ACTIONS(157),
    [anon_sym_NA] = ACTIONS(157),
    [anon_sym_NA_integer_] = ACTIONS(157),
    [anon_sym_NA_real_] = ACTIONS(157),
    [anon_sym_NA_complex_] = ACTIONS(157),
    [anon_sym_NA_character_] = ACTIONS(157),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(155),
    [sym__semicolon] = ACTIONS(155),
    [sym__raw_string_open] = ACTIONS(155),
    [sym__external_open_parenthesis] = ACTIONS(319),
    [sym__external_open_brace] = ACTIONS(155),
    [sym__external_open_bracket] = ACTIONS(321),
    [sym__external_open_bracket2] = ACTIONS(323),
  },
  [247] = {
    [sym_string] = STATE(342),
    [sym__raw_string] = STATE(301),
    [sym__single_quoted_string] = STATE(302),
    [sym__double_quoted_string] = STATE(303),
    [aux_sym_function_definition_repeat1] = STATE(210),
    [sym_identifier] = ACTIONS(375),
    [anon_sym_BSLASH] = ACTIONS(325),
    [anon_sym_function] = ACTIONS(329),
    [anon_sym_EQ] = ACTIONS(329),
    [anon_sym_if] = ACTIONS(329),
    [anon_sym_for] = ACTIONS(329),
    [anon_sym_while] = ACTIONS(329),
    [anon_sym_repeat] = ACTIONS(329),
    [anon_sym_QMARK] = ACTIONS(325),
    [anon_sym_TILDE] = ACTIONS(325),
    [anon_sym_BANG] = ACTIONS(329),
    [anon_sym_PLUS] = ACTIONS(325),
    [anon_sym_DASH] = ACTIONS(329),
    [anon_sym_LT_DASH] = ACTIONS(325),
    [anon_sym_LT_LT_DASH] = ACTIONS(325),
    [anon_sym_COLON_EQ] = ACTIONS(325),
    [anon_sym_DASH_GT] = ACTIONS(329),
    [anon_sym_DASH_GT_GT] = ACTIONS(325),
    [anon_sym_PIPE] = ACTIONS(329),
    [anon_sym_AMP] = ACTIONS(329),
    [anon_sym_PIPE_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(325),
    [anon_sym_LT] = ACTIONS(329),
    [anon_sym_LT_EQ] = ACTIONS(325),
    [anon_sym_GT] = ACTIONS(329),
    [anon_sym_GT_EQ] = ACTIONS(325),
    [anon_sym_EQ_EQ] = ACTIONS(325),
    [anon_sym_BANG_EQ] = ACTIONS(325),
    [anon_sym_STAR] = ACTIONS(329),
    [anon_sym_SLASH] = ACTIONS(325),
    [anon_sym_STAR_STAR] = ACTIONS(325),
    [anon_sym_CARET] = ACTIONS(325),
    [aux_sym_binary_operator_token1] = ACTIONS(325),
    [anon_sym_PIPE_GT] = ACTIONS(325),
    [anon_sym_COLON] = ACTIONS(329),
    [anon_sym_DOLLAR] = ACTIONS(325),
    [anon_sym_AT] = ACTIONS(325),
    [sym__hex_literal] = ACTIONS(325),
    [sym__number_literal] = ACTIONS(329),
    [anon_sym_SQUOTE] = ACTIONS(363),
    [anon_sym_DQUOTE] = ACTIONS(365),
    [sym_dots] = ACTIONS(375),
    [sym_dot_dot_i] = ACTIONS(375),
    [sym_next] = ACTIONS(329),
    [sym_break] = ACTIONS(329),
    [sym_true] = ACTIONS(329),
    [sym_false] = ACTIONS(329),
    [sym_null] = ACTIONS(329),
    [sym_inf] = ACTIONS(329),
    [sym_nan] = ACTIONS(329),
    [anon_sym_NA] = ACTIONS(329),
    [anon_sym_NA_integer_] = ACTIONS(329),
    [anon_sym_NA_real_] = ACTIONS(329),
    [anon_sym_NA_complex_] = ACTIONS(329),
    [anon_sym_NA_character_] = ACTIONS(329),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(377),
    [sym__semicolon] = ACTIONS(325),
    [sym__raw_string_open] = ACTIONS(367),
    [sym__external_else] = ACTIONS(325),
    [sym__external_open_parenthesis] = ACTIONS(325),
    [sym__external_open_brace] = ACTIONS(325),
    [sym__external_close_brace] = ACTIONS(325),
    [sym__external_open_bracket] = ACTIONS(325),
    [sym__external_open_bracket2] = ACTIONS(325),
  },
  [248] = {
    [sym_function_definition] = STATE(1490),
    [sym_if_statement] = STATE(1490),
    [sym_for_statement] = STATE(1490),
    [sym_while_statement] = STATE(1490),
    [sym_repeat_statement] = STATE(1490),
    [sym_braced_expression] = STATE(1490),
    [sym_parenthesized_expression] = STATE(1490),
    [sym_call] = STATE(1490),
    [sym_subset] = STATE(1490),
    [sym_subset2] = STATE(1490),
    [sym_argument] = STATE(1935),
    [sym__argument_named] = STATE(2062),
    [sym__argument_unnamed] = STATE(2065),
    [sym__argument_value] = STATE(2071),
    [sym_unary_operator] = STATE(1490),
    [sym_binary_operator] = STATE(1490),
    [sym_extract_operator] = STATE(1490),
    [sym_namespace_operator] = STATE(1490),
    [sym_integer] = STATE(1490),
    [sym_complex] = STATE(1490),
    [sym_float] = STATE(1490),
    [sym__float_literal] = STATE(1649),
    [sym_string] = STATE(1636),
    [sym__raw_string] = STATE(1632),
    [sym__single_quoted_string] = STATE(1617),
    [sym__double_quoted_string] = STATE(1619),
    [sym__argument_name_string_or_identifier_or_null] = STATE(2082),
    [sym_na] = STATE(1490),
    [sym__expression] = STATE(1490),
    [sym__open_parenthesis] = STATE(1075),
    [sym__open_brace] = STATE(386),
    [sym__close_bracket] = STATE(1723),
    [aux_sym_call_arguments_repeat1] = STATE(1938),
    [sym_identifier] = ACTIONS(379),
    [anon_sym_BSLASH] = ACTIONS(381),
    [anon_sym_function] = ACTIONS(383),
    [anon_sym_if] = ACTIONS(385),
    [anon_sym_for] = ACTIONS(387),
    [anon_sym_while] = ACTIONS(389),
    [anon_sym_repeat] = ACTIONS(391),
    [anon_sym_QMARK] = ACTIONS(393),
    [anon_sym_TILDE] = ACTIONS(395),
    [anon_sym_BANG] = ACTIONS(397),
    [anon_sym_PLUS] = ACTIONS(399),
    [anon_sym_DASH] = ACTIONS(399),
    [sym__hex_literal] = ACTIONS(401),
    [sym__number_literal] = ACTIONS(403),
    [anon_sym_SQUOTE] = ACTIONS(405),
    [anon_sym_DQUOTE] = ACTIONS(407),
    [sym_dots] = ACTIONS(379),
    [sym_dot_dot_i] = ACTIONS(379),
    [sym_next] = ACTIONS(409),
    [sym_break] = ACTIONS(409),
    [sym_true] = ACTIONS(409),
    [sym_false] = ACTIONS(409),
    [sym_null] = ACTIONS(411),
    [sym_inf] = ACTIONS(409),
    [sym_nan] = ACTIONS(409),
    [anon_sym_NA] = ACTIONS(413),
    [anon_sym_NA_integer_] = ACTIONS(413),
    [anon_sym_NA_real_] = ACTIONS(413),
    [anon_sym_NA_complex_] = ACTIONS(413),
    [anon_sym_NA_character_] = ACTIONS(413),
    [sym_comment] = ACTIONS(3),
    [sym_comma] = ACTIONS(415),
    [sym__raw_string_open] = ACTIONS(417),
    [sym__external_open_parenthesis] = ACTIONS(419),
    [sym__external_open_brace] = ACTIONS(421),
    [sym__external_close_bracket] = ACTIONS(423),
  },
  [249] = {
    [sym_string] = STATE(439),
    [sym__raw_string] = STATE(319),
    [sym__single_quoted_string] = STATE(324),
    [sym__double_quoted_string] = STATE(325),
    [aux_sym_function_definition_repeat1] = STATE(404),
    [ts_builtin_sym_end] = ACTIONS(349),
    [sym_identifier] = ACTIONS(425),
    [anon_sym_BSLASH] = ACTIONS(349),
    [anon_sym_function] = ACTIONS(353),
    [anon_sym_EQ] = ACTIONS(353),
    [anon_sym_if] = ACTIONS(353),
    [anon_sym_for] = ACTIONS(353),
    [anon_sym_while] = ACTIONS(353),
    [anon_sym_repeat] = ACTIONS(353),
    [anon_sym_QMARK] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(349),
    [anon_sym_BANG] = ACTIONS(353),
    [anon_sym_PLUS] = ACTIONS(349),
    [anon_sym_DASH] = ACTIONS(353),
    [anon_sym_LT_DASH] = ACTIONS(349),
    [anon_sym_LT_LT_DASH] = ACTIONS(349),
    [anon_sym_COLON_EQ] = ACTIONS(349),
    [anon_sym_DASH_GT] = ACTIONS(353),
    [anon_sym_DASH_GT_GT] = ACTIONS(349),
    [anon_sym_PIPE] = ACTIONS(353),
    [anon_sym_AMP] = ACTIONS(353),
    [anon_sym_PIPE_PIPE] = ACTIONS(349),
    [anon_sym_AMP_AMP] = ACTIONS(349),
    [anon_sym_LT] = ACTIONS(353),
    [anon_sym_LT_EQ] = ACTIONS(349),
    [anon_sym_GT] = ACTIONS(353),
    [anon_sym_GT_EQ] = ACTIONS(349),
    [anon_sym_EQ_EQ] = ACTIONS(349),
    [anon_sym_BANG_EQ] = ACTIONS(349),
    [anon_sym_STAR] = ACTIONS(353),
    [anon_sym_SLASH] = ACTIONS(349),
    [anon_sym_STAR_STAR] = ACTIONS(349),
    [anon_sym_CARET] = ACTIONS(349),
    [aux_sym_binary_operator_token1] = ACTIONS(349),
    [anon_sym_PIPE_GT] = ACTIONS(349),
    [anon_sym_COLON] = ACTIONS(353),
    [anon_sym_DOLLAR] = ACTIONS(349),
    [anon_sym_AT] = ACTIONS(349),
    [sym__hex_literal] = ACTIONS(349),
    [sym__number_literal] = ACTIONS(353),
    [anon_sym_SQUOTE] = ACTIONS(427),
    [anon_sym_DQUOTE] = ACTIONS(429),
    [sym_dots] = ACTIONS(425),
    [sym_dot_dot_i] = ACTIONS(425),
    [sym_next] = ACTIONS(353),
    [sym_break] = ACTIONS(353),
    [sym_true] = ACTIONS(353),
    [sym_false] = ACTIONS(353),
    [sym_null] = ACTIONS(353),
    [sym_inf] = ACTIONS(353),
    [sym_nan] = ACTIONS(353),
    [anon_sym_NA] = ACTIONS(353),
    [anon_sym_NA_integer_] = ACTIONS(353),
    [anon_sym_NA_real_] = ACTIONS(353),
    [anon_sym_NA_complex_] = ACTIONS(353),
    [anon_sym_NA_character_] = ACTIONS(353),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(349),
    [sym__semicolon] = ACTIONS(349),
    [sym__raw_string_open] = ACTIONS(431),
    [sym__external_open_parenthesis] = ACTIONS(349),
    [sym__external_open_brace] = ACTIONS(349),
    [sym__external_open_bracket] = ACTIONS(349),
    [sym__external_open_bracket2] = ACTIONS(349),
  },
  [250] = {
    [sym_string] = STATE(456),
    [sym__raw_string] = STATE(331),
    [sym__single_quoted_string] = STATE(332),
    [sym__double_quoted_string] = STATE(333),
    [aux_sym_function_definition_repeat1] = STATE(353),
    [sym_identifier] = ACTIONS(433),
    [anon_sym_BSLASH] = ACTIONS(349),
    [anon_sym_function] = ACTIONS(353),
    [anon_sym_EQ] = ACTIONS(353),
    [anon_sym_if] = ACTIONS(353),
    [anon_sym_for] = ACTIONS(353),
    [anon_sym_while] = ACTIONS(353),
    [anon_sym_repeat] = ACTIONS(353),
    [anon_sym_QMARK] = ACTIONS(349),
    [anon_sym_TILDE] = ACTIONS(349),
    [anon_sym_BANG] = ACTIONS(353),
    [anon_sym_PLUS] = ACTIONS(349),
    [anon_sym_DASH] = ACTIONS(353),
    [anon_sym_LT_DASH] = ACTIONS(349),
    [anon_sym_LT_LT_DASH] = ACTIONS(349),
    [anon_sym_COLON_EQ] = ACTIONS(349),
    [anon_sym_DASH_GT] = ACTIONS(353),
    [anon_sym_DASH_GT_GT] = ACTIONS(349),
    [anon_sym_PIPE] = ACTIONS(353),
    [anon_sym_AMP] = ACTIONS(353),
    [anon_sym_PIPE_PIPE] = ACTIONS(349),
    [anon_sym_AMP_AMP] = ACTIONS(349),
    [anon_sym_LT] = ACTIONS(353),
    [anon_sym_LT_EQ] = ACTIONS(349),
    [anon_sym_GT] = ACTIONS(353),
    [anon_sym_GT_EQ] = ACTIONS(349),
    [anon_sym_EQ_EQ] = ACTIONS(349),
    [anon_sym_BANG_EQ] = ACTIONS(349),
    [anon_sym_STAR] = ACTIONS(353),
    [anon_sym_SLASH] = ACTIONS(349),
    [anon_sym_STAR_STAR] = ACTIONS(349),
    [anon_sym_CARET] = ACTIONS(349),
    [aux_sym_binary_operator_token1] = ACTIONS(349),
    [anon_sym_PIPE_GT] = ACTIONS(349),
    [anon_sym_COLON] = ACTIONS(353),
    [anon_sym_DOLLAR] = ACTIONS(349),
    [anon_sym_AT] = ACTIONS(349),
    [sym__hex_literal] = ACTIONS(349),
    [sym__number_literal] = ACTIONS(353),
    [anon_sym_SQUOTE] = ACTIONS(435),
    [anon_sym_DQUOTE] = ACTIONS(437),
    [sym_dots] = ACTIONS(433),
    [sym_dot_dot_i] = ACTIONS(433),
    [sym_next] = ACTIONS(353),
    [sym_break] = ACTIONS(353),
    [sym_true] = ACTIONS(353),
    [sym_false] = ACTIONS(353),
    [sym_null] = ACTIONS(353),
    [sym_inf] = ACTIONS(353),
    [sym_nan] = ACTIONS(353),
    [anon_sym_NA] = ACTIONS(353),
    [anon_sym_NA_integer_] = ACTIONS(353),
    [anon_sym_NA_real_] = ACTIONS(353),
    [anon_sym_NA_complex_] = ACTIONS(353),
    [anon_sym_NA_character_] = ACTIONS(353),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(349),
    [sym__semicolon] = ACTIONS(349),
    [sym__raw_string_open] = ACTIONS(439),
    [sym__external_open_parenthesis] = ACTIONS(349),
    [sym__external_open_brace] = ACTIONS(349),
    [sym__external_close_brace] = ACTIONS(349),
    [sym__external_open_bracket] = ACTIONS(349),
    [sym__external_open_bracket2] = ACTIONS(349),
  },
  [251] = {
    [sym_function_definition] = STATE(1552),
    [sym_if_statement] = STATE(1552),
    [sym_for_statement] = STATE(1552),
    [sym_while_statement] = STATE(1552),
    [sym_repeat_statement] = STATE(1552),
    [sym_braced_expression] = STATE(1552),
    [sym_parenthesized_expression] = STATE(1552),
    [sym_call] = STATE(1552),
    [sym_subset] = STATE(1552),
    [sym_subset2] = STATE(1552),
    [sym_argument] = STATE(1915),
    [sym__argument_named] = STATE(2077),
    [sym__argument_unnamed] = STATE(2060),
    [sym__argument_value] = STATE(2054),
    [sym_unary_operator] = STATE(1552),
    [sym_binary_operator] = STATE(1552),
    [sym_extract_operator] = STATE(1552),
    [sym_namespace_operator] = STATE(1552),
    [sym_integer] = STATE(1552),
    [sym_complex] = STATE(1552),
    [sym_float] = STATE(1552),
    [sym__float_literal] = STATE(1638),
    [sym_string] = STATE(1634),
    [sym__raw_string] = STATE(1639),
    [sym__single_quoted_string] = STATE(1641),
    [sym__double_quoted_string] = STATE(1651),
    [sym__argument_name_string_or_identifier_or_null] = STATE(2085),
    [sym_na] = STATE(1552),
    [sym__expression] = STATE(1552),
    [sym__open_parenthesis] = STATE(1080),
    [sym__open_brace] = STATE(389),
    [sym__close_bracket2] = STATE(405),
    [aux_sym_call_arguments_repeat1] = STATE(1943),
    [sym_identifier] = ACTIONS(441),
    [anon_sym_BSLASH] = ACTIONS(443),
    [anon_sym_function] = ACTIONS(445),
    [anon_sym_if] = ACTIONS(447),
    [anon_sym_for] = ACTIONS(449),
    [anon_sym_while] = ACTIONS(451),
    [anon_sym_repeat] = ACTIONS(453),
    [anon_sym_QMARK] = ACTIONS(455),
    [anon_sym_TILDE] = ACTIONS(457),
    [anon_sym_BANG] = ACTIONS(459),
    [anon_sym_PLUS] = ACTIONS(461),
    [anon_sym_DASH] = ACTIONS(461),
    [sym__hex_literal] = ACTIONS(463),
    [sym__number_literal] = ACTIONS(465),
    [anon_sym_SQUOTE] = ACTIONS(467),
    [anon_sym_DQUOTE] = ACTIONS(469),
    [sym_dots] = ACTIONS(441),
    [sym_dot_dot_i] = ACTIONS(441),
    [sym_next] = ACTIONS(471),
    [sym_break] = ACTIONS(471),
    [sym_true] = ACTIONS(471),
    [sym_false] = ACTIONS(471),
    [sym_null] = ACTIONS(473),
    [sym_inf] = ACTIONS(471),
    [sym_nan] = ACTIONS(471),
    [anon_sym_NA] = ACTIONS(475),
    [anon_sym_NA_integer_] = ACTIONS(475),
    [anon_sym_NA_real_] = ACTIONS(475),
    [anon_sym_NA_complex_] = ACTIONS(475),
    [anon_sym_NA_character_] = ACTIONS(475),
    [sym_comment] = ACTIONS(3),
    [sym_comma] = ACTIONS(477),
    [sym__raw_string_open] = ACTIONS(479),
    [sym__external_open_parenthesis] = ACTIONS(481),
    [sym__external_open_brace] = ACTIONS(483),
    [sym__external_close_bracket2] = ACTIONS(485),
  },
  [252] = {
    [sym_string] = STATE(339),
    [sym__raw_string] = STATE(301),
    [sym__single_quoted_string] = STATE(302),
    [sym__double_quoted_string] = STATE(303),
    [sym_identifier] = ACTIONS(487),
    [anon_sym_BSLASH] = ACTIONS(489),
    [anon_sym_function] = ACTIONS(491),
    [anon_sym_EQ] = ACTIONS(491),
    [anon_sym_if] = ACTIONS(491),
    [anon_sym_for] = ACTIONS(491),
    [anon_sym_while] = ACTIONS(491),
    [anon_sym_repeat] = ACTIONS(491),
    [anon_sym_QMARK] = ACTIONS(489),
    [anon_sym_TILDE] = ACTIONS(489),
    [anon_sym_BANG] = ACTIONS(491),
    [anon_sym_PLUS] = ACTIONS(489),
    [anon_sym_DASH] = ACTIONS(491),
    [anon_sym_LT_DASH] = ACTIONS(489),
    [anon_sym_LT_LT_DASH] = ACTIONS(489),
    [anon_sym_COLON_EQ] = ACTIONS(489),
    [anon_sym_DASH_GT] = ACTIONS(491),
    [anon_sym_DASH_GT_GT] = ACTIONS(489),
    [anon_sym_PIPE] = ACTIONS(491),
    [anon_sym_AMP] = ACTIONS(491),
    [anon_sym_PIPE_PIPE] = ACTIONS(489),
    [anon_sym_AMP_AMP] = ACTIONS(489),
    [anon_sym_LT] = ACTIONS(491),
    [anon_sym_LT_EQ] = ACTIONS(489),
    [anon_sym_GT] = ACTIONS(491),
    [anon_sym_GT_EQ] = ACTIONS(489),
    [anon_sym_EQ_EQ] = ACTIONS(489),
    [anon_sym_BANG_EQ] = ACTIONS(489),
    [anon_sym_STAR] = ACTIONS(491),
    [anon_sym_SLASH] = ACTIONS(489),
    [anon_sym_STAR_STAR] = ACTIONS(489),
    [anon_sym_CARET] = ACTIONS(489),
    [aux_sym_binary_operator_token1] = ACTIONS(489),
    [anon_sym_PIPE_GT] = ACTIONS(489),
    [anon_sym_COLON] = ACTIONS(491),
    [anon_sym_DOLLAR] = ACTIONS(489),
    [anon_sym_AT] = ACTIONS(489),
    [sym__hex_literal] = ACTIONS(489),
    [sym__number_literal] = ACTIONS(491),
    [anon_sym_SQUOTE] = ACTIONS(363),
    [anon_sym_DQUOTE] = ACTIONS(365),
    [sym_dots] = ACTIONS(487),
    [sym_dot_dot_i] = ACTIONS(487),
    [sym_next] = ACTIONS(491),
    [sym_break] = ACTIONS(491),
    [sym_true] = ACTIONS(491),
    [sym_false] = ACTIONS(491),
    [sym_null] = ACTIONS(491),
    [sym_inf] = ACTIONS(491),
    [sym_nan] = ACTIONS(491),
    [anon_sym_NA] = ACTIONS(491),
    [anon_sym_NA_integer_] = ACTIONS(491),
    [anon_sym_NA_real_] = ACTIONS(491),
    [anon_sym_NA_complex_] = ACTIONS(491),
    [anon_sym_NA_character_] = ACTIONS(491),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(489),
    [sym__semicolon] = ACTIONS(489),
    [sym__raw_string_open] = ACTIONS(367),
    [sym__external_else] = ACTIONS(489),
    [sym__external_open_parenthesis] = ACTIONS(489),
    [sym__external_open_brace] = ACTIONS(489),
    [sym__external_close_brace] = ACTIONS(489),
    [sym__external_open_bracket] = ACTIONS(489),
    [sym__external_open_bracket2] = ACTIONS(489),
  },
  [253] = {
    [sym_string] = STATE(433),
    [sym__raw_string] = STATE(319),
    [sym__single_quoted_string] = STATE(324),
    [sym__double_quoted_string] = STATE(325),
    [aux_sym_function_definition_repeat1] = STATE(249),
    [ts_builtin_sym_end] = ACTIONS(325),
    [sym_identifier] = ACTIONS(493),
    [anon_sym_BSLASH] = ACTIONS(325),
    [anon_sym_function] = ACTIONS(329),
    [anon_sym_EQ] = ACTIONS(329),
    [anon_sym_if] = ACTIONS(329),
    [anon_sym_for] = ACTIONS(329),
    [anon_sym_while] = ACTIONS(329),
    [anon_sym_repeat] = ACTIONS(329),
    [anon_sym_QMARK] = ACTIONS(325),
    [anon_sym_TILDE] = ACTIONS(325),
    [anon_sym_BANG] = ACTIONS(329),
    [anon_sym_PLUS] = ACTIONS(325),
    [anon_sym_DASH] = ACTIONS(329),
    [anon_sym_LT_DASH] = ACTIONS(325),
    [anon_sym_LT_LT_DASH] = ACTIONS(325),
    [anon_sym_COLON_EQ] = ACTIONS(325),
    [anon_sym_DASH_GT] = ACTIONS(329),
    [anon_sym_DASH_GT_GT] = ACTIONS(325),
    [anon_sym_PIPE] = ACTIONS(329),
    [anon_sym_AMP] = ACTIONS(329),
    [anon_sym_PIPE_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(325),
    [anon_sym_LT] = ACTIONS(329),
    [anon_sym_LT_EQ] = ACTIONS(325),
    [anon_sym_GT] = ACTIONS(329),
    [anon_sym_GT_EQ] = ACTIONS(325),
    [anon_sym_EQ_EQ] = ACTIONS(325),
    [anon_sym_BANG_EQ] = ACTIONS(325),
    [anon_sym_STAR] = ACTIONS(329),
    [anon_sym_SLASH] = ACTIONS(325),
    [anon_sym_STAR_STAR] = ACTIONS(325),
    [anon_sym_CARET] = ACTIONS(325),
    [aux_sym_binary_operator_token1] = ACTIONS(325),
    [anon_sym_PIPE_GT] = ACTIONS(325),
    [anon_sym_COLON] = ACTIONS(329),
    [anon_sym_DOLLAR] = ACTIONS(325),
    [anon_sym_AT] = ACTIONS(325),
    [sym__hex_literal] = ACTIONS(325),
    [sym__number_literal] = ACTIONS(329),
    [anon_sym_SQUOTE] = ACTIONS(427),
    [anon_sym_DQUOTE] = ACTIONS(429),
    [sym_dots] = ACTIONS(493),
    [sym_dot_dot_i] = ACTIONS(493),
    [sym_next] = ACTIONS(329),
    [sym_break] = ACTIONS(329),
    [sym_true] = ACTIONS(329),
    [sym_false] = ACTIONS(329),
    [sym_null] = ACTIONS(329),
    [sym_inf] = ACTIONS(329),
    [sym_nan] = ACTIONS(329),
    [anon_sym_NA] = ACTIONS(329),
    [anon_sym_NA_integer_] = ACTIONS(329),
    [anon_sym_NA_real_] = ACTIONS(329),
    [anon_sym_NA_complex_] = ACTIONS(329),
    [anon_sym_NA_character_] = ACTIONS(329),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(495),
    [sym__semicolon] = ACTIONS(325),
    [sym__raw_string_open] = ACTIONS(431),
    [sym__external_open_parenthesis] = ACTIONS(325),
    [sym__external_open_brace] = ACTIONS(325),
    [sym__external_open_bracket] = ACTIONS(325),
    [sym__external_open_bracket2] = ACTIONS(325),
  },
  [254] = {
    [sym_function_definition] = STATE(1372),
    [sym_if_statement] = STATE(1372),
    [sym_for_statement] = STATE(1372),
    [sym_while_statement] = STATE(1372),
    [sym_repeat_statement] = STATE(1372),
    [sym_braced_expression] = STATE(1372),
    [sym_parenthesized_expression] = STATE(1372),
    [sym_call] = STATE(1372),
    [sym_subset] = STATE(1372),
    [sym_subset2] = STATE(1372),
    [sym_argument] = STATE(1877),
    [sym__argument_named] = STATE(2070),
    [sym__argument_unnamed] = STATE(2056),
    [sym__argument_value] = STATE(2061),
    [sym_unary_operator] = STATE(1372),
    [sym_binary_operator] = STATE(1372),
    [sym_extract_operator] = STATE(1372),
    [sym_namespace_operator] = STATE(1372),
    [sym_integer] = STATE(1372),
    [sym_complex] = STATE(1372),
    [sym_float] = STATE(1372),
    [sym__float_literal] = STATE(1626),
    [sym_string] = STATE(1635),
    [sym__raw_string] = STATE(1627),
    [sym__single_quoted_string] = STATE(1628),
    [sym__double_quoted_string] = STATE(1629),
    [sym__argument_name_string_or_identifier_or_null] = STATE(2106),
    [sym_na] = STATE(1372),
    [sym__expression] = STATE(1372),
    [sym__open_parenthesis] = STATE(1065),
    [sym__close_parenthesis] = STATE(420),
    [sym__open_brace] = STATE(381),
    [aux_sym_call_arguments_repeat1] = STATE(1924),
    [sym_identifier] = ACTIONS(497),
    [anon_sym_BSLASH] = ACTIONS(499),
    [anon_sym_function] = ACTIONS(501),
    [anon_sym_if] = ACTIONS(503),
    [anon_sym_for] = ACTIONS(505),
    [anon_sym_while] = ACTIONS(507),
    [anon_sym_repeat] = ACTIONS(509),
    [anon_sym_QMARK] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(513),
    [anon_sym_BANG] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(517),
    [anon_sym_DASH] = ACTIONS(517),
    [sym__hex_literal] = ACTIONS(519),
    [sym__number_literal] = ACTIONS(521),
    [anon_sym_SQUOTE] = ACTIONS(523),
    [anon_sym_DQUOTE] = ACTIONS(525),
    [sym_dots] = ACTIONS(497),
    [sym_dot_dot_i] = ACTIONS(497),
    [sym_next] = ACTIONS(527),
    [sym_break] = ACTIONS(527),
    [sym_true] = ACTIONS(527),
    [sym_false] = ACTIONS(527),
    [sym_null] = ACTIONS(529),
    [sym_inf] = ACTIONS(527),
    [sym_nan] = ACTIONS(527),
    [anon_sym_NA] = ACTIONS(531),
    [anon_sym_NA_integer_] = ACTIONS(531),
    [anon_sym_NA_real_] = ACTIONS(531),
    [anon_sym_NA_complex_] = ACTIONS(531),
    [anon_sym_NA_character_] = ACTIONS(531),
    [sym_comment] = ACTIONS(3),
    [sym_comma] = ACTIONS(533),
    [sym__raw_string_open] = ACTIONS(535),
    [sym__external_open_parenthesis] = ACTIONS(537),
    [sym__external_close_parenthesis] = ACTIONS(539),
    [sym__external_open_brace] = ACTIONS(541),
  },
  [255] = {
    [sym_function_definition] = STATE(1552),
    [sym_if_statement] = STATE(1552),
    [sym_for_statement] = STATE(1552),
    [sym_while_statement] = STATE(1552),
    [sym_repeat_statement] = STATE(1552),
    [sym_braced_expression] = STATE(1552),
    [sym_parenthesized_expression] = STATE(1552),
    [sym_call] = STATE(1552),
    [sym_subset] = STATE(1552),
    [sym_subset2] = STATE(1552),
    [sym_argument] = STATE(1868),
    [sym__argument_named] = STATE(2077),
    [sym__argument_unnamed] = STATE(2060),
    [sym__argument_value] = STATE(2054),
    [sym_unary_operator] = STATE(1552),
    [sym_binary_operator] = STATE(1552),
    [sym_extract_operator] = STATE(1552),
    [sym_namespace_operator] = STATE(1552),
    [sym_integer] = STATE(1552),
    [sym_complex] = STATE(1552),
    [sym_float] = STATE(1552),
    [sym__float_literal] = STATE(1638),
    [sym_string] = STATE(1634),
    [sym__raw_string] = STATE(1639),
    [sym__single_quoted_string] = STATE(1641),
    [sym__double_quoted_string] = STATE(1651),
    [sym__argument_name_string_or_identifier_or_null] = STATE(2085),
    [sym_na] = STATE(1552),
    [sym__expression] = STATE(1552),
    [sym__open_parenthesis] = STATE(1080),
    [sym__open_brace] = STATE(389),
    [sym__close_bracket2] = STATE(1705),
    [aux_sym_call_arguments_repeat1] = STATE(1876),
    [sym_identifier] = ACTIONS(441),
    [anon_sym_BSLASH] = ACTIONS(443),
    [anon_sym_function] = ACTIONS(445),
    [anon_sym_if] = ACTIONS(447),
    [anon_sym_for] = ACTIONS(449),
    [anon_sym_while] = ACTIONS(451),
    [anon_sym_repeat] = ACTIONS(453),
    [anon_sym_QMARK] = ACTIONS(455),
    [anon_sym_TILDE] = ACTIONS(457),
    [anon_sym_BANG] = ACTIONS(459),
    [anon_sym_PLUS] = ACTIONS(461),
    [anon_sym_DASH] = ACTIONS(461),
    [sym__hex_literal] = ACTIONS(463),
    [sym__number_literal] = ACTIONS(465),
    [anon_sym_SQUOTE] = ACTIONS(467),
    [anon_sym_DQUOTE] = ACTIONS(469),
    [sym_dots] = ACTIONS(441),
    [sym_dot_dot_i] = ACTIONS(441),
    [sym_next] = ACTIONS(471),
    [sym_break] = ACTIONS(471),
    [sym_true] = ACTIONS(471),
    [sym_false] = ACTIONS(471),
    [sym_null] = ACTIONS(473),
    [sym_inf] = ACTIONS(471),
    [sym_nan] = ACTIONS(471),
    [anon_sym_NA] = ACTIONS(475),
    [anon_sym_NA_integer_] = ACTIONS(475),
    [anon_sym_NA_real_] = ACTIONS(475),
    [anon_sym_NA_complex_] = ACTIONS(475),
    [anon_sym_NA_character_] = ACTIONS(475),
    [sym_comment] = ACTIONS(3),
    [sym_comma] = ACTIONS(477),
    [sym__raw_string_open] = ACTIONS(479),
    [sym__external_open_parenthesis] = ACTIONS(481),
    [sym__external_open_brace] = ACTIONS(483),
    [sym__external_close_bracket2] = ACTIONS(543),
  },
  [256] = {
    [sym_string] = STATE(455),
    [sym__raw_string] = STATE(331),
    [sym__single_quoted_string] = STATE(332),
    [sym__double_quoted_string] = STATE(333),
    [aux_sym_function_definition_repeat1] = STATE(250),
    [sym_identifier] = ACTIONS(545),
    [anon_sym_BSLASH] = ACTIONS(325),
    [anon_sym_function] = ACTIONS(329),
    [anon_sym_EQ] = ACTIONS(329),
    [anon_sym_if] = ACTIONS(329),
    [anon_sym_for] = ACTIONS(329),
    [anon_sym_while] = ACTIONS(329),
    [anon_sym_repeat] = ACTIONS(329),
    [anon_sym_QMARK] = ACTIONS(325),
    [anon_sym_TILDE] = ACTIONS(325),
    [anon_sym_BANG] = ACTIONS(329),
    [anon_sym_PLUS] = ACTIONS(325),
    [anon_sym_DASH] = ACTIONS(329),
    [anon_sym_LT_DASH] = ACTIONS(325),
    [anon_sym_LT_LT_DASH] = ACTIONS(325),
    [anon_sym_COLON_EQ] = ACTIONS(325),
    [anon_sym_DASH_GT] = ACTIONS(329),
    [anon_sym_DASH_GT_GT] = ACTIONS(325),
    [anon_sym_PIPE] = ACTIONS(329),
    [anon_sym_AMP] = ACTIONS(329),
    [anon_sym_PIPE_PIPE] = ACTIONS(325),
    [anon_sym_AMP_AMP] = ACTIONS(325),
    [anon_sym_LT] = ACTIONS(329),
    [anon_sym_LT_EQ] = ACTIONS(325),
    [anon_sym_GT] = ACTIONS(329),
    [anon_sym_GT_EQ] = ACTIONS(325),
    [anon_sym_EQ_EQ] = ACTIONS(325),
    [anon_sym_BANG_EQ] = ACTIONS(325),
    [anon_sym_STAR] = ACTIONS(329),
    [anon_sym_SLASH] = ACTIONS(325),
    [anon_sym_STAR_STAR] = ACTIONS(325),
    [anon_sym_CARET] = ACTIONS(325),
    [aux_sym_binary_operator_token1] = ACTIONS(325),
    [anon_sym_PIPE_GT] = ACTIONS(325),
    [anon_sym_COLON] = ACTIONS(329),
    [anon_sym_DOLLAR] = ACTIONS(325),
    [anon_sym_AT] = ACTIONS(325),
    [sym__hex_literal] = ACTIONS(325),
    [sym__number_literal] = ACTIONS(329),
    [anon_sym_SQUOTE] = ACTIONS(435),
    [anon_sym_DQUOTE] = ACTIONS(437),
    [sym_dots] = ACTIONS(545),
    [sym_dot_dot_i] = ACTIONS(545),
    [sym_next] = ACTIONS(329),
    [sym_break] = ACTIONS(329),
    [sym_true] = ACTIONS(329),
    [sym_false] = ACTIONS(329),
    [sym_null] = ACTIONS(329),
    [sym_inf] = ACTIONS(329),
    [sym_nan] = ACTIONS(329),
    [anon_sym_NA] = ACTIONS(329),
    [anon_sym_NA_integer_] = ACTIONS(329),
    [anon_sym_NA_real_] = ACTIONS(329),
    [anon_sym_NA_complex_] = ACTIONS(329),
    [anon_sym_NA_character_] = ACTIONS(329),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(547),
    [sym__semicolon] = ACTIONS(325),
    [sym__raw_string_open] = ACTIONS(439),
    [sym__external_open_parenthesis] = ACTIONS(325),
    [sym__external_open_brace] = ACTIONS(325),
    [sym__external_close_brace] = ACTIONS(325),
    [sym__external_open_bracket] = ACTIONS(325),
    [sym__external_open_bracket2] = ACTIONS(325),
  },
  [257] = {
    [sym_string] = STATE(340),
    [sym__raw_string] = STATE(290),
    [sym__single_quoted_string] = STATE(291),
    [sym__double_quoted_string] = STATE(286),
    [ts_builtin_sym_end] = ACTIONS(489),
    [sym_identifier] = ACTIONS(549),
    [anon_sym_BSLASH] = ACTIONS(489),
    [anon_sym_function] = ACTIONS(491),
    [anon_sym_EQ] = ACTIONS(491),
    [anon_sym_if] = ACTIONS(491),
    [anon_sym_for] = ACTIONS(491),
    [anon_sym_while] = ACTIONS(491),
    [anon_sym_repeat] = ACTIONS(491),
    [anon_sym_QMARK] = ACTIONS(489),
    [anon_sym_TILDE] = ACTIONS(489),
    [anon_sym_BANG] = ACTIONS(491),
    [anon_sym_PLUS] = ACTIONS(489),
    [anon_sym_DASH] = ACTIONS(491),
    [anon_sym_LT_DASH] = ACTIONS(489),
    [anon_sym_LT_LT_DASH] = ACTIONS(489),
    [anon_sym_COLON_EQ] = ACTIONS(489),
    [anon_sym_DASH_GT] = ACTIONS(491),
    [anon_sym_DASH_GT_GT] = ACTIONS(489),
    [anon_sym_PIPE] = ACTIONS(491),
    [anon_sym_AMP] = ACTIONS(491),
    [anon_sym_PIPE_PIPE] = ACTIONS(489),
    [anon_sym_AMP_AMP] = ACTIONS(489),
    [anon_sym_LT] = ACTIONS(491),
    [anon_sym_LT_EQ] = ACTIONS(489),
    [anon_sym_GT] = ACTIONS(491),
    [anon_sym_GT_EQ] = ACTIONS(489),
    [anon_sym_EQ_EQ] = ACTIONS(489),
    [anon_sym_BANG_EQ] = ACTIONS(489),
    [anon_sym_STAR] = ACTIONS(491),
    [anon_sym_SLASH] = ACTIONS(489),
    [anon_sym_STAR_STAR] = ACTIONS(489),
    [anon_sym_CARET] = ACTIONS(489),
    [aux_sym_binary_operator_token1] = ACTIONS(489),
    [anon_sym_PIPE_GT] = ACTIONS(489),
    [anon_sym_COLON] = ACTIONS(491),
    [anon_sym_DOLLAR] = ACTIONS(489),
    [anon_sym_AT] = ACTIONS(489),
    [sym__hex_literal] = ACTIONS(489),
    [sym__number_literal] = ACTIONS(491),
    [anon_sym_SQUOTE] = ACTIONS(331),
    [anon_sym_DQUOTE] = ACTIONS(333),
    [sym_dots] = ACTIONS(549),
    [sym_dot_dot_i] = ACTIONS(549),
    [sym_next] = ACTIONS(491),
    [sym_break] = ACTIONS(491),
    [sym_true] = ACTIONS(491),
    [sym_false] = ACTIONS(491),
    [sym_null] = ACTIONS(491),
    [sym_inf] = ACTIONS(491),
    [sym_nan] = ACTIONS(491),
    [anon_sym_NA] = ACTIONS(491),
    [anon_sym_NA_integer_] = ACTIONS(491),
    [anon_sym_NA_real_] = ACTIONS(491),
    [anon_sym_NA_complex_] = ACTIONS(491),
    [anon_sym_NA_character_] = ACTIONS(491),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(489),
    [sym__semicolon] = ACTIONS(489),
    [sym__raw_string_open] = ACTIONS(337),
    [sym__external_else] = ACTIONS(489),
    [sym__external_open_parenthesis] = ACTIONS(489),
    [sym__external_open_brace] = ACTIONS(489),
    [sym__external_open_bracket] = ACTIONS(489),
    [sym__external_open_bracket2] = ACTIONS(489),
  },
  [258] = {
    [sym_function_definition] = STATE(1372),
    [sym_if_statement] = STATE(1372),
    [sym_for_statement] = STATE(1372),
    [sym_while_statement] = STATE(1372),
    [sym_repeat_statement] = STATE(1372),
    [sym_braced_expression] = STATE(1372),
    [sym_parenthesized_expression] = STATE(1372),
    [sym_call] = STATE(1372),
    [sym_subset] = STATE(1372),
    [sym_subset2] = STATE(1372),
    [sym_argument] = STATE(1941),
    [sym__argument_named] = STATE(2070),
    [sym__argument_unnamed] = STATE(2056),
    [sym__argument_value] = STATE(2061),
    [sym_unary_operator] = STATE(1372),
    [sym_binary_operator] = STATE(1372),
    [sym_extract_operator] = STATE(1372),
    [sym_namespace_operator] = STATE(1372),
    [sym_integer] = STATE(1372),
    [sym_complex] = STATE(1372),
    [sym_float] = STATE(1372),
    [sym__float_literal] = STATE(1626),
    [sym_string] = STATE(1635),
    [sym__raw_string] = STATE(1627),
    [sym__single_quoted_string] = STATE(1628),
    [sym__double_quoted_string] = STATE(1629),
    [sym__argument_name_string_or_identifier_or_null] = STATE(2106),
    [sym_na] = STATE(1372),
    [sym__expression] = STATE(1372),
    [sym__open_parenthesis] = STATE(1065),
    [sym__close_parenthesis] = STATE(1736),
    [sym__open_brace] = STATE(381),
    [aux_sym_call_arguments_repeat1] = STATE(1996),
    [sym_identifier] = ACTIONS(497),
    [anon_sym_BSLASH] = ACTIONS(499),
    [anon_sym_function] = ACTIONS(501),
    [anon_sym_if] = ACTIONS(503),
    [anon_sym_for] = ACTIONS(505),
    [anon_sym_while] = ACTIONS(507),
    [anon_sym_repeat] = ACTIONS(509),
    [anon_sym_QMARK] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(513),
    [anon_sym_BANG] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(517),
    [anon_sym_DASH] = ACTIONS(517),
    [sym__hex_literal] = ACTIONS(519),
    [sym__number_literal] = ACTIONS(521),
    [anon_sym_SQUOTE] = ACTIONS(523),
    [anon_sym_DQUOTE] = ACTIONS(525),
    [sym_dots] = ACTIONS(497),
    [sym_dot_dot_i] = ACTIONS(497),
    [sym_next] = ACTIONS(527),
    [sym_break] = ACTIONS(527),
    [sym_true] = ACTIONS(527),
    [sym_false] = ACTIONS(527),
    [sym_null] = ACTIONS(529),
    [sym_inf] = ACTIONS(527),
    [sym_nan] = ACTIONS(527),
    [anon_sym_NA] = ACTIONS(531),
    [anon_sym_NA_integer_] = ACTIONS(531),
    [anon_sym_NA_real_] = ACTIONS(531),
    [anon_sym_NA_complex_] = ACTIONS(531),
    [anon_sym_NA_character_] = ACTIONS(531),
    [sym_comment] = ACTIONS(3),
    [sym_comma] = ACTIONS(533),
    [sym__raw_string_open] = ACTIONS(535),
    [sym__external_open_parenthesis] = ACTIONS(537),
    [sym__external_close_parenthesis] = ACTIONS(551),
    [sym__external_open_brace] = ACTIONS(541),
  },
  [259] = {
    [sym_function_definition] = STATE(1490),
    [sym_if_statement] = STATE(1490),
    [sym_for_statement] = STATE(1490),
    [sym_while_statement] = STATE(1490),
    [sym_repeat_statement] = STATE(1490),
    [sym_braced_expression] = STATE(1490),
    [sym_parenthesized_expression] = STATE(1490),
    [sym_call] = STATE(1490),
    [sym_subset] = STATE(1490),
    [sym_subset2] = STATE(1490),
    [sym_argument] = STATE(1829),
    [sym__argument_named] = STATE(2062),
    [sym__argument_unnamed] = STATE(2065),
    [sym__argument_value] = STATE(2071),
    [sym_unary_operator] = STATE(1490),
    [sym_binary_operator] = STATE(1490),
    [sym_extract_operator] = STATE(1490),
    [sym_namespace_operator] = STATE(1490),
    [sym_integer] = STATE(1490),
    [sym_complex] = STATE(1490),
    [sym_float] = STATE(1490),
    [sym__float_literal] = STATE(1649),
    [sym_string] = STATE(1636),
    [sym__raw_string] = STATE(1632),
    [sym__single_quoted_string] = STATE(1617),
    [sym__double_quoted_string] = STATE(1619),
    [sym__argument_name_string_or_identifier_or_null] = STATE(2082),
    [sym_na] = STATE(1490),
    [sym__expression] = STATE(1490),
    [sym__open_parenthesis] = STATE(1075),
    [sym__open_brace] = STATE(386),
    [sym__close_bracket] = STATE(1737),
    [aux_sym_call_arguments_repeat1] = STATE(1832),
    [sym_identifier] = ACTIONS(379),
    [anon_sym_BSLASH] = ACTIONS(381),
    [anon_sym_function] = ACTIONS(383),
    [anon_sym_if] = ACTIONS(385),
    [anon_sym_for] = ACTIONS(387),
    [anon_sym_while] = ACTIONS(389),
    [anon_sym_repeat] = ACTIONS(391),
    [anon_sym_QMARK] = ACTIONS(393),
    [anon_sym_TILDE] = ACTIONS(395),
    [anon_sym_BANG] = ACTIONS(397),
    [anon_sym_PLUS] = ACTIONS(399),
    [anon_sym_DASH] = ACTIONS(399),
    [sym__hex_literal] = ACTIONS(401),
    [sym__number_literal] = ACTIONS(403),
    [anon_sym_SQUOTE] = ACTIONS(405),
    [anon_sym_DQUOTE] = ACTIONS(407),
    [sym_dots] = ACTIONS(379),
    [sym_dot_dot_i] = ACTIONS(379),
    [sym_next] = ACTIONS(409),
    [sym_break] = ACTIONS(409),
    [sym_true] = ACTIONS(409),
    [sym_false] = ACTIONS(409),
    [sym_null] = ACTIONS(411),
    [sym_inf] = ACTIONS(409),
    [sym_nan] = ACTIONS(409),
    [anon_sym_NA] = ACTIONS(413),
    [anon_sym_NA_integer_] = ACTIONS(413),
    [anon_sym_NA_real_] = ACTIONS(413),
    [anon_sym_NA_complex_] = ACTIONS(413),
    [anon_sym_NA_character_] = ACTIONS(413),
    [sym_comment] = ACTIONS(3),
    [sym_comma] = ACTIONS(415),
    [sym__raw_string_open] = ACTIONS(417),
    [sym__external_open_parenthesis] = ACTIONS(419),
    [sym__external_open_brace] = ACTIONS(421),
    [sym__external_close_bracket] = ACTIONS(553),
  },
  [260] = {
    [sym_function_definition] = STATE(1552),
    [sym_if_statement] = STATE(1552),
    [sym_for_statement] = STATE(1552),
    [sym_while_statement] = STATE(1552),
    [sym_repeat_statement] = STATE(1552),
    [sym_braced_expression] = STATE(1552),
    [sym_parenthesized_expression] = STATE(1552),
    [sym_call] = STATE(1552),
    [sym_subset] = STATE(1552),
    [sym_subset2] = STATE(1552),
    [sym_argument] = STATE(1836),
    [sym__argument_named] = STATE(2077),
    [sym__argument_unnamed] = STATE(2060),
    [sym__argument_value] = STATE(2054),
    [sym_unary_operator] = STATE(1552),
    [sym_binary_operator] = STATE(1552),
    [sym_extract_operator] = STATE(1552),
    [sym_namespace_operator] = STATE(1552),
    [sym_integer] = STATE(1552),
    [sym_complex] = STATE(1552),
    [sym_float] = STATE(1552),
    [sym__float_literal] = STATE(1638),
    [sym_string] = STATE(1634),
    [sym__raw_string] = STATE(1639),
    [sym__single_quoted_string] = STATE(1641),
    [sym__double_quoted_string] = STATE(1651),
    [sym__argument_name_string_or_identifier_or_null] = STATE(2085),
    [sym_na] = STATE(1552),
    [sym__expression] = STATE(1552),
    [sym__open_parenthesis] = STATE(1080),
    [sym__open_brace] = STATE(389),
    [sym__close_bracket2] = STATE(1738),
    [aux_sym_call_arguments_repeat1] = STATE(1838),
    [sym_identifier] = ACTIONS(441),
    [anon_sym_BSLASH] = ACTIONS(443),
    [anon_sym_function] = ACTIONS(445),
    [anon_sym_if] = ACTIONS(447),
    [anon_sym_for] = ACTIONS(449),
    [anon_sym_while] = ACTIONS(451),
    [anon_sym_repeat] = ACTIONS(453),
    [anon_sym_QMARK] = ACTIONS(455),
    [anon_sym_TILDE] = ACTIONS(457),
    [anon_sym_BANG] = ACTIONS(459),
    [anon_sym_PLUS] = ACTIONS(461),
    [anon_sym_DASH] = ACTIONS(461),
    [sym__hex_literal] = ACTIONS(463),
    [sym__number_literal] = ACTIONS(465),
    [anon_sym_SQUOTE] = ACTIONS(467),
    [anon_sym_DQUOTE] = ACTIONS(469),
    [sym_dots] = ACTIONS(441),
    [sym_dot_dot_i] = ACTIONS(441),
    [sym_next] = ACTIONS(471),
    [sym_break] = ACTIONS(471),
    [sym_true] = ACTIONS(471),
    [sym_false] = ACTIONS(471),
    [sym_null] = ACTIONS(473),
    [sym_inf] = ACTIONS(471),
    [sym_nan] = ACTIONS(471),
    [anon_sym_NA] = ACTIONS(475),
    [anon_sym_NA_integer_] = ACTIONS(475),
    [anon_sym_NA_real_] = ACTIONS(475),
    [anon_sym_NA_complex_] = ACTIONS(475),
    [anon_sym_NA_character_] = ACTIONS(475),
    [sym_comment] = ACTIONS(3),
    [sym_comma] = ACTIONS(477),
    [sym__raw_string_open] = ACTIONS(479),
    [sym__external_open_parenthesis] = ACTIONS(481),
    [sym__external_open_brace] = ACTIONS(483),
    [sym__external_close_bracket2] = ACTIONS(555),
  },
  [261] = {
    [sym_function_definition] = STATE(1490),
    [sym_if_statement] = STATE(1490),
    [sym_for_statement] = STATE(1490),
    [sym_while_statement] = STATE(1490),
    [sym_repeat_statement] = STATE(1490),
    [sym_braced_expression] = STATE(1490),
    [sym_parenthesized_expression] = STATE(1490),
    [sym_call] = STATE(1490),
    [sym_subset] = STATE(1490),
    [sym_subset2] = STATE(1490),
    [sym_argument] = STATE(1933),
    [sym__argument_named] = STATE(2062),
    [sym__argument_unnamed] = STATE(2065),
    [sym__argument_value] = STATE(2071),
    [sym_unary_operator] = STATE(1490),
    [sym_binary_operator] = STATE(1490),
    [sym_extract_operator] = STATE(1490),
    [sym_namespace_operator] = STATE(1490),
    [sym_integer] = STATE(1490),
    [sym_complex] = STATE(1490),
    [sym_float] = STATE(1490),
    [sym__float_literal] = STATE(1649),
    [sym_string] = STATE(1636),
    [sym__raw_string] = STATE(1632),
    [sym__single_quoted_string] = STATE(1617),
    [sym__double_quoted_string] = STATE(1619),
    [sym__argument_name_string_or_identifier_or_null] = STATE(2082),
    [sym_na] = STATE(1490),
    [sym__expression] = STATE(1490),
    [sym__open_parenthesis] = STATE(1075),
    [sym__open_brace] = STATE(386),
    [sym__close_bracket] = STATE(450),
    [aux_sym_call_arguments_repeat1] = STATE(1967),
    [sym_identifier] = ACTIONS(379),
    [anon_sym_BSLASH] = ACTIONS(381),
    [anon_sym_function] = ACTIONS(383),
    [anon_sym_if] = ACTIONS(385),
    [anon_sym_for] = ACTIONS(387),
    [anon_sym_while] = ACTIONS(389),
    [anon_sym_repeat] = ACTIONS(391),
    [anon_sym_QMARK] = ACTIONS(393),
    [anon_sym_TILDE] = ACTIONS(395),
    [anon_sym_BANG] = ACTIONS(397),
    [anon_sym_PLUS] = ACTIONS(399),
    [anon_sym_DASH] = ACTIONS(399),
    [sym__hex_literal] = ACTIONS(401),
    [sym__number_literal] = ACTIONS(403),
    [anon_sym_SQUOTE] = ACTIONS(405),
    [anon_sym_DQUOTE] = ACTIONS(407),
    [sym_dots] = ACTIONS(379),
    [sym_dot_dot_i] = ACTIONS(379),
    [sym_next] = ACTIONS(409),
    [sym_break] = ACTIONS(409),
    [sym_true] = ACTIONS(409),
    [sym_false] = ACTIONS(409),
    [sym_null] = ACTIONS(411),
    [sym_inf] = ACTIONS(409),
    [sym_nan] = ACTIONS(409),
    [anon_sym_NA] = ACTIONS(413),
    [anon_sym_NA_integer_] = ACTIONS(413),
    [anon_sym_NA_real_] = ACTIONS(413),
    [anon_sym_NA_complex_] = ACTIONS(413),
    [anon_sym_NA_character_] = ACTIONS(413),
    [sym_comment] = ACTIONS(3),
    [sym_comma] = ACTIONS(415),
    [sym__raw_string_open] = ACTIONS(417),
    [sym__external_open_parenthesis] = ACTIONS(419),
    [sym__external_open_brace] = ACTIONS(421),
    [sym__external_close_bracket] = ACTIONS(557),
  },
  [262] = {
    [sym_function_definition] = STATE(1490),
    [sym_if_statement] = STATE(1490),
    [sym_for_statement] = STATE(1490),
    [sym_while_statement] = STATE(1490),
    [sym_repeat_statement] = STATE(1490),
    [sym_braced_expression] = STATE(1490),
    [sym_parenthesized_expression] = STATE(1490),
    [sym_call] = STATE(1490),
    [sym_subset] = STATE(1490),
    [sym_subset2] = STATE(1490),
    [sym_argument] = STATE(1866),
    [sym__argument_named] = STATE(2062),
    [sym__argument_unnamed] = STATE(2065),
    [sym__argument_value] = STATE(2071),
    [sym_unary_operator] = STATE(1490),
    [sym_binary_operator] = STATE(1490),
    [sym_extract_operator] = STATE(1490),
    [sym_namespace_operator] = STATE(1490),
    [sym_integer] = STATE(1490),
    [sym_complex] = STATE(1490),
    [sym_float] = STATE(1490),
    [sym__float_literal] = STATE(1649),
    [sym_string] = STATE(1636),
    [sym__raw_string] = STATE(1632),
    [sym__single_quoted_string] = STATE(1617),
    [sym__double_quoted_string] = STATE(1619),
    [sym__argument_name_string_or_identifier_or_null] = STATE(2082),
    [sym_na] = STATE(1490),
    [sym__expression] = STATE(1490),
    [sym__open_parenthesis] = STATE(1075),
    [sym__open_brace] = STATE(386),
    [sym__close_bracket] = STATE(1704),
    [aux_sym_call_arguments_repeat1] = STATE(1867),
    [sym_identifier] = ACTIONS(379),
    [anon_sym_BSLASH] = ACTIONS(381),
    [anon_sym_function] = ACTIONS(383),
    [anon_sym_if] = ACTIONS(385),
    [anon_sym_for] = ACTIONS(387),
    [anon_sym_while] = ACTIONS(389),
    [anon_sym_repeat] = ACTIONS(391),
    [anon_sym_QMARK] = ACTIONS(393),
    [anon_sym_TILDE] = ACTIONS(395),
    [anon_sym_BANG] = ACTIONS(397),
    [anon_sym_PLUS] = ACTIONS(399),
    [anon_sym_DASH] = ACTIONS(399),
    [sym__hex_literal] = ACTIONS(401),
    [sym__number_literal] = ACTIONS(403),
    [anon_sym_SQUOTE] = ACTIONS(405),
    [anon_sym_DQUOTE] = ACTIONS(407),
    [sym_dots] = ACTIONS(379),
    [sym_dot_dot_i] = ACTIONS(379),
    [sym_next] = ACTIONS(409),
    [sym_break] = ACTIONS(409),
    [sym_true] = ACTIONS(409),
    [sym_false] = ACTIONS(409),
    [sym_null] = ACTIONS(411),
    [sym_inf] = ACTIONS(409),
    [sym_nan] = ACTIONS(409),
    [anon_sym_NA] = ACTIONS(413),
    [anon_sym_NA_integer_] = ACTIONS(413),
    [anon_sym_NA_real_] = ACTIONS(413),
    [anon_sym_NA_complex_] = ACTIONS(413),
    [anon_sym_NA_character_] = ACTIONS(413),
    [sym_comment] = ACTIONS(3),
    [sym_comma] = ACTIONS(415),
    [sym__raw_string_open] = ACTIONS(417),
    [sym__external_open_parenthesis] = ACTIONS(419),
    [sym__external_open_brace] = ACTIONS(421),
    [sym__external_close_bracket] = ACTIONS(559),
  },
  [263] = {
    [sym_function_definition] = STATE(1490),
    [sym_if_statement] = STATE(1490),
    [sym_for_statement] = STATE(1490),
    [sym_while_statement] = STATE(1490),
    [sym_repeat_statement] = STATE(1490),
    [sym_braced_expression] = STATE(1490),
    [sym_parenthesized_expression] = STATE(1490),
    [sym_call] = STATE(1490),
    [sym_subset] = STATE(1490),
    [sym_subset2] = STATE(1490),
    [sym_argument] = STATE(1930),
    [sym__argument_named] = STATE(2062),
    [sym__argument_unnamed] = STATE(2065),
    [sym__argument_value] = STATE(2071),
    [sym_unary_operator] = STATE(1490),
    [sym_binary_operator] = STATE(1490),
    [sym_extract_operator] = STATE(1490),
    [sym_namespace_operator] = STATE(1490),
    [sym_integer] = STATE(1490),
    [sym_complex] = STATE(1490),
    [sym_float] = STATE(1490),
    [sym__float_literal] = STATE(1649),
    [sym_string] = STATE(1636),
    [sym__raw_string] = STATE(1632),
    [sym__single_quoted_string] = STATE(1617),
    [sym__double_quoted_string] = STATE(1619),
    [sym__argument_name_string_or_identifier_or_null] = STATE(2082),
    [sym_na] = STATE(1490),
    [sym__expression] = STATE(1490),
    [sym__open_parenthesis] = STATE(1075),
    [sym__open_brace] = STATE(386),
    [sym__close_bracket] = STATE(424),
    [aux_sym_call_arguments_repeat1] = STATE(1949),
    [sym_identifier] = ACTIONS(379),
    [anon_sym_BSLASH] = ACTIONS(381),
    [anon_sym_function] = ACTIONS(383),
    [anon_sym_if] = ACTIONS(385),
    [anon_sym_for] = ACTIONS(387),
    [anon_sym_while] = ACTIONS(389),
    [anon_sym_repeat] = ACTIONS(391),
    [anon_sym_QMARK] = ACTIONS(393),
    [anon_sym_TILDE] = ACTIONS(395),
    [anon_sym_BANG] = ACTIONS(397),
    [anon_sym_PLUS] = ACTIONS(399),
    [anon_sym_DASH] = ACTIONS(399),
    [sym__hex_literal] = ACTIONS(401),
    [sym__number_literal] = ACTIONS(403),
    [anon_sym_SQUOTE] = ACTIONS(405),
    [anon_sym_DQUOTE] = ACTIONS(407),
    [sym_dots] = ACTIONS(379),
    [sym_dot_dot_i] = ACTIONS(379),
    [sym_next] = ACTIONS(409),
    [sym_break] = ACTIONS(409),
    [sym_true] = ACTIONS(409),
    [sym_false] = ACTIONS(409),
    [sym_null] = ACTIONS(411),
    [sym_inf] = ACTIONS(409),
    [sym_nan] = ACTIONS(409),
    [anon_sym_NA] = ACTIONS(413),
    [anon_sym_NA_integer_] = ACTIONS(413),
    [anon_sym_NA_real_] = ACTIONS(413),
    [anon_sym_NA_complex_] = ACTIONS(413),
    [anon_sym_NA_character_] = ACTIONS(413),
    [sym_comment] = ACTIONS(3),
    [sym_comma] = ACTIONS(415),
    [sym__raw_string_open] = ACTIONS(417),
    [sym__external_open_parenthesis] = ACTIONS(419),
    [sym__external_open_brace] = ACTIONS(421),
    [sym__external_close_bracket] = ACTIONS(561),
  },
  [264] = {
    [sym_function_definition] = STATE(1552),
    [sym_if_statement] = STATE(1552),
    [sym_for_statement] = STATE(1552),
    [sym_while_statement] = STATE(1552),
    [sym_repeat_statement] = STATE(1552),
    [sym_braced_expression] = STATE(1552),
    [sym_parenthesized_expression] = STATE(1552),
    [sym_call] = STATE(1552),
    [sym_subset] = STATE(1552),
    [sym_subset2] = STATE(1552),
    [sym_argument] = STATE(1950),
    [sym__argument_named] = STATE(2077),
    [sym__argument_unnamed] = STATE(2060),
    [sym__argument_value] = STATE(2054),
    [sym_unary_operator] = STATE(1552),
    [sym_binary_operator] = STATE(1552),
    [sym_extract_operator] = STATE(1552),
    [sym_namespace_operator] = STATE(1552),
    [sym_integer] = STATE(1552),
    [sym_complex] = STATE(1552),
    [sym_float] = STATE(1552),
    [sym__float_literal] = STATE(1638),
    [sym_string] = STATE(1634),
    [sym__raw_string] = STATE(1639),
    [sym__single_quoted_string] = STATE(1641),
    [sym__double_quoted_string] = STATE(1651),
    [sym__argument_name_string_or_identifier_or_null] = STATE(2085),
    [sym_na] = STATE(1552),
    [sym__expression] = STATE(1552),
    [sym__open_parenthesis] = STATE(1080),
    [sym__open_brace] = STATE(389),
    [sym__close_bracket2] = STATE(426),
    [aux_sym_call_arguments_repeat1] = STATE(1963),
    [sym_identifier] = ACTIONS(441),
    [anon_sym_BSLASH] = ACTIONS(443),
    [anon_sym_function] = ACTIONS(445),
    [anon_sym_if] = ACTIONS(447),
    [anon_sym_for] = ACTIONS(449),
    [anon_sym_while] = ACTIONS(451),
    [anon_sym_repeat] = ACTIONS(453),
    [anon_sym_QMARK] = ACTIONS(455),
    [anon_sym_TILDE] = ACTIONS(457),
    [anon_sym_BANG] = ACTIONS(459),
    [anon_sym_PLUS] = ACTIONS(461),
    [anon_sym_DASH] = ACTIONS(461),
    [sym__hex_literal] = ACTIONS(463),
    [sym__number_literal] = ACTIONS(465),
    [anon_sym_SQUOTE] = ACTIONS(467),
    [anon_sym_DQUOTE] = ACTIONS(469),
    [sym_dots] = ACTIONS(441),
    [sym_dot_dot_i] = ACTIONS(441),
    [sym_next] = ACTIONS(471),
    [sym_break] = ACTIONS(471),
    [sym_true] = ACTIONS(471),
    [sym_false] = ACTIONS(471),
    [sym_null] = ACTIONS(473),
    [sym_inf] = ACTIONS(471),
    [sym_nan] = ACTIONS(471),
    [anon_sym_NA] = ACTIONS(475),
    [anon_sym_NA_integer_] = ACTIONS(475),
    [anon_sym_NA_real_] = ACTIONS(475),
    [anon_sym_NA_complex_] = ACTIONS(475),
    [anon_sym_NA_character_] = ACTIONS(475),
    [sym_comment] = ACTIONS(3),
    [sym_comma] = ACTIONS(477),
    [sym__raw_string_open] = ACTIONS(479),
    [sym__external_open_parenthesis] = ACTIONS(481),
    [sym__external_open_brace] = ACTIONS(483),
    [sym__external_close_bracket2] = ACTIONS(563),
  },
  [265] = {
    [sym_function_definition] = STATE(1372),
    [sym_if_statement] = STATE(1372),
    [sym_for_statement] = STATE(1372),
    [sym_while_statement] = STATE(1372),
    [sym_repeat_statement] = STATE(1372),
    [sym_braced_expression] = STATE(1372),
    [sym_parenthesized_expression] = STATE(1372),
    [sym_call] = STATE(1372),
    [sym_subset] = STATE(1372),
    [sym_subset2] = STATE(1372),
    [sym_argument] = STATE(1849),
    [sym__argument_named] = STATE(2070),
    [sym__argument_unnamed] = STATE(2056),
    [sym__argument_value] = STATE(2061),
    [sym_unary_operator] = STATE(1372),
    [sym_binary_operator] = STATE(1372),
    [sym_extract_operator] = STATE(1372),
    [sym_namespace_operator] = STATE(1372),
    [sym_integer] = STATE(1372),
    [sym_complex] = STATE(1372),
    [sym_float] = STATE(1372),
    [sym__float_literal] = STATE(1626),
    [sym_string] = STATE(1635),
    [sym__raw_string] = STATE(1627),
    [sym__single_quoted_string] = STATE(1628),
    [sym__double_quoted_string] = STATE(1629),
    [sym__argument_name_string_or_identifier_or_null] = STATE(2106),
    [sym_na] = STATE(1372),
    [sym__expression] = STATE(1372),
    [sym__open_parenthesis] = STATE(1065),
    [sym__close_parenthesis] = STATE(1799),
    [sym__open_brace] = STATE(381),
    [aux_sym_call_arguments_repeat1] = STATE(1850),
    [sym_identifier] = ACTIONS(497),
    [anon_sym_BSLASH] = ACTIONS(499),
    [anon_sym_function] = ACTIONS(501),
    [anon_sym_if] = ACTIONS(503),
    [anon_sym_for] = ACTIONS(505),
    [anon_sym_while] = ACTIONS(507),
    [anon_sym_repeat] = ACTIONS(509),
    [anon_sym_QMARK] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(513),
    [anon_sym_BANG] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(517),
    [anon_sym_DASH] = ACTIONS(517),
    [sym__hex_literal] = ACTIONS(519),
    [sym__number_literal] = ACTIONS(521),
    [anon_sym_SQUOTE] = ACTIONS(523),
    [anon_sym_DQUOTE] = ACTIONS(525),
    [sym_dots] = ACTIONS(497),
    [sym_dot_dot_i] = ACTIONS(497),
    [sym_next] = ACTIONS(527),
    [sym_break] = ACTIONS(527),
    [sym_true] = ACTIONS(527),
    [sym_false] = ACTIONS(527),
    [sym_null] = ACTIONS(529),
    [sym_inf] = ACTIONS(527),
    [sym_nan] = ACTIONS(527),
    [anon_sym_NA] = ACTIONS(531),
    [anon_sym_NA_integer_] = ACTIONS(531),
    [anon_sym_NA_real_] = ACTIONS(531),
    [anon_sym_NA_complex_] = ACTIONS(531),
    [anon_sym_NA_character_] = ACTIONS(531),
    [sym_comment] = ACTIONS(3),
    [sym_comma] = ACTIONS(533),
    [sym__raw_string_open] = ACTIONS(535),
    [sym__external_open_parenthesis] = ACTIONS(537),
    [sym__external_close_parenthesis] = ACTIONS(565),
    [sym__external_open_brace] = ACTIONS(541),
  },
  [266] = {
    [sym_function_definition] = STATE(1490),
    [sym_if_statement] = STATE(1490),
    [sym_for_statement] = STATE(1490),
    [sym_while_statement] = STATE(1490),
    [sym_repeat_statement] = STATE(1490),
    [sym_braced_expression] = STATE(1490),
    [sym_parenthesized_expression] = STATE(1490),
    [sym_call] = STATE(1490),
    [sym_subset] = STATE(1490),
    [sym_subset2] = STATE(1490),
    [sym_argument] = STATE(1971),
    [sym__argument_named] = STATE(2062),
    [sym__argument_unnamed] = STATE(2065),
    [sym__argument_value] = STATE(2071),
    [sym_unary_operator] = STATE(1490),
    [sym_binary_operator] = STATE(1490),
    [sym_extract_operator] = STATE(1490),
    [sym_namespace_operator] = STATE(1490),
    [sym_integer] = STATE(1490),
    [sym_complex] = STATE(1490),
    [sym_float] = STATE(1490),
    [sym__float_literal] = STATE(1649),
    [sym_string] = STATE(1636),
    [sym__raw_string] = STATE(1632),
    [sym__single_quoted_string] = STATE(1617),
    [sym__double_quoted_string] = STATE(1619),
    [sym__argument_name_string_or_identifier_or_null] = STATE(2082),
    [sym_na] = STATE(1490),
    [sym__expression] = STATE(1490),
    [sym__open_parenthesis] = STATE(1075),
    [sym__open_brace] = STATE(386),
    [sym__close_bracket] = STATE(1800),
    [aux_sym_call_arguments_repeat1] = STATE(1975),
    [sym_identifier] = ACTIONS(379),
    [anon_sym_BSLASH] = ACTIONS(381),
    [anon_sym_function] = ACTIONS(383),
    [anon_sym_if] = ACTIONS(385),
    [anon_sym_for] = ACTIONS(387),
    [anon_sym_while] = ACTIONS(389),
    [anon_sym_repeat] = ACTIONS(391),
    [anon_sym_QMARK] = ACTIONS(393),
    [anon_sym_TILDE] = ACTIONS(395),
    [anon_sym_BANG] = ACTIONS(397),
    [anon_sym_PLUS] = ACTIONS(399),
    [anon_sym_DASH] = ACTIONS(399),
    [sym__hex_literal] = ACTIONS(401),
    [sym__number_literal] = ACTIONS(403),
    [anon_sym_SQUOTE] = ACTIONS(405),
    [anon_sym_DQUOTE] = ACTIONS(407),
    [sym_dots] = ACTIONS(379),
    [sym_dot_dot_i] = ACTIONS(379),
    [sym_next] = ACTIONS(409),
    [sym_break] = ACTIONS(409),
    [sym_true] = ACTIONS(409),
    [sym_false] = ACTIONS(409),
    [sym_null] = ACTIONS(411),
    [sym_inf] = ACTIONS(409),
    [sym_nan] = ACTIONS(409),
    [anon_sym_NA] = ACTIONS(413),
    [anon_sym_NA_integer_] = ACTIONS(413),
    [anon_sym_NA_real_] = ACTIONS(413),
    [anon_sym_NA_complex_] = ACTIONS(413),
    [anon_sym_NA_character_] = ACTIONS(413),
    [sym_comment] = ACTIONS(3),
    [sym_comma] = ACTIONS(415),
    [sym__raw_string_open] = ACTIONS(417),
    [sym__external_open_parenthesis] = ACTIONS(419),
    [sym__external_open_brace] = ACTIONS(421),
    [sym__external_close_bracket] = ACTIONS(567),
  },
  [267] = {
    [sym_function_definition] = STATE(1552),
    [sym_if_statement] = STATE(1552),
    [sym_for_statement] = STATE(1552),
    [sym_while_statement] = STATE(1552),
    [sym_repeat_statement] = STATE(1552),
    [sym_braced_expression] = STATE(1552),
    [sym_parenthesized_expression] = STATE(1552),
    [sym_call] = STATE(1552),
    [sym_subset] = STATE(1552),
    [sym_subset2] = STATE(1552),
    [sym_argument] = STATE(1979),
    [sym__argument_named] = STATE(2077),
    [sym__argument_unnamed] = STATE(2060),
    [sym__argument_value] = STATE(2054),
    [sym_unary_operator] = STATE(1552),
    [sym_binary_operator] = STATE(1552),
    [sym_extract_operator] = STATE(1552),
    [sym_namespace_operator] = STATE(1552),
    [sym_integer] = STATE(1552),
    [sym_complex] = STATE(1552),
    [sym_float] = STATE(1552),
    [sym__float_literal] = STATE(1638),
    [sym_string] = STATE(1634),
    [sym__raw_string] = STATE(1639),
    [sym__single_quoted_string] = STATE(1641),
    [sym__double_quoted_string] = STATE(1651),
    [sym__argument_name_string_or_identifier_or_null] = STATE(2085),
    [sym_na] = STATE(1552),
    [sym__expression] = STATE(1552),
    [sym__open_parenthesis] = STATE(1080),
    [sym__open_brace] = STATE(389),
    [sym__close_bracket2] = STATE(1802),
    [aux_sym_call_arguments_repeat1] = STATE(1985),
    [sym_identifier] = ACTIONS(441),
    [anon_sym_BSLASH] = ACTIONS(443),
    [anon_sym_function] = ACTIONS(445),
    [anon_sym_if] = ACTIONS(447),
    [anon_sym_for] = ACTIONS(449),
    [anon_sym_while] = ACTIONS(451),
    [anon_sym_repeat] = ACTIONS(453),
    [anon_sym_QMARK] = ACTIONS(455),
    [anon_sym_TILDE] = ACTIONS(457),
    [anon_sym_BANG] = ACTIONS(459),
    [anon_sym_PLUS] = ACTIONS(461),
    [anon_sym_DASH] = ACTIONS(461),
    [sym__hex_literal] = ACTIONS(463),
    [sym__number_literal] = ACTIONS(465),
    [anon_sym_SQUOTE] = ACTIONS(467),
    [anon_sym_DQUOTE] = ACTIONS(469),
    [sym_dots] = ACTIONS(441),
    [sym_dot_dot_i] = ACTIONS(441),
    [sym_next] = ACTIONS(471),
    [sym_break] = ACTIONS(471),
    [sym_true] = ACTIONS(471),
    [sym_false] = ACTIONS(471),
    [sym_null] = ACTIONS(473),
    [sym_inf] = ACTIONS(471),
    [sym_nan] = ACTIONS(471),
    [anon_sym_NA] = ACTIONS(475),
    [anon_sym_NA_integer_] = ACTIONS(475),
    [anon_sym_NA_real_] = ACTIONS(475),
    [anon_sym_NA_complex_] = ACTIONS(475),
    [anon_sym_NA_character_] = ACTIONS(475),
    [sym_comment] = ACTIONS(3),
    [sym_comma] = ACTIONS(477),
    [sym__raw_string_open] = ACTIONS(479),
    [sym__external_open_parenthesis] = ACTIONS(481),
    [sym__external_open_brace] = ACTIONS(483),
    [sym__external_close_bracket2] = ACTIONS(569),
  },
  [268] = {
    [sym_function_definition] = STATE(1372),
    [sym_if_statement] = STATE(1372),
    [sym_for_statement] = STATE(1372),
    [sym_while_statement] = STATE(1372),
    [sym_repeat_statement] = STATE(1372),
    [sym_braced_expression] = STATE(1372),
    [sym_parenthesized_expression] = STATE(1372),
    [sym_call] = STATE(1372),
    [sym_subset] = STATE(1372),
    [sym_subset2] = STATE(1372),
    [sym_argument] = STATE(1896),
    [sym__argument_named] = STATE(2070),
    [sym__argument_unnamed] = STATE(2056),
    [sym__argument_value] = STATE(2061),
    [sym_unary_operator] = STATE(1372),
    [sym_binary_operator] = STATE(1372),
    [sym_extract_operator] = STATE(1372),
    [sym_namespace_operator] = STATE(1372),
    [sym_integer] = STATE(1372),
    [sym_complex] = STATE(1372),
    [sym_float] = STATE(1372),
    [sym__float_literal] = STATE(1626),
    [sym_string] = STATE(1635),
    [sym__raw_string] = STATE(1627),
    [sym__single_quoted_string] = STATE(1628),
    [sym__double_quoted_string] = STATE(1629),
    [sym__argument_name_string_or_identifier_or_null] = STATE(2106),
    [sym_na] = STATE(1372),
    [sym__expression] = STATE(1372),
    [sym__open_parenthesis] = STATE(1065),
    [sym__close_parenthesis] = STATE(1804),
    [sym__open_brace] = STATE(381),
    [aux_sym_call_arguments_repeat1] = STATE(1899),
    [sym_identifier] = ACTIONS(497),
    [anon_sym_BSLASH] = ACTIONS(499),
    [anon_sym_function] = ACTIONS(501),
    [anon_sym_if] = ACTIONS(503),
    [anon_sym_for] = ACTIONS(505),
    [anon_sym_while] = ACTIONS(507),
    [anon_sym_repeat] = ACTIONS(509),
    [anon_sym_QMARK] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(513),
    [anon_sym_BANG] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(517),
    [anon_sym_DASH] = ACTIONS(517),
    [sym__hex_literal] = ACTIONS(519),
    [sym__number_literal] = ACTIONS(521),
    [anon_sym_SQUOTE] = ACTIONS(523),
    [anon_sym_DQUOTE] = ACTIONS(525),
    [sym_dots] = ACTIONS(497),
    [sym_dot_dot_i] = ACTIONS(497),
    [sym_next] = ACTIONS(527),
    [sym_break] = ACTIONS(527),
    [sym_true] = ACTIONS(527),
    [sym_false] = ACTIONS(527),
    [sym_null] = ACTIONS(529),
    [sym_inf] = ACTIONS(527),
    [sym_nan] = ACTIONS(527),
    [anon_sym_NA] = ACTIONS(531),
    [anon_sym_NA_integer_] = ACTIONS(531),
    [anon_sym_NA_real_] = ACTIONS(531),
    [anon_sym_NA_complex_] = ACTIONS(531),
    [anon_sym_NA_character_] = ACTIONS(531),
    [sym_comment] = ACTIONS(3),
    [sym_comma] = ACTIONS(533),
    [sym__raw_string_open] = ACTIONS(535),
    [sym__external_open_parenthesis] = ACTIONS(537),
    [sym__external_close_parenthesis] = ACTIONS(571),
    [sym__external_open_brace] = ACTIONS(541),
  },
  [269] = {
    [sym_function_definition] = STATE(1490),
    [sym_if_statement] = STATE(1490),
    [sym_for_statement] = STATE(1490),
    [sym_while_statement] = STATE(1490),
    [sym_repeat_statement] = STATE(1490),
    [sym_braced_expression] = STATE(1490),
    [sym_parenthesized_expression] = STATE(1490),
    [sym_call] = STATE(1490),
    [sym_subset] = STATE(1490),
    [sym_subset2] = STATE(1490),
    [sym_argument] = STATE(1887),
    [sym__argument_named] = STATE(2062),
    [sym__argument_unnamed] = STATE(2065),
    [sym__argument_value] = STATE(2071),
    [sym_unary_operator] = STATE(1490),
    [sym_binary_operator] = STATE(1490),
    [sym_extract_operator] = STATE(1490),
    [sym_namespace_operator] = STATE(1490),
    [sym_integer] = STATE(1490),
    [sym_complex] = STATE(1490),
    [sym_float] = STATE(1490),
    [sym__float_literal] = STATE(1649),
    [sym_string] = STATE(1636),
    [sym__raw_string] = STATE(1632),
    [sym__single_quoted_string] = STATE(1617),
    [sym__double_quoted_string] = STATE(1619),
    [sym__argument_name_string_or_identifier_or_null] = STATE(2082),
    [sym_na] = STATE(1490),
    [sym__expression] = STATE(1490),
    [sym__open_parenthesis] = STATE(1075),
    [sym__open_brace] = STATE(386),
    [sym__close_bracket] = STATE(1728),
    [aux_sym_call_arguments_repeat1] = STATE(1918),
    [sym_identifier] = ACTIONS(379),
    [anon_sym_BSLASH] = ACTIONS(381),
    [anon_sym_function] = ACTIONS(383),
    [anon_sym_if] = ACTIONS(385),
    [anon_sym_for] = ACTIONS(387),
    [anon_sym_while] = ACTIONS(389),
    [anon_sym_repeat] = ACTIONS(391),
    [anon_sym_QMARK] = ACTIONS(393),
    [anon_sym_TILDE] = ACTIONS(395),
    [anon_sym_BANG] = ACTIONS(397),
    [anon_sym_PLUS] = ACTIONS(399),
    [anon_sym_DASH] = ACTIONS(399),
    [sym__hex_literal] = ACTIONS(401),
    [sym__number_literal] = ACTIONS(403),
    [anon_sym_SQUOTE] = ACTIONS(405),
    [anon_sym_DQUOTE] = ACTIONS(407),
    [sym_dots] = ACTIONS(379),
    [sym_dot_dot_i] = ACTIONS(379),
    [sym_next] = ACTIONS(409),
    [sym_break] = ACTIONS(409),
    [sym_true] = ACTIONS(409),
    [sym_false] = ACTIONS(409),
    [sym_null] = ACTIONS(411),
    [sym_inf] = ACTIONS(409),
    [sym_nan] = ACTIONS(409),
    [anon_sym_NA] = ACTIONS(413),
    [anon_sym_NA_integer_] = ACTIONS(413),
    [anon_sym_NA_real_] = ACTIONS(413),
    [anon_sym_NA_complex_] = ACTIONS(413),
    [anon_sym_NA_character_] = ACTIONS(413),
    [sym_comment] = ACTIONS(3),
    [sym_comma] = ACTIONS(415),
    [sym__raw_string_open] = ACTIONS(417),
    [sym__external_open_parenthesis] = ACTIONS(419),
    [sym__external_open_brace] = ACTIONS(421),
    [sym__external_close_bracket] = ACTIONS(573),
  },
  [270] = {
    [sym_function_definition] = STATE(1552),
    [sym_if_statement] = STATE(1552),
    [sym_for_statement] = STATE(1552),
    [sym_while_statement] = STATE(1552),
    [sym_repeat_statement] = STATE(1552),
    [sym_braced_expression] = STATE(1552),
    [sym_parenthesized_expression] = STATE(1552),
    [sym_call] = STATE(1552),
    [sym_subset] = STATE(1552),
    [sym_subset2] = STATE(1552),
    [sym_argument] = STATE(1945),
    [sym__argument_named] = STATE(2077),
    [sym__argument_unnamed] = STATE(2060),
    [sym__argument_value] = STATE(2054),
    [sym_unary_operator] = STATE(1552),
    [sym_binary_operator] = STATE(1552),
    [sym_extract_operator] = STATE(1552),
    [sym_namespace_operator] = STATE(1552),
    [sym_integer] = STATE(1552),
    [sym_complex] = STATE(1552),
    [sym_float] = STATE(1552),
    [sym__float_literal] = STATE(1638),
    [sym_string] = STATE(1634),
    [sym__raw_string] = STATE(1639),
    [sym__single_quoted_string] = STATE(1641),
    [sym__double_quoted_string] = STATE(1651),
    [sym__argument_name_string_or_identifier_or_null] = STATE(2085),
    [sym_na] = STATE(1552),
    [sym__expression] = STATE(1552),
    [sym__open_parenthesis] = STATE(1080),
    [sym__open_brace] = STATE(389),
    [sym__close_bracket2] = STATE(1744),
    [aux_sym_call_arguments_repeat1] = STATE(1969),
    [sym_identifier] = ACTIONS(441),
    [anon_sym_BSLASH] = ACTIONS(443),
    [anon_sym_function] = ACTIONS(445),
    [anon_sym_if] = ACTIONS(447),
    [anon_sym_for] = ACTIONS(449),
    [anon_sym_while] = ACTIONS(451),
    [anon_sym_repeat] = ACTIONS(453),
    [anon_sym_QMARK] = ACTIONS(455),
    [anon_sym_TILDE] = ACTIONS(457),
    [anon_sym_BANG] = ACTIONS(459),
    [anon_sym_PLUS] = ACTIONS(461),
    [anon_sym_DASH] = ACTIONS(461),
    [sym__hex_literal] = ACTIONS(463),
    [sym__number_literal] = ACTIONS(465),
    [anon_sym_SQUOTE] = ACTIONS(467),
    [anon_sym_DQUOTE] = ACTIONS(469),
    [sym_dots] = ACTIONS(441),
    [sym_dot_dot_i] = ACTIONS(441),
    [sym_next] = ACTIONS(471),
    [sym_break] = ACTIONS(471),
    [sym_true] = ACTIONS(471),
    [sym_false] = ACTIONS(471),
    [sym_null] = ACTIONS(473),
    [sym_inf] = ACTIONS(471),
    [sym_nan] = ACTIONS(471),
    [anon_sym_NA] = ACTIONS(475),
    [anon_sym_NA_integer_] = ACTIONS(475),
    [anon_sym_NA_real_] = ACTIONS(475),
    [anon_sym_NA_complex_] = ACTIONS(475),
    [anon_sym_NA_character_] = ACTIONS(475),
    [sym_comment] = ACTIONS(3),
    [sym_comma] = ACTIONS(477),
    [sym__raw_string_open] = ACTIONS(479),
    [sym__external_open_parenthesis] = ACTIONS(481),
    [sym__external_open_brace] = ACTIONS(483),
    [sym__external_close_bracket2] = ACTIONS(575),
  },
  [271] = {
    [sym_function_definition] = STATE(1372),
    [sym_if_statement] = STATE(1372),
    [sym_for_statement] = STATE(1372),
    [sym_while_statement] = STATE(1372),
    [sym_repeat_statement] = STATE(1372),
    [sym_braced_expression] = STATE(1372),
    [sym_parenthesized_expression] = STATE(1372),
    [sym_call] = STATE(1372),
    [sym_subset] = STATE(1372),
    [sym_subset2] = STATE(1372),
    [sym_argument] = STATE(1934),
    [sym__argument_named] = STATE(2070),
    [sym__argument_unnamed] = STATE(2056),
    [sym__argument_value] = STATE(2061),
    [sym_unary_operator] = STATE(1372),
    [sym_binary_operator] = STATE(1372),
    [sym_extract_operator] = STATE(1372),
    [sym_namespace_operator] = STATE(1372),
    [sym_integer] = STATE(1372),
    [sym_complex] = STATE(1372),
    [sym_float] = STATE(1372),
    [sym__float_literal] = STATE(1626),
    [sym_string] = STATE(1635),
    [sym__raw_string] = STATE(1627),
    [sym__single_quoted_string] = STATE(1628),
    [sym__double_quoted_string] = STATE(1629),
    [sym__argument_name_string_or_identifier_or_null] = STATE(2106),
    [sym_na] = STATE(1372),
    [sym__expression] = STATE(1372),
    [sym__open_parenthesis] = STATE(1065),
    [sym__close_parenthesis] = STATE(390),
    [sym__open_brace] = STATE(381),
    [aux_sym_call_arguments_repeat1] = STATE(1936),
    [sym_identifier] = ACTIONS(497),
    [anon_sym_BSLASH] = ACTIONS(499),
    [anon_sym_function] = ACTIONS(501),
    [anon_sym_if] = ACTIONS(503),
    [anon_sym_for] = ACTIONS(505),
    [anon_sym_while] = ACTIONS(507),
    [anon_sym_repeat] = ACTIONS(509),
    [anon_sym_QMARK] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(513),
    [anon_sym_BANG] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(517),
    [anon_sym_DASH] = ACTIONS(517),
    [sym__hex_literal] = ACTIONS(519),
    [sym__number_literal] = ACTIONS(521),
    [anon_sym_SQUOTE] = ACTIONS(523),
    [anon_sym_DQUOTE] = ACTIONS(525),
    [sym_dots] = ACTIONS(497),
    [sym_dot_dot_i] = ACTIONS(497),
    [sym_next] = ACTIONS(527),
    [sym_break] = ACTIONS(527),
    [sym_true] = ACTIONS(527),
    [sym_false] = ACTIONS(527),
    [sym_null] = ACTIONS(529),
    [sym_inf] = ACTIONS(527),
    [sym_nan] = ACTIONS(527),
    [anon_sym_NA] = ACTIONS(531),
    [anon_sym_NA_integer_] = ACTIONS(531),
    [anon_sym_NA_real_] = ACTIONS(531),
    [anon_sym_NA_complex_] = ACTIONS(531),
    [anon_sym_NA_character_] = ACTIONS(531),
    [sym_comment] = ACTIONS(3),
    [sym_comma] = ACTIONS(533),
    [sym__raw_string_open] = ACTIONS(535),
    [sym__external_open_parenthesis] = ACTIONS(537),
    [sym__external_close_parenthesis] = ACTIONS(577),
    [sym__external_open_brace] = ACTIONS(541),
  },
  [272] = {
    [sym_function_definition] = STATE(1490),
    [sym_if_statement] = STATE(1490),
    [sym_for_statement] = STATE(1490),
    [sym_while_statement] = STATE(1490),
    [sym_repeat_statement] = STATE(1490),
    [sym_braced_expression] = STATE(1490),
    [sym_parenthesized_expression] = STATE(1490),
    [sym_call] = STATE(1490),
    [sym_subset] = STATE(1490),
    [sym_subset2] = STATE(1490),
    [sym_argument] = STATE(1951),
    [sym__argument_named] = STATE(2062),
    [sym__argument_unnamed] = STATE(2065),
    [sym__argument_value] = STATE(2071),
    [sym_unary_operator] = STATE(1490),
    [sym_binary_operator] = STATE(1490),
    [sym_extract_operator] = STATE(1490),
    [sym_namespace_operator] = STATE(1490),
    [sym_integer] = STATE(1490),
    [sym_complex] = STATE(1490),
    [sym_float] = STATE(1490),
    [sym__float_literal] = STATE(1649),
    [sym_string] = STATE(1636),
    [sym__raw_string] = STATE(1632),
    [sym__single_quoted_string] = STATE(1617),
    [sym__double_quoted_string] = STATE(1619),
    [sym__argument_name_string_or_identifier_or_null] = STATE(2082),
    [sym_na] = STATE(1490),
    [sym__expression] = STATE(1490),
    [sym__open_parenthesis] = STATE(1075),
    [sym__open_brace] = STATE(386),
    [sym__close_bracket] = STATE(391),
    [aux_sym_call_arguments_repeat1] = STATE(1955),
    [sym_identifier] = ACTIONS(379),
    [anon_sym_BSLASH] = ACTIONS(381),
    [anon_sym_function] = ACTIONS(383),
    [anon_sym_if] = ACTIONS(385),
    [anon_sym_for] = ACTIONS(387),
    [anon_sym_while] = ACTIONS(389),
    [anon_sym_repeat] = ACTIONS(391),
    [anon_sym_QMARK] = ACTIONS(393),
    [anon_sym_TILDE] = ACTIONS(395),
    [anon_sym_BANG] = ACTIONS(397),
    [anon_sym_PLUS] = ACTIONS(399),
    [anon_sym_DASH] = ACTIONS(399),
    [sym__hex_literal] = ACTIONS(401),
    [sym__number_literal] = ACTIONS(403),
    [anon_sym_SQUOTE] = ACTIONS(405),
    [anon_sym_DQUOTE] = ACTIONS(407),
    [sym_dots] = ACTIONS(379),
    [sym_dot_dot_i] = ACTIONS(379),
    [sym_next] = ACTIONS(409),
    [sym_break] = ACTIONS(409),
    [sym_true] = ACTIONS(409),
    [sym_false] = ACTIONS(409),
    [sym_null] = ACTIONS(411),
    [sym_inf] = ACTIONS(409),
    [sym_nan] = ACTIONS(409),
    [anon_sym_NA] = ACTIONS(413),
    [anon_sym_NA_integer_] = ACTIONS(413),
    [anon_sym_NA_real_] = ACTIONS(413),
    [anon_sym_NA_complex_] = ACTIONS(413),
    [anon_sym_NA_character_] = ACTIONS(413),
    [sym_comment] = ACTIONS(3),
    [sym_comma] = ACTIONS(415),
    [sym__raw_string_open] = ACTIONS(417),
    [sym__external_open_parenthesis] = ACTIONS(419),
    [sym__external_open_brace] = ACTIONS(421),
    [sym__external_close_bracket] = ACTIONS(579),
  },
  [273] = {
    [sym_function_definition] = STATE(1552),
    [sym_if_statement] = STATE(1552),
    [sym_for_statement] = STATE(1552),
    [sym_while_statement] = STATE(1552),
    [sym_repeat_statement] = STATE(1552),
    [sym_braced_expression] = STATE(1552),
    [sym_parenthesized_expression] = STATE(1552),
    [sym_call] = STATE(1552),
    [sym_subset] = STATE(1552),
    [sym_subset2] = STATE(1552),
    [sym_argument] = STATE(1958),
    [sym__argument_named] = STATE(2077),
    [sym__argument_unnamed] = STATE(2060),
    [sym__argument_value] = STATE(2054),
    [sym_unary_operator] = STATE(1552),
    [sym_binary_operator] = STATE(1552),
    [sym_extract_operator] = STATE(1552),
    [sym_namespace_operator] = STATE(1552),
    [sym_integer] = STATE(1552),
    [sym_complex] = STATE(1552),
    [sym_float] = STATE(1552),
    [sym__float_literal] = STATE(1638),
    [sym_string] = STATE(1634),
    [sym__raw_string] = STATE(1639),
    [sym__single_quoted_string] = STATE(1641),
    [sym__double_quoted_string] = STATE(1651),
    [sym__argument_name_string_or_identifier_or_null] = STATE(2085),
    [sym_na] = STATE(1552),
    [sym__expression] = STATE(1552),
    [sym__open_parenthesis] = STATE(1080),
    [sym__open_brace] = STATE(389),
    [sym__close_bracket2] = STATE(392),
    [aux_sym_call_arguments_repeat1] = STATE(1977),
    [sym_identifier] = ACTIONS(441),
    [anon_sym_BSLASH] = ACTIONS(443),
    [anon_sym_function] = ACTIONS(445),
    [anon_sym_if] = ACTIONS(447),
    [anon_sym_for] = ACTIONS(449),
    [anon_sym_while] = ACTIONS(451),
    [anon_sym_repeat] = ACTIONS(453),
    [anon_sym_QMARK] = ACTIONS(455),
    [anon_sym_TILDE] = ACTIONS(457),
    [anon_sym_BANG] = ACTIONS(459),
    [anon_sym_PLUS] = ACTIONS(461),
    [anon_sym_DASH] = ACTIONS(461),
    [sym__hex_literal] = ACTIONS(463),
    [sym__number_literal] = ACTIONS(465),
    [anon_sym_SQUOTE] = ACTIONS(467),
    [anon_sym_DQUOTE] = ACTIONS(469),
    [sym_dots] = ACTIONS(441),
    [sym_dot_dot_i] = ACTIONS(441),
    [sym_next] = ACTIONS(471),
    [sym_break] = ACTIONS(471),
    [sym_true] = ACTIONS(471),
    [sym_false] = ACTIONS(471),
    [sym_null] = ACTIONS(473),
    [sym_inf] = ACTIONS(471),
    [sym_nan] = ACTIONS(471),
    [anon_sym_NA] = ACTIONS(475),
    [anon_sym_NA_integer_] = ACTIONS(475),
    [anon_sym_NA_real_] = ACTIONS(475),
    [anon_sym_NA_complex_] = ACTIONS(475),
    [anon_sym_NA_character_] = ACTIONS(475),
    [sym_comment] = ACTIONS(3),
    [sym_comma] = ACTIONS(477),
    [sym__raw_string_open] = ACTIONS(479),
    [sym__external_open_parenthesis] = ACTIONS(481),
    [sym__external_open_brace] = ACTIONS(483),
    [sym__external_close_bracket2] = ACTIONS(581),
  },
  [274] = {
    [sym_function_definition] = STATE(1372),
    [sym_if_statement] = STATE(1372),
    [sym_for_statement] = STATE(1372),
    [sym_while_statement] = STATE(1372),
    [sym_repeat_statement] = STATE(1372),
    [sym_braced_expression] = STATE(1372),
    [sym_parenthesized_expression] = STATE(1372),
    [sym_call] = STATE(1372),
    [sym_subset] = STATE(1372),
    [sym_subset2] = STATE(1372),
    [sym_argument] = STATE(2020),
    [sym__argument_named] = STATE(2070),
    [sym__argument_unnamed] = STATE(2056),
    [sym__argument_value] = STATE(2061),
    [sym_unary_operator] = STATE(1372),
    [sym_binary_operator] = STATE(1372),
    [sym_extract_operator] = STATE(1372),
    [sym_namespace_operator] = STATE(1372),
    [sym_integer] = STATE(1372),
    [sym_complex] = STATE(1372),
    [sym_float] = STATE(1372),
    [sym__float_literal] = STATE(1626),
    [sym_string] = STATE(1635),
    [sym__raw_string] = STATE(1627),
    [sym__single_quoted_string] = STATE(1628),
    [sym__double_quoted_string] = STATE(1629),
    [sym__argument_name_string_or_identifier_or_null] = STATE(2106),
    [sym_na] = STATE(1372),
    [sym__expression] = STATE(1372),
    [sym__open_parenthesis] = STATE(1065),
    [sym__close_parenthesis] = STATE(1722),
    [sym__open_brace] = STATE(381),
    [aux_sym_call_arguments_repeat1] = STATE(1840),
    [sym_identifier] = ACTIONS(497),
    [anon_sym_BSLASH] = ACTIONS(499),
    [anon_sym_function] = ACTIONS(501),
    [anon_sym_if] = ACTIONS(503),
    [anon_sym_for] = ACTIONS(505),
    [anon_sym_while] = ACTIONS(507),
    [anon_sym_repeat] = ACTIONS(509),
    [anon_sym_QMARK] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(513),
    [anon_sym_BANG] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(517),
    [anon_sym_DASH] = ACTIONS(517),
    [sym__hex_literal] = ACTIONS(519),
    [sym__number_literal] = ACTIONS(521),
    [anon_sym_SQUOTE] = ACTIONS(523),
    [anon_sym_DQUOTE] = ACTIONS(525),
    [sym_dots] = ACTIONS(497),
    [sym_dot_dot_i] = ACTIONS(497),
    [sym_next] = ACTIONS(527),
    [sym_break] = ACTIONS(527),
    [sym_true] = ACTIONS(527),
    [sym_false] = ACTIONS(527),
    [sym_null] = ACTIONS(529),
    [sym_inf] = ACTIONS(527),
    [sym_nan] = ACTIONS(527),
    [anon_sym_NA] = ACTIONS(531),
    [anon_sym_NA_integer_] = ACTIONS(531),
    [anon_sym_NA_real_] = ACTIONS(531),
    [anon_sym_NA_complex_] = ACTIONS(531),
    [anon_sym_NA_character_] = ACTIONS(531),
    [sym_comment] = ACTIONS(3),
    [sym_comma] = ACTIONS(533),
    [sym__raw_string_open] = ACTIONS(535),
    [sym__external_open_parenthesis] = ACTIONS(537),
    [sym__external_close_parenthesis] = ACTIONS(583),
    [sym__external_open_brace] = ACTIONS(541),
  },
  [275] = {
    [sym_function_definition] = STATE(1552),
    [sym_if_statement] = STATE(1552),
    [sym_for_statement] = STATE(1552),
    [sym_while_statement] = STATE(1552),
    [sym_repeat_statement] = STATE(1552),
    [sym_braced_expression] = STATE(1552),
    [sym_parenthesized_expression] = STATE(1552),
    [sym_call] = STATE(1552),
    [sym_subset] = STATE(1552),
    [sym_subset2] = STATE(1552),
    [sym_argument] = STATE(1940),
    [sym__argument_named] = STATE(2077),
    [sym__argument_unnamed] = STATE(2060),
    [sym__argument_value] = STATE(2054),
    [sym_unary_operator] = STATE(1552),
    [sym_binary_operator] = STATE(1552),
    [sym_extract_operator] = STATE(1552),
    [sym_namespace_operator] = STATE(1552),
    [sym_integer] = STATE(1552),
    [sym_complex] = STATE(1552),
    [sym_float] = STATE(1552),
    [sym__float_literal] = STATE(1638),
    [sym_string] = STATE(1634),
    [sym__raw_string] = STATE(1639),
    [sym__single_quoted_string] = STATE(1641),
    [sym__double_quoted_string] = STATE(1651),
    [sym__argument_name_string_or_identifier_or_null] = STATE(2085),
    [sym_na] = STATE(1552),
    [sym__expression] = STATE(1552),
    [sym__open_parenthesis] = STATE(1080),
    [sym__open_brace] = STATE(389),
    [sym__close_bracket2] = STATE(1724),
    [aux_sym_call_arguments_repeat1] = STATE(1944),
    [sym_identifier] = ACTIONS(441),
    [anon_sym_BSLASH] = ACTIONS(443),
    [anon_sym_function] = ACTIONS(445),
    [anon_sym_if] = ACTIONS(447),
    [anon_sym_for] = ACTIONS(449),
    [anon_sym_while] = ACTIONS(451),
    [anon_sym_repeat] = ACTIONS(453),
    [anon_sym_QMARK] = ACTIONS(455),
    [anon_sym_TILDE] = ACTIONS(457),
    [anon_sym_BANG] = ACTIONS(459),
    [anon_sym_PLUS] = ACTIONS(461),
    [anon_sym_DASH] = ACTIONS(461),
    [sym__hex_literal] = ACTIONS(463),
    [sym__number_literal] = ACTIONS(465),
    [anon_sym_SQUOTE] = ACTIONS(467),
    [anon_sym_DQUOTE] = ACTIONS(469),
    [sym_dots] = ACTIONS(441),
    [sym_dot_dot_i] = ACTIONS(441),
    [sym_next] = ACTIONS(471),
    [sym_break] = ACTIONS(471),
    [sym_true] = ACTIONS(471),
    [sym_false] = ACTIONS(471),
    [sym_null] = ACTIONS(473),
    [sym_inf] = ACTIONS(471),
    [sym_nan] = ACTIONS(471),
    [anon_sym_NA] = ACTIONS(475),
    [anon_sym_NA_integer_] = ACTIONS(475),
    [anon_sym_NA_real_] = ACTIONS(475),
    [anon_sym_NA_complex_] = ACTIONS(475),
    [anon_sym_NA_character_] = ACTIONS(475),
    [sym_comment] = ACTIONS(3),
    [sym_comma] = ACTIONS(477),
    [sym__raw_string_open] = ACTIONS(479),
    [sym__external_open_parenthesis] = ACTIONS(481),
    [sym__external_open_brace] = ACTIONS(483),
    [sym__external_close_bracket2] = ACTIONS(585),
  },
  [276] = {
    [sym_function_definition] = STATE(1372),
    [sym_if_statement] = STATE(1372),
    [sym_for_statement] = STATE(1372),
    [sym_while_statement] = STATE(1372),
    [sym_repeat_statement] = STATE(1372),
    [sym_braced_expression] = STATE(1372),
    [sym_parenthesized_expression] = STATE(1372),
    [sym_call] = STATE(1372),
    [sym_subset] = STATE(1372),
    [sym_subset2] = STATE(1372),
    [sym_argument] = STATE(1858),
    [sym__argument_named] = STATE(2070),
    [sym__argument_unnamed] = STATE(2056),
    [sym__argument_value] = STATE(2061),
    [sym_unary_operator] = STATE(1372),
    [sym_binary_operator] = STATE(1372),
    [sym_extract_operator] = STATE(1372),
    [sym_namespace_operator] = STATE(1372),
    [sym_integer] = STATE(1372),
    [sym_complex] = STATE(1372),
    [sym_float] = STATE(1372),
    [sym__float_literal] = STATE(1626),
    [sym_string] = STATE(1635),
    [sym__raw_string] = STATE(1627),
    [sym__single_quoted_string] = STATE(1628),
    [sym__double_quoted_string] = STATE(1629),
    [sym__argument_name_string_or_identifier_or_null] = STATE(2106),
    [sym_na] = STATE(1372),
    [sym__expression] = STATE(1372),
    [sym__open_parenthesis] = STATE(1065),
    [sym__close_parenthesis] = STATE(343),
    [sym__open_brace] = STATE(381),
    [aux_sym_call_arguments_repeat1] = STATE(1859),
    [sym_identifier] = ACTIONS(497),
    [anon_sym_BSLASH] = ACTIONS(499),
    [anon_sym_function] = ACTIONS(501),
    [anon_sym_if] = ACTIONS(503),
    [anon_sym_for] = ACTIONS(505),
    [anon_sym_while] = ACTIONS(507),
    [anon_sym_repeat] = ACTIONS(509),
    [anon_sym_QMARK] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(513),
    [anon_sym_BANG] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(517),
    [anon_sym_DASH] = ACTIONS(517),
    [sym__hex_literal] = ACTIONS(519),
    [sym__number_literal] = ACTIONS(521),
    [anon_sym_SQUOTE] = ACTIONS(523),
    [anon_sym_DQUOTE] = ACTIONS(525),
    [sym_dots] = ACTIONS(497),
    [sym_dot_dot_i] = ACTIONS(497),
    [sym_next] = ACTIONS(527),
    [sym_break] = ACTIONS(527),
    [sym_true] = ACTIONS(527),
    [sym_false] = ACTIONS(527),
    [sym_null] = ACTIONS(529),
    [sym_inf] = ACTIONS(527),
    [sym_nan] = ACTIONS(527),
    [anon_sym_NA] = ACTIONS(531),
    [anon_sym_NA_integer_] = ACTIONS(531),
    [anon_sym_NA_real_] = ACTIONS(531),
    [anon_sym_NA_complex_] = ACTIONS(531),
    [anon_sym_NA_character_] = ACTIONS(531),
    [sym_comment] = ACTIONS(3),
    [sym_comma] = ACTIONS(533),
    [sym__raw_string_open] = ACTIONS(535),
    [sym__external_open_parenthesis] = ACTIONS(537),
    [sym__external_close_parenthesis] = ACTIONS(587),
    [sym__external_open_brace] = ACTIONS(541),
  },
  [277] = {
    [sym_function_definition] = STATE(1490),
    [sym_if_statement] = STATE(1490),
    [sym_for_statement] = STATE(1490),
    [sym_while_statement] = STATE(1490),
    [sym_repeat_statement] = STATE(1490),
    [sym_braced_expression] = STATE(1490),
    [sym_parenthesized_expression] = STATE(1490),
    [sym_call] = STATE(1490),
    [sym_subset] = STATE(1490),
    [sym_subset2] = STATE(1490),
    [sym_argument] = STATE(1907),
    [sym__argument_named] = STATE(2062),
    [sym__argument_unnamed] = STATE(2065),
    [sym__argument_value] = STATE(2071),
    [sym_unary_operator] = STATE(1490),
    [sym_binary_operator] = STATE(1490),
    [sym_extract_operator] = STATE(1490),
    [sym_namespace_operator] = STATE(1490),
    [sym_integer] = STATE(1490),
    [sym_complex] = STATE(1490),
    [sym_float] = STATE(1490),
    [sym__float_literal] = STATE(1649),
    [sym_string] = STATE(1636),
    [sym__raw_string] = STATE(1632),
    [sym__single_quoted_string] = STATE(1617),
    [sym__double_quoted_string] = STATE(1619),
    [sym__argument_name_string_or_identifier_or_null] = STATE(2082),
    [sym_na] = STATE(1490),
    [sym__expression] = STATE(1490),
    [sym__open_parenthesis] = STATE(1075),
    [sym__open_brace] = STATE(386),
    [sym__close_bracket] = STATE(344),
    [aux_sym_call_arguments_repeat1] = STATE(1908),
    [sym_identifier] = ACTIONS(379),
    [anon_sym_BSLASH] = ACTIONS(381),
    [anon_sym_function] = ACTIONS(383),
    [anon_sym_if] = ACTIONS(385),
    [anon_sym_for] = ACTIONS(387),
    [anon_sym_while] = ACTIONS(389),
    [anon_sym_repeat] = ACTIONS(391),
    [anon_sym_QMARK] = ACTIONS(393),
    [anon_sym_TILDE] = ACTIONS(395),
    [anon_sym_BANG] = ACTIONS(397),
    [anon_sym_PLUS] = ACTIONS(399),
    [anon_sym_DASH] = ACTIONS(399),
    [sym__hex_literal] = ACTIONS(401),
    [sym__number_literal] = ACTIONS(403),
    [anon_sym_SQUOTE] = ACTIONS(405),
    [anon_sym_DQUOTE] = ACTIONS(407),
    [sym_dots] = ACTIONS(379),
    [sym_dot_dot_i] = ACTIONS(379),
    [sym_next] = ACTIONS(409),
    [sym_break] = ACTIONS(409),
    [sym_true] = ACTIONS(409),
    [sym_false] = ACTIONS(409),
    [sym_null] = ACTIONS(411),
    [sym_inf] = ACTIONS(409),
    [sym_nan] = ACTIONS(409),
    [anon_sym_NA] = ACTIONS(413),
    [anon_sym_NA_integer_] = ACTIONS(413),
    [anon_sym_NA_real_] = ACTIONS(413),
    [anon_sym_NA_complex_] = ACTIONS(413),
    [anon_sym_NA_character_] = ACTIONS(413),
    [sym_comment] = ACTIONS(3),
    [sym_comma] = ACTIONS(415),
    [sym__raw_string_open] = ACTIONS(417),
    [sym__external_open_parenthesis] = ACTIONS(419),
    [sym__external_open_brace] = ACTIONS(421),
    [sym__external_close_bracket] = ACTIONS(589),
  },
  [278] = {
    [sym_function_definition] = STATE(1552),
    [sym_if_statement] = STATE(1552),
    [sym_for_statement] = STATE(1552),
    [sym_while_statement] = STATE(1552),
    [sym_repeat_statement] = STATE(1552),
    [sym_braced_expression] = STATE(1552),
    [sym_parenthesized_expression] = STATE(1552),
    [sym_call] = STATE(1552),
    [sym_subset] = STATE(1552),
    [sym_subset2] = STATE(1552),
    [sym_argument] = STATE(1909),
    [sym__argument_named] = STATE(2077),
    [sym__argument_unnamed] = STATE(2060),
    [sym__argument_value] = STATE(2054),
    [sym_unary_operator] = STATE(1552),
    [sym_binary_operator] = STATE(1552),
    [sym_extract_operator] = STATE(1552),
    [sym_namespace_operator] = STATE(1552),
    [sym_integer] = STATE(1552),
    [sym_complex] = STATE(1552),
    [sym_float] = STATE(1552),
    [sym__float_literal] = STATE(1638),
    [sym_string] = STATE(1634),
    [sym__raw_string] = STATE(1639),
    [sym__single_quoted_string] = STATE(1641),
    [sym__double_quoted_string] = STATE(1651),
    [sym__argument_name_string_or_identifier_or_null] = STATE(2085),
    [sym_na] = STATE(1552),
    [sym__expression] = STATE(1552),
    [sym__open_parenthesis] = STATE(1080),
    [sym__open_brace] = STATE(389),
    [sym__close_bracket2] = STATE(345),
    [aux_sym_call_arguments_repeat1] = STATE(1912),
    [sym_identifier] = ACTIONS(441),
    [anon_sym_BSLASH] = ACTIONS(443),
    [anon_sym_function] = ACTIONS(445),
    [anon_sym_if] = ACTIONS(447),
    [anon_sym_for] = ACTIONS(449),
    [anon_sym_while] = ACTIONS(451),
    [anon_sym_repeat] = ACTIONS(453),
    [anon_sym_QMARK] = ACTIONS(455),
    [anon_sym_TILDE] = ACTIONS(457),
    [anon_sym_BANG] = ACTIONS(459),
    [anon_sym_PLUS] = ACTIONS(461),
    [anon_sym_DASH] = ACTIONS(461),
    [sym__hex_literal] = ACTIONS(463),
    [sym__number_literal] = ACTIONS(465),
    [anon_sym_SQUOTE] = ACTIONS(467),
    [anon_sym_DQUOTE] = ACTIONS(469),
    [sym_dots] = ACTIONS(441),
    [sym_dot_dot_i] = ACTIONS(441),
    [sym_next] = ACTIONS(471),
    [sym_break] = ACTIONS(471),
    [sym_true] = ACTIONS(471),
    [sym_false] = ACTIONS(471),
    [sym_null] = ACTIONS(473),
    [sym_inf] = ACTIONS(471),
    [sym_nan] = ACTIONS(471),
    [anon_sym_NA] = ACTIONS(475),
    [anon_sym_NA_integer_] = ACTIONS(475),
    [anon_sym_NA_real_] = ACTIONS(475),
    [anon_sym_NA_complex_] = ACTIONS(475),
    [anon_sym_NA_character_] = ACTIONS(475),
    [sym_comment] = ACTIONS(3),
    [sym_comma] = ACTIONS(477),
    [sym__raw_string_open] = ACTIONS(479),
    [sym__external_open_parenthesis] = ACTIONS(481),
    [sym__external_open_brace] = ACTIONS(483),
    [sym__external_close_bracket2] = ACTIONS(591),
  },
  [279] = {
    [sym_function_definition] = STATE(1372),
    [sym_if_statement] = STATE(1372),
    [sym_for_statement] = STATE(1372),
    [sym_while_statement] = STATE(1372),
    [sym_repeat_statement] = STATE(1372),
    [sym_braced_expression] = STATE(1372),
    [sym_parenthesized_expression] = STATE(1372),
    [sym_call] = STATE(1372),
    [sym_subset] = STATE(1372),
    [sym_subset2] = STATE(1372),
    [sym_argument] = STATE(1879),
    [sym__argument_named] = STATE(2070),
    [sym__argument_unnamed] = STATE(2056),
    [sym__argument_value] = STATE(2061),
    [sym_unary_operator] = STATE(1372),
    [sym_binary_operator] = STATE(1372),
    [sym_extract_operator] = STATE(1372),
    [sym_namespace_operator] = STATE(1372),
    [sym_integer] = STATE(1372),
    [sym_complex] = STATE(1372),
    [sym_float] = STATE(1372),
    [sym__float_literal] = STATE(1626),
    [sym_string] = STATE(1635),
    [sym__raw_string] = STATE(1627),
    [sym__single_quoted_string] = STATE(1628),
    [sym__double_quoted_string] = STATE(1629),
    [sym__argument_name_string_or_identifier_or_null] = STATE(2106),
    [sym_na] = STATE(1372),
    [sym__expression] = STATE(1372),
    [sym__open_parenthesis] = STATE(1065),
    [sym__close_parenthesis] = STATE(1654),
    [sym__open_brace] = STATE(381),
    [aux_sym_call_arguments_repeat1] = STATE(1880),
    [sym_identifier] = ACTIONS(497),
    [anon_sym_BSLASH] = ACTIONS(499),
    [anon_sym_function] = ACTIONS(501),
    [anon_sym_if] = ACTIONS(503),
    [anon_sym_for] = ACTIONS(505),
    [anon_sym_while] = ACTIONS(507),
    [anon_sym_repeat] = ACTIONS(509),
    [anon_sym_QMARK] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(513),
    [anon_sym_BANG] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(517),
    [anon_sym_DASH] = ACTIONS(517),
    [sym__hex_literal] = ACTIONS(519),
    [sym__number_literal] = ACTIONS(521),
    [anon_sym_SQUOTE] = ACTIONS(523),
    [anon_sym_DQUOTE] = ACTIONS(525),
    [sym_dots] = ACTIONS(497),
    [sym_dot_dot_i] = ACTIONS(497),
    [sym_next] = ACTIONS(527),
    [sym_break] = ACTIONS(527),
    [sym_true] = ACTIONS(527),
    [sym_false] = ACTIONS(527),
    [sym_null] = ACTIONS(529),
    [sym_inf] = ACTIONS(527),
    [sym_nan] = ACTIONS(527),
    [anon_sym_NA] = ACTIONS(531),
    [anon_sym_NA_integer_] = ACTIONS(531),
    [anon_sym_NA_real_] = ACTIONS(531),
    [anon_sym_NA_complex_] = ACTIONS(531),
    [anon_sym_NA_character_] = ACTIONS(531),
    [sym_comment] = ACTIONS(3),
    [sym_comma] = ACTIONS(533),
    [sym__raw_string_open] = ACTIONS(535),
    [sym__external_open_parenthesis] = ACTIONS(537),
    [sym__external_close_parenthesis] = ACTIONS(593),
    [sym__external_open_brace] = ACTIONS(541),
  },
  [280] = {
    [sym_function_definition] = STATE(1490),
    [sym_if_statement] = STATE(1490),
    [sym_for_statement] = STATE(1490),
    [sym_while_statement] = STATE(1490),
    [sym_repeat_statement] = STATE(1490),
    [sym_braced_expression] = STATE(1490),
    [sym_parenthesized_expression] = STATE(1490),
    [sym_call] = STATE(1490),
    [sym_subset] = STATE(1490),
    [sym_subset2] = STATE(1490),
    [sym_argument] = STATE(1860),
    [sym__argument_named] = STATE(2062),
    [sym__argument_unnamed] = STATE(2065),
    [sym__argument_value] = STATE(2071),
    [sym_unary_operator] = STATE(1490),
    [sym_binary_operator] = STATE(1490),
    [sym_extract_operator] = STATE(1490),
    [sym_namespace_operator] = STATE(1490),
    [sym_integer] = STATE(1490),
    [sym_complex] = STATE(1490),
    [sym_float] = STATE(1490),
    [sym__float_literal] = STATE(1649),
    [sym_string] = STATE(1636),
    [sym__raw_string] = STATE(1632),
    [sym__single_quoted_string] = STATE(1617),
    [sym__double_quoted_string] = STATE(1619),
    [sym__argument_name_string_or_identifier_or_null] = STATE(2082),
    [sym_na] = STATE(1490),
    [sym__expression] = STATE(1490),
    [sym__open_parenthesis] = STATE(1075),
    [sym__open_brace] = STATE(386),
    [sym__close_bracket] = STATE(1670),
    [aux_sym_call_arguments_repeat1] = STATE(1863),
    [sym_identifier] = ACTIONS(379),
    [anon_sym_BSLASH] = ACTIONS(381),
    [anon_sym_function] = ACTIONS(383),
    [anon_sym_if] = ACTIONS(385),
    [anon_sym_for] = ACTIONS(387),
    [anon_sym_while] = ACTIONS(389),
    [anon_sym_repeat] = ACTIONS(391),
    [anon_sym_QMARK] = ACTIONS(393),
    [anon_sym_TILDE] = ACTIONS(395),
    [anon_sym_BANG] = ACTIONS(397),
    [anon_sym_PLUS] = ACTIONS(399),
    [anon_sym_DASH] = ACTIONS(399),
    [sym__hex_literal] = ACTIONS(401),
    [sym__number_literal] = ACTIONS(403),
    [anon_sym_SQUOTE] = ACTIONS(405),
    [anon_sym_DQUOTE] = ACTIONS(407),
    [sym_dots] = ACTIONS(379),
    [sym_dot_dot_i] = ACTIONS(379),
    [sym_next] = ACTIONS(409),
    [sym_break] = ACTIONS(409),
    [sym_true] = ACTIONS(409),
    [sym_false] = ACTIONS(409),
    [sym_null] = ACTIONS(411),
    [sym_inf] = ACTIONS(409),
    [sym_nan] = ACTIONS(409),
    [anon_sym_NA] = ACTIONS(413),
    [anon_sym_NA_integer_] = ACTIONS(413),
    [anon_sym_NA_real_] = ACTIONS(413),
    [anon_sym_NA_complex_] = ACTIONS(413),
    [anon_sym_NA_character_] = ACTIONS(413),
    [sym_comment] = ACTIONS(3),
    [sym_comma] = ACTIONS(415),
    [sym__raw_string_open] = ACTIONS(417),
    [sym__external_open_parenthesis] = ACTIONS(419),
    [sym__external_open_brace] = ACTIONS(421),
    [sym__external_close_bracket] = ACTIONS(595),
  },
  [281] = {
    [sym_function_definition] = STATE(1552),
    [sym_if_statement] = STATE(1552),
    [sym_for_statement] = STATE(1552),
    [sym_while_statement] = STATE(1552),
    [sym_repeat_statement] = STATE(1552),
    [sym_braced_expression] = STATE(1552),
    [sym_parenthesized_expression] = STATE(1552),
    [sym_call] = STATE(1552),
    [sym_subset] = STATE(1552),
    [sym_subset2] = STATE(1552),
    [sym_argument] = STATE(1864),
    [sym__argument_named] = STATE(2077),
    [sym__argument_unnamed] = STATE(2060),
    [sym__argument_value] = STATE(2054),
    [sym_unary_operator] = STATE(1552),
    [sym_binary_operator] = STATE(1552),
    [sym_extract_operator] = STATE(1552),
    [sym_namespace_operator] = STATE(1552),
    [sym_integer] = STATE(1552),
    [sym_complex] = STATE(1552),
    [sym_float] = STATE(1552),
    [sym__float_literal] = STATE(1638),
    [sym_string] = STATE(1634),
    [sym__raw_string] = STATE(1639),
    [sym__single_quoted_string] = STATE(1641),
    [sym__double_quoted_string] = STATE(1651),
    [sym__argument_name_string_or_identifier_or_null] = STATE(2085),
    [sym_na] = STATE(1552),
    [sym__expression] = STATE(1552),
    [sym__open_parenthesis] = STATE(1080),
    [sym__open_brace] = STATE(389),
    [sym__close_bracket2] = STATE(1671),
    [aux_sym_call_arguments_repeat1] = STATE(1894),
    [sym_identifier] = ACTIONS(441),
    [anon_sym_BSLASH] = ACTIONS(443),
    [anon_sym_function] = ACTIONS(445),
    [anon_sym_if] = ACTIONS(447),
    [anon_sym_for] = ACTIONS(449),
    [anon_sym_while] = ACTIONS(451),
    [anon_sym_repeat] = ACTIONS(453),
    [anon_sym_QMARK] = ACTIONS(455),
    [anon_sym_TILDE] = ACTIONS(457),
    [anon_sym_BANG] = ACTIONS(459),
    [anon_sym_PLUS] = ACTIONS(461),
    [anon_sym_DASH] = ACTIONS(461),
    [sym__hex_literal] = ACTIONS(463),
    [sym__number_literal] = ACTIONS(465),
    [anon_sym_SQUOTE] = ACTIONS(467),
    [anon_sym_DQUOTE] = ACTIONS(469),
    [sym_dots] = ACTIONS(441),
    [sym_dot_dot_i] = ACTIONS(441),
    [sym_next] = ACTIONS(471),
    [sym_break] = ACTIONS(471),
    [sym_true] = ACTIONS(471),
    [sym_false] = ACTIONS(471),
    [sym_null] = ACTIONS(473),
    [sym_inf] = ACTIONS(471),
    [sym_nan] = ACTIONS(471),
    [anon_sym_NA] = ACTIONS(475),
    [anon_sym_NA_integer_] = ACTIONS(475),
    [anon_sym_NA_real_] = ACTIONS(475),
    [anon_sym_NA_complex_] = ACTIONS(475),
    [anon_sym_NA_character_] = ACTIONS(475),
    [sym_comment] = ACTIONS(3),
    [sym_comma] = ACTIONS(477),
    [sym__raw_string_open] = ACTIONS(479),
    [sym__external_open_parenthesis] = ACTIONS(481),
    [sym__external_open_brace] = ACTIONS(483),
    [sym__external_close_bracket2] = ACTIONS(597),
  },
  [282] = {
    [sym_function_definition] = STATE(1372),
    [sym_if_statement] = STATE(1372),
    [sym_for_statement] = STATE(1372),
    [sym_while_statement] = STATE(1372),
    [sym_repeat_statement] = STATE(1372),
    [sym_braced_expression] = STATE(1372),
    [sym_parenthesized_expression] = STATE(1372),
    [sym_call] = STATE(1372),
    [sym_subset] = STATE(1372),
    [sym_subset2] = STATE(1372),
    [sym_argument] = STATE(1897),
    [sym__argument_named] = STATE(2070),
    [sym__argument_unnamed] = STATE(2056),
    [sym__argument_value] = STATE(2061),
    [sym_unary_operator] = STATE(1372),
    [sym_binary_operator] = STATE(1372),
    [sym_extract_operator] = STATE(1372),
    [sym_namespace_operator] = STATE(1372),
    [sym_integer] = STATE(1372),
    [sym_complex] = STATE(1372),
    [sym_float] = STATE(1372),
    [sym__float_literal] = STATE(1626),
    [sym_string] = STATE(1635),
    [sym__raw_string] = STATE(1627),
    [sym__single_quoted_string] = STATE(1628),
    [sym__double_quoted_string] = STATE(1629),
    [sym__argument_name_string_or_identifier_or_null] = STATE(2106),
    [sym_na] = STATE(1372),
    [sym__expression] = STATE(1372),
    [sym__open_parenthesis] = STATE(1065),
    [sym__close_parenthesis] = STATE(1703),
    [sym__open_brace] = STATE(381),
    [aux_sym_call_arguments_repeat1] = STATE(1898),
    [sym_identifier] = ACTIONS(497),
    [anon_sym_BSLASH] = ACTIONS(499),
    [anon_sym_function] = ACTIONS(501),
    [anon_sym_if] = ACTIONS(503),
    [anon_sym_for] = ACTIONS(505),
    [anon_sym_while] = ACTIONS(507),
    [anon_sym_repeat] = ACTIONS(509),
    [anon_sym_QMARK] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(513),
    [anon_sym_BANG] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(517),
    [anon_sym_DASH] = ACTIONS(517),
    [sym__hex_literal] = ACTIONS(519),
    [sym__number_literal] = ACTIONS(521),
    [anon_sym_SQUOTE] = ACTIONS(523),
    [anon_sym_DQUOTE] = ACTIONS(525),
    [sym_dots] = ACTIONS(497),
    [sym_dot_dot_i] = ACTIONS(497),
    [sym_next] = ACTIONS(527),
    [sym_break] = ACTIONS(527),
    [sym_true] = ACTIONS(527),
    [sym_false] = ACTIONS(527),
    [sym_null] = ACTIONS(529),
    [sym_inf] = ACTIONS(527),
    [sym_nan] = ACTIONS(527),
    [anon_sym_NA] = ACTIONS(531),
    [anon_sym_NA_integer_] = ACTIONS(531),
    [anon_sym_NA_real_] = ACTIONS(531),
    [anon_sym_NA_complex_] = ACTIONS(531),
    [anon_sym_NA_character_] = ACTIONS(531),
    [sym_comment] = ACTIONS(3),
    [sym_comma] = ACTIONS(533),
    [sym__raw_string_open] = ACTIONS(535),
    [sym__external_open_parenthesis] = ACTIONS(537),
    [sym__external_close_parenthesis] = ACTIONS(599),
    [sym__external_open_brace] = ACTIONS(541),
  },
  [283] = {
    [sym_function_definition] = STATE(1372),
    [sym_if_statement] = STATE(1372),
    [sym_for_statement] = STATE(1372),
    [sym_while_statement] = STATE(1372),
    [sym_repeat_statement] = STATE(1372),
    [sym_braced_expression] = STATE(1372),
    [sym_parenthesized_expression] = STATE(1372),
    [sym_call] = STATE(1372),
    [sym_subset] = STATE(1372),
    [sym_subset2] = STATE(1372),
    [sym_argument] = STATE(1906),
    [sym__argument_named] = STATE(2070),
    [sym__argument_unnamed] = STATE(2056),
    [sym__argument_value] = STATE(2061),
    [sym_unary_operator] = STATE(1372),
    [sym_binary_operator] = STATE(1372),
    [sym_extract_operator] = STATE(1372),
    [sym_namespace_operator] = STATE(1372),
    [sym_integer] = STATE(1372),
    [sym_complex] = STATE(1372),
    [sym_float] = STATE(1372),
    [sym__float_literal] = STATE(1626),
    [sym_string] = STATE(1635),
    [sym__raw_string] = STATE(1627),
    [sym__single_quoted_string] = STATE(1628),
    [sym__double_quoted_string] = STATE(1629),
    [sym__argument_name_string_or_identifier_or_null] = STATE(2106),
    [sym_na] = STATE(1372),
    [sym__expression] = STATE(1372),
    [sym__open_parenthesis] = STATE(1065),
    [sym__close_parenthesis] = STATE(412),
    [sym__open_brace] = STATE(381),
    [aux_sym_call_arguments_repeat1] = STATE(1914),
    [sym_identifier] = ACTIONS(497),
    [anon_sym_BSLASH] = ACTIONS(499),
    [anon_sym_function] = ACTIONS(501),
    [anon_sym_if] = ACTIONS(503),
    [anon_sym_for] = ACTIONS(505),
    [anon_sym_while] = ACTIONS(507),
    [anon_sym_repeat] = ACTIONS(509),
    [anon_sym_QMARK] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(513),
    [anon_sym_BANG] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(517),
    [anon_sym_DASH] = ACTIONS(517),
    [sym__hex_literal] = ACTIONS(519),
    [sym__number_literal] = ACTIONS(521),
    [anon_sym_SQUOTE] = ACTIONS(523),
    [anon_sym_DQUOTE] = ACTIONS(525),
    [sym_dots] = ACTIONS(497),
    [sym_dot_dot_i] = ACTIONS(497),
    [sym_next] = ACTIONS(527),
    [sym_break] = ACTIONS(527),
    [sym_true] = ACTIONS(527),
    [sym_false] = ACTIONS(527),
    [sym_null] = ACTIONS(529),
    [sym_inf] = ACTIONS(527),
    [sym_nan] = ACTIONS(527),
    [anon_sym_NA] = ACTIONS(531),
    [anon_sym_NA_integer_] = ACTIONS(531),
    [anon_sym_NA_real_] = ACTIONS(531),
    [anon_sym_NA_complex_] = ACTIONS(531),
    [anon_sym_NA_character_] = ACTIONS(531),
    [sym_comment] = ACTIONS(3),
    [sym_comma] = ACTIONS(533),
    [sym__raw_string_open] = ACTIONS(535),
    [sym__external_open_parenthesis] = ACTIONS(537),
    [sym__external_close_parenthesis] = ACTIONS(601),
    [sym__external_open_brace] = ACTIONS(541),
  },
  [284] = {
    [sym_string] = STATE(417),
    [sym__raw_string] = STATE(319),
    [sym__single_quoted_string] = STATE(324),
    [sym__double_quoted_string] = STATE(325),
    [ts_builtin_sym_end] = ACTIONS(489),
    [sym_identifier] = ACTIONS(603),
    [anon_sym_BSLASH] = ACTIONS(489),
    [anon_sym_function] = ACTIONS(491),
    [anon_sym_EQ] = ACTIONS(491),
    [anon_sym_if] = ACTIONS(491),
    [anon_sym_for] = ACTIONS(491),
    [anon_sym_while] = ACTIONS(491),
    [anon_sym_repeat] = ACTIONS(491),
    [anon_sym_QMARK] = ACTIONS(489),
    [anon_sym_TILDE] = ACTIONS(489),
    [anon_sym_BANG] = ACTIONS(491),
    [anon_sym_PLUS] = ACTIONS(489),
    [anon_sym_DASH] = ACTIONS(491),
    [anon_sym_LT_DASH] = ACTIONS(489),
    [anon_sym_LT_LT_DASH] = ACTIONS(489),
    [anon_sym_COLON_EQ] = ACTIONS(489),
    [anon_sym_DASH_GT] = ACTIONS(491),
    [anon_sym_DASH_GT_GT] = ACTIONS(489),
    [anon_sym_PIPE] = ACTIONS(491),
    [anon_sym_AMP] = ACTIONS(491),
    [anon_sym_PIPE_PIPE] = ACTIONS(489),
    [anon_sym_AMP_AMP] = ACTIONS(489),
    [anon_sym_LT] = ACTIONS(491),
    [anon_sym_LT_EQ] = ACTIONS(489),
    [anon_sym_GT] = ACTIONS(491),
    [anon_sym_GT_EQ] = ACTIONS(489),
    [anon_sym_EQ_EQ] = ACTIONS(489),
    [anon_sym_BANG_EQ] = ACTIONS(489),
    [anon_sym_STAR] = ACTIONS(491),
    [anon_sym_SLASH] = ACTIONS(489),
    [anon_sym_STAR_STAR] = ACTIONS(489),
    [anon_sym_CARET] = ACTIONS(489),
    [aux_sym_binary_operator_token1] = ACTIONS(489),
    [anon_sym_PIPE_GT] = ACTIONS(489),
    [anon_sym_COLON] = ACTIONS(491),
    [anon_sym_DOLLAR] = ACTIONS(489),
    [anon_sym_AT] = ACTIONS(489),
    [sym__hex_literal] = ACTIONS(489),
    [sym__number_literal] = ACTIONS(491),
    [anon_sym_SQUOTE] = ACTIONS(427),
    [anon_sym_DQUOTE] = ACTIONS(429),
    [sym_dots] = ACTIONS(603),
    [sym_dot_dot_i] = ACTIONS(603),
    [sym_next] = ACTIONS(491),
    [sym_break] = ACTIONS(491),
    [sym_true] = ACTIONS(491),
    [sym_false] = ACTIONS(491),
    [sym_null] = ACTIONS(491),
    [sym_inf] = ACTIONS(491),
    [sym_nan] = ACTIONS(491),
    [anon_sym_NA] = ACTIONS(491),
    [anon_sym_NA_integer_] = ACTIONS(491),
    [anon_sym_NA_real_] = ACTIONS(491),
    [anon_sym_NA_complex_] = ACTIONS(491),
    [anon_sym_NA_character_] = ACTIONS(491),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(489),
    [sym__semicolon] = ACTIONS(489),
    [sym__raw_string_open] = ACTIONS(431),
    [sym__external_open_parenthesis] = ACTIONS(489),
    [sym__external_open_brace] = ACTIONS(489),
    [sym__external_open_bracket] = ACTIONS(489),
    [sym__external_open_bracket2] = ACTIONS(489),
  },
  [285] = {
    [sym_string] = STATE(411),
    [sym__raw_string] = STATE(331),
    [sym__single_quoted_string] = STATE(332),
    [sym__double_quoted_string] = STATE(333),
    [sym_identifier] = ACTIONS(605),
    [anon_sym_BSLASH] = ACTIONS(489),
    [anon_sym_function] = ACTIONS(491),
    [anon_sym_EQ] = ACTIONS(491),
    [anon_sym_if] = ACTIONS(491),
    [anon_sym_for] = ACTIONS(491),
    [anon_sym_while] = ACTIONS(491),
    [anon_sym_repeat] = ACTIONS(491),
    [anon_sym_QMARK] = ACTIONS(489),
    [anon_sym_TILDE] = ACTIONS(489),
    [anon_sym_BANG] = ACTIONS(491),
    [anon_sym_PLUS] = ACTIONS(489),
    [anon_sym_DASH] = ACTIONS(491),
    [anon_sym_LT_DASH] = ACTIONS(489),
    [anon_sym_LT_LT_DASH] = ACTIONS(489),
    [anon_sym_COLON_EQ] = ACTIONS(489),
    [anon_sym_DASH_GT] = ACTIONS(491),
    [anon_sym_DASH_GT_GT] = ACTIONS(489),
    [anon_sym_PIPE] = ACTIONS(491),
    [anon_sym_AMP] = ACTIONS(491),
    [anon_sym_PIPE_PIPE] = ACTIONS(489),
    [anon_sym_AMP_AMP] = ACTIONS(489),
    [anon_sym_LT] = ACTIONS(491),
    [anon_sym_LT_EQ] = ACTIONS(489),
    [anon_sym_GT] = ACTIONS(491),
    [anon_sym_GT_EQ] = ACTIONS(489),
    [anon_sym_EQ_EQ] = ACTIONS(489),
    [anon_sym_BANG_EQ] = ACTIONS(489),
    [anon_sym_STAR] = ACTIONS(491),
    [anon_sym_SLASH] = ACTIONS(489),
    [anon_sym_STAR_STAR] = ACTIONS(489),
    [anon_sym_CARET] = ACTIONS(489),
    [aux_sym_binary_operator_token1] = ACTIONS(489),
    [anon_sym_PIPE_GT] = ACTIONS(489),
    [anon_sym_COLON] = ACTIONS(491),
    [anon_sym_DOLLAR] = ACTIONS(489),
    [anon_sym_AT] = ACTIONS(489),
    [sym__hex_literal] = ACTIONS(489),
    [sym__number_literal] = ACTIONS(491),
    [anon_sym_SQUOTE] = ACTIONS(435),
    [anon_sym_DQUOTE] = ACTIONS(437),
    [sym_dots] = ACTIONS(605),
    [sym_dot_dot_i] = ACTIONS(605),
    [sym_next] = ACTIONS(491),
    [sym_break] = ACTIONS(491),
    [sym_true] = ACTIONS(491),
    [sym_false] = ACTIONS(491),
    [sym_null] = ACTIONS(491),
    [sym_inf] = ACTIONS(491),
    [sym_nan] = ACTIONS(491),
    [anon_sym_NA] = ACTIONS(491),
    [anon_sym_NA_integer_] = ACTIONS(491),
    [anon_sym_NA_real_] = ACTIONS(491),
    [anon_sym_NA_complex_] = ACTIONS(491),
    [anon_sym_NA_character_] = ACTIONS(491),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(489),
    [sym__semicolon] = ACTIONS(489),
    [sym__raw_string_open] = ACTIONS(439),
    [sym__external_open_parenthesis] = ACTIONS(489),
    [sym__external_open_brace] = ACTIONS(489),
    [sym__external_close_brace] = ACTIONS(489),
    [sym__external_open_bracket] = ACTIONS(489),
    [sym__external_open_bracket2] = ACTIONS(489),
  },
  [286] = {
    [ts_builtin_sym_end] = ACTIONS(607),
    [sym_identifier] = ACTIONS(609),
    [anon_sym_BSLASH] = ACTIONS(607),
    [anon_sym_function] = ACTIONS(609),
    [anon_sym_EQ] = ACTIONS(609),
    [anon_sym_if] = ACTIONS(609),
    [anon_sym_for] = ACTIONS(609),
    [anon_sym_while] = ACTIONS(609),
    [anon_sym_repeat] = ACTIONS(609),
    [anon_sym_QMARK] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(607),
    [anon_sym_BANG] = ACTIONS(609),
    [anon_sym_PLUS] = ACTIONS(607),
    [anon_sym_DASH] = ACTIONS(609),
    [anon_sym_LT_DASH] = ACTIONS(607),
    [anon_sym_LT_LT_DASH] = ACTIONS(607),
    [anon_sym_COLON_EQ] = ACTIONS(607),
    [anon_sym_DASH_GT] = ACTIONS(609),
    [anon_sym_DASH_GT_GT] = ACTIONS(607),
    [anon_sym_PIPE] = ACTIONS(609),
    [anon_sym_AMP] = ACTIONS(609),
    [anon_sym_PIPE_PIPE] = ACTIONS(607),
    [anon_sym_AMP_AMP] = ACTIONS(607),
    [anon_sym_LT] = ACTIONS(609),
    [anon_sym_LT_EQ] = ACTIONS(607),
    [anon_sym_GT] = ACTIONS(609),
    [anon_sym_GT_EQ] = ACTIONS(607),
    [anon_sym_EQ_EQ] = ACTIONS(607),
    [anon_sym_BANG_EQ] = ACTIONS(607),
    [anon_sym_STAR] = ACTIONS(609),
    [anon_sym_SLASH] = ACTIONS(607),
    [anon_sym_STAR_STAR] = ACTIONS(607),
    [anon_sym_CARET] = ACTIONS(607),
    [aux_sym_binary_operator_token1] = ACTIONS(607),
    [anon_sym_PIPE_GT] = ACTIONS(607),
    [anon_sym_COLON] = ACTIONS(609),
    [anon_sym_DOLLAR] = ACTIONS(607),
    [anon_sym_AT] = ACTIONS(607),
    [anon_sym_COLON_COLON] = ACTIONS(609),
    [anon_sym_COLON_COLON_COLON] = ACTIONS(607),
    [sym__hex_literal] = ACTIONS(607),
    [sym__number_literal] = ACTIONS(609),
    [anon_sym_SQUOTE] = ACTIONS(607),
    [anon_sym_DQUOTE] = ACTIONS(607),
    [sym_dots] = ACTIONS(609),
    [sym_dot_dot_i] = ACTIONS(609),
    [sym_next] = ACTIONS(609),
    [sym_break] = ACTIONS(609),
    [sym_true] = ACTIONS(609),
    [sym_false] = ACTIONS(609),
    [sym_null] = ACTIONS(609),
    [sym_inf] = ACTIONS(609),
    [sym_nan] = ACTIONS(609),
    [anon_sym_NA] = ACTIONS(609),
    [anon_sym_NA_integer_] = ACTIONS(609),
    [anon_sym_NA_real_] = ACTIONS(609),
    [anon_sym_NA_complex_] = ACTIONS(609),
    [anon_sym_NA_character_] = ACTIONS(609),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(607),
    [sym__semicolon] = ACTIONS(607),
    [sym__raw_string_open] = ACTIONS(607),
    [sym__external_else] = ACTIONS(607),
    [sym__external_open_parenthesis] = ACTIONS(607),
    [sym__external_open_brace] = ACTIONS(607),
    [sym__external_open_bracket] = ACTIONS(607),
    [sym__external_open_bracket2] = ACTIONS(607),
  },
  [287] = {
    [ts_builtin_sym_end] = ACTIONS(611),
    [sym_identifier] = ACTIONS(613),
    [anon_sym_BSLASH] = ACTIONS(611),
    [anon_sym_function] = ACTIONS(613),
    [anon_sym_EQ] = ACTIONS(613),
    [anon_sym_if] = ACTIONS(613),
    [anon_sym_for] = ACTIONS(613),
    [anon_sym_while] = ACTIONS(613),
    [anon_sym_repeat] = ACTIONS(613),
    [anon_sym_QMARK] = ACTIONS(611),
    [anon_sym_TILDE] = ACTIONS(611),
    [anon_sym_BANG] = ACTIONS(613),
    [anon_sym_PLUS] = ACTIONS(611),
    [anon_sym_DASH] = ACTIONS(613),
    [anon_sym_LT_DASH] = ACTIONS(611),
    [anon_sym_LT_LT_DASH] = ACTIONS(611),
    [anon_sym_COLON_EQ] = ACTIONS(611),
    [anon_sym_DASH_GT] = ACTIONS(613),
    [anon_sym_DASH_GT_GT] = ACTIONS(611),
    [anon_sym_PIPE] = ACTIONS(613),
    [anon_sym_AMP] = ACTIONS(613),
    [anon_sym_PIPE_PIPE] = ACTIONS(611),
    [anon_sym_AMP_AMP] = ACTIONS(611),
    [anon_sym_LT] = ACTIONS(613),
    [anon_sym_LT_EQ] = ACTIONS(611),
    [anon_sym_GT] = ACTIONS(613),
    [anon_sym_GT_EQ] = ACTIONS(611),
    [anon_sym_EQ_EQ] = ACTIONS(611),
    [anon_sym_BANG_EQ] = ACTIONS(611),
    [anon_sym_STAR] = ACTIONS(613),
    [anon_sym_SLASH] = ACTIONS(611),
    [anon_sym_STAR_STAR] = ACTIONS(611),
    [anon_sym_CARET] = ACTIONS(611),
    [aux_sym_binary_operator_token1] = ACTIONS(611),
    [anon_sym_PIPE_GT] = ACTIONS(611),
    [anon_sym_COLON] = ACTIONS(613),
    [anon_sym_DOLLAR] = ACTIONS(611),
    [anon_sym_AT] = ACTIONS(611),
    [anon_sym_COLON_COLON] = ACTIONS(613),
    [anon_sym_COLON_COLON_COLON] = ACTIONS(611),
    [sym__hex_literal] = ACTIONS(611),
    [sym__number_literal] = ACTIONS(613),
    [anon_sym_SQUOTE] = ACTIONS(611),
    [anon_sym_DQUOTE] = ACTIONS(611),
    [sym_dots] = ACTIONS(613),
    [sym_dot_dot_i] = ACTIONS(613),
    [sym_next] = ACTIONS(613),
    [sym_break] = ACTIONS(613),
    [sym_true] = ACTIONS(613),
    [sym_false] = ACTIONS(613),
    [sym_null] = ACTIONS(613),
    [sym_inf] = ACTIONS(613),
    [sym_nan] = ACTIONS(613),
    [anon_sym_NA] = ACTIONS(613),
    [anon_sym_NA_integer_] = ACTIONS(613),
    [anon_sym_NA_real_] = ACTIONS(613),
    [anon_sym_NA_complex_] = ACTIONS(613),
    [anon_sym_NA_character_] = ACTIONS(613),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(611),
    [sym__semicolon] = ACTIONS(611),
    [sym__raw_string_open] = ACTIONS(611),
    [sym__external_else] = ACTIONS(611),
    [sym__external_open_parenthesis] = ACTIONS(611),
    [sym__external_open_brace] = ACTIONS(611),
    [sym__external_open_bracket] = ACTIONS(611),
    [sym__external_open_bracket2] = ACTIONS(611),
  },
  [288] = {
    [ts_builtin_sym_end] = ACTIONS(615),
    [sym_identifier] = ACTIONS(617),
    [anon_sym_BSLASH] = ACTIONS(615),
    [anon_sym_function] = ACTIONS(617),
    [anon_sym_EQ] = ACTIONS(617),
    [anon_sym_if] = ACTIONS(617),
    [anon_sym_for] = ACTIONS(617),
    [anon_sym_while] = ACTIONS(617),
    [anon_sym_repeat] = ACTIONS(617),
    [anon_sym_QMARK] = ACTIONS(615),
    [anon_sym_TILDE] = ACTIONS(615),
    [anon_sym_BANG] = ACTIONS(617),
    [anon_sym_PLUS] = ACTIONS(615),
    [anon_sym_DASH] = ACTIONS(617),
    [anon_sym_LT_DASH] = ACTIONS(615),
    [anon_sym_LT_LT_DASH] = ACTIONS(615),
    [anon_sym_COLON_EQ] = ACTIONS(615),
    [anon_sym_DASH_GT] = ACTIONS(617),
    [anon_sym_DASH_GT_GT] = ACTIONS(615),
    [anon_sym_PIPE] = ACTIONS(617),
    [anon_sym_AMP] = ACTIONS(617),
    [anon_sym_PIPE_PIPE] = ACTIONS(615),
    [anon_sym_AMP_AMP] = ACTIONS(615),
    [anon_sym_LT] = ACTIONS(617),
    [anon_sym_LT_EQ] = ACTIONS(615),
    [anon_sym_GT] = ACTIONS(617),
    [anon_sym_GT_EQ] = ACTIONS(615),
    [anon_sym_EQ_EQ] = ACTIONS(615),
    [anon_sym_BANG_EQ] = ACTIONS(615),
    [anon_sym_STAR] = ACTIONS(617),
    [anon_sym_SLASH] = ACTIONS(615),
    [anon_sym_STAR_STAR] = ACTIONS(615),
    [anon_sym_CARET] = ACTIONS(615),
    [aux_sym_binary_operator_token1] = ACTIONS(615),
    [anon_sym_PIPE_GT] = ACTIONS(615),
    [anon_sym_COLON] = ACTIONS(617),
    [anon_sym_DOLLAR] = ACTIONS(615),
    [anon_sym_AT] = ACTIONS(615),
    [anon_sym_COLON_COLON] = ACTIONS(619),
    [anon_sym_COLON_COLON_COLON] = ACTIONS(621),
    [sym__hex_literal] = ACTIONS(615),
    [sym__number_literal] = ACTIONS(617),
    [anon_sym_SQUOTE] = ACTIONS(615),
    [anon_sym_DQUOTE] = ACTIONS(615),
    [sym_dots] = ACTIONS(617),
    [sym_dot_dot_i] = ACTIONS(617),
    [sym_next] = ACTIONS(617),
    [sym_break] = ACTIONS(617),
    [sym_true] = ACTIONS(617),
    [sym_false] = ACTIONS(617),
    [sym_null] = ACTIONS(617),
    [sym_inf] = ACTIONS(617),
    [sym_nan] = ACTIONS(617),
    [anon_sym_NA] = ACTIONS(617),
    [anon_sym_NA_integer_] = ACTIONS(617),
    [anon_sym_NA_real_] = ACTIONS(617),
    [anon_sym_NA_complex_] = ACTIONS(617),
    [anon_sym_NA_character_] = ACTIONS(617),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(615),
    [sym__semicolon] = ACTIONS(615),
    [sym__raw_string_open] = ACTIONS(615),
    [sym__external_else] = ACTIONS(615),
    [sym__external_open_parenthesis] = ACTIONS(615),
    [sym__external_open_brace] = ACTIONS(615),
    [sym__external_open_bracket] = ACTIONS(615),
    [sym__external_open_bracket2] = ACTIONS(615),
  },
  [289] = {
    [ts_builtin_sym_end] = ACTIONS(623),
    [sym_identifier] = ACTIONS(625),
    [anon_sym_BSLASH] = ACTIONS(623),
    [anon_sym_function] = ACTIONS(625),
    [anon_sym_EQ] = ACTIONS(625),
    [anon_sym_if] = ACTIONS(625),
    [anon_sym_for] = ACTIONS(625),
    [anon_sym_while] = ACTIONS(625),
    [anon_sym_repeat] = ACTIONS(625),
    [anon_sym_QMARK] = ACTIONS(623),
    [anon_sym_TILDE] = ACTIONS(623),
    [anon_sym_BANG] = ACTIONS(625),
    [anon_sym_PLUS] = ACTIONS(623),
    [anon_sym_DASH] = ACTIONS(625),
    [anon_sym_LT_DASH] = ACTIONS(623),
    [anon_sym_LT_LT_DASH] = ACTIONS(623),
    [anon_sym_COLON_EQ] = ACTIONS(623),
    [anon_sym_DASH_GT] = ACTIONS(625),
    [anon_sym_DASH_GT_GT] = ACTIONS(623),
    [anon_sym_PIPE] = ACTIONS(625),
    [anon_sym_AMP] = ACTIONS(625),
    [anon_sym_PIPE_PIPE] = ACTIONS(623),
    [anon_sym_AMP_AMP] = ACTIONS(623),
    [anon_sym_LT] = ACTIONS(625),
    [anon_sym_LT_EQ] = ACTIONS(623),
    [anon_sym_GT] = ACTIONS(625),
    [anon_sym_GT_EQ] = ACTIONS(623),
    [anon_sym_EQ_EQ] = ACTIONS(623),
    [anon_sym_BANG_EQ] = ACTIONS(623),
    [anon_sym_STAR] = ACTIONS(625),
    [anon_sym_SLASH] = ACTIONS(623),
    [anon_sym_STAR_STAR] = ACTIONS(623),
    [anon_sym_CARET] = ACTIONS(623),
    [aux_sym_binary_operator_token1] = ACTIONS(623),
    [anon_sym_PIPE_GT] = ACTIONS(623),
    [anon_sym_COLON] = ACTIONS(625),
    [anon_sym_DOLLAR] = ACTIONS(623),
    [anon_sym_AT] = ACTIONS(623),
    [anon_sym_L] = ACTIONS(627),
    [anon_sym_i] = ACTIONS(629),
    [sym__hex_literal] = ACTIONS(623),
    [sym__number_literal] = ACTIONS(625),
    [anon_sym_SQUOTE] = ACTIONS(623),
    [anon_sym_DQUOTE] = ACTIONS(623),
    [sym_dots] = ACTIONS(625),
    [sym_dot_dot_i] = ACTIONS(625),
    [sym_next] = ACTIONS(625),
    [sym_break] = ACTIONS(625),
    [sym_true] = ACTIONS(625),
    [sym_false] = ACTIONS(625),
    [sym_null] = ACTIONS(625),
    [sym_inf] = ACTIONS(625),
    [sym_nan] = ACTIONS(625),
    [anon_sym_NA] = ACTIONS(625),
    [anon_sym_NA_integer_] = ACTIONS(625),
    [anon_sym_NA_real_] = ACTIONS(625),
    [anon_sym_NA_complex_] = ACTIONS(625),
    [anon_sym_NA_character_] = ACTIONS(625),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(623),
    [sym__semicolon] = ACTIONS(623),
    [sym__raw_string_open] = ACTIONS(623),
    [sym__external_else] = ACTIONS(623),
    [sym__external_open_parenthesis] = ACTIONS(623),
    [sym__external_open_brace] = ACTIONS(623),
    [sym__external_open_bracket] = ACTIONS(623),
    [sym__external_open_bracket2] = ACTIONS(623),
  },
  [290] = {
    [ts_builtin_sym_end] = ACTIONS(607),
    [sym_identifier] = ACTIONS(609),
    [anon_sym_BSLASH] = ACTIONS(607),
    [anon_sym_function] = ACTIONS(609),
    [anon_sym_EQ] = ACTIONS(609),
    [anon_sym_if] = ACTIONS(609),
    [anon_sym_for] = ACTIONS(609),
    [anon_sym_while] = ACTIONS(609),
    [anon_sym_repeat] = ACTIONS(609),
    [anon_sym_QMARK] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(607),
    [anon_sym_BANG] = ACTIONS(609),
    [anon_sym_PLUS] = ACTIONS(607),
    [anon_sym_DASH] = ACTIONS(609),
    [anon_sym_LT_DASH] = ACTIONS(607),
    [anon_sym_LT_LT_DASH] = ACTIONS(607),
    [anon_sym_COLON_EQ] = ACTIONS(607),
    [anon_sym_DASH_GT] = ACTIONS(609),
    [anon_sym_DASH_GT_GT] = ACTIONS(607),
    [anon_sym_PIPE] = ACTIONS(609),
    [anon_sym_AMP] = ACTIONS(609),
    [anon_sym_PIPE_PIPE] = ACTIONS(607),
    [anon_sym_AMP_AMP] = ACTIONS(607),
    [anon_sym_LT] = ACTIONS(609),
    [anon_sym_LT_EQ] = ACTIONS(607),
    [anon_sym_GT] = ACTIONS(609),
    [anon_sym_GT_EQ] = ACTIONS(607),
    [anon_sym_EQ_EQ] = ACTIONS(607),
    [anon_sym_BANG_EQ] = ACTIONS(607),
    [anon_sym_STAR] = ACTIONS(609),
    [anon_sym_SLASH] = ACTIONS(607),
    [anon_sym_STAR_STAR] = ACTIONS(607),
    [anon_sym_CARET] = ACTIONS(607),
    [aux_sym_binary_operator_token1] = ACTIONS(607),
    [anon_sym_PIPE_GT] = ACTIONS(607),
    [anon_sym_COLON] = ACTIONS(609),
    [anon_sym_DOLLAR] = ACTIONS(607),
    [anon_sym_AT] = ACTIONS(607),
    [anon_sym_COLON_COLON] = ACTIONS(609),
    [anon_sym_COLON_COLON_COLON] = ACTIONS(607),
    [sym__hex_literal] = ACTIONS(607),
    [sym__number_literal] = ACTIONS(609),
    [anon_sym_SQUOTE] = ACTIONS(607),
    [anon_sym_DQUOTE] = ACTIONS(607),
    [sym_dots] = ACTIONS(609),
    [sym_dot_dot_i] = ACTIONS(609),
    [sym_next] = ACTIONS(609),
    [sym_break] = ACTIONS(609),
    [sym_true] = ACTIONS(609),
    [sym_false] = ACTIONS(609),
    [sym_null] = ACTIONS(609),
    [sym_inf] = ACTIONS(609),
    [sym_nan] = ACTIONS(609),
    [anon_sym_NA] = ACTIONS(609),
    [anon_sym_NA_integer_] = ACTIONS(609),
    [anon_sym_NA_real_] = ACTIONS(609),
    [anon_sym_NA_complex_] = ACTIONS(609),
    [anon_sym_NA_character_] = ACTIONS(609),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(607),
    [sym__semicolon] = ACTIONS(607),
    [sym__raw_string_open] = ACTIONS(607),
    [sym__external_else] = ACTIONS(607),
    [sym__external_open_parenthesis] = ACTIONS(607),
    [sym__external_open_brace] = ACTIONS(607),
    [sym__external_open_bracket] = ACTIONS(607),
    [sym__external_open_bracket2] = ACTIONS(607),
  },
  [291] = {
    [ts_builtin_sym_end] = ACTIONS(607),
    [sym_identifier] = ACTIONS(609),
    [anon_sym_BSLASH] = ACTIONS(607),
    [anon_sym_function] = ACTIONS(609),
    [anon_sym_EQ] = ACTIONS(609),
    [anon_sym_if] = ACTIONS(609),
    [anon_sym_for] = ACTIONS(609),
    [anon_sym_while] = ACTIONS(609),
    [anon_sym_repeat] = ACTIONS(609),
    [anon_sym_QMARK] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(607),
    [anon_sym_BANG] = ACTIONS(609),
    [anon_sym_PLUS] = ACTIONS(607),
    [anon_sym_DASH] = ACTIONS(609),
    [anon_sym_LT_DASH] = ACTIONS(607),
    [anon_sym_LT_LT_DASH] = ACTIONS(607),
    [anon_sym_COLON_EQ] = ACTIONS(607),
    [anon_sym_DASH_GT] = ACTIONS(609),
    [anon_sym_DASH_GT_GT] = ACTIONS(607),
    [anon_sym_PIPE] = ACTIONS(609),
    [anon_sym_AMP] = ACTIONS(609),
    [anon_sym_PIPE_PIPE] = ACTIONS(607),
    [anon_sym_AMP_AMP] = ACTIONS(607),
    [anon_sym_LT] = ACTIONS(609),
    [anon_sym_LT_EQ] = ACTIONS(607),
    [anon_sym_GT] = ACTIONS(609),
    [anon_sym_GT_EQ] = ACTIONS(607),
    [anon_sym_EQ_EQ] = ACTIONS(607),
    [anon_sym_BANG_EQ] = ACTIONS(607),
    [anon_sym_STAR] = ACTIONS(609),
    [anon_sym_SLASH] = ACTIONS(607),
    [anon_sym_STAR_STAR] = ACTIONS(607),
    [anon_sym_CARET] = ACTIONS(607),
    [aux_sym_binary_operator_token1] = ACTIONS(607),
    [anon_sym_PIPE_GT] = ACTIONS(607),
    [anon_sym_COLON] = ACTIONS(609),
    [anon_sym_DOLLAR] = ACTIONS(607),
    [anon_sym_AT] = ACTIONS(607),
    [anon_sym_COLON_COLON] = ACTIONS(609),
    [anon_sym_COLON_COLON_COLON] = ACTIONS(607),
    [sym__hex_literal] = ACTIONS(607),
    [sym__number_literal] = ACTIONS(609),
    [anon_sym_SQUOTE] = ACTIONS(607),
    [anon_sym_DQUOTE] = ACTIONS(607),
    [sym_dots] = ACTIONS(609),
    [sym_dot_dot_i] = ACTIONS(609),
    [sym_next] = ACTIONS(609),
    [sym_break] = ACTIONS(609),
    [sym_true] = ACTIONS(609),
    [sym_false] = ACTIONS(609),
    [sym_null] = ACTIONS(609),
    [sym_inf] = ACTIONS(609),
    [sym_nan] = ACTIONS(609),
    [anon_sym_NA] = ACTIONS(609),
    [anon_sym_NA_integer_] = ACTIONS(609),
    [anon_sym_NA_real_] = ACTIONS(609),
    [anon_sym_NA_complex_] = ACTIONS(609),
    [anon_sym_NA_character_] = ACTIONS(609),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(607),
    [sym__semicolon] = ACTIONS(607),
    [sym__raw_string_open] = ACTIONS(607),
    [sym__external_else] = ACTIONS(607),
    [sym__external_open_parenthesis] = ACTIONS(607),
    [sym__external_open_brace] = ACTIONS(607),
    [sym__external_open_bracket] = ACTIONS(607),
    [sym__external_open_bracket2] = ACTIONS(607),
  },
  [292] = {
    [ts_builtin_sym_end] = ACTIONS(631),
    [sym_identifier] = ACTIONS(633),
    [anon_sym_BSLASH] = ACTIONS(631),
    [anon_sym_function] = ACTIONS(633),
    [anon_sym_EQ] = ACTIONS(633),
    [anon_sym_if] = ACTIONS(633),
    [anon_sym_for] = ACTIONS(633),
    [anon_sym_while] = ACTIONS(633),
    [anon_sym_repeat] = ACTIONS(633),
    [anon_sym_QMARK] = ACTIONS(631),
    [anon_sym_TILDE] = ACTIONS(631),
    [anon_sym_BANG] = ACTIONS(633),
    [anon_sym_PLUS] = ACTIONS(631),
    [anon_sym_DASH] = ACTIONS(633),
    [anon_sym_LT_DASH] = ACTIONS(631),
    [anon_sym_LT_LT_DASH] = ACTIONS(631),
    [anon_sym_COLON_EQ] = ACTIONS(631),
    [anon_sym_DASH_GT] = ACTIONS(633),
    [anon_sym_DASH_GT_GT] = ACTIONS(631),
    [anon_sym_PIPE] = ACTIONS(633),
    [anon_sym_AMP] = ACTIONS(633),
    [anon_sym_PIPE_PIPE] = ACTIONS(631),
    [anon_sym_AMP_AMP] = ACTIONS(631),
    [anon_sym_LT] = ACTIONS(633),
    [anon_sym_LT_EQ] = ACTIONS(631),
    [anon_sym_GT] = ACTIONS(633),
    [anon_sym_GT_EQ] = ACTIONS(631),
    [anon_sym_EQ_EQ] = ACTIONS(631),
    [anon_sym_BANG_EQ] = ACTIONS(631),
    [anon_sym_STAR] = ACTIONS(633),
    [anon_sym_SLASH] = ACTIONS(631),
    [anon_sym_STAR_STAR] = ACTIONS(631),
    [anon_sym_CARET] = ACTIONS(631),
    [aux_sym_binary_operator_token1] = ACTIONS(631),
    [anon_sym_PIPE_GT] = ACTIONS(631),
    [anon_sym_COLON] = ACTIONS(633),
    [anon_sym_DOLLAR] = ACTIONS(631),
    [anon_sym_AT] = ACTIONS(631),
    [anon_sym_COLON_COLON] = ACTIONS(633),
    [anon_sym_COLON_COLON_COLON] = ACTIONS(631),
    [sym__hex_literal] = ACTIONS(631),
    [sym__number_literal] = ACTIONS(633),
    [anon_sym_SQUOTE] = ACTIONS(631),
    [anon_sym_DQUOTE] = ACTIONS(631),
    [sym_dots] = ACTIONS(633),
    [sym_dot_dot_i] = ACTIONS(633),
    [sym_next] = ACTIONS(633),
    [sym_break] = ACTIONS(633),
    [sym_true] = ACTIONS(633),
    [sym_false] = ACTIONS(633),
    [sym_null] = ACTIONS(633),
    [sym_inf] = ACTIONS(633),
    [sym_nan] = ACTIONS(633),
    [anon_sym_NA] = ACTIONS(633),
    [anon_sym_NA_integer_] = ACTIONS(633),
    [anon_sym_NA_real_] = ACTIONS(633),
    [anon_sym_NA_complex_] = ACTIONS(633),
    [anon_sym_NA_character_] = ACTIONS(633),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(631),
    [sym__semicolon] = ACTIONS(631),
    [sym__raw_string_open] = ACTIONS(631),
    [sym__external_else] = ACTIONS(631),
    [sym__external_open_parenthesis] = ACTIONS(631),
    [sym__external_open_brace] = ACTIONS(631),
    [sym__external_open_bracket] = ACTIONS(631),
    [sym__external_open_bracket2] = ACTIONS(631),
  },
  [293] = {
    [ts_builtin_sym_end] = ACTIONS(635),
    [sym_identifier] = ACTIONS(637),
    [anon_sym_BSLASH] = ACTIONS(635),
    [anon_sym_function] = ACTIONS(637),
    [anon_sym_EQ] = ACTIONS(637),
    [anon_sym_if] = ACTIONS(637),
    [anon_sym_for] = ACTIONS(637),
    [anon_sym_while] = ACTIONS(637),
    [anon_sym_repeat] = ACTIONS(637),
    [anon_sym_QMARK] = ACTIONS(635),
    [anon_sym_TILDE] = ACTIONS(635),
    [anon_sym_BANG] = ACTIONS(637),
    [anon_sym_PLUS] = ACTIONS(635),
    [anon_sym_DASH] = ACTIONS(637),
    [anon_sym_LT_DASH] = ACTIONS(635),
    [anon_sym_LT_LT_DASH] = ACTIONS(635),
    [anon_sym_COLON_EQ] = ACTIONS(635),
    [anon_sym_DASH_GT] = ACTIONS(637),
    [anon_sym_DASH_GT_GT] = ACTIONS(635),
    [anon_sym_PIPE] = ACTIONS(637),
    [anon_sym_AMP] = ACTIONS(637),
    [anon_sym_PIPE_PIPE] = ACTIONS(635),
    [anon_sym_AMP_AMP] = ACTIONS(635),
    [anon_sym_LT] = ACTIONS(637),
    [anon_sym_LT_EQ] = ACTIONS(635),
    [anon_sym_GT] = ACTIONS(637),
    [anon_sym_GT_EQ] = ACTIONS(635),
    [anon_sym_EQ_EQ] = ACTIONS(635),
    [anon_sym_BANG_EQ] = ACTIONS(635),
    [anon_sym_STAR] = ACTIONS(637),
    [anon_sym_SLASH] = ACTIONS(635),
    [anon_sym_STAR_STAR] = ACTIONS(635),
    [anon_sym_CARET] = ACTIONS(635),
    [aux_sym_binary_operator_token1] = ACTIONS(635),
    [anon_sym_PIPE_GT] = ACTIONS(635),
    [anon_sym_COLON] = ACTIONS(637),
    [anon_sym_DOLLAR] = ACTIONS(635),
    [anon_sym_AT] = ACTIONS(635),
    [anon_sym_COLON_COLON] = ACTIONS(637),
    [anon_sym_COLON_COLON_COLON] = ACTIONS(635),
    [sym__hex_literal] = ACTIONS(635),
    [sym__number_literal] = ACTIONS(637),
    [anon_sym_SQUOTE] = ACTIONS(635),
    [anon_sym_DQUOTE] = ACTIONS(635),
    [sym_dots] = ACTIONS(637),
    [sym_dot_dot_i] = ACTIONS(637),
    [sym_next] = ACTIONS(637),
    [sym_break] = ACTIONS(637),
    [sym_true] = ACTIONS(637),
    [sym_false] = ACTIONS(637),
    [sym_null] = ACTIONS(637),
    [sym_inf] = ACTIONS(637),
    [sym_nan] = ACTIONS(637),
    [anon_sym_NA] = ACTIONS(637),
    [anon_sym_NA_integer_] = ACTIONS(637),
    [anon_sym_NA_real_] = ACTIONS(637),
    [anon_sym_NA_complex_] = ACTIONS(637),
    [anon_sym_NA_character_] = ACTIONS(637),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(635),
    [sym__semicolon] = ACTIONS(635),
    [sym__raw_string_open] = ACTIONS(635),
    [sym__external_else] = ACTIONS(635),
    [sym__external_open_parenthesis] = ACTIONS(635),
    [sym__external_open_brace] = ACTIONS(635),
    [sym__external_open_bracket] = ACTIONS(635),
    [sym__external_open_bracket2] = ACTIONS(635),
  },
  [294] = {
    [sym_function_definition] = STATE(1372),
    [sym_if_statement] = STATE(1372),
    [sym_for_statement] = STATE(1372),
    [sym_while_statement] = STATE(1372),
    [sym_repeat_statement] = STATE(1372),
    [sym_braced_expression] = STATE(1372),
    [sym_parenthesized_expression] = STATE(1372),
    [sym_call] = STATE(1372),
    [sym_subset] = STATE(1372),
    [sym_subset2] = STATE(1372),
    [sym_argument] = STATE(2066),
    [sym__argument_named] = STATE(2070),
    [sym__argument_unnamed] = STATE(2056),
    [sym__argument_value] = STATE(2061),
    [sym_unary_operator] = STATE(1372),
    [sym_binary_operator] = STATE(1372),
    [sym_extract_operator] = STATE(1372),
    [sym_namespace_operator] = STATE(1372),
    [sym_integer] = STATE(1372),
    [sym_complex] = STATE(1372),
    [sym_float] = STATE(1372),
    [sym__float_literal] = STATE(1626),
    [sym_string] = STATE(1635),
    [sym__raw_string] = STATE(1627),
    [sym__single_quoted_string] = STATE(1628),
    [sym__double_quoted_string] = STATE(1629),
    [sym__argument_name_string_or_identifier_or_null] = STATE(2106),
    [sym_na] = STATE(1372),
    [sym__expression] = STATE(1372),
    [sym__open_parenthesis] = STATE(1065),
    [sym__open_brace] = STATE(381),
    [sym_identifier] = ACTIONS(497),
    [anon_sym_BSLASH] = ACTIONS(499),
    [anon_sym_function] = ACTIONS(501),
    [anon_sym_if] = ACTIONS(503),
    [anon_sym_for] = ACTIONS(505),
    [anon_sym_while] = ACTIONS(507),
    [anon_sym_repeat] = ACTIONS(509),
    [anon_sym_QMARK] = ACTIONS(511),
    [anon_sym_TILDE] = ACTIONS(513),
    [anon_sym_BANG] = ACTIONS(515),
    [anon_sym_PLUS] = ACTIONS(517),
    [anon_sym_DASH] = ACTIONS(517),
    [sym__hex_literal] = ACTIONS(519),
    [sym__number_literal] = ACTIONS(521),
    [anon_sym_SQUOTE] = ACTIONS(523),
    [anon_sym_DQUOTE] = ACTIONS(525),
    [sym_dots] = ACTIONS(497),
    [sym_dot_dot_i] = ACTIONS(497),
    [sym_next] = ACTIONS(527),
    [sym_break] = ACTIONS(527),
    [sym_true] = ACTIONS(527),
    [sym_false] = ACTIONS(527),
    [sym_null] = ACTIONS(529),
    [sym_inf] = ACTIONS(527),
    [sym_nan] = ACTIONS(527),
    [anon_sym_NA] = ACTIONS(531),
    [anon_sym_NA_integer_] = ACTIONS(531),
    [anon_sym_NA_real_] = ACTIONS(531),
    [anon_sym_NA_complex_] = ACTIONS(531),
    [anon_sym_NA_character_] = ACTIONS(531),
    [sym_comment] = ACTIONS(3),
    [sym_comma] = ACTIONS(639),
    [sym__raw_string_open] = ACTIONS(535),
    [sym__external_open_parenthesis] = ACTIONS(537),
    [sym__external_close_parenthesis] = ACTIONS(639),
    [sym__external_open_brace] = ACTIONS(541),
  },
  [295] = {
    [ts_builtin_sym_end] = ACTIONS(641),
    [sym_identifier] = ACTIONS(643),
    [anon_sym_BSLASH] = ACTIONS(641),
    [anon_sym_function] = ACTIONS(643),
    [anon_sym_EQ] = ACTIONS(643),
    [anon_sym_if] = ACTIONS(643),
    [anon_sym_for] = ACTIONS(643),
    [anon_sym_while] = ACTIONS(643),
    [anon_sym_repeat] = ACTIONS(643),
    [anon_sym_QMARK] = ACTIONS(641),
    [anon_sym_TILDE] = ACTIONS(641),
    [anon_sym_BANG] = ACTIONS(643),
    [anon_sym_PLUS] = ACTIONS(641),
    [anon_sym_DASH] = ACTIONS(643),
    [anon_sym_LT_DASH] = ACTIONS(641),
    [anon_sym_LT_LT_DASH] = ACTIONS(641),
    [anon_sym_COLON_EQ] = ACTIONS(641),
    [anon_sym_DASH_GT] = ACTIONS(643),
    [anon_sym_DASH_GT_GT] = ACTIONS(641),
    [anon_sym_PIPE] = ACTIONS(643),
    [anon_sym_AMP] = ACTIONS(643),
    [anon_sym_PIPE_PIPE] = ACTIONS(641),
    [anon_sym_AMP_AMP] = ACTIONS(641),
    [anon_sym_LT] = ACTIONS(643),
    [anon_sym_LT_EQ] = ACTIONS(641),
    [anon_sym_GT] = ACTIONS(643),
    [anon_sym_GT_EQ] = ACTIONS(641),
    [anon_sym_EQ_EQ] = ACTIONS(641),
    [anon_sym_BANG_EQ] = ACTIONS(641),
    [anon_sym_STAR] = ACTIONS(643),
    [anon_sym_SLASH] = ACTIONS(641),
    [anon_sym_STAR_STAR] = ACTIONS(641),
    [anon_sym_CARET] = ACTIONS(641),
    [aux_sym_binary_operator_token1] = ACTIONS(641),
    [anon_sym_PIPE_GT] = ACTIONS(641),
    [anon_sym_COLON] = ACTIONS(643),
    [anon_sym_DOLLAR] = ACTIONS(641),
    [anon_sym_AT] = ACTIONS(641),
    [anon_sym_COLON_COLON] = ACTIONS(643),
    [anon_sym_COLON_COLON_COLON] = ACTIONS(641),
    [sym__hex_literal] = ACTIONS(641),
    [sym__number_literal] = ACTIONS(643),
    [anon_sym_SQUOTE] = ACTIONS(641),
    [anon_sym_DQUOTE] = ACTIONS(641),
    [sym_dots] = ACTIONS(643),
    [sym_dot_dot_i] = ACTIONS(643),
    [sym_next] = ACTIONS(643),
    [sym_break] = ACTIONS(643),
    [sym_true] = ACTIONS(643),
    [sym_false] = ACTIONS(643),
    [sym_null] = ACTIONS(643),
    [sym_inf] = ACTIONS(643),
    [sym_nan] = ACTIONS(643),
    [anon_sym_NA] = ACTIONS(643),
    [anon_sym_NA_integer_] = ACTIONS(643),
    [anon_sym_NA_real_] = ACTIONS(643),
    [anon_sym_NA_complex_] = ACTIONS(643),
    [anon_sym_NA_character_] = ACTIONS(643),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(641),
    [sym__semicolon] = ACTIONS(641),
    [sym__raw_string_open] = ACTIONS(641),
    [sym__external_else] = ACTIONS(641),
    [sym__external_open_parenthesis] = ACTIONS(641),
    [sym__external_open_brace] = ACTIONS(641),
    [sym__external_open_bracket] = ACTIONS(641),
    [sym__external_open_bracket2] = ACTIONS(641),
  },
  [296] = {
    [ts_builtin_sym_end] = ACTIONS(645),
    [sym_identifier] = ACTIONS(647),
    [anon_sym_BSLASH] = ACTIONS(645),
    [anon_sym_function] = ACTIONS(647),
    [anon_sym_EQ] = ACTIONS(647),
    [anon_sym_if] = ACTIONS(647),
    [anon_sym_for] = ACTIONS(647),
    [anon_sym_while] = ACTIONS(647),
    [anon_sym_repeat] = ACTIONS(647),
    [anon_sym_QMARK] = ACTIONS(645),
    [anon_sym_TILDE] = ACTIONS(645),
    [anon_sym_BANG] = ACTIONS(647),
    [anon_sym_PLUS] = ACTIONS(645),
    [anon_sym_DASH] = ACTIONS(647),
    [anon_sym_LT_DASH] = ACTIONS(645),
    [anon_sym_LT_LT_DASH] = ACTIONS(645),
    [anon_sym_COLON_EQ] = ACTIONS(645),
    [anon_sym_DASH_GT] = ACTIONS(647),
    [anon_sym_DASH_GT_GT] = ACTIONS(645),
    [anon_sym_PIPE] = ACTIONS(647),
    [anon_sym_AMP] = ACTIONS(647),
    [anon_sym_PIPE_PIPE] = ACTIONS(645),
    [anon_sym_AMP_AMP] = ACTIONS(645),
    [anon_sym_LT] = ACTIONS(647),
    [anon_sym_LT_EQ] = ACTIONS(645),
    [anon_sym_GT] = ACTIONS(647),
    [anon_sym_GT_EQ] = ACTIONS(645),
    [anon_sym_EQ_EQ] = ACTIONS(645),
    [anon_sym_BANG_EQ] = ACTIONS(645),
    [anon_sym_STAR] = ACTIONS(647),
    [anon_sym_SLASH] = ACTIONS(645),
    [anon_sym_STAR_STAR] = ACTIONS(645),
    [anon_sym_CARET] = ACTIONS(645),
    [aux_sym_binary_operator_token1] = ACTIONS(645),
    [anon_sym_PIPE_GT] = ACTIONS(645),
    [anon_sym_COLON] = ACTIONS(647),
    [anon_sym_DOLLAR] = ACTIONS(645),
    [anon_sym_AT] = ACTIONS(645),
    [anon_sym_COLON_COLON] = ACTIONS(647),
    [anon_sym_COLON_COLON_COLON] = ACTIONS(645),
    [sym__hex_literal] = ACTIONS(645),
    [sym__number_literal] = ACTIONS(647),
    [anon_sym_SQUOTE] = ACTIONS(645),
    [anon_sym_DQUOTE] = ACTIONS(645),
    [sym_dots] = ACTIONS(647),
    [sym_dot_dot_i] = ACTIONS(647),
    [sym_next] = ACTIONS(647),
    [sym_break] = ACTIONS(647),
    [sym_true] = ACTIONS(647),
    [sym_false] = ACTIONS(647),
    [sym_null] = ACTIONS(647),
    [sym_inf] = ACTIONS(647),
    [sym_nan] = ACTIONS(647),
    [anon_sym_NA] = ACTIONS(647),
    [anon_sym_NA_integer_] = ACTIONS(647),
    [anon_sym_NA_real_] = ACTIONS(647),
    [anon_sym_NA_complex_] = ACTIONS(647),
    [anon_sym_NA_character_] = ACTIONS(647),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(645),
    [sym__semicolon] = ACTIONS(645),
    [sym__raw_string_open] = ACTIONS(645),
    [sym__external_else] = ACTIONS(645),
    [sym__external_open_parenthesis] = ACTIONS(645),
    [sym__external_open_brace] = ACTIONS(645),
    [sym__external_open_bracket] = ACTIONS(645),
    [sym__external_open_bracket2] = ACTIONS(645),
  },
  [297] = {
    [ts_builtin_sym_end] = ACTIONS(649),
    [sym_identifier] = ACTIONS(651),
    [anon_sym_BSLASH] = ACTIONS(649),
    [anon_sym_function] = ACTIONS(651),
    [anon_sym_EQ] = ACTIONS(651),
    [anon_sym_if] = ACTIONS(651),
    [anon_sym_for] = ACTIONS(651),
    [anon_sym_while] = ACTIONS(651),
    [anon_sym_repeat] = ACTIONS(651),
    [anon_sym_QMARK] = ACTIONS(649),
    [anon_sym_TILDE] = ACTIONS(649),
    [anon_sym_BANG] = ACTIONS(651),
    [anon_sym_PLUS] = ACTIONS(649),
    [anon_sym_DASH] = ACTIONS(651),
    [anon_sym_LT_DASH] = ACTIONS(649),
    [anon_sym_LT_LT_DASH] = ACTIONS(649),
    [anon_sym_COLON_EQ] = ACTIONS(649),
    [anon_sym_DASH_GT] = ACTIONS(651),
    [anon_sym_DASH_GT_GT] = ACTIONS(649),
    [anon_sym_PIPE] = ACTIONS(651),
    [anon_sym_AMP] = ACTIONS(651),
    [anon_sym_PIPE_PIPE] = ACTIONS(649),
    [anon_sym_AMP_AMP] = ACTIONS(649),
    [anon_sym_LT] = ACTIONS(651),
    [anon_sym_LT_EQ] = ACTIONS(649),
    [anon_sym_GT] = ACTIONS(651),
    [anon_sym_GT_EQ] = ACTIONS(649),
    [anon_sym_EQ_EQ] = ACTIONS(649),
    [anon_sym_BANG_EQ] = ACTIONS(649),
    [anon_sym_STAR] = ACTIONS(651),
    [anon_sym_SLASH] = ACTIONS(649),
    [anon_sym_STAR_STAR] = ACTIONS(649),
    [anon_sym_CARET] = ACTIONS(649),
    [aux_sym_binary_operator_token1] = ACTIONS(649),
    [anon_sym_PIPE_GT] = ACTIONS(649),
    [anon_sym_COLON] = ACTIONS(651),
    [anon_sym_DOLLAR] = ACTIONS(649),
    [anon_sym_AT] = ACTIONS(649),
    [anon_sym_COLON_COLON] = ACTIONS(651),
    [anon_sym_COLON_COLON_COLON] = ACTIONS(649),
    [sym__hex_literal] = ACTIONS(649),
    [sym__number_literal] = ACTIONS(651),
    [anon_sym_SQUOTE] = ACTIONS(649),
    [anon_sym_DQUOTE] = ACTIONS(649),
    [sym_dots] = ACTIONS(651),
    [sym_dot_dot_i] = ACTIONS(651),
    [sym_next] = ACTIONS(651),
    [sym_break] = ACTIONS(651),
    [sym_true] = ACTIONS(651),
    [sym_false] = ACTIONS(651),
    [sym_null] = ACTIONS(651),
    [sym_inf] = ACTIONS(651),
    [sym_nan] = ACTIONS(651),
    [anon_sym_NA] = ACTIONS(651),
    [anon_sym_NA_integer_] = ACTIONS(651),
    [anon_sym_NA_real_] = ACTIONS(651),
    [anon_sym_NA_complex_] = ACTIONS(651),
    [anon_sym_NA_character_] = ACTIONS(651),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(649),
    [sym__semicolon] = ACTIONS(649),
    [sym__raw_string_open] = ACTIONS(649),
    [sym__external_else] = ACTIONS(649),
    [sym__external_open_parenthesis] = ACTIONS(649),
    [sym__external_open_brace] = ACTIONS(649),
    [sym__external_open_bracket] = ACTIONS(649),
    [sym__external_open_bracket2] = ACTIONS(649),
  },
  [298] = {
    [sym_function_definition] = STATE(1552),
    [sym_if_statement] = STATE(1552),
    [sym_for_statement] = STATE(1552),
    [sym_while_statement] = STATE(1552),
    [sym_repeat_statement] = STATE(1552),
    [sym_braced_expression] = STATE(1552),
    [sym_parenthesized_expression] = STATE(1552),
    [sym_call] = STATE(1552),
    [sym_subset] = STATE(1552),
    [sym_subset2] = STATE(1552),
    [sym_argument] = STATE(2075),
    [sym__argument_named] = STATE(2077),
    [sym__argument_unnamed] = STATE(2060),
    [sym__argument_value] = STATE(2054),
    [sym_unary_operator] = STATE(1552),
    [sym_binary_operator] = STATE(1552),
    [sym_extract_operator] = STATE(1552),
    [sym_namespace_operator] = STATE(1552),
    [sym_integer] = STATE(1552),
    [sym_complex] = STATE(1552),
    [sym_float] = STATE(1552),
    [sym__float_literal] = STATE(1638),
    [sym_string] = STATE(1634),
    [sym__raw_string] = STATE(1639),
    [sym__single_quoted_string] = STATE(1641),
    [sym__double_quoted_string] = STATE(1651),
    [sym__argument_name_string_or_identifier_or_null] = STATE(2085),
    [sym_na] = STATE(1552),
    [sym__expression] = STATE(1552),
    [sym__open_parenthesis] = STATE(1080),
    [sym__open_brace] = STATE(389),
    [sym_identifier] = ACTIONS(441),
    [anon_sym_BSLASH] = ACTIONS(443),
    [anon_sym_function] = ACTIONS(445),
    [anon_sym_if] = ACTIONS(447),
    [anon_sym_for] = ACTIONS(449),
    [anon_sym_while] = ACTIONS(451),
    [anon_sym_repeat] = ACTIONS(453),
    [anon_sym_QMARK] = ACTIONS(455),
    [anon_sym_TILDE] = ACTIONS(457),
    [anon_sym_BANG] = ACTIONS(459),
    [anon_sym_PLUS] = ACTIONS(461),
    [anon_sym_DASH] = ACTIONS(461),
    [sym__hex_literal] = ACTIONS(463),
    [sym__number_literal] = ACTIONS(465),
    [anon_sym_SQUOTE] = ACTIONS(467),
    [anon_sym_DQUOTE] = ACTIONS(469),
    [sym_dots] = ACTIONS(441),
    [sym_dot_dot_i] = ACTIONS(441),
    [sym_next] = ACTIONS(471),
    [sym_break] = ACTIONS(471),
    [sym_true] = ACTIONS(471),
    [sym_false] = ACTIONS(471),
    [sym_null] = ACTIONS(473),
    [sym_inf] = ACTIONS(471),
    [sym_nan] = ACTIONS(471),
    [anon_sym_NA] = ACTIONS(475),
    [anon_sym_NA_integer_] = ACTIONS(475),
    [anon_sym_NA_real_] = ACTIONS(475),
    [anon_sym_NA_complex_] = ACTIONS(475),
    [anon_sym_NA_character_] = ACTIONS(475),
    [sym_comment] = ACTIONS(3),
    [sym_comma] = ACTIONS(639),
    [sym__raw_string_open] = ACTIONS(479),
    [sym__external_open_parenthesis] = ACTIONS(481),
    [sym__external_open_brace] = ACTIONS(483),
    [sym__external_close_bracket2] = ACTIONS(639),
  },
  [299] = {
    [sym_identifier] = ACTIONS(617),
    [anon_sym_BSLASH] = ACTIONS(615),
    [anon_sym_function] = ACTIONS(617),
    [anon_sym_EQ] = ACTIONS(617),
    [anon_sym_if] = ACTIONS(617),
    [anon_sym_for] = ACTIONS(617),
    [anon_sym_while] = ACTIONS(617),
    [anon_sym_repeat] = ACTIONS(617),
    [anon_sym_QMARK] = ACTIONS(615),
    [anon_sym_TILDE] = ACTIONS(615),
    [anon_sym_BANG] = ACTIONS(617),
    [anon_sym_PLUS] = ACTIONS(615),
    [anon_sym_DASH] = ACTIONS(617),
    [anon_sym_LT_DASH] = ACTIONS(615),
    [anon_sym_LT_LT_DASH] = ACTIONS(615),
    [anon_sym_COLON_EQ] = ACTIONS(615),
    [anon_sym_DASH_GT] = ACTIONS(617),
    [anon_sym_DASH_GT_GT] = ACTIONS(615),
    [anon_sym_PIPE] = ACTIONS(617),
    [anon_sym_AMP] = ACTIONS(617),
    [anon_sym_PIPE_PIPE] = ACTIONS(615),
    [anon_sym_AMP_AMP] = ACTIONS(615),
    [anon_sym_LT] = ACTIONS(617),
    [anon_sym_LT_EQ] = ACTIONS(615),
    [anon_sym_GT] = ACTIONS(617),
    [anon_sym_GT_EQ] = ACTIONS(615),
    [anon_sym_EQ_EQ] = ACTIONS(615),
    [anon_sym_BANG_EQ] = ACTIONS(615),
    [anon_sym_STAR] = ACTIONS(617),
    [anon_sym_SLASH] = ACTIONS(615),
    [anon_sym_STAR_STAR] = ACTIONS(615),
    [anon_sym_CARET] = ACTIONS(615),
    [aux_sym_binary_operator_token1] = ACTIONS(615),
    [anon_sym_PIPE_GT] = ACTIONS(615),
    [anon_sym_COLON] = ACTIONS(617),
    [anon_sym_DOLLAR] = ACTIONS(615),
    [anon_sym_AT] = ACTIONS(615),
    [anon_sym_COLON_COLON] = ACTIONS(653),
    [anon_sym_COLON_COLON_COLON] = ACTIONS(655),
    [sym__hex_literal] = ACTIONS(615),
    [sym__number_literal] = ACTIONS(617),
    [anon_sym_SQUOTE] = ACTIONS(615),
    [anon_sym_DQUOTE] = ACTIONS(615),
    [sym_dots] = ACTIONS(617),
    [sym_dot_dot_i] = ACTIONS(617),
    [sym_next] = ACTIONS(617),
    [sym_break] = ACTIONS(617),
    [sym_true] = ACTIONS(617),
    [sym_false] = ACTIONS(617),
    [sym_null] = ACTIONS(617),
    [sym_inf] = ACTIONS(617),
    [sym_nan] = ACTIONS(617),
    [anon_sym_NA] = ACTIONS(617),
    [anon_sym_NA_integer_] = ACTIONS(617),
    [anon_sym_NA_real_] = ACTIONS(617),
    [anon_sym_NA_complex_] = ACTIONS(617),
    [anon_sym_NA_character_] = ACTIONS(617),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(615),
    [sym__semicolon] = ACTIONS(615),
    [sym__raw_string_open] = ACTIONS(615),
    [sym__external_else] = ACTIONS(615),
    [sym__external_open_parenthesis] = ACTIONS(615),
    [sym__external_open_brace] = ACTIONS(615),
    [sym__external_close_brace] = ACTIONS(615),
    [sym__external_open_bracket] = ACTIONS(615),
    [sym__external_open_bracket2] = ACTIONS(615),
  },
  [300] = {
    [sym_identifier] = ACTIONS(625),
    [anon_sym_BSLASH] = ACTIONS(623),
    [anon_sym_function] = ACTIONS(625),
    [anon_sym_EQ] = ACTIONS(625),
    [anon_sym_if] = ACTIONS(625),
    [anon_sym_for] = ACTIONS(625),
    [anon_sym_while] = ACTIONS(625),
    [anon_sym_repeat] = ACTIONS(625),
    [anon_sym_QMARK] = ACTIONS(623),
    [anon_sym_TILDE] = ACTIONS(623),
    [anon_sym_BANG] = ACTIONS(625),
    [anon_sym_PLUS] = ACTIONS(623),
    [anon_sym_DASH] = ACTIONS(625),
    [anon_sym_LT_DASH] = ACTIONS(623),
    [anon_sym_LT_LT_DASH] = ACTIONS(623),
    [anon_sym_COLON_EQ] = ACTIONS(623),
    [anon_sym_DASH_GT] = ACTIONS(625),
    [anon_sym_DASH_GT_GT] = ACTIONS(623),
    [anon_sym_PIPE] = ACTIONS(625),
    [anon_sym_AMP] = ACTIONS(625),
    [anon_sym_PIPE_PIPE] = ACTIONS(623),
    [anon_sym_AMP_AMP] = ACTIONS(623),
    [anon_sym_LT] = ACTIONS(625),
    [anon_sym_LT_EQ] = ACTIONS(623),
    [anon_sym_GT] = ACTIONS(625),
    [anon_sym_GT_EQ] = ACTIONS(623),
    [anon_sym_EQ_EQ] = ACTIONS(623),
    [anon_sym_BANG_EQ] = ACTIONS(623),
    [anon_sym_STAR] = ACTIONS(625),
    [anon_sym_SLASH] = ACTIONS(623),
    [anon_sym_STAR_STAR] = ACTIONS(623),
    [anon_sym_CARET] = ACTIONS(623),
    [aux_sym_binary_operator_token1] = ACTIONS(623),
    [anon_sym_PIPE_GT] = ACTIONS(623),
    [anon_sym_COLON] = ACTIONS(625),
    [anon_sym_DOLLAR] = ACTIONS(623),
    [anon_sym_AT] = ACTIONS(623),
    [anon_sym_L] = ACTIONS(657),
    [anon_sym_i] = ACTIONS(659),
    [sym__hex_literal] = ACTIONS(623),
    [sym__number_literal] = ACTIONS(625),
    [anon_sym_SQUOTE] = ACTIONS(623),
    [anon_sym_DQUOTE] = ACTIONS(623),
    [sym_dots] = ACTIONS(625),
    [sym_dot_dot_i] = ACTIONS(625),
    [sym_next] = ACTIONS(625),
    [sym_break] = ACTIONS(625),
    [sym_true] = ACTIONS(625),
    [sym_false] = ACTIONS(625),
    [sym_null] = ACTIONS(625),
    [sym_inf] = ACTIONS(625),
    [sym_nan] = ACTIONS(625),
    [anon_sym_NA] = ACTIONS(625),
    [anon_sym_NA_integer_] = ACTIONS(625),
    [anon_sym_NA_real_] = ACTIONS(625),
    [anon_sym_NA_complex_] = ACTIONS(625),
    [anon_sym_NA_character_] = ACTIONS(625),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(623),
    [sym__semicolon] = ACTIONS(623),
    [sym__raw_string_open] = ACTIONS(623),
    [sym__external_else] = ACTIONS(623),
    [sym__external_open_parenthesis] = ACTIONS(623),
    [sym__external_open_brace] = ACTIONS(623),
    [sym__external_close_brace] = ACTIONS(623),
    [sym__external_open_bracket] = ACTIONS(623),
    [sym__external_open_bracket2] = ACTIONS(623),
  },
  [301] = {
    [sym_identifier] = ACTIONS(609),
    [anon_sym_BSLASH] = ACTIONS(607),
    [anon_sym_function] = ACTIONS(609),
    [anon_sym_EQ] = ACTIONS(609),
    [anon_sym_if] = ACTIONS(609),
    [anon_sym_for] = ACTIONS(609),
    [anon_sym_while] = ACTIONS(609),
    [anon_sym_repeat] = ACTIONS(609),
    [anon_sym_QMARK] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(607),
    [anon_sym_BANG] = ACTIONS(609),
    [anon_sym_PLUS] = ACTIONS(607),
    [anon_sym_DASH] = ACTIONS(609),
    [anon_sym_LT_DASH] = ACTIONS(607),
    [anon_sym_LT_LT_DASH] = ACTIONS(607),
    [anon_sym_COLON_EQ] = ACTIONS(607),
    [anon_sym_DASH_GT] = ACTIONS(609),
    [anon_sym_DASH_GT_GT] = ACTIONS(607),
    [anon_sym_PIPE] = ACTIONS(609),
    [anon_sym_AMP] = ACTIONS(609),
    [anon_sym_PIPE_PIPE] = ACTIONS(607),
    [anon_sym_AMP_AMP] = ACTIONS(607),
    [anon_sym_LT] = ACTIONS(609),
    [anon_sym_LT_EQ] = ACTIONS(607),
    [anon_sym_GT] = ACTIONS(609),
    [anon_sym_GT_EQ] = ACTIONS(607),
    [anon_sym_EQ_EQ] = ACTIONS(607),
    [anon_sym_BANG_EQ] = ACTIONS(607),
    [anon_sym_STAR] = ACTIONS(609),
    [anon_sym_SLASH] = ACTIONS(607),
    [anon_sym_STAR_STAR] = ACTIONS(607),
    [anon_sym_CARET] = ACTIONS(607),
    [aux_sym_binary_operator_token1] = ACTIONS(607),
    [anon_sym_PIPE_GT] = ACTIONS(607),
    [anon_sym_COLON] = ACTIONS(609),
    [anon_sym_DOLLAR] = ACTIONS(607),
    [anon_sym_AT] = ACTIONS(607),
    [anon_sym_COLON_COLON] = ACTIONS(609),
    [anon_sym_COLON_COLON_COLON] = ACTIONS(607),
    [sym__hex_literal] = ACTIONS(607),
    [sym__number_literal] = ACTIONS(609),
    [anon_sym_SQUOTE] = ACTIONS(607),
    [anon_sym_DQUOTE] = ACTIONS(607),
    [sym_dots] = ACTIONS(609),
    [sym_dot_dot_i] = ACTIONS(609),
    [sym_next] = ACTIONS(609),
    [sym_break] = ACTIONS(609),
    [sym_true] = ACTIONS(609),
    [sym_false] = ACTIONS(609),
    [sym_null] = ACTIONS(609),
    [sym_inf] = ACTIONS(609),
    [sym_nan] = ACTIONS(609),
    [anon_sym_NA] = ACTIONS(609),
    [anon_sym_NA_integer_] = ACTIONS(609),
    [anon_sym_NA_real_] = ACTIONS(609),
    [anon_sym_NA_complex_] = ACTIONS(609),
    [anon_sym_NA_character_] = ACTIONS(609),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(607),
    [sym__semicolon] = ACTIONS(607),
    [sym__raw_string_open] = ACTIONS(607),
    [sym__external_else] = ACTIONS(607),
    [sym__external_open_parenthesis] = ACTIONS(607),
    [sym__external_open_brace] = ACTIONS(607),
    [sym__external_close_brace] = ACTIONS(607),
    [sym__external_open_bracket] = ACTIONS(607),
    [sym__external_open_bracket2] = ACTIONS(607),
  },
  [302] = {
    [sym_identifier] = ACTIONS(609),
    [anon_sym_BSLASH] = ACTIONS(607),
    [anon_sym_function] = ACTIONS(609),
    [anon_sym_EQ] = ACTIONS(609),
    [anon_sym_if] = ACTIONS(609),
    [anon_sym_for] = ACTIONS(609),
    [anon_sym_while] = ACTIONS(609),
    [anon_sym_repeat] = ACTIONS(609),
    [anon_sym_QMARK] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(607),
    [anon_sym_BANG] = ACTIONS(609),
    [anon_sym_PLUS] = ACTIONS(607),
    [anon_sym_DASH] = ACTIONS(609),
    [anon_sym_LT_DASH] = ACTIONS(607),
    [anon_sym_LT_LT_DASH] = ACTIONS(607),
    [anon_sym_COLON_EQ] = ACTIONS(607),
    [anon_sym_DASH_GT] = ACTIONS(609),
    [anon_sym_DASH_GT_GT] = ACTIONS(607),
    [anon_sym_PIPE] = ACTIONS(609),
    [anon_sym_AMP] = ACTIONS(609),
    [anon_sym_PIPE_PIPE] = ACTIONS(607),
    [anon_sym_AMP_AMP] = ACTIONS(607),
    [anon_sym_LT] = ACTIONS(609),
    [anon_sym_LT_EQ] = ACTIONS(607),
    [anon_sym_GT] = ACTIONS(609),
    [anon_sym_GT_EQ] = ACTIONS(607),
    [anon_sym_EQ_EQ] = ACTIONS(607),
    [anon_sym_BANG_EQ] = ACTIONS(607),
    [anon_sym_STAR] = ACTIONS(609),
    [anon_sym_SLASH] = ACTIONS(607),
    [anon_sym_STAR_STAR] = ACTIONS(607),
    [anon_sym_CARET] = ACTIONS(607),
    [aux_sym_binary_operator_token1] = ACTIONS(607),
    [anon_sym_PIPE_GT] = ACTIONS(607),
    [anon_sym_COLON] = ACTIONS(609),
    [anon_sym_DOLLAR] = ACTIONS(607),
    [anon_sym_AT] = ACTIONS(607),
    [anon_sym_COLON_COLON] = ACTIONS(609),
    [anon_sym_COLON_COLON_COLON] = ACTIONS(607),
    [sym__hex_literal] = ACTIONS(607),
    [sym__number_literal] = ACTIONS(609),
    [anon_sym_SQUOTE] = ACTIONS(607),
    [anon_sym_DQUOTE] = ACTIONS(607),
    [sym_dots] = ACTIONS(609),
    [sym_dot_dot_i] = ACTIONS(609),
    [sym_next] = ACTIONS(609),
    [sym_break] = ACTIONS(609),
    [sym_true] = ACTIONS(609),
    [sym_false] = ACTIONS(609),
    [sym_null] = ACTIONS(609),
    [sym_inf] = ACTIONS(609),
    [sym_nan] = ACTIONS(609),
    [anon_sym_NA] = ACTIONS(609),
    [anon_sym_NA_integer_] = ACTIONS(609),
    [anon_sym_NA_real_] = ACTIONS(609),
    [anon_sym_NA_complex_] = ACTIONS(609),
    [anon_sym_NA_character_] = ACTIONS(609),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(607),
    [sym__semicolon] = ACTIONS(607),
    [sym__raw_string_open] = ACTIONS(607),
    [sym__external_else] = ACTIONS(607),
    [sym__external_open_parenthesis] = ACTIONS(607),
    [sym__external_open_brace] = ACTIONS(607),
    [sym__external_close_brace] = ACTIONS(607),
    [sym__external_open_bracket] = ACTIONS(607),
    [sym__external_open_bracket2] = ACTIONS(607),
  },
  [303] = {
    [sym_identifier] = ACTIONS(609),
    [anon_sym_BSLASH] = ACTIONS(607),
    [anon_sym_function] = ACTIONS(609),
    [anon_sym_EQ] = ACTIONS(609),
    [anon_sym_if] = ACTIONS(609),
    [anon_sym_for] = ACTIONS(609),
    [anon_sym_while] = ACTIONS(609),
    [anon_sym_repeat] = ACTIONS(609),
    [anon_sym_QMARK] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(607),
    [anon_sym_BANG] = ACTIONS(609),
    [anon_sym_PLUS] = ACTIONS(607),
    [anon_sym_DASH] = ACTIONS(609),
    [anon_sym_LT_DASH] = ACTIONS(607),
    [anon_sym_LT_LT_DASH] = ACTIONS(607),
    [anon_sym_COLON_EQ] = ACTIONS(607),
    [anon_sym_DASH_GT] = ACTIONS(609),
    [anon_sym_DASH_GT_GT] = ACTIONS(607),
    [anon_sym_PIPE] = ACTIONS(609),
    [anon_sym_AMP] = ACTIONS(609),
    [anon_sym_PIPE_PIPE] = ACTIONS(607),
    [anon_sym_AMP_AMP] = ACTIONS(607),
    [anon_sym_LT] = ACTIONS(609),
    [anon_sym_LT_EQ] = ACTIONS(607),
    [anon_sym_GT] = ACTIONS(609),
    [anon_sym_GT_EQ] = ACTIONS(607),
    [anon_sym_EQ_EQ] = ACTIONS(607),
    [anon_sym_BANG_EQ] = ACTIONS(607),
    [anon_sym_STAR] = ACTIONS(609),
    [anon_sym_SLASH] = ACTIONS(607),
    [anon_sym_STAR_STAR] = ACTIONS(607),
    [anon_sym_CARET] = ACTIONS(607),
    [aux_sym_binary_operator_token1] = ACTIONS(607),
    [anon_sym_PIPE_GT] = ACTIONS(607),
    [anon_sym_COLON] = ACTIONS(609),
    [anon_sym_DOLLAR] = ACTIONS(607),
    [anon_sym_AT] = ACTIONS(607),
    [anon_sym_COLON_COLON] = ACTIONS(609),
    [anon_sym_COLON_COLON_COLON] = ACTIONS(607),
    [sym__hex_literal] = ACTIONS(607),
    [sym__number_literal] = ACTIONS(609),
    [anon_sym_SQUOTE] = ACTIONS(607),
    [anon_sym_DQUOTE] = ACTIONS(607),
    [sym_dots] = ACTIONS(609),
    [sym_dot_dot_i] = ACTIONS(609),
    [sym_next] = ACTIONS(609),
    [sym_break] = ACTIONS(609),
    [sym_true] = ACTIONS(609),
    [sym_false] = ACTIONS(609),
    [sym_null] = ACTIONS(609),
    [sym_inf] = ACTIONS(609),
    [sym_nan] = ACTIONS(609),
    [anon_sym_NA] = ACTIONS(609),
    [anon_sym_NA_integer_] = ACTIONS(609),
    [anon_sym_NA_real_] = ACTIONS(609),
    [anon_sym_NA_complex_] = ACTIONS(609),
    [anon_sym_NA_character_] = ACTIONS(609),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(607),
    [sym__semicolon] = ACTIONS(607),
    [sym__raw_string_open] = ACTIONS(607),
    [sym__external_else] = ACTIONS(607),
    [sym__external_open_parenthesis] = ACTIONS(607),
    [sym__external_open_brace] = ACTIONS(607),
    [sym__external_close_brace] = ACTIONS(607),
    [sym__external_open_bracket] = ACTIONS(607),
    [sym__external_open_bracket2] = ACTIONS(607),
  },
  [304] = {
    [sym_identifier] = ACTIONS(637),
    [anon_sym_BSLASH] = ACTIONS(635),
    [anon_sym_function] = ACTIONS(637),
    [anon_sym_EQ] = ACTIONS(637),
    [anon_sym_if] = ACTIONS(637),
    [anon_sym_for] = ACTIONS(637),
    [anon_sym_while] = ACTIONS(637),
    [anon_sym_repeat] = ACTIONS(637),
    [anon_sym_QMARK] = ACTIONS(635),
    [anon_sym_TILDE] = ACTIONS(635),
    [anon_sym_BANG] = ACTIONS(637),
    [anon_sym_PLUS] = ACTIONS(635),
    [anon_sym_DASH] = ACTIONS(637),
    [anon_sym_LT_DASH] = ACTIONS(635),
    [anon_sym_LT_LT_DASH] = ACTIONS(635),
    [anon_sym_COLON_EQ] = ACTIONS(635),
    [anon_sym_DASH_GT] = ACTIONS(637),
    [anon_sym_DASH_GT_GT] = ACTIONS(635),
    [anon_sym_PIPE] = ACTIONS(637),
    [anon_sym_AMP] = ACTIONS(637),
    [anon_sym_PIPE_PIPE] = ACTIONS(635),
    [anon_sym_AMP_AMP] = ACTIONS(635),
    [anon_sym_LT] = ACTIONS(637),
    [anon_sym_LT_EQ] = ACTIONS(635),
    [anon_sym_GT] = ACTIONS(637),
    [anon_sym_GT_EQ] = ACTIONS(635),
    [anon_sym_EQ_EQ] = ACTIONS(635),
    [anon_sym_BANG_EQ] = ACTIONS(635),
    [anon_sym_STAR] = ACTIONS(637),
    [anon_sym_SLASH] = ACTIONS(635),
    [anon_sym_STAR_STAR] = ACTIONS(635),
    [anon_sym_CARET] = ACTIONS(635),
    [aux_sym_binary_operator_token1] = ACTIONS(635),
    [anon_sym_PIPE_GT] = ACTIONS(635),
    [anon_sym_COLON] = ACTIONS(637),
    [anon_sym_DOLLAR] = ACTIONS(635),
    [anon_sym_AT] = ACTIONS(635),
    [anon_sym_COLON_COLON] = ACTIONS(637),
    [anon_sym_COLON_COLON_COLON] = ACTIONS(635),
    [sym__hex_literal] = ACTIONS(635),
    [sym__number_literal] = ACTIONS(637),
    [anon_sym_SQUOTE] = ACTIONS(635),
    [anon_sym_DQUOTE] = ACTIONS(635),
    [sym_dots] = ACTIONS(637),
    [sym_dot_dot_i] = ACTIONS(637),
    [sym_next] = ACTIONS(637),
    [sym_break] = ACTIONS(637),
    [sym_true] = ACTIONS(637),
    [sym_false] = ACTIONS(637),
    [sym_null] = ACTIONS(637),
    [sym_inf] = ACTIONS(637),
    [sym_nan] = ACTIONS(637),
    [anon_sym_NA] = ACTIONS(637),
    [anon_sym_NA_integer_] = ACTIONS(637),
    [anon_sym_NA_real_] = ACTIONS(637),
    [anon_sym_NA_complex_] = ACTIONS(637),
    [anon_sym_NA_character_] = ACTIONS(637),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(635),
    [sym__semicolon] = ACTIONS(635),
    [sym__raw_string_open] = ACTIONS(635),
    [sym__external_else] = ACTIONS(635),
    [sym__external_open_parenthesis] = ACTIONS(635),
    [sym__external_open_brace] = ACTIONS(635),
    [sym__external_close_brace] = ACTIONS(635),
    [sym__external_open_bracket] = ACTIONS(635),
    [sym__external_open_bracket2] = ACTIONS(635),
  },
  [305] = {
    [sym_identifier] = ACTIONS(643),
    [anon_sym_BSLASH] = ACTIONS(641),
    [anon_sym_function] = ACTIONS(643),
    [anon_sym_EQ] = ACTIONS(643),
    [anon_sym_if] = ACTIONS(643),
    [anon_sym_for] = ACTIONS(643),
    [anon_sym_while] = ACTIONS(643),
    [anon_sym_repeat] = ACTIONS(643),
    [anon_sym_QMARK] = ACTIONS(641),
    [anon_sym_TILDE] = ACTIONS(641),
    [anon_sym_BANG] = ACTIONS(643),
    [anon_sym_PLUS] = ACTIONS(641),
    [anon_sym_DASH] = ACTIONS(643),
    [anon_sym_LT_DASH] = ACTIONS(641),
    [anon_sym_LT_LT_DASH] = ACTIONS(641),
    [anon_sym_COLON_EQ] = ACTIONS(641),
    [anon_sym_DASH_GT] = ACTIONS(643),
    [anon_sym_DASH_GT_GT] = ACTIONS(641),
    [anon_sym_PIPE] = ACTIONS(643),
    [anon_sym_AMP] = ACTIONS(643),
    [anon_sym_PIPE_PIPE] = ACTIONS(641),
    [anon_sym_AMP_AMP] = ACTIONS(641),
    [anon_sym_LT] = ACTIONS(643),
    [anon_sym_LT_EQ] = ACTIONS(641),
    [anon_sym_GT] = ACTIONS(643),
    [anon_sym_GT_EQ] = ACTIONS(641),
    [anon_sym_EQ_EQ] = ACTIONS(641),
    [anon_sym_BANG_EQ] = ACTIONS(641),
    [anon_sym_STAR] = ACTIONS(643),
    [anon_sym_SLASH] = ACTIONS(641),
    [anon_sym_STAR_STAR] = ACTIONS(641),
    [anon_sym_CARET] = ACTIONS(641),
    [aux_sym_binary_operator_token1] = ACTIONS(641),
    [anon_sym_PIPE_GT] = ACTIONS(641),
    [anon_sym_COLON] = ACTIONS(643),
    [anon_sym_DOLLAR] = ACTIONS(641),
    [anon_sym_AT] = ACTIONS(641),
    [anon_sym_COLON_COLON] = ACTIONS(643),
    [anon_sym_COLON_COLON_COLON] = ACTIONS(641),
    [sym__hex_literal] = ACTIONS(641),
    [sym__number_literal] = ACTIONS(643),
    [anon_sym_SQUOTE] = ACTIONS(641),
    [anon_sym_DQUOTE] = ACTIONS(641),
    [sym_dots] = ACTIONS(643),
    [sym_dot_dot_i] = ACTIONS(643),
    [sym_next] = ACTIONS(643),
    [sym_break] = ACTIONS(643),
    [sym_true] = ACTIONS(643),
    [sym_false] = ACTIONS(643),
    [sym_null] = ACTIONS(643),
    [sym_inf] = ACTIONS(643),
    [sym_nan] = ACTIONS(643),
    [anon_sym_NA] = ACTIONS(643),
    [anon_sym_NA_integer_] = ACTIONS(643),
    [anon_sym_NA_real_] = ACTIONS(643),
    [anon_sym_NA_complex_] = ACTIONS(643),
    [anon_sym_NA_character_] = ACTIONS(643),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(641),
    [sym__semicolon] = ACTIONS(641),
    [sym__raw_string_open] = ACTIONS(641),
    [sym__external_else] = ACTIONS(641),
    [sym__external_open_parenthesis] = ACTIONS(641),
    [sym__external_open_brace] = ACTIONS(641),
    [sym__external_close_brace] = ACTIONS(641),
    [sym__external_open_bracket] = ACTIONS(641),
    [sym__external_open_bracket2] = ACTIONS(641),
  },
  [306] = {
    [sym_identifier] = ACTIONS(647),
    [anon_sym_BSLASH] = ACTIONS(645),
    [anon_sym_function] = ACTIONS(647),
    [anon_sym_EQ] = ACTIONS(647),
    [anon_sym_if] = ACTIONS(647),
    [anon_sym_for] = ACTIONS(647),
    [anon_sym_while] = ACTIONS(647),
    [anon_sym_repeat] = ACTIONS(647),
    [anon_sym_QMARK] = ACTIONS(645),
    [anon_sym_TILDE] = ACTIONS(645),
    [anon_sym_BANG] = ACTIONS(647),
    [anon_sym_PLUS] = ACTIONS(645),
    [anon_sym_DASH] = ACTIONS(647),
    [anon_sym_LT_DASH] = ACTIONS(645),
    [anon_sym_LT_LT_DASH] = ACTIONS(645),
    [anon_sym_COLON_EQ] = ACTIONS(645),
    [anon_sym_DASH_GT] = ACTIONS(647),
    [anon_sym_DASH_GT_GT] = ACTIONS(645),
    [anon_sym_PIPE] = ACTIONS(647),
    [anon_sym_AMP] = ACTIONS(647),
    [anon_sym_PIPE_PIPE] = ACTIONS(645),
    [anon_sym_AMP_AMP] = ACTIONS(645),
    [anon_sym_LT] = ACTIONS(647),
    [anon_sym_LT_EQ] = ACTIONS(645),
    [anon_sym_GT] = ACTIONS(647),
    [anon_sym_GT_EQ] = ACTIONS(645),
    [anon_sym_EQ_EQ] = ACTIONS(645),
    [anon_sym_BANG_EQ] = ACTIONS(645),
    [anon_sym_STAR] = ACTIONS(647),
    [anon_sym_SLASH] = ACTIONS(645),
    [anon_sym_STAR_STAR] = ACTIONS(645),
    [anon_sym_CARET] = ACTIONS(645),
    [aux_sym_binary_operator_token1] = ACTIONS(645),
    [anon_sym_PIPE_GT] = ACTIONS(645),
    [anon_sym_COLON] = ACTIONS(647),
    [anon_sym_DOLLAR] = ACTIONS(645),
    [anon_sym_AT] = ACTIONS(645),
    [anon_sym_COLON_COLON] = ACTIONS(647),
    [anon_sym_COLON_COLON_COLON] = ACTIONS(645),
    [sym__hex_literal] = ACTIONS(645),
    [sym__number_literal] = ACTIONS(647),
    [anon_sym_SQUOTE] = ACTIONS(645),
    [anon_sym_DQUOTE] = ACTIONS(645),
    [sym_dots] = ACTIONS(647),
    [sym_dot_dot_i] = ACTIONS(647),
    [sym_next] = ACTIONS(647),
    [sym_break] = ACTIONS(647),
    [sym_true] = ACTIONS(647),
    [sym_false] = ACTIONS(647),
    [sym_null] = ACTIONS(647),
    [sym_inf] = ACTIONS(647),
    [sym_nan] = ACTIONS(647),
    [anon_sym_NA] = ACTIONS(647),
    [anon_sym_NA_integer_] = ACTIONS(647),
    [anon_sym_NA_real_] = ACTIONS(647),
    [anon_sym_NA_complex_] = ACTIONS(647),
    [anon_sym_NA_character_] = ACTIONS(647),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(645),
    [sym__semicolon] = ACTIONS(645),
    [sym__raw_string_open] = ACTIONS(645),
    [sym__external_else] = ACTIONS(645),
    [sym__external_open_parenthesis] = ACTIONS(645),
    [sym__external_open_brace] = ACTIONS(645),
    [sym__external_close_brace] = ACTIONS(645),
    [sym__external_open_bracket] = ACTIONS(645),
    [sym__external_open_bracket2] = ACTIONS(645),
  },
  [307] = {
    [sym_identifier] = ACTIONS(651),
    [anon_sym_BSLASH] = ACTIONS(649),
    [anon_sym_function] = ACTIONS(651),
    [anon_sym_EQ] = ACTIONS(651),
    [anon_sym_if] = ACTIONS(651),
    [anon_sym_for] = ACTIONS(651),
    [anon_sym_while] = ACTIONS(651),
    [anon_sym_repeat] = ACTIONS(651),
    [anon_sym_QMARK] = ACTIONS(649),
    [anon_sym_TILDE] = ACTIONS(649),
    [anon_sym_BANG] = ACTIONS(651),
    [anon_sym_PLUS] = ACTIONS(649),
    [anon_sym_DASH] = ACTIONS(651),
    [anon_sym_LT_DASH] = ACTIONS(649),
    [anon_sym_LT_LT_DASH] = ACTIONS(649),
    [anon_sym_COLON_EQ] = ACTIONS(649),
    [anon_sym_DASH_GT] = ACTIONS(651),
    [anon_sym_DASH_GT_GT] = ACTIONS(649),
    [anon_sym_PIPE] = ACTIONS(651),
    [anon_sym_AMP] = ACTIONS(651),
    [anon_sym_PIPE_PIPE] = ACTIONS(649),
    [anon_sym_AMP_AMP] = ACTIONS(649),
    [anon_sym_LT] = ACTIONS(651),
    [anon_sym_LT_EQ] = ACTIONS(649),
    [anon_sym_GT] = ACTIONS(651),
    [anon_sym_GT_EQ] = ACTIONS(649),
    [anon_sym_EQ_EQ] = ACTIONS(649),
    [anon_sym_BANG_EQ] = ACTIONS(649),
    [anon_sym_STAR] = ACTIONS(651),
    [anon_sym_SLASH] = ACTIONS(649),
    [anon_sym_STAR_STAR] = ACTIONS(649),
    [anon_sym_CARET] = ACTIONS(649),
    [aux_sym_binary_operator_token1] = ACTIONS(649),
    [anon_sym_PIPE_GT] = ACTIONS(649),
    [anon_sym_COLON] = ACTIONS(651),
    [anon_sym_DOLLAR] = ACTIONS(649),
    [anon_sym_AT] = ACTIONS(649),
    [anon_sym_COLON_COLON] = ACTIONS(651),
    [anon_sym_COLON_COLON_COLON] = ACTIONS(649),
    [sym__hex_literal] = ACTIONS(649),
    [sym__number_literal] = ACTIONS(651),
    [anon_sym_SQUOTE] = ACTIONS(649),
    [anon_sym_DQUOTE] = ACTIONS(649),
    [sym_dots] = ACTIONS(651),
    [sym_dot_dot_i] = ACTIONS(651),
    [sym_next] = ACTIONS(651),
    [sym_break] = ACTIONS(651),
    [sym_true] = ACTIONS(651),
    [sym_false] = ACTIONS(651),
    [sym_null] = ACTIONS(651),
    [sym_inf] = ACTIONS(651),
    [sym_nan] = ACTIONS(651),
    [anon_sym_NA] = ACTIONS(651),
    [anon_sym_NA_integer_] = ACTIONS(651),
    [anon_sym_NA_real_] = ACTIONS(651),
    [anon_sym_NA_complex_] = ACTIONS(651),
    [anon_sym_NA_character_] = ACTIONS(651),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(649),
    [sym__semicolon] = ACTIONS(649),
    [sym__raw_string_open] = ACTIONS(649),
    [sym__external_else] = ACTIONS(649),
    [sym__external_open_parenthesis] = ACTIONS(649),
    [sym__external_open_brace] = ACTIONS(649),
    [sym__external_close_brace] = ACTIONS(649),
    [sym__external_open_bracket] = ACTIONS(649),
    [sym__external_open_bracket2] = ACTIONS(649),
  },
  [308] = {
    [sym_identifier] = ACTIONS(613),
    [anon_sym_BSLASH] = ACTIONS(611),
    [anon_sym_function] = ACTIONS(613),
    [anon_sym_EQ] = ACTIONS(613),
    [anon_sym_if] = ACTIONS(613),
    [anon_sym_for] = ACTIONS(613),
    [anon_sym_while] = ACTIONS(613),
    [anon_sym_repeat] = ACTIONS(613),
    [anon_sym_QMARK] = ACTIONS(611),
    [anon_sym_TILDE] = ACTIONS(611),
    [anon_sym_BANG] = ACTIONS(613),
    [anon_sym_PLUS] = ACTIONS(611),
    [anon_sym_DASH] = ACTIONS(613),
    [anon_sym_LT_DASH] = ACTIONS(611),
    [anon_sym_LT_LT_DASH] = ACTIONS(611),
    [anon_sym_COLON_EQ] = ACTIONS(611),
    [anon_sym_DASH_GT] = ACTIONS(613),
    [anon_sym_DASH_GT_GT] = ACTIONS(611),
    [anon_sym_PIPE] = ACTIONS(613),
    [anon_sym_AMP] = ACTIONS(613),
    [anon_sym_PIPE_PIPE] = ACTIONS(611),
    [anon_sym_AMP_AMP] = ACTIONS(611),
    [anon_sym_LT] = ACTIONS(613),
    [anon_sym_LT_EQ] = ACTIONS(611),
    [anon_sym_GT] = ACTIONS(613),
    [anon_sym_GT_EQ] = ACTIONS(611),
    [anon_sym_EQ_EQ] = ACTIONS(611),
    [anon_sym_BANG_EQ] = ACTIONS(611),
    [anon_sym_STAR] = ACTIONS(613),
    [anon_sym_SLASH] = ACTIONS(611),
    [anon_sym_STAR_STAR] = ACTIONS(611),
    [anon_sym_CARET] = ACTIONS(611),
    [aux_sym_binary_operator_token1] = ACTIONS(611),
    [anon_sym_PIPE_GT] = ACTIONS(611),
    [anon_sym_COLON] = ACTIONS(613),
    [anon_sym_DOLLAR] = ACTIONS(611),
    [anon_sym_AT] = ACTIONS(611),
    [anon_sym_COLON_COLON] = ACTIONS(613),
    [anon_sym_COLON_COLON_COLON] = ACTIONS(611),
    [sym__hex_literal] = ACTIONS(611),
    [sym__number_literal] = ACTIONS(613),
    [anon_sym_SQUOTE] = ACTIONS(611),
    [anon_sym_DQUOTE] = ACTIONS(611),
    [sym_dots] = ACTIONS(613),
    [sym_dot_dot_i] = ACTIONS(613),
    [sym_next] = ACTIONS(613),
    [sym_break] = ACTIONS(613),
    [sym_true] = ACTIONS(613),
    [sym_false] = ACTIONS(613),
    [sym_null] = ACTIONS(613),
    [sym_inf] = ACTIONS(613),
    [sym_nan] = ACTIONS(613),
    [anon_sym_NA] = ACTIONS(613),
    [anon_sym_NA_integer_] = ACTIONS(613),
    [anon_sym_NA_real_] = ACTIONS(613),
    [anon_sym_NA_complex_] = ACTIONS(613),
    [anon_sym_NA_character_] = ACTIONS(613),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(611),
    [sym__semicolon] = ACTIONS(611),
    [sym__raw_string_open] = ACTIONS(611),
    [sym__external_else] = ACTIONS(611),
    [sym__external_open_parenthesis] = ACTIONS(611),
    [sym__external_open_brace] = ACTIONS(611),
    [sym__external_close_brace] = ACTIONS(611),
    [sym__external_open_bracket] = ACTIONS(611),
    [sym__external_open_bracket2] = ACTIONS(611),
  },
  [309] = {
    [sym_identifier] = ACTIONS(633),
    [anon_sym_BSLASH] = ACTIONS(631),
    [anon_sym_function] = ACTIONS(633),
    [anon_sym_EQ] = ACTIONS(633),
    [anon_sym_if] = ACTIONS(633),
    [anon_sym_for] = ACTIONS(633),
    [anon_sym_while] = ACTIONS(633),
    [anon_sym_repeat] = ACTIONS(633),
    [anon_sym_QMARK] = ACTIONS(631),
    [anon_sym_TILDE] = ACTIONS(631),
    [anon_sym_BANG] = ACTIONS(633),
    [anon_sym_PLUS] = ACTIONS(631),
    [anon_sym_DASH] = ACTIONS(633),
    [anon_sym_LT_DASH] = ACTIONS(631),
    [anon_sym_LT_LT_DASH] = ACTIONS(631),
    [anon_sym_COLON_EQ] = ACTIONS(631),
    [anon_sym_DASH_GT] = ACTIONS(633),
    [anon_sym_DASH_GT_GT] = ACTIONS(631),
    [anon_sym_PIPE] = ACTIONS(633),
    [anon_sym_AMP] = ACTIONS(633),
    [anon_sym_PIPE_PIPE] = ACTIONS(631),
    [anon_sym_AMP_AMP] = ACTIONS(631),
    [anon_sym_LT] = ACTIONS(633),
    [anon_sym_LT_EQ] = ACTIONS(631),
    [anon_sym_GT] = ACTIONS(633),
    [anon_sym_GT_EQ] = ACTIONS(631),
    [anon_sym_EQ_EQ] = ACTIONS(631),
    [anon_sym_BANG_EQ] = ACTIONS(631),
    [anon_sym_STAR] = ACTIONS(633),
    [anon_sym_SLASH] = ACTIONS(631),
    [anon_sym_STAR_STAR] = ACTIONS(631),
    [anon_sym_CARET] = ACTIONS(631),
    [aux_sym_binary_operator_token1] = ACTIONS(631),
    [anon_sym_PIPE_GT] = ACTIONS(631),
    [anon_sym_COLON] = ACTIONS(633),
    [anon_sym_DOLLAR] = ACTIONS(631),
    [anon_sym_AT] = ACTIONS(631),
    [anon_sym_COLON_COLON] = ACTIONS(633),
    [anon_sym_COLON_COLON_COLON] = ACTIONS(631),
    [sym__hex_literal] = ACTIONS(631),
    [sym__number_literal] = ACTIONS(633),
    [anon_sym_SQUOTE] = ACTIONS(631),
    [anon_sym_DQUOTE] = ACTIONS(631),
    [sym_dots] = ACTIONS(633),
    [sym_dot_dot_i] = ACTIONS(633),
    [sym_next] = ACTIONS(633),
    [sym_break] = ACTIONS(633),
    [sym_true] = ACTIONS(633),
    [sym_false] = ACTIONS(633),
    [sym_null] = ACTIONS(633),
    [sym_inf] = ACTIONS(633),
    [sym_nan] = ACTIONS(633),
    [anon_sym_NA] = ACTIONS(633),
    [anon_sym_NA_integer_] = ACTIONS(633),
    [anon_sym_NA_real_] = ACTIONS(633),
    [anon_sym_NA_complex_] = ACTIONS(633),
    [anon_sym_NA_character_] = ACTIONS(633),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(631),
    [sym__semicolon] = ACTIONS(631),
    [sym__raw_string_open] = ACTIONS(631),
    [sym__external_else] = ACTIONS(631),
    [sym__external_open_parenthesis] = ACTIONS(631),
    [sym__external_open_brace] = ACTIONS(631),
    [sym__external_close_brace] = ACTIONS(631),
    [sym__external_open_bracket] = ACTIONS(631),
    [sym__external_open_bracket2] = ACTIONS(631),
  },
  [310] = {
    [sym_function_definition] = STATE(1490),
    [sym_if_statement] = STATE(1490),
    [sym_for_statement] = STATE(1490),
    [sym_while_statement] = STATE(1490),
    [sym_repeat_statement] = STATE(1490),
    [sym_braced_expression] = STATE(1490),
    [sym_parenthesized_expression] = STATE(1490),
    [sym_call] = STATE(1490),
    [sym_subset] = STATE(1490),
    [sym_subset2] = STATE(1490),
    [sym_argument] = STATE(2068),
    [sym__argument_named] = STATE(2062),
    [sym__argument_unnamed] = STATE(2065),
    [sym__argument_value] = STATE(2071),
    [sym_unary_operator] = STATE(1490),
    [sym_binary_operator] = STATE(1490),
    [sym_extract_operator] = STATE(1490),
    [sym_namespace_operator] = STATE(1490),
    [sym_integer] = STATE(1490),
    [sym_complex] = STATE(1490),
    [sym_float] = STATE(1490),
    [sym__float_literal] = STATE(1649),
    [sym_string] = STATE(1636),
    [sym__raw_string] = STATE(1632),
    [sym__single_quoted_string] = STATE(1617),
    [sym__double_quoted_string] = STATE(1619),
    [sym__argument_name_string_or_identifier_or_null] = STATE(2082),
    [sym_na] = STATE(1490),
    [sym__expression] = STATE(1490),
    [sym__open_parenthesis] = STATE(1075),
    [sym__open_brace] = STATE(386),
    [sym_identifier] = ACTIONS(379),
    [anon_sym_BSLASH] = ACTIONS(381),
    [anon_sym_function] = ACTIONS(383),
    [anon_sym_if] = ACTIONS(385),
    [anon_sym_for] = ACTIONS(387),
    [anon_sym_while] = ACTIONS(389),
    [anon_sym_repeat] = ACTIONS(391),
    [anon_sym_QMARK] = ACTIONS(393),
    [anon_sym_TILDE] = ACTIONS(395),
    [anon_sym_BANG] = ACTIONS(397),
    [anon_sym_PLUS] = ACTIONS(399),
    [anon_sym_DASH] = ACTIONS(399),
    [sym__hex_literal] = ACTIONS(401),
    [sym__number_literal] = ACTIONS(403),
    [anon_sym_SQUOTE] = ACTIONS(405),
    [anon_sym_DQUOTE] = ACTIONS(407),
    [sym_dots] = ACTIONS(379),
    [sym_dot_dot_i] = ACTIONS(379),
    [sym_next] = ACTIONS(409),
    [sym_break] = ACTIONS(409),
    [sym_true] = ACTIONS(409),
    [sym_false] = ACTIONS(409),
    [sym_null] = ACTIONS(411),
    [sym_inf] = ACTIONS(409),
    [sym_nan] = ACTIONS(409),
    [anon_sym_NA] = ACTIONS(413),
    [anon_sym_NA_integer_] = ACTIONS(413),
    [anon_sym_NA_real_] = ACTIONS(413),
    [anon_sym_NA_complex_] = ACTIONS(413),
    [anon_sym_NA_character_] = ACTIONS(413),
    [sym_comment] = ACTIONS(3),
    [sym_comma] = ACTIONS(639),
    [sym__raw_string_open] = ACTIONS(417),
    [sym__external_open_parenthesis] = ACTIONS(419),
    [sym__external_open_brace] = ACTIONS(421),
    [sym__external_close_bracket] = ACTIONS(639),
  },
  [311] = {
    [sym_identifier] = ACTIONS(617),
    [anon_sym_BSLASH] = ACTIONS(615),
    [anon_sym_function] = ACTIONS(617),
    [anon_sym_EQ] = ACTIONS(617),
    [anon_sym_if] = ACTIONS(617),
    [anon_sym_for] = ACTIONS(617),
    [anon_sym_while] = ACTIONS(617),
    [anon_sym_repeat] = ACTIONS(617),
    [anon_sym_QMARK] = ACTIONS(615),
    [anon_sym_TILDE] = ACTIONS(615),
    [anon_sym_BANG] = ACTIONS(617),
    [anon_sym_PLUS] = ACTIONS(615),
    [anon_sym_DASH] = ACTIONS(617),
    [anon_sym_LT_DASH] = ACTIONS(615),
    [anon_sym_LT_LT_DASH] = ACTIONS(615),
    [anon_sym_COLON_EQ] = ACTIONS(615),
    [anon_sym_DASH_GT] = ACTIONS(617),
    [anon_sym_DASH_GT_GT] = ACTIONS(615),
    [anon_sym_PIPE] = ACTIONS(617),
    [anon_sym_AMP] = ACTIONS(617),
    [anon_sym_PIPE_PIPE] = ACTIONS(615),
    [anon_sym_AMP_AMP] = ACTIONS(615),
    [anon_sym_LT] = ACTIONS(617),
    [anon_sym_LT_EQ] = ACTIONS(615),
    [anon_sym_GT] = ACTIONS(617),
    [anon_sym_GT_EQ] = ACTIONS(615),
    [anon_sym_EQ_EQ] = ACTIONS(615),
    [anon_sym_BANG_EQ] = ACTIONS(615),
    [anon_sym_STAR] = ACTIONS(617),
    [anon_sym_SLASH] = ACTIONS(615),
    [anon_sym_STAR_STAR] = ACTIONS(615),
    [anon_sym_CARET] = ACTIONS(615),
    [aux_sym_binary_operator_token1] = ACTIONS(615),
    [anon_sym_PIPE_GT] = ACTIONS(615),
    [anon_sym_COLON] = ACTIONS(617),
    [anon_sym_DOLLAR] = ACTIONS(615),
    [anon_sym_AT] = ACTIONS(615),
    [anon_sym_COLON_COLON] = ACTIONS(661),
    [anon_sym_COLON_COLON_COLON] = ACTIONS(663),
    [sym__hex_literal] = ACTIONS(615),
    [sym__number_literal] = ACTIONS(617),
    [anon_sym_SQUOTE] = ACTIONS(615),
    [anon_sym_DQUOTE] = ACTIONS(615),
    [sym_dots] = ACTIONS(617),
    [sym_dot_dot_i] = ACTIONS(617),
    [sym_next] = ACTIONS(617),
    [sym_break] = ACTIONS(617),
    [sym_true] = ACTIONS(617),
    [sym_false] = ACTIONS(617),
    [sym_null] = ACTIONS(617),
    [sym_inf] = ACTIONS(617),
    [sym_nan] = ACTIONS(617),
    [anon_sym_NA] = ACTIONS(617),
    [anon_sym_NA_integer_] = ACTIONS(617),
    [anon_sym_NA_real_] = ACTIONS(617),
    [anon_sym_NA_complex_] = ACTIONS(617),
    [anon_sym_NA_character_] = ACTIONS(617),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(615),
    [sym__semicolon] = ACTIONS(615),
    [sym__raw_string_open] = ACTIONS(615),
    [sym__external_open_parenthesis] = ACTIONS(615),
    [sym__external_open_brace] = ACTIONS(615),
    [sym__external_close_brace] = ACTIONS(615),
    [sym__external_open_bracket] = ACTIONS(615),
    [sym__external_open_bracket2] = ACTIONS(615),
  },
  [312] = {
    [sym_identifier] = ACTIONS(633),
    [anon_sym_BSLASH] = ACTIONS(631),
    [anon_sym_function] = ACTIONS(633),
    [anon_sym_EQ] = ACTIONS(633),
    [anon_sym_if] = ACTIONS(633),
    [anon_sym_for] = ACTIONS(633),
    [anon_sym_while] = ACTIONS(633),
    [anon_sym_repeat] = ACTIONS(633),
    [anon_sym_QMARK] = ACTIONS(631),
    [anon_sym_TILDE] = ACTIONS(631),
    [anon_sym_BANG] = ACTIONS(633),
    [anon_sym_PLUS] = ACTIONS(631),
    [anon_sym_DASH] = ACTIONS(633),
    [anon_sym_LT_DASH] = ACTIONS(631),
    [anon_sym_LT_LT_DASH] = ACTIONS(631),
    [anon_sym_COLON_EQ] = ACTIONS(631),
    [anon_sym_DASH_GT] = ACTIONS(633),
    [anon_sym_DASH_GT_GT] = ACTIONS(631),
    [anon_sym_PIPE] = ACTIONS(633),
    [anon_sym_AMP] = ACTIONS(633),
    [anon_sym_PIPE_PIPE] = ACTIONS(631),
    [anon_sym_AMP_AMP] = ACTIONS(631),
    [anon_sym_LT] = ACTIONS(633),
    [anon_sym_LT_EQ] = ACTIONS(631),
    [anon_sym_GT] = ACTIONS(633),
    [anon_sym_GT_EQ] = ACTIONS(631),
    [anon_sym_EQ_EQ] = ACTIONS(631),
    [anon_sym_BANG_EQ] = ACTIONS(631),
    [anon_sym_STAR] = ACTIONS(633),
    [anon_sym_SLASH] = ACTIONS(631),
    [anon_sym_STAR_STAR] = ACTIONS(631),
    [anon_sym_CARET] = ACTIONS(631),
    [aux_sym_binary_operator_token1] = ACTIONS(631),
    [anon_sym_PIPE_GT] = ACTIONS(631),
    [anon_sym_COLON] = ACTIONS(633),
    [anon_sym_DOLLAR] = ACTIONS(631),
    [anon_sym_AT] = ACTIONS(631),
    [anon_sym_COLON_COLON] = ACTIONS(633),
    [anon_sym_COLON_COLON_COLON] = ACTIONS(631),
    [sym__hex_literal] = ACTIONS(631),
    [sym__number_literal] = ACTIONS(633),
    [anon_sym_SQUOTE] = ACTIONS(631),
    [anon_sym_DQUOTE] = ACTIONS(631),
    [sym_dots] = ACTIONS(633),
    [sym_dot_dot_i] = ACTIONS(633),
    [sym_next] = ACTIONS(633),
    [sym_break] = ACTIONS(633),
    [sym_true] = ACTIONS(633),
    [sym_false] = ACTIONS(633),
    [sym_null] = ACTIONS(633),
    [sym_inf] = ACTIONS(633),
    [sym_nan] = ACTIONS(633),
    [anon_sym_NA] = ACTIONS(633),
    [anon_sym_NA_integer_] = ACTIONS(633),
    [anon_sym_NA_real_] = ACTIONS(633),
    [anon_sym_NA_complex_] = ACTIONS(633),
    [anon_sym_NA_character_] = ACTIONS(633),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(631),
    [sym__semicolon] = ACTIONS(631),
    [sym__raw_string_open] = ACTIONS(631),
    [sym__external_open_parenthesis] = ACTIONS(631),
    [sym__external_open_brace] = ACTIONS(631),
    [sym__external_close_brace] = ACTIONS(631),
    [sym__external_open_bracket] = ACTIONS(631),
    [sym__external_open_bracket2] = ACTIONS(631),
  },
  [313] = {
    [sym_identifier] = ACTIONS(643),
    [anon_sym_BSLASH] = ACTIONS(641),
    [anon_sym_function] = ACTIONS(643),
    [anon_sym_EQ] = ACTIONS(643),
    [anon_sym_if] = ACTIONS(643),
    [anon_sym_for] = ACTIONS(643),
    [anon_sym_while] = ACTIONS(643),
    [anon_sym_repeat] = ACTIONS(643),
    [anon_sym_QMARK] = ACTIONS(641),
    [anon_sym_TILDE] = ACTIONS(641),
    [anon_sym_BANG] = ACTIONS(643),
    [anon_sym_PLUS] = ACTIONS(641),
    [anon_sym_DASH] = ACTIONS(643),
    [anon_sym_LT_DASH] = ACTIONS(641),
    [anon_sym_LT_LT_DASH] = ACTIONS(641),
    [anon_sym_COLON_EQ] = ACTIONS(641),
    [anon_sym_DASH_GT] = ACTIONS(643),
    [anon_sym_DASH_GT_GT] = ACTIONS(641),
    [anon_sym_PIPE] = ACTIONS(643),
    [anon_sym_AMP] = ACTIONS(643),
    [anon_sym_PIPE_PIPE] = ACTIONS(641),
    [anon_sym_AMP_AMP] = ACTIONS(641),
    [anon_sym_LT] = ACTIONS(643),
    [anon_sym_LT_EQ] = ACTIONS(641),
    [anon_sym_GT] = ACTIONS(643),
    [anon_sym_GT_EQ] = ACTIONS(641),
    [anon_sym_EQ_EQ] = ACTIONS(641),
    [anon_sym_BANG_EQ] = ACTIONS(641),
    [anon_sym_STAR] = ACTIONS(643),
    [anon_sym_SLASH] = ACTIONS(641),
    [anon_sym_STAR_STAR] = ACTIONS(641),
    [anon_sym_CARET] = ACTIONS(641),
    [aux_sym_binary_operator_token1] = ACTIONS(641),
    [anon_sym_PIPE_GT] = ACTIONS(641),
    [anon_sym_COLON] = ACTIONS(643),
    [anon_sym_DOLLAR] = ACTIONS(641),
    [anon_sym_AT] = ACTIONS(641),
    [anon_sym_COLON_COLON] = ACTIONS(643),
    [anon_sym_COLON_COLON_COLON] = ACTIONS(641),
    [sym__hex_literal] = ACTIONS(641),
    [sym__number_literal] = ACTIONS(643),
    [anon_sym_SQUOTE] = ACTIONS(641),
    [anon_sym_DQUOTE] = ACTIONS(641),
    [sym_dots] = ACTIONS(643),
    [sym_dot_dot_i] = ACTIONS(643),
    [sym_next] = ACTIONS(643),
    [sym_break] = ACTIONS(643),
    [sym_true] = ACTIONS(643),
    [sym_false] = ACTIONS(643),
    [sym_null] = ACTIONS(643),
    [sym_inf] = ACTIONS(643),
    [sym_nan] = ACTIONS(643),
    [anon_sym_NA] = ACTIONS(643),
    [anon_sym_NA_integer_] = ACTIONS(643),
    [anon_sym_NA_real_] = ACTIONS(643),
    [anon_sym_NA_complex_] = ACTIONS(643),
    [anon_sym_NA_character_] = ACTIONS(643),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(641),
    [sym__semicolon] = ACTIONS(641),
    [sym__raw_string_open] = ACTIONS(641),
    [sym__external_open_parenthesis] = ACTIONS(641),
    [sym__external_open_brace] = ACTIONS(641),
    [sym__external_close_brace] = ACTIONS(641),
    [sym__external_open_bracket] = ACTIONS(641),
    [sym__external_open_bracket2] = ACTIONS(641),
  },
  [314] = {
    [sym_identifier] = ACTIONS(647),
    [anon_sym_BSLASH] = ACTIONS(645),
    [anon_sym_function] = ACTIONS(647),
    [anon_sym_EQ] = ACTIONS(647),
    [anon_sym_if] = ACTIONS(647),
    [anon_sym_for] = ACTIONS(647),
    [anon_sym_while] = ACTIONS(647),
    [anon_sym_repeat] = ACTIONS(647),
    [anon_sym_QMARK] = ACTIONS(645),
    [anon_sym_TILDE] = ACTIONS(645),
    [anon_sym_BANG] = ACTIONS(647),
    [anon_sym_PLUS] = ACTIONS(645),
    [anon_sym_DASH] = ACTIONS(647),
    [anon_sym_LT_DASH] = ACTIONS(645),
    [anon_sym_LT_LT_DASH] = ACTIONS(645),
    [anon_sym_COLON_EQ] = ACTIONS(645),
    [anon_sym_DASH_GT] = ACTIONS(647),
    [anon_sym_DASH_GT_GT] = ACTIONS(645),
    [anon_sym_PIPE] = ACTIONS(647),
    [anon_sym_AMP] = ACTIONS(647),
    [anon_sym_PIPE_PIPE] = ACTIONS(645),
    [anon_sym_AMP_AMP] = ACTIONS(645),
    [anon_sym_LT] = ACTIONS(647),
    [anon_sym_LT_EQ] = ACTIONS(645),
    [anon_sym_GT] = ACTIONS(647),
    [anon_sym_GT_EQ] = ACTIONS(645),
    [anon_sym_EQ_EQ] = ACTIONS(645),
    [anon_sym_BANG_EQ] = ACTIONS(645),
    [anon_sym_STAR] = ACTIONS(647),
    [anon_sym_SLASH] = ACTIONS(645),
    [anon_sym_STAR_STAR] = ACTIONS(645),
    [anon_sym_CARET] = ACTIONS(645),
    [aux_sym_binary_operator_token1] = ACTIONS(645),
    [anon_sym_PIPE_GT] = ACTIONS(645),
    [anon_sym_COLON] = ACTIONS(647),
    [anon_sym_DOLLAR] = ACTIONS(645),
    [anon_sym_AT] = ACTIONS(645),
    [anon_sym_COLON_COLON] = ACTIONS(647),
    [anon_sym_COLON_COLON_COLON] = ACTIONS(645),
    [sym__hex_literal] = ACTIONS(645),
    [sym__number_literal] = ACTIONS(647),
    [anon_sym_SQUOTE] = ACTIONS(645),
    [anon_sym_DQUOTE] = ACTIONS(645),
    [sym_dots] = ACTIONS(647),
    [sym_dot_dot_i] = ACTIONS(647),
    [sym_next] = ACTIONS(647),
    [sym_break] = ACTIONS(647),
    [sym_true] = ACTIONS(647),
    [sym_false] = ACTIONS(647),
    [sym_null] = ACTIONS(647),
    [sym_inf] = ACTIONS(647),
    [sym_nan] = ACTIONS(647),
    [anon_sym_NA] = ACTIONS(647),
    [anon_sym_NA_integer_] = ACTIONS(647),
    [anon_sym_NA_real_] = ACTIONS(647),
    [anon_sym_NA_complex_] = ACTIONS(647),
    [anon_sym_NA_character_] = ACTIONS(647),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(645),
    [sym__semicolon] = ACTIONS(645),
    [sym__raw_string_open] = ACTIONS(645),
    [sym__external_open_parenthesis] = ACTIONS(645),
    [sym__external_open_brace] = ACTIONS(645),
    [sym__external_close_brace] = ACTIONS(645),
    [sym__external_open_bracket] = ACTIONS(645),
    [sym__external_open_bracket2] = ACTIONS(645),
  },
  [315] = {
    [ts_builtin_sym_end] = ACTIONS(611),
    [sym_identifier] = ACTIONS(613),
    [anon_sym_BSLASH] = ACTIONS(611),
    [anon_sym_function] = ACTIONS(613),
    [anon_sym_EQ] = ACTIONS(613),
    [anon_sym_if] = ACTIONS(613),
    [anon_sym_for] = ACTIONS(613),
    [anon_sym_while] = ACTIONS(613),
    [anon_sym_repeat] = ACTIONS(613),
    [anon_sym_QMARK] = ACTIONS(611),
    [anon_sym_TILDE] = ACTIONS(611),
    [anon_sym_BANG] = ACTIONS(613),
    [anon_sym_PLUS] = ACTIONS(611),
    [anon_sym_DASH] = ACTIONS(613),
    [anon_sym_LT_DASH] = ACTIONS(611),
    [anon_sym_LT_LT_DASH] = ACTIONS(611),
    [anon_sym_COLON_EQ] = ACTIONS(611),
    [anon_sym_DASH_GT] = ACTIONS(613),
    [anon_sym_DASH_GT_GT] = ACTIONS(611),
    [anon_sym_PIPE] = ACTIONS(613),
    [anon_sym_AMP] = ACTIONS(613),
    [anon_sym_PIPE_PIPE] = ACTIONS(611),
    [anon_sym_AMP_AMP] = ACTIONS(611),
    [anon_sym_LT] = ACTIONS(613),
    [anon_sym_LT_EQ] = ACTIONS(611),
    [anon_sym_GT] = ACTIONS(613),
    [anon_sym_GT_EQ] = ACTIONS(611),
    [anon_sym_EQ_EQ] = ACTIONS(611),
    [anon_sym_BANG_EQ] = ACTIONS(611),
    [anon_sym_STAR] = ACTIONS(613),
    [anon_sym_SLASH] = ACTIONS(611),
    [anon_sym_STAR_STAR] = ACTIONS(611),
    [anon_sym_CARET] = ACTIONS(611),
    [aux_sym_binary_operator_token1] = ACTIONS(611),
    [anon_sym_PIPE_GT] = ACTIONS(611),
    [anon_sym_COLON] = ACTIONS(613),
    [anon_sym_DOLLAR] = ACTIONS(611),
    [anon_sym_AT] = ACTIONS(611),
    [anon_sym_COLON_COLON] = ACTIONS(613),
    [anon_sym_COLON_COLON_COLON] = ACTIONS(611),
    [sym__hex_literal] = ACTIONS(611),
    [sym__number_literal] = ACTIONS(613),
    [anon_sym_SQUOTE] = ACTIONS(611),
    [anon_sym_DQUOTE] = ACTIONS(611),
    [sym_dots] = ACTIONS(613),
    [sym_dot_dot_i] = ACTIONS(613),
    [sym_next] = ACTIONS(613),
    [sym_break] = ACTIONS(613),
    [sym_true] = ACTIONS(613),
    [sym_false] = ACTIONS(613),
    [sym_null] = ACTIONS(613),
    [sym_inf] = ACTIONS(613),
    [sym_nan] = ACTIONS(613),
    [anon_sym_NA] = ACTIONS(613),
    [anon_sym_NA_integer_] = ACTIONS(613),
    [anon_sym_NA_real_] = ACTIONS(613),
    [anon_sym_NA_complex_] = ACTIONS(613),
    [anon_sym_NA_character_] = ACTIONS(613),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(611),
    [sym__semicolon] = ACTIONS(611),
    [sym__raw_string_open] = ACTIONS(611),
    [sym__external_open_parenthesis] = ACTIONS(611),
    [sym__external_open_brace] = ACTIONS(611),
    [sym__external_open_bracket] = ACTIONS(611),
    [sym__external_open_bracket2] = ACTIONS(611),
  },
  [316] = {
    [ts_builtin_sym_end] = ACTIONS(623),
    [sym_identifier] = ACTIONS(625),
    [anon_sym_BSLASH] = ACTIONS(623),
    [anon_sym_function] = ACTIONS(625),
    [anon_sym_EQ] = ACTIONS(625),
    [anon_sym_if] = ACTIONS(625),
    [anon_sym_for] = ACTIONS(625),
    [anon_sym_while] = ACTIONS(625),
    [anon_sym_repeat] = ACTIONS(625),
    [anon_sym_QMARK] = ACTIONS(623),
    [anon_sym_TILDE] = ACTIONS(623),
    [anon_sym_BANG] = ACTIONS(625),
    [anon_sym_PLUS] = ACTIONS(623),
    [anon_sym_DASH] = ACTIONS(625),
    [anon_sym_LT_DASH] = ACTIONS(623),
    [anon_sym_LT_LT_DASH] = ACTIONS(623),
    [anon_sym_COLON_EQ] = ACTIONS(623),
    [anon_sym_DASH_GT] = ACTIONS(625),
    [anon_sym_DASH_GT_GT] = ACTIONS(623),
    [anon_sym_PIPE] = ACTIONS(625),
    [anon_sym_AMP] = ACTIONS(625),
    [anon_sym_PIPE_PIPE] = ACTIONS(623),
    [anon_sym_AMP_AMP] = ACTIONS(623),
    [anon_sym_LT] = ACTIONS(625),
    [anon_sym_LT_EQ] = ACTIONS(623),
    [anon_sym_GT] = ACTIONS(625),
    [anon_sym_GT_EQ] = ACTIONS(623),
    [anon_sym_EQ_EQ] = ACTIONS(623),
    [anon_sym_BANG_EQ] = ACTIONS(623),
    [anon_sym_STAR] = ACTIONS(625),
    [anon_sym_SLASH] = ACTIONS(623),
    [anon_sym_STAR_STAR] = ACTIONS(623),
    [anon_sym_CARET] = ACTIONS(623),
    [aux_sym_binary_operator_token1] = ACTIONS(623),
    [anon_sym_PIPE_GT] = ACTIONS(623),
    [anon_sym_COLON] = ACTIONS(625),
    [anon_sym_DOLLAR] = ACTIONS(623),
    [anon_sym_AT] = ACTIONS(623),
    [anon_sym_L] = ACTIONS(665),
    [anon_sym_i] = ACTIONS(667),
    [sym__hex_literal] = ACTIONS(623),
    [sym__number_literal] = ACTIONS(625),
    [anon_sym_SQUOTE] = ACTIONS(623),
    [anon_sym_DQUOTE] = ACTIONS(623),
    [sym_dots] = ACTIONS(625),
    [sym_dot_dot_i] = ACTIONS(625),
    [sym_next] = ACTIONS(625),
    [sym_break] = ACTIONS(625),
    [sym_true] = ACTIONS(625),
    [sym_false] = ACTIONS(625),
    [sym_null] = ACTIONS(625),
    [sym_inf] = ACTIONS(625),
    [sym_nan] = ACTIONS(625),
    [anon_sym_NA] = ACTIONS(625),
    [anon_sym_NA_integer_] = ACTIONS(625),
    [anon_sym_NA_real_] = ACTIONS(625),
    [anon_sym_NA_complex_] = ACTIONS(625),
    [anon_sym_NA_character_] = ACTIONS(625),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(623),
    [sym__semicolon] = ACTIONS(623),
    [sym__raw_string_open] = ACTIONS(623),
    [sym__external_open_parenthesis] = ACTIONS(623),
    [sym__external_open_brace] = ACTIONS(623),
    [sym__external_open_bracket] = ACTIONS(623),
    [sym__external_open_bracket2] = ACTIONS(623),
  },
  [317] = {
    [aux_sym_function_definition_repeat1] = STATE(317),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_BSLASH] = ACTIONS(671),
    [anon_sym_function] = ACTIONS(669),
    [anon_sym_EQ] = ACTIONS(669),
    [anon_sym_if] = ACTIONS(669),
    [anon_sym_for] = ACTIONS(669),
    [anon_sym_while] = ACTIONS(669),
    [anon_sym_repeat] = ACTIONS(669),
    [anon_sym_QMARK] = ACTIONS(671),
    [anon_sym_TILDE] = ACTIONS(671),
    [anon_sym_BANG] = ACTIONS(669),
    [anon_sym_PLUS] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(669),
    [anon_sym_LT_DASH] = ACTIONS(671),
    [anon_sym_LT_LT_DASH] = ACTIONS(671),
    [anon_sym_COLON_EQ] = ACTIONS(671),
    [anon_sym_DASH_GT] = ACTIONS(669),
    [anon_sym_DASH_GT_GT] = ACTIONS(671),
    [anon_sym_PIPE] = ACTIONS(669),
    [anon_sym_AMP] = ACTIONS(669),
    [anon_sym_PIPE_PIPE] = ACTIONS(671),
    [anon_sym_AMP_AMP] = ACTIONS(671),
    [anon_sym_LT] = ACTIONS(669),
    [anon_sym_LT_EQ] = ACTIONS(671),
    [anon_sym_GT] = ACTIONS(669),
    [anon_sym_GT_EQ] = ACTIONS(671),
    [anon_sym_EQ_EQ] = ACTIONS(671),
    [anon_sym_BANG_EQ] = ACTIONS(671),
    [anon_sym_STAR] = ACTIONS(669),
    [anon_sym_SLASH] = ACTIONS(671),
    [anon_sym_STAR_STAR] = ACTIONS(671),
    [anon_sym_CARET] = ACTIONS(671),
    [aux_sym_binary_operator_token1] = ACTIONS(671),
    [anon_sym_PIPE_GT] = ACTIONS(671),
    [anon_sym_COLON] = ACTIONS(669),
    [anon_sym_DOLLAR] = ACTIONS(671),
    [anon_sym_AT] = ACTIONS(671),
    [sym__hex_literal] = ACTIONS(671),
    [sym__number_literal] = ACTIONS(669),
    [anon_sym_SQUOTE] = ACTIONS(671),
    [anon_sym_DQUOTE] = ACTIONS(671),
    [sym_dots] = ACTIONS(669),
    [sym_dot_dot_i] = ACTIONS(669),
    [sym_next] = ACTIONS(669),
    [sym_break] = ACTIONS(669),
    [sym_true] = ACTIONS(669),
    [sym_false] = ACTIONS(669),
    [sym_null] = ACTIONS(669),
    [sym_inf] = ACTIONS(669),
    [sym_nan] = ACTIONS(669),
    [anon_sym_NA] = ACTIONS(669),
    [anon_sym_NA_integer_] = ACTIONS(669),
    [anon_sym_NA_real_] = ACTIONS(669),
    [anon_sym_NA_complex_] = ACTIONS(669),
    [anon_sym_NA_character_] = ACTIONS(669),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(673),
    [sym__semicolon] = ACTIONS(671),
    [sym__raw_string_open] = ACTIONS(671),
    [sym__external_else] = ACTIONS(671),
    [sym__external_open_parenthesis] = ACTIONS(671),
    [sym__external_open_brace] = ACTIONS(671),
    [sym__external_close_brace] = ACTIONS(671),
    [sym__external_open_bracket] = ACTIONS(671),
    [sym__external_open_bracket2] = ACTIONS(671),
  },
  [318] = {
    [ts_builtin_sym_end] = ACTIONS(615),
    [sym_identifier] = ACTIONS(617),
    [anon_sym_BSLASH] = ACTIONS(615),
    [anon_sym_function] = ACTIONS(617),
    [anon_sym_EQ] = ACTIONS(617),
    [anon_sym_if] = ACTIONS(617),
    [anon_sym_for] = ACTIONS(617),
    [anon_sym_while] = ACTIONS(617),
    [anon_sym_repeat] = ACTIONS(617),
    [anon_sym_QMARK] = ACTIONS(615),
    [anon_sym_TILDE] = ACTIONS(615),
    [anon_sym_BANG] = ACTIONS(617),
    [anon_sym_PLUS] = ACTIONS(615),
    [anon_sym_DASH] = ACTIONS(617),
    [anon_sym_LT_DASH] = ACTIONS(615),
    [anon_sym_LT_LT_DASH] = ACTIONS(615),
    [anon_sym_COLON_EQ] = ACTIONS(615),
    [anon_sym_DASH_GT] = ACTIONS(617),
    [anon_sym_DASH_GT_GT] = ACTIONS(615),
    [anon_sym_PIPE] = ACTIONS(617),
    [anon_sym_AMP] = ACTIONS(617),
    [anon_sym_PIPE_PIPE] = ACTIONS(615),
    [anon_sym_AMP_AMP] = ACTIONS(615),
    [anon_sym_LT] = ACTIONS(617),
    [anon_sym_LT_EQ] = ACTIONS(615),
    [anon_sym_GT] = ACTIONS(617),
    [anon_sym_GT_EQ] = ACTIONS(615),
    [anon_sym_EQ_EQ] = ACTIONS(615),
    [anon_sym_BANG_EQ] = ACTIONS(615),
    [anon_sym_STAR] = ACTIONS(617),
    [anon_sym_SLASH] = ACTIONS(615),
    [anon_sym_STAR_STAR] = ACTIONS(615),
    [anon_sym_CARET] = ACTIONS(615),
    [aux_sym_binary_operator_token1] = ACTIONS(615),
    [anon_sym_PIPE_GT] = ACTIONS(615),
    [anon_sym_COLON] = ACTIONS(617),
    [anon_sym_DOLLAR] = ACTIONS(615),
    [anon_sym_AT] = ACTIONS(615),
    [anon_sym_COLON_COLON] = ACTIONS(676),
    [anon_sym_COLON_COLON_COLON] = ACTIONS(678),
    [sym__hex_literal] = ACTIONS(615),
    [sym__number_literal] = ACTIONS(617),
    [anon_sym_SQUOTE] = ACTIONS(615),
    [anon_sym_DQUOTE] = ACTIONS(615),
    [sym_dots] = ACTIONS(617),
    [sym_dot_dot_i] = ACTIONS(617),
    [sym_next] = ACTIONS(617),
    [sym_break] = ACTIONS(617),
    [sym_true] = ACTIONS(617),
    [sym_false] = ACTIONS(617),
    [sym_null] = ACTIONS(617),
    [sym_inf] = ACTIONS(617),
    [sym_nan] = ACTIONS(617),
    [anon_sym_NA] = ACTIONS(617),
    [anon_sym_NA_integer_] = ACTIONS(617),
    [anon_sym_NA_real_] = ACTIONS(617),
    [anon_sym_NA_complex_] = ACTIONS(617),
    [anon_sym_NA_character_] = ACTIONS(617),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(615),
    [sym__semicolon] = ACTIONS(615),
    [sym__raw_string_open] = ACTIONS(615),
    [sym__external_open_parenthesis] = ACTIONS(615),
    [sym__external_open_brace] = ACTIONS(615),
    [sym__external_open_bracket] = ACTIONS(615),
    [sym__external_open_bracket2] = ACTIONS(615),
  },
  [319] = {
    [ts_builtin_sym_end] = ACTIONS(607),
    [sym_identifier] = ACTIONS(609),
    [anon_sym_BSLASH] = ACTIONS(607),
    [anon_sym_function] = ACTIONS(609),
    [anon_sym_EQ] = ACTIONS(609),
    [anon_sym_if] = ACTIONS(609),
    [anon_sym_for] = ACTIONS(609),
    [anon_sym_while] = ACTIONS(609),
    [anon_sym_repeat] = ACTIONS(609),
    [anon_sym_QMARK] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(607),
    [anon_sym_BANG] = ACTIONS(609),
    [anon_sym_PLUS] = ACTIONS(607),
    [anon_sym_DASH] = ACTIONS(609),
    [anon_sym_LT_DASH] = ACTIONS(607),
    [anon_sym_LT_LT_DASH] = ACTIONS(607),
    [anon_sym_COLON_EQ] = ACTIONS(607),
    [anon_sym_DASH_GT] = ACTIONS(609),
    [anon_sym_DASH_GT_GT] = ACTIONS(607),
    [anon_sym_PIPE] = ACTIONS(609),
    [anon_sym_AMP] = ACTIONS(609),
    [anon_sym_PIPE_PIPE] = ACTIONS(607),
    [anon_sym_AMP_AMP] = ACTIONS(607),
    [anon_sym_LT] = ACTIONS(609),
    [anon_sym_LT_EQ] = ACTIONS(607),
    [anon_sym_GT] = ACTIONS(609),
    [anon_sym_GT_EQ] = ACTIONS(607),
    [anon_sym_EQ_EQ] = ACTIONS(607),
    [anon_sym_BANG_EQ] = ACTIONS(607),
    [anon_sym_STAR] = ACTIONS(609),
    [anon_sym_SLASH] = ACTIONS(607),
    [anon_sym_STAR_STAR] = ACTIONS(607),
    [anon_sym_CARET] = ACTIONS(607),
    [aux_sym_binary_operator_token1] = ACTIONS(607),
    [anon_sym_PIPE_GT] = ACTIONS(607),
    [anon_sym_COLON] = ACTIONS(609),
    [anon_sym_DOLLAR] = ACTIONS(607),
    [anon_sym_AT] = ACTIONS(607),
    [anon_sym_COLON_COLON] = ACTIONS(609),
    [anon_sym_COLON_COLON_COLON] = ACTIONS(607),
    [sym__hex_literal] = ACTIONS(607),
    [sym__number_literal] = ACTIONS(609),
    [anon_sym_SQUOTE] = ACTIONS(607),
    [anon_sym_DQUOTE] = ACTIONS(607),
    [sym_dots] = ACTIONS(609),
    [sym_dot_dot_i] = ACTIONS(609),
    [sym_next] = ACTIONS(609),
    [sym_break] = ACTIONS(609),
    [sym_true] = ACTIONS(609),
    [sym_false] = ACTIONS(609),
    [sym_null] = ACTIONS(609),
    [sym_inf] = ACTIONS(609),
    [sym_nan] = ACTIONS(609),
    [anon_sym_NA] = ACTIONS(609),
    [anon_sym_NA_integer_] = ACTIONS(609),
    [anon_sym_NA_real_] = ACTIONS(609),
    [anon_sym_NA_complex_] = ACTIONS(609),
    [anon_sym_NA_character_] = ACTIONS(609),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(607),
    [sym__semicolon] = ACTIONS(607),
    [sym__raw_string_open] = ACTIONS(607),
    [sym__external_open_parenthesis] = ACTIONS(607),
    [sym__external_open_brace] = ACTIONS(607),
    [sym__external_open_bracket] = ACTIONS(607),
    [sym__external_open_bracket2] = ACTIONS(607),
  },
  [320] = {
    [ts_builtin_sym_end] = ACTIONS(631),
    [sym_identifier] = ACTIONS(633),
    [anon_sym_BSLASH] = ACTIONS(631),
    [anon_sym_function] = ACTIONS(633),
    [anon_sym_EQ] = ACTIONS(633),
    [anon_sym_if] = ACTIONS(633),
    [anon_sym_for] = ACTIONS(633),
    [anon_sym_while] = ACTIONS(633),
    [anon_sym_repeat] = ACTIONS(633),
    [anon_sym_QMARK] = ACTIONS(631),
    [anon_sym_TILDE] = ACTIONS(631),
    [anon_sym_BANG] = ACTIONS(633),
    [anon_sym_PLUS] = ACTIONS(631),
    [anon_sym_DASH] = ACTIONS(633),
    [anon_sym_LT_DASH] = ACTIONS(631),
    [anon_sym_LT_LT_DASH] = ACTIONS(631),
    [anon_sym_COLON_EQ] = ACTIONS(631),
    [anon_sym_DASH_GT] = ACTIONS(633),
    [anon_sym_DASH_GT_GT] = ACTIONS(631),
    [anon_sym_PIPE] = ACTIONS(633),
    [anon_sym_AMP] = ACTIONS(633),
    [anon_sym_PIPE_PIPE] = ACTIONS(631),
    [anon_sym_AMP_AMP] = ACTIONS(631),
    [anon_sym_LT] = ACTIONS(633),
    [anon_sym_LT_EQ] = ACTIONS(631),
    [anon_sym_GT] = ACTIONS(633),
    [anon_sym_GT_EQ] = ACTIONS(631),
    [anon_sym_EQ_EQ] = ACTIONS(631),
    [anon_sym_BANG_EQ] = ACTIONS(631),
    [anon_sym_STAR] = ACTIONS(633),
    [anon_sym_SLASH] = ACTIONS(631),
    [anon_sym_STAR_STAR] = ACTIONS(631),
    [anon_sym_CARET] = ACTIONS(631),
    [aux_sym_binary_operator_token1] = ACTIONS(631),
    [anon_sym_PIPE_GT] = ACTIONS(631),
    [anon_sym_COLON] = ACTIONS(633),
    [anon_sym_DOLLAR] = ACTIONS(631),
    [anon_sym_AT] = ACTIONS(631),
    [anon_sym_COLON_COLON] = ACTIONS(633),
    [anon_sym_COLON_COLON_COLON] = ACTIONS(631),
    [sym__hex_literal] = ACTIONS(631),
    [sym__number_literal] = ACTIONS(633),
    [anon_sym_SQUOTE] = ACTIONS(631),
    [anon_sym_DQUOTE] = ACTIONS(631),
    [sym_dots] = ACTIONS(633),
    [sym_dot_dot_i] = ACTIONS(633),
    [sym_next] = ACTIONS(633),
    [sym_break] = ACTIONS(633),
    [sym_true] = ACTIONS(633),
    [sym_false] = ACTIONS(633),
    [sym_null] = ACTIONS(633),
    [sym_inf] = ACTIONS(633),
    [sym_nan] = ACTIONS(633),
    [anon_sym_NA] = ACTIONS(633),
    [anon_sym_NA_integer_] = ACTIONS(633),
    [anon_sym_NA_real_] = ACTIONS(633),
    [anon_sym_NA_complex_] = ACTIONS(633),
    [anon_sym_NA_character_] = ACTIONS(633),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(631),
    [sym__semicolon] = ACTIONS(631),
    [sym__raw_string_open] = ACTIONS(631),
    [sym__external_open_parenthesis] = ACTIONS(631),
    [sym__external_open_brace] = ACTIONS(631),
    [sym__external_open_bracket] = ACTIONS(631),
    [sym__external_open_bracket2] = ACTIONS(631),
  },
  [321] = {
    [sym_identifier] = ACTIONS(613),
    [anon_sym_BSLASH] = ACTIONS(611),
    [anon_sym_function] = ACTIONS(613),
    [anon_sym_EQ] = ACTIONS(613),
    [anon_sym_if] = ACTIONS(613),
    [anon_sym_for] = ACTIONS(613),
    [anon_sym_while] = ACTIONS(613),
    [anon_sym_repeat] = ACTIONS(613),
    [anon_sym_QMARK] = ACTIONS(611),
    [anon_sym_TILDE] = ACTIONS(611),
    [anon_sym_BANG] = ACTIONS(613),
    [anon_sym_PLUS] = ACTIONS(611),
    [anon_sym_DASH] = ACTIONS(613),
    [anon_sym_LT_DASH] = ACTIONS(611),
    [anon_sym_LT_LT_DASH] = ACTIONS(611),
    [anon_sym_COLON_EQ] = ACTIONS(611),
    [anon_sym_DASH_GT] = ACTIONS(613),
    [anon_sym_DASH_GT_GT] = ACTIONS(611),
    [anon_sym_PIPE] = ACTIONS(613),
    [anon_sym_AMP] = ACTIONS(613),
    [anon_sym_PIPE_PIPE] = ACTIONS(611),
    [anon_sym_AMP_AMP] = ACTIONS(611),
    [anon_sym_LT] = ACTIONS(613),
    [anon_sym_LT_EQ] = ACTIONS(611),
    [anon_sym_GT] = ACTIONS(613),
    [anon_sym_GT_EQ] = ACTIONS(611),
    [anon_sym_EQ_EQ] = ACTIONS(611),
    [anon_sym_BANG_EQ] = ACTIONS(611),
    [anon_sym_STAR] = ACTIONS(613),
    [anon_sym_SLASH] = ACTIONS(611),
    [anon_sym_STAR_STAR] = ACTIONS(611),
    [anon_sym_CARET] = ACTIONS(611),
    [aux_sym_binary_operator_token1] = ACTIONS(611),
    [anon_sym_PIPE_GT] = ACTIONS(611),
    [anon_sym_COLON] = ACTIONS(613),
    [anon_sym_DOLLAR] = ACTIONS(611),
    [anon_sym_AT] = ACTIONS(611),
    [anon_sym_COLON_COLON] = ACTIONS(613),
    [anon_sym_COLON_COLON_COLON] = ACTIONS(611),
    [sym__hex_literal] = ACTIONS(611),
    [sym__number_literal] = ACTIONS(613),
    [anon_sym_SQUOTE] = ACTIONS(611),
    [anon_sym_DQUOTE] = ACTIONS(611),
    [sym_dots] = ACTIONS(613),
    [sym_dot_dot_i] = ACTIONS(613),
    [sym_next] = ACTIONS(613),
    [sym_break] = ACTIONS(613),
    [sym_true] = ACTIONS(613),
    [sym_false] = ACTIONS(613),
    [sym_null] = ACTIONS(613),
    [sym_inf] = ACTIONS(613),
    [sym_nan] = ACTIONS(613),
    [anon_sym_NA] = ACTIONS(613),
    [anon_sym_NA_integer_] = ACTIONS(613),
    [anon_sym_NA_real_] = ACTIONS(613),
    [anon_sym_NA_complex_] = ACTIONS(613),
    [anon_sym_NA_character_] = ACTIONS(613),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(611),
    [sym__semicolon] = ACTIONS(611),
    [sym__raw_string_open] = ACTIONS(611),
    [sym__external_open_parenthesis] = ACTIONS(611),
    [sym__external_open_brace] = ACTIONS(611),
    [sym__external_close_brace] = ACTIONS(611),
    [sym__external_open_bracket] = ACTIONS(611),
    [sym__external_open_bracket2] = ACTIONS(611),
  },
  [322] = {
    [sym_identifier] = ACTIONS(651),
    [anon_sym_BSLASH] = ACTIONS(649),
    [anon_sym_function] = ACTIONS(651),
    [anon_sym_EQ] = ACTIONS(651),
    [anon_sym_if] = ACTIONS(651),
    [anon_sym_for] = ACTIONS(651),
    [anon_sym_while] = ACTIONS(651),
    [anon_sym_repeat] = ACTIONS(651),
    [anon_sym_QMARK] = ACTIONS(649),
    [anon_sym_TILDE] = ACTIONS(649),
    [anon_sym_BANG] = ACTIONS(651),
    [anon_sym_PLUS] = ACTIONS(649),
    [anon_sym_DASH] = ACTIONS(651),
    [anon_sym_LT_DASH] = ACTIONS(649),
    [anon_sym_LT_LT_DASH] = ACTIONS(649),
    [anon_sym_COLON_EQ] = ACTIONS(649),
    [anon_sym_DASH_GT] = ACTIONS(651),
    [anon_sym_DASH_GT_GT] = ACTIONS(649),
    [anon_sym_PIPE] = ACTIONS(651),
    [anon_sym_AMP] = ACTIONS(651),
    [anon_sym_PIPE_PIPE] = ACTIONS(649),
    [anon_sym_AMP_AMP] = ACTIONS(649),
    [anon_sym_LT] = ACTIONS(651),
    [anon_sym_LT_EQ] = ACTIONS(649),
    [anon_sym_GT] = ACTIONS(651),
    [anon_sym_GT_EQ] = ACTIONS(649),
    [anon_sym_EQ_EQ] = ACTIONS(649),
    [anon_sym_BANG_EQ] = ACTIONS(649),
    [anon_sym_STAR] = ACTIONS(651),
    [anon_sym_SLASH] = ACTIONS(649),
    [anon_sym_STAR_STAR] = ACTIONS(649),
    [anon_sym_CARET] = ACTIONS(649),
    [aux_sym_binary_operator_token1] = ACTIONS(649),
    [anon_sym_PIPE_GT] = ACTIONS(649),
    [anon_sym_COLON] = ACTIONS(651),
    [anon_sym_DOLLAR] = ACTIONS(649),
    [anon_sym_AT] = ACTIONS(649),
    [anon_sym_COLON_COLON] = ACTIONS(651),
    [anon_sym_COLON_COLON_COLON] = ACTIONS(649),
    [sym__hex_literal] = ACTIONS(649),
    [sym__number_literal] = ACTIONS(651),
    [anon_sym_SQUOTE] = ACTIONS(649),
    [anon_sym_DQUOTE] = ACTIONS(649),
    [sym_dots] = ACTIONS(651),
    [sym_dot_dot_i] = ACTIONS(651),
    [sym_next] = ACTIONS(651),
    [sym_break] = ACTIONS(651),
    [sym_true] = ACTIONS(651),
    [sym_false] = ACTIONS(651),
    [sym_null] = ACTIONS(651),
    [sym_inf] = ACTIONS(651),
    [sym_nan] = ACTIONS(651),
    [anon_sym_NA] = ACTIONS(651),
    [anon_sym_NA_integer_] = ACTIONS(651),
    [anon_sym_NA_real_] = ACTIONS(651),
    [anon_sym_NA_complex_] = ACTIONS(651),
    [anon_sym_NA_character_] = ACTIONS(651),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(649),
    [sym__semicolon] = ACTIONS(649),
    [sym__raw_string_open] = ACTIONS(649),
    [sym__external_open_parenthesis] = ACTIONS(649),
    [sym__external_open_brace] = ACTIONS(649),
    [sym__external_close_brace] = ACTIONS(649),
    [sym__external_open_bracket] = ACTIONS(649),
    [sym__external_open_bracket2] = ACTIONS(649),
  },
  [323] = {
    [aux_sym_function_definition_repeat1] = STATE(323),
    [ts_builtin_sym_end] = ACTIONS(671),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_BSLASH] = ACTIONS(671),
    [anon_sym_function] = ACTIONS(669),
    [anon_sym_EQ] = ACTIONS(669),
    [anon_sym_if] = ACTIONS(669),
    [anon_sym_for] = ACTIONS(669),
    [anon_sym_while] = ACTIONS(669),
    [anon_sym_repeat] = ACTIONS(669),
    [anon_sym_QMARK] = ACTIONS(671),
    [anon_sym_TILDE] = ACTIONS(671),
    [anon_sym_BANG] = ACTIONS(669),
    [anon_sym_PLUS] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(669),
    [anon_sym_LT_DASH] = ACTIONS(671),
    [anon_sym_LT_LT_DASH] = ACTIONS(671),
    [anon_sym_COLON_EQ] = ACTIONS(671),
    [anon_sym_DASH_GT] = ACTIONS(669),
    [anon_sym_DASH_GT_GT] = ACTIONS(671),
    [anon_sym_PIPE] = ACTIONS(669),
    [anon_sym_AMP] = ACTIONS(669),
    [anon_sym_PIPE_PIPE] = ACTIONS(671),
    [anon_sym_AMP_AMP] = ACTIONS(671),
    [anon_sym_LT] = ACTIONS(669),
    [anon_sym_LT_EQ] = ACTIONS(671),
    [anon_sym_GT] = ACTIONS(669),
    [anon_sym_GT_EQ] = ACTIONS(671),
    [anon_sym_EQ_EQ] = ACTIONS(671),
    [anon_sym_BANG_EQ] = ACTIONS(671),
    [anon_sym_STAR] = ACTIONS(669),
    [anon_sym_SLASH] = ACTIONS(671),
    [anon_sym_STAR_STAR] = ACTIONS(671),
    [anon_sym_CARET] = ACTIONS(671),
    [aux_sym_binary_operator_token1] = ACTIONS(671),
    [anon_sym_PIPE_GT] = ACTIONS(671),
    [anon_sym_COLON] = ACTIONS(669),
    [anon_sym_DOLLAR] = ACTIONS(671),
    [anon_sym_AT] = ACTIONS(671),
    [sym__hex_literal] = ACTIONS(671),
    [sym__number_literal] = ACTIONS(669),
    [anon_sym_SQUOTE] = ACTIONS(671),
    [anon_sym_DQUOTE] = ACTIONS(671),
    [sym_dots] = ACTIONS(669),
    [sym_dot_dot_i] = ACTIONS(669),
    [sym_next] = ACTIONS(669),
    [sym_break] = ACTIONS(669),
    [sym_true] = ACTIONS(669),
    [sym_false] = ACTIONS(669),
    [sym_null] = ACTIONS(669),
    [sym_inf] = ACTIONS(669),
    [sym_nan] = ACTIONS(669),
    [anon_sym_NA] = ACTIONS(669),
    [anon_sym_NA_integer_] = ACTIONS(669),
    [anon_sym_NA_real_] = ACTIONS(669),
    [anon_sym_NA_complex_] = ACTIONS(669),
    [anon_sym_NA_character_] = ACTIONS(669),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(680),
    [sym__semicolon] = ACTIONS(671),
    [sym__raw_string_open] = ACTIONS(671),
    [sym__external_else] = ACTIONS(671),
    [sym__external_open_parenthesis] = ACTIONS(671),
    [sym__external_open_brace] = ACTIONS(671),
    [sym__external_open_bracket] = ACTIONS(671),
    [sym__external_open_bracket2] = ACTIONS(671),
  },
  [324] = {
    [ts_builtin_sym_end] = ACTIONS(607),
    [sym_identifier] = ACTIONS(609),
    [anon_sym_BSLASH] = ACTIONS(607),
    [anon_sym_function] = ACTIONS(609),
    [anon_sym_EQ] = ACTIONS(609),
    [anon_sym_if] = ACTIONS(609),
    [anon_sym_for] = ACTIONS(609),
    [anon_sym_while] = ACTIONS(609),
    [anon_sym_repeat] = ACTIONS(609),
    [anon_sym_QMARK] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(607),
    [anon_sym_BANG] = ACTIONS(609),
    [anon_sym_PLUS] = ACTIONS(607),
    [anon_sym_DASH] = ACTIONS(609),
    [anon_sym_LT_DASH] = ACTIONS(607),
    [anon_sym_LT_LT_DASH] = ACTIONS(607),
    [anon_sym_COLON_EQ] = ACTIONS(607),
    [anon_sym_DASH_GT] = ACTIONS(609),
    [anon_sym_DASH_GT_GT] = ACTIONS(607),
    [anon_sym_PIPE] = ACTIONS(609),
    [anon_sym_AMP] = ACTIONS(609),
    [anon_sym_PIPE_PIPE] = ACTIONS(607),
    [anon_sym_AMP_AMP] = ACTIONS(607),
    [anon_sym_LT] = ACTIONS(609),
    [anon_sym_LT_EQ] = ACTIONS(607),
    [anon_sym_GT] = ACTIONS(609),
    [anon_sym_GT_EQ] = ACTIONS(607),
    [anon_sym_EQ_EQ] = ACTIONS(607),
    [anon_sym_BANG_EQ] = ACTIONS(607),
    [anon_sym_STAR] = ACTIONS(609),
    [anon_sym_SLASH] = ACTIONS(607),
    [anon_sym_STAR_STAR] = ACTIONS(607),
    [anon_sym_CARET] = ACTIONS(607),
    [aux_sym_binary_operator_token1] = ACTIONS(607),
    [anon_sym_PIPE_GT] = ACTIONS(607),
    [anon_sym_COLON] = ACTIONS(609),
    [anon_sym_DOLLAR] = ACTIONS(607),
    [anon_sym_AT] = ACTIONS(607),
    [anon_sym_COLON_COLON] = ACTIONS(609),
    [anon_sym_COLON_COLON_COLON] = ACTIONS(607),
    [sym__hex_literal] = ACTIONS(607),
    [sym__number_literal] = ACTIONS(609),
    [anon_sym_SQUOTE] = ACTIONS(607),
    [anon_sym_DQUOTE] = ACTIONS(607),
    [sym_dots] = ACTIONS(609),
    [sym_dot_dot_i] = ACTIONS(609),
    [sym_next] = ACTIONS(609),
    [sym_break] = ACTIONS(609),
    [sym_true] = ACTIONS(609),
    [sym_false] = ACTIONS(609),
    [sym_null] = ACTIONS(609),
    [sym_inf] = ACTIONS(609),
    [sym_nan] = ACTIONS(609),
    [anon_sym_NA] = ACTIONS(609),
    [anon_sym_NA_integer_] = ACTIONS(609),
    [anon_sym_NA_real_] = ACTIONS(609),
    [anon_sym_NA_complex_] = ACTIONS(609),
    [anon_sym_NA_character_] = ACTIONS(609),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(607),
    [sym__semicolon] = ACTIONS(607),
    [sym__raw_string_open] = ACTIONS(607),
    [sym__external_open_parenthesis] = ACTIONS(607),
    [sym__external_open_brace] = ACTIONS(607),
    [sym__external_open_bracket] = ACTIONS(607),
    [sym__external_open_bracket2] = ACTIONS(607),
  },
  [325] = {
    [ts_builtin_sym_end] = ACTIONS(607),
    [sym_identifier] = ACTIONS(609),
    [anon_sym_BSLASH] = ACTIONS(607),
    [anon_sym_function] = ACTIONS(609),
    [anon_sym_EQ] = ACTIONS(609),
    [anon_sym_if] = ACTIONS(609),
    [anon_sym_for] = ACTIONS(609),
    [anon_sym_while] = ACTIONS(609),
    [anon_sym_repeat] = ACTIONS(609),
    [anon_sym_QMARK] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(607),
    [anon_sym_BANG] = ACTIONS(609),
    [anon_sym_PLUS] = ACTIONS(607),
    [anon_sym_DASH] = ACTIONS(609),
    [anon_sym_LT_DASH] = ACTIONS(607),
    [anon_sym_LT_LT_DASH] = ACTIONS(607),
    [anon_sym_COLON_EQ] = ACTIONS(607),
    [anon_sym_DASH_GT] = ACTIONS(609),
    [anon_sym_DASH_GT_GT] = ACTIONS(607),
    [anon_sym_PIPE] = ACTIONS(609),
    [anon_sym_AMP] = ACTIONS(609),
    [anon_sym_PIPE_PIPE] = ACTIONS(607),
    [anon_sym_AMP_AMP] = ACTIONS(607),
    [anon_sym_LT] = ACTIONS(609),
    [anon_sym_LT_EQ] = ACTIONS(607),
    [anon_sym_GT] = ACTIONS(609),
    [anon_sym_GT_EQ] = ACTIONS(607),
    [anon_sym_EQ_EQ] = ACTIONS(607),
    [anon_sym_BANG_EQ] = ACTIONS(607),
    [anon_sym_STAR] = ACTIONS(609),
    [anon_sym_SLASH] = ACTIONS(607),
    [anon_sym_STAR_STAR] = ACTIONS(607),
    [anon_sym_CARET] = ACTIONS(607),
    [aux_sym_binary_operator_token1] = ACTIONS(607),
    [anon_sym_PIPE_GT] = ACTIONS(607),
    [anon_sym_COLON] = ACTIONS(609),
    [anon_sym_DOLLAR] = ACTIONS(607),
    [anon_sym_AT] = ACTIONS(607),
    [anon_sym_COLON_COLON] = ACTIONS(609),
    [anon_sym_COLON_COLON_COLON] = ACTIONS(607),
    [sym__hex_literal] = ACTIONS(607),
    [sym__number_literal] = ACTIONS(609),
    [anon_sym_SQUOTE] = ACTIONS(607),
    [anon_sym_DQUOTE] = ACTIONS(607),
    [sym_dots] = ACTIONS(609),
    [sym_dot_dot_i] = ACTIONS(609),
    [sym_next] = ACTIONS(609),
    [sym_break] = ACTIONS(609),
    [sym_true] = ACTIONS(609),
    [sym_false] = ACTIONS(609),
    [sym_null] = ACTIONS(609),
    [sym_inf] = ACTIONS(609),
    [sym_nan] = ACTIONS(609),
    [anon_sym_NA] = ACTIONS(609),
    [anon_sym_NA_integer_] = ACTIONS(609),
    [anon_sym_NA_real_] = ACTIONS(609),
    [anon_sym_NA_complex_] = ACTIONS(609),
    [anon_sym_NA_character_] = ACTIONS(609),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(607),
    [sym__semicolon] = ACTIONS(607),
    [sym__raw_string_open] = ACTIONS(607),
    [sym__external_open_parenthesis] = ACTIONS(607),
    [sym__external_open_brace] = ACTIONS(607),
    [sym__external_open_bracket] = ACTIONS(607),
    [sym__external_open_bracket2] = ACTIONS(607),
  },
  [326] = {
    [ts_builtin_sym_end] = ACTIONS(635),
    [sym_identifier] = ACTIONS(637),
    [anon_sym_BSLASH] = ACTIONS(635),
    [anon_sym_function] = ACTIONS(637),
    [anon_sym_EQ] = ACTIONS(637),
    [anon_sym_if] = ACTIONS(637),
    [anon_sym_for] = ACTIONS(637),
    [anon_sym_while] = ACTIONS(637),
    [anon_sym_repeat] = ACTIONS(637),
    [anon_sym_QMARK] = ACTIONS(635),
    [anon_sym_TILDE] = ACTIONS(635),
    [anon_sym_BANG] = ACTIONS(637),
    [anon_sym_PLUS] = ACTIONS(635),
    [anon_sym_DASH] = ACTIONS(637),
    [anon_sym_LT_DASH] = ACTIONS(635),
    [anon_sym_LT_LT_DASH] = ACTIONS(635),
    [anon_sym_COLON_EQ] = ACTIONS(635),
    [anon_sym_DASH_GT] = ACTIONS(637),
    [anon_sym_DASH_GT_GT] = ACTIONS(635),
    [anon_sym_PIPE] = ACTIONS(637),
    [anon_sym_AMP] = ACTIONS(637),
    [anon_sym_PIPE_PIPE] = ACTIONS(635),
    [anon_sym_AMP_AMP] = ACTIONS(635),
    [anon_sym_LT] = ACTIONS(637),
    [anon_sym_LT_EQ] = ACTIONS(635),
    [anon_sym_GT] = ACTIONS(637),
    [anon_sym_GT_EQ] = ACTIONS(635),
    [anon_sym_EQ_EQ] = ACTIONS(635),
    [anon_sym_BANG_EQ] = ACTIONS(635),
    [anon_sym_STAR] = ACTIONS(637),
    [anon_sym_SLASH] = ACTIONS(635),
    [anon_sym_STAR_STAR] = ACTIONS(635),
    [anon_sym_CARET] = ACTIONS(635),
    [aux_sym_binary_operator_token1] = ACTIONS(635),
    [anon_sym_PIPE_GT] = ACTIONS(635),
    [anon_sym_COLON] = ACTIONS(637),
    [anon_sym_DOLLAR] = ACTIONS(635),
    [anon_sym_AT] = ACTIONS(635),
    [anon_sym_COLON_COLON] = ACTIONS(637),
    [anon_sym_COLON_COLON_COLON] = ACTIONS(635),
    [sym__hex_literal] = ACTIONS(635),
    [sym__number_literal] = ACTIONS(637),
    [anon_sym_SQUOTE] = ACTIONS(635),
    [anon_sym_DQUOTE] = ACTIONS(635),
    [sym_dots] = ACTIONS(637),
    [sym_dot_dot_i] = ACTIONS(637),
    [sym_next] = ACTIONS(637),
    [sym_break] = ACTIONS(637),
    [sym_true] = ACTIONS(637),
    [sym_false] = ACTIONS(637),
    [sym_null] = ACTIONS(637),
    [sym_inf] = ACTIONS(637),
    [sym_nan] = ACTIONS(637),
    [anon_sym_NA] = ACTIONS(637),
    [anon_sym_NA_integer_] = ACTIONS(637),
    [anon_sym_NA_real_] = ACTIONS(637),
    [anon_sym_NA_complex_] = ACTIONS(637),
    [anon_sym_NA_character_] = ACTIONS(637),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(635),
    [sym__semicolon] = ACTIONS(635),
    [sym__raw_string_open] = ACTIONS(635),
    [sym__external_open_parenthesis] = ACTIONS(635),
    [sym__external_open_brace] = ACTIONS(635),
    [sym__external_open_bracket] = ACTIONS(635),
    [sym__external_open_bracket2] = ACTIONS(635),
  },
  [327] = {
    [ts_builtin_sym_end] = ACTIONS(641),
    [sym_identifier] = ACTIONS(643),
    [anon_sym_BSLASH] = ACTIONS(641),
    [anon_sym_function] = ACTIONS(643),
    [anon_sym_EQ] = ACTIONS(643),
    [anon_sym_if] = ACTIONS(643),
    [anon_sym_for] = ACTIONS(643),
    [anon_sym_while] = ACTIONS(643),
    [anon_sym_repeat] = ACTIONS(643),
    [anon_sym_QMARK] = ACTIONS(641),
    [anon_sym_TILDE] = ACTIONS(641),
    [anon_sym_BANG] = ACTIONS(643),
    [anon_sym_PLUS] = ACTIONS(641),
    [anon_sym_DASH] = ACTIONS(643),
    [anon_sym_LT_DASH] = ACTIONS(641),
    [anon_sym_LT_LT_DASH] = ACTIONS(641),
    [anon_sym_COLON_EQ] = ACTIONS(641),
    [anon_sym_DASH_GT] = ACTIONS(643),
    [anon_sym_DASH_GT_GT] = ACTIONS(641),
    [anon_sym_PIPE] = ACTIONS(643),
    [anon_sym_AMP] = ACTIONS(643),
    [anon_sym_PIPE_PIPE] = ACTIONS(641),
    [anon_sym_AMP_AMP] = ACTIONS(641),
    [anon_sym_LT] = ACTIONS(643),
    [anon_sym_LT_EQ] = ACTIONS(641),
    [anon_sym_GT] = ACTIONS(643),
    [anon_sym_GT_EQ] = ACTIONS(641),
    [anon_sym_EQ_EQ] = ACTIONS(641),
    [anon_sym_BANG_EQ] = ACTIONS(641),
    [anon_sym_STAR] = ACTIONS(643),
    [anon_sym_SLASH] = ACTIONS(641),
    [anon_sym_STAR_STAR] = ACTIONS(641),
    [anon_sym_CARET] = ACTIONS(641),
    [aux_sym_binary_operator_token1] = ACTIONS(641),
    [anon_sym_PIPE_GT] = ACTIONS(641),
    [anon_sym_COLON] = ACTIONS(643),
    [anon_sym_DOLLAR] = ACTIONS(641),
    [anon_sym_AT] = ACTIONS(641),
    [anon_sym_COLON_COLON] = ACTIONS(643),
    [anon_sym_COLON_COLON_COLON] = ACTIONS(641),
    [sym__hex_literal] = ACTIONS(641),
    [sym__number_literal] = ACTIONS(643),
    [anon_sym_SQUOTE] = ACTIONS(641),
    [anon_sym_DQUOTE] = ACTIONS(641),
    [sym_dots] = ACTIONS(643),
    [sym_dot_dot_i] = ACTIONS(643),
    [sym_next] = ACTIONS(643),
    [sym_break] = ACTIONS(643),
    [sym_true] = ACTIONS(643),
    [sym_false] = ACTIONS(643),
    [sym_null] = ACTIONS(643),
    [sym_inf] = ACTIONS(643),
    [sym_nan] = ACTIONS(643),
    [anon_sym_NA] = ACTIONS(643),
    [anon_sym_NA_integer_] = ACTIONS(643),
    [anon_sym_NA_real_] = ACTIONS(643),
    [anon_sym_NA_complex_] = ACTIONS(643),
    [anon_sym_NA_character_] = ACTIONS(643),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(641),
    [sym__semicolon] = ACTIONS(641),
    [sym__raw_string_open] = ACTIONS(641),
    [sym__external_open_parenthesis] = ACTIONS(641),
    [sym__external_open_brace] = ACTIONS(641),
    [sym__external_open_bracket] = ACTIONS(641),
    [sym__external_open_bracket2] = ACTIONS(641),
  },
  [328] = {
    [ts_builtin_sym_end] = ACTIONS(645),
    [sym_identifier] = ACTIONS(647),
    [anon_sym_BSLASH] = ACTIONS(645),
    [anon_sym_function] = ACTIONS(647),
    [anon_sym_EQ] = ACTIONS(647),
    [anon_sym_if] = ACTIONS(647),
    [anon_sym_for] = ACTIONS(647),
    [anon_sym_while] = ACTIONS(647),
    [anon_sym_repeat] = ACTIONS(647),
    [anon_sym_QMARK] = ACTIONS(645),
    [anon_sym_TILDE] = ACTIONS(645),
    [anon_sym_BANG] = ACTIONS(647),
    [anon_sym_PLUS] = ACTIONS(645),
    [anon_sym_DASH] = ACTIONS(647),
    [anon_sym_LT_DASH] = ACTIONS(645),
    [anon_sym_LT_LT_DASH] = ACTIONS(645),
    [anon_sym_COLON_EQ] = ACTIONS(645),
    [anon_sym_DASH_GT] = ACTIONS(647),
    [anon_sym_DASH_GT_GT] = ACTIONS(645),
    [anon_sym_PIPE] = ACTIONS(647),
    [anon_sym_AMP] = ACTIONS(647),
    [anon_sym_PIPE_PIPE] = ACTIONS(645),
    [anon_sym_AMP_AMP] = ACTIONS(645),
    [anon_sym_LT] = ACTIONS(647),
    [anon_sym_LT_EQ] = ACTIONS(645),
    [anon_sym_GT] = ACTIONS(647),
    [anon_sym_GT_EQ] = ACTIONS(645),
    [anon_sym_EQ_EQ] = ACTIONS(645),
    [anon_sym_BANG_EQ] = ACTIONS(645),
    [anon_sym_STAR] = ACTIONS(647),
    [anon_sym_SLASH] = ACTIONS(645),
    [anon_sym_STAR_STAR] = ACTIONS(645),
    [anon_sym_CARET] = ACTIONS(645),
    [aux_sym_binary_operator_token1] = ACTIONS(645),
    [anon_sym_PIPE_GT] = ACTIONS(645),
    [anon_sym_COLON] = ACTIONS(647),
    [anon_sym_DOLLAR] = ACTIONS(645),
    [anon_sym_AT] = ACTIONS(645),
    [anon_sym_COLON_COLON] = ACTIONS(647),
    [anon_sym_COLON_COLON_COLON] = ACTIONS(645),
    [sym__hex_literal] = ACTIONS(645),
    [sym__number_literal] = ACTIONS(647),
    [anon_sym_SQUOTE] = ACTIONS(645),
    [anon_sym_DQUOTE] = ACTIONS(645),
    [sym_dots] = ACTIONS(647),
    [sym_dot_dot_i] = ACTIONS(647),
    [sym_next] = ACTIONS(647),
    [sym_break] = ACTIONS(647),
    [sym_true] = ACTIONS(647),
    [sym_false] = ACTIONS(647),
    [sym_null] = ACTIONS(647),
    [sym_inf] = ACTIONS(647),
    [sym_nan] = ACTIONS(647),
    [anon_sym_NA] = ACTIONS(647),
    [anon_sym_NA_integer_] = ACTIONS(647),
    [anon_sym_NA_real_] = ACTIONS(647),
    [anon_sym_NA_complex_] = ACTIONS(647),
    [anon_sym_NA_character_] = ACTIONS(647),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(645),
    [sym__semicolon] = ACTIONS(645),
    [sym__raw_string_open] = ACTIONS(645),
    [sym__external_open_parenthesis] = ACTIONS(645),
    [sym__external_open_brace] = ACTIONS(645),
    [sym__external_open_bracket] = ACTIONS(645),
    [sym__external_open_bracket2] = ACTIONS(645),
  },
  [329] = {
    [ts_builtin_sym_end] = ACTIONS(649),
    [sym_identifier] = ACTIONS(651),
    [anon_sym_BSLASH] = ACTIONS(649),
    [anon_sym_function] = ACTIONS(651),
    [anon_sym_EQ] = ACTIONS(651),
    [anon_sym_if] = ACTIONS(651),
    [anon_sym_for] = ACTIONS(651),
    [anon_sym_while] = ACTIONS(651),
    [anon_sym_repeat] = ACTIONS(651),
    [anon_sym_QMARK] = ACTIONS(649),
    [anon_sym_TILDE] = ACTIONS(649),
    [anon_sym_BANG] = ACTIONS(651),
    [anon_sym_PLUS] = ACTIONS(649),
    [anon_sym_DASH] = ACTIONS(651),
    [anon_sym_LT_DASH] = ACTIONS(649),
    [anon_sym_LT_LT_DASH] = ACTIONS(649),
    [anon_sym_COLON_EQ] = ACTIONS(649),
    [anon_sym_DASH_GT] = ACTIONS(651),
    [anon_sym_DASH_GT_GT] = ACTIONS(649),
    [anon_sym_PIPE] = ACTIONS(651),
    [anon_sym_AMP] = ACTIONS(651),
    [anon_sym_PIPE_PIPE] = ACTIONS(649),
    [anon_sym_AMP_AMP] = ACTIONS(649),
    [anon_sym_LT] = ACTIONS(651),
    [anon_sym_LT_EQ] = ACTIONS(649),
    [anon_sym_GT] = ACTIONS(651),
    [anon_sym_GT_EQ] = ACTIONS(649),
    [anon_sym_EQ_EQ] = ACTIONS(649),
    [anon_sym_BANG_EQ] = ACTIONS(649),
    [anon_sym_STAR] = ACTIONS(651),
    [anon_sym_SLASH] = ACTIONS(649),
    [anon_sym_STAR_STAR] = ACTIONS(649),
    [anon_sym_CARET] = ACTIONS(649),
    [aux_sym_binary_operator_token1] = ACTIONS(649),
    [anon_sym_PIPE_GT] = ACTIONS(649),
    [anon_sym_COLON] = ACTIONS(651),
    [anon_sym_DOLLAR] = ACTIONS(649),
    [anon_sym_AT] = ACTIONS(649),
    [anon_sym_COLON_COLON] = ACTIONS(651),
    [anon_sym_COLON_COLON_COLON] = ACTIONS(649),
    [sym__hex_literal] = ACTIONS(649),
    [sym__number_literal] = ACTIONS(651),
    [anon_sym_SQUOTE] = ACTIONS(649),
    [anon_sym_DQUOTE] = ACTIONS(649),
    [sym_dots] = ACTIONS(651),
    [sym_dot_dot_i] = ACTIONS(651),
    [sym_next] = ACTIONS(651),
    [sym_break] = ACTIONS(651),
    [sym_true] = ACTIONS(651),
    [sym_false] = ACTIONS(651),
    [sym_null] = ACTIONS(651),
    [sym_inf] = ACTIONS(651),
    [sym_nan] = ACTIONS(651),
    [anon_sym_NA] = ACTIONS(651),
    [anon_sym_NA_integer_] = ACTIONS(651),
    [anon_sym_NA_real_] = ACTIONS(651),
    [anon_sym_NA_complex_] = ACTIONS(651),
    [anon_sym_NA_character_] = ACTIONS(651),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(649),
    [sym__semicolon] = ACTIONS(649),
    [sym__raw_string_open] = ACTIONS(649),
    [sym__external_open_parenthesis] = ACTIONS(649),
    [sym__external_open_brace] = ACTIONS(649),
    [sym__external_open_bracket] = ACTIONS(649),
    [sym__external_open_bracket2] = ACTIONS(649),
  },
  [330] = {
    [sym_identifier] = ACTIONS(625),
    [anon_sym_BSLASH] = ACTIONS(623),
    [anon_sym_function] = ACTIONS(625),
    [anon_sym_EQ] = ACTIONS(625),
    [anon_sym_if] = ACTIONS(625),
    [anon_sym_for] = ACTIONS(625),
    [anon_sym_while] = ACTIONS(625),
    [anon_sym_repeat] = ACTIONS(625),
    [anon_sym_QMARK] = ACTIONS(623),
    [anon_sym_TILDE] = ACTIONS(623),
    [anon_sym_BANG] = ACTIONS(625),
    [anon_sym_PLUS] = ACTIONS(623),
    [anon_sym_DASH] = ACTIONS(625),
    [anon_sym_LT_DASH] = ACTIONS(623),
    [anon_sym_LT_LT_DASH] = ACTIONS(623),
    [anon_sym_COLON_EQ] = ACTIONS(623),
    [anon_sym_DASH_GT] = ACTIONS(625),
    [anon_sym_DASH_GT_GT] = ACTIONS(623),
    [anon_sym_PIPE] = ACTIONS(625),
    [anon_sym_AMP] = ACTIONS(625),
    [anon_sym_PIPE_PIPE] = ACTIONS(623),
    [anon_sym_AMP_AMP] = ACTIONS(623),
    [anon_sym_LT] = ACTIONS(625),
    [anon_sym_LT_EQ] = ACTIONS(623),
    [anon_sym_GT] = ACTIONS(625),
    [anon_sym_GT_EQ] = ACTIONS(623),
    [anon_sym_EQ_EQ] = ACTIONS(623),
    [anon_sym_BANG_EQ] = ACTIONS(623),
    [anon_sym_STAR] = ACTIONS(625),
    [anon_sym_SLASH] = ACTIONS(623),
    [anon_sym_STAR_STAR] = ACTIONS(623),
    [anon_sym_CARET] = ACTIONS(623),
    [aux_sym_binary_operator_token1] = ACTIONS(623),
    [anon_sym_PIPE_GT] = ACTIONS(623),
    [anon_sym_COLON] = ACTIONS(625),
    [anon_sym_DOLLAR] = ACTIONS(623),
    [anon_sym_AT] = ACTIONS(623),
    [anon_sym_L] = ACTIONS(683),
    [anon_sym_i] = ACTIONS(685),
    [sym__hex_literal] = ACTIONS(623),
    [sym__number_literal] = ACTIONS(625),
    [anon_sym_SQUOTE] = ACTIONS(623),
    [anon_sym_DQUOTE] = ACTIONS(623),
    [sym_dots] = ACTIONS(625),
    [sym_dot_dot_i] = ACTIONS(625),
    [sym_next] = ACTIONS(625),
    [sym_break] = ACTIONS(625),
    [sym_true] = ACTIONS(625),
    [sym_false] = ACTIONS(625),
    [sym_null] = ACTIONS(625),
    [sym_inf] = ACTIONS(625),
    [sym_nan] = ACTIONS(625),
    [anon_sym_NA] = ACTIONS(625),
    [anon_sym_NA_integer_] = ACTIONS(625),
    [anon_sym_NA_real_] = ACTIONS(625),
    [anon_sym_NA_complex_] = ACTIONS(625),
    [anon_sym_NA_character_] = ACTIONS(625),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(623),
    [sym__semicolon] = ACTIONS(623),
    [sym__raw_string_open] = ACTIONS(623),
    [sym__external_open_parenthesis] = ACTIONS(623),
    [sym__external_open_brace] = ACTIONS(623),
    [sym__external_close_brace] = ACTIONS(623),
    [sym__external_open_bracket] = ACTIONS(623),
    [sym__external_open_bracket2] = ACTIONS(623),
  },
  [331] = {
    [sym_identifier] = ACTIONS(609),
    [anon_sym_BSLASH] = ACTIONS(607),
    [anon_sym_function] = ACTIONS(609),
    [anon_sym_EQ] = ACTIONS(609),
    [anon_sym_if] = ACTIONS(609),
    [anon_sym_for] = ACTIONS(609),
    [anon_sym_while] = ACTIONS(609),
    [anon_sym_repeat] = ACTIONS(609),
    [anon_sym_QMARK] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(607),
    [anon_sym_BANG] = ACTIONS(609),
    [anon_sym_PLUS] = ACTIONS(607),
    [anon_sym_DASH] = ACTIONS(609),
    [anon_sym_LT_DASH] = ACTIONS(607),
    [anon_sym_LT_LT_DASH] = ACTIONS(607),
    [anon_sym_COLON_EQ] = ACTIONS(607),
    [anon_sym_DASH_GT] = ACTIONS(609),
    [anon_sym_DASH_GT_GT] = ACTIONS(607),
    [anon_sym_PIPE] = ACTIONS(609),
    [anon_sym_AMP] = ACTIONS(609),
    [anon_sym_PIPE_PIPE] = ACTIONS(607),
    [anon_sym_AMP_AMP] = ACTIONS(607),
    [anon_sym_LT] = ACTIONS(609),
    [anon_sym_LT_EQ] = ACTIONS(607),
    [anon_sym_GT] = ACTIONS(609),
    [anon_sym_GT_EQ] = ACTIONS(607),
    [anon_sym_EQ_EQ] = ACTIONS(607),
    [anon_sym_BANG_EQ] = ACTIONS(607),
    [anon_sym_STAR] = ACTIONS(609),
    [anon_sym_SLASH] = ACTIONS(607),
    [anon_sym_STAR_STAR] = ACTIONS(607),
    [anon_sym_CARET] = ACTIONS(607),
    [aux_sym_binary_operator_token1] = ACTIONS(607),
    [anon_sym_PIPE_GT] = ACTIONS(607),
    [anon_sym_COLON] = ACTIONS(609),
    [anon_sym_DOLLAR] = ACTIONS(607),
    [anon_sym_AT] = ACTIONS(607),
    [anon_sym_COLON_COLON] = ACTIONS(609),
    [anon_sym_COLON_COLON_COLON] = ACTIONS(607),
    [sym__hex_literal] = ACTIONS(607),
    [sym__number_literal] = ACTIONS(609),
    [anon_sym_SQUOTE] = ACTIONS(607),
    [anon_sym_DQUOTE] = ACTIONS(607),
    [sym_dots] = ACTIONS(609),
    [sym_dot_dot_i] = ACTIONS(609),
    [sym_next] = ACTIONS(609),
    [sym_break] = ACTIONS(609),
    [sym_true] = ACTIONS(609),
    [sym_false] = ACTIONS(609),
    [sym_null] = ACTIONS(609),
    [sym_inf] = ACTIONS(609),
    [sym_nan] = ACTIONS(609),
    [anon_sym_NA] = ACTIONS(609),
    [anon_sym_NA_integer_] = ACTIONS(609),
    [anon_sym_NA_real_] = ACTIONS(609),
    [anon_sym_NA_complex_] = ACTIONS(609),
    [anon_sym_NA_character_] = ACTIONS(609),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(607),
    [sym__semicolon] = ACTIONS(607),
    [sym__raw_string_open] = ACTIONS(607),
    [sym__external_open_parenthesis] = ACTIONS(607),
    [sym__external_open_brace] = ACTIONS(607),
    [sym__external_close_brace] = ACTIONS(607),
    [sym__external_open_bracket] = ACTIONS(607),
    [sym__external_open_bracket2] = ACTIONS(607),
  },
  [332] = {
    [sym_identifier] = ACTIONS(609),
    [anon_sym_BSLASH] = ACTIONS(607),
    [anon_sym_function] = ACTIONS(609),
    [anon_sym_EQ] = ACTIONS(609),
    [anon_sym_if] = ACTIONS(609),
    [anon_sym_for] = ACTIONS(609),
    [anon_sym_while] = ACTIONS(609),
    [anon_sym_repeat] = ACTIONS(609),
    [anon_sym_QMARK] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(607),
    [anon_sym_BANG] = ACTIONS(609),
    [anon_sym_PLUS] = ACTIONS(607),
    [anon_sym_DASH] = ACTIONS(609),
    [anon_sym_LT_DASH] = ACTIONS(607),
    [anon_sym_LT_LT_DASH] = ACTIONS(607),
    [anon_sym_COLON_EQ] = ACTIONS(607),
    [anon_sym_DASH_GT] = ACTIONS(609),
    [anon_sym_DASH_GT_GT] = ACTIONS(607),
    [anon_sym_PIPE] = ACTIONS(609),
    [anon_sym_AMP] = ACTIONS(609),
    [anon_sym_PIPE_PIPE] = ACTIONS(607),
    [anon_sym_AMP_AMP] = ACTIONS(607),
    [anon_sym_LT] = ACTIONS(609),
    [anon_sym_LT_EQ] = ACTIONS(607),
    [anon_sym_GT] = ACTIONS(609),
    [anon_sym_GT_EQ] = ACTIONS(607),
    [anon_sym_EQ_EQ] = ACTIONS(607),
    [anon_sym_BANG_EQ] = ACTIONS(607),
    [anon_sym_STAR] = ACTIONS(609),
    [anon_sym_SLASH] = ACTIONS(607),
    [anon_sym_STAR_STAR] = ACTIONS(607),
    [anon_sym_CARET] = ACTIONS(607),
    [aux_sym_binary_operator_token1] = ACTIONS(607),
    [anon_sym_PIPE_GT] = ACTIONS(607),
    [anon_sym_COLON] = ACTIONS(609),
    [anon_sym_DOLLAR] = ACTIONS(607),
    [anon_sym_AT] = ACTIONS(607),
    [anon_sym_COLON_COLON] = ACTIONS(609),
    [anon_sym_COLON_COLON_COLON] = ACTIONS(607),
    [sym__hex_literal] = ACTIONS(607),
    [sym__number_literal] = ACTIONS(609),
    [anon_sym_SQUOTE] = ACTIONS(607),
    [anon_sym_DQUOTE] = ACTIONS(607),
    [sym_dots] = ACTIONS(609),
    [sym_dot_dot_i] = ACTIONS(609),
    [sym_next] = ACTIONS(609),
    [sym_break] = ACTIONS(609),
    [sym_true] = ACTIONS(609),
    [sym_false] = ACTIONS(609),
    [sym_null] = ACTIONS(609),
    [sym_inf] = ACTIONS(609),
    [sym_nan] = ACTIONS(609),
    [anon_sym_NA] = ACTIONS(609),
    [anon_sym_NA_integer_] = ACTIONS(609),
    [anon_sym_NA_real_] = ACTIONS(609),
    [anon_sym_NA_complex_] = ACTIONS(609),
    [anon_sym_NA_character_] = ACTIONS(609),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(607),
    [sym__semicolon] = ACTIONS(607),
    [sym__raw_string_open] = ACTIONS(607),
    [sym__external_open_parenthesis] = ACTIONS(607),
    [sym__external_open_brace] = ACTIONS(607),
    [sym__external_close_brace] = ACTIONS(607),
    [sym__external_open_bracket] = ACTIONS(607),
    [sym__external_open_bracket2] = ACTIONS(607),
  },
  [333] = {
    [sym_identifier] = ACTIONS(609),
    [anon_sym_BSLASH] = ACTIONS(607),
    [anon_sym_function] = ACTIONS(609),
    [anon_sym_EQ] = ACTIONS(609),
    [anon_sym_if] = ACTIONS(609),
    [anon_sym_for] = ACTIONS(609),
    [anon_sym_while] = ACTIONS(609),
    [anon_sym_repeat] = ACTIONS(609),
    [anon_sym_QMARK] = ACTIONS(607),
    [anon_sym_TILDE] = ACTIONS(607),
    [anon_sym_BANG] = ACTIONS(609),
    [anon_sym_PLUS] = ACTIONS(607),
    [anon_sym_DASH] = ACTIONS(609),
    [anon_sym_LT_DASH] = ACTIONS(607),
    [anon_sym_LT_LT_DASH] = ACTIONS(607),
    [anon_sym_COLON_EQ] = ACTIONS(607),
    [anon_sym_DASH_GT] = ACTIONS(609),
    [anon_sym_DASH_GT_GT] = ACTIONS(607),
    [anon_sym_PIPE] = ACTIONS(609),
    [anon_sym_AMP] = ACTIONS(609),
    [anon_sym_PIPE_PIPE] = ACTIONS(607),
    [anon_sym_AMP_AMP] = ACTIONS(607),
    [anon_sym_LT] = ACTIONS(609),
    [anon_sym_LT_EQ] = ACTIONS(607),
    [anon_sym_GT] = ACTIONS(609),
    [anon_sym_GT_EQ] = ACTIONS(607),
    [anon_sym_EQ_EQ] = ACTIONS(607),
    [anon_sym_BANG_EQ] = ACTIONS(607),
    [anon_sym_STAR] = ACTIONS(609),
    [anon_sym_SLASH] = ACTIONS(607),
    [anon_sym_STAR_STAR] = ACTIONS(607),
    [anon_sym_CARET] = ACTIONS(607),
    [aux_sym_binary_operator_token1] = ACTIONS(607),
    [anon_sym_PIPE_GT] = ACTIONS(607),
    [anon_sym_COLON] = ACTIONS(609),
    [anon_sym_DOLLAR] = ACTIONS(607),
    [anon_sym_AT] = ACTIONS(607),
    [anon_sym_COLON_COLON] = ACTIONS(609),
    [anon_sym_COLON_COLON_COLON] = ACTIONS(607),
    [sym__hex_literal] = ACTIONS(607),
    [sym__number_literal] = ACTIONS(609),
    [anon_sym_SQUOTE] = ACTIONS(607),
    [anon_sym_DQUOTE] = ACTIONS(607),
    [sym_dots] = ACTIONS(609),
    [sym_dot_dot_i] = ACTIONS(609),
    [sym_next] = ACTIONS(609),
    [sym_break] = ACTIONS(609),
    [sym_true] = ACTIONS(609),
    [sym_false] = ACTIONS(609),
    [sym_null] = ACTIONS(609),
    [sym_inf] = ACTIONS(609),
    [sym_nan] = ACTIONS(609),
    [anon_sym_NA] = ACTIONS(609),
    [anon_sym_NA_integer_] = ACTIONS(609),
    [anon_sym_NA_real_] = ACTIONS(609),
    [anon_sym_NA_complex_] = ACTIONS(609),
    [anon_sym_NA_character_] = ACTIONS(609),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(607),
    [sym__semicolon] = ACTIONS(607),
    [sym__raw_string_open] = ACTIONS(607),
    [sym__external_open_parenthesis] = ACTIONS(607),
    [sym__external_open_brace] = ACTIONS(607),
    [sym__external_close_brace] = ACTIONS(607),
    [sym__external_open_bracket] = ACTIONS(607),
    [sym__external_open_bracket2] = ACTIONS(607),
  },
  [334] = {
    [sym_identifier] = ACTIONS(637),
    [anon_sym_BSLASH] = ACTIONS(635),
    [anon_sym_function] = ACTIONS(637),
    [anon_sym_EQ] = ACTIONS(637),
    [anon_sym_if] = ACTIONS(637),
    [anon_sym_for] = ACTIONS(637),
    [anon_sym_while] = ACTIONS(637),
    [anon_sym_repeat] = ACTIONS(637),
    [anon_sym_QMARK] = ACTIONS(635),
    [anon_sym_TILDE] = ACTIONS(635),
    [anon_sym_BANG] = ACTIONS(637),
    [anon_sym_PLUS] = ACTIONS(635),
    [anon_sym_DASH] = ACTIONS(637),
    [anon_sym_LT_DASH] = ACTIONS(635),
    [anon_sym_LT_LT_DASH] = ACTIONS(635),
    [anon_sym_COLON_EQ] = ACTIONS(635),
    [anon_sym_DASH_GT] = ACTIONS(637),
    [anon_sym_DASH_GT_GT] = ACTIONS(635),
    [anon_sym_PIPE] = ACTIONS(637),
    [anon_sym_AMP] = ACTIONS(637),
    [anon_sym_PIPE_PIPE] = ACTIONS(635),
    [anon_sym_AMP_AMP] = ACTIONS(635),
    [anon_sym_LT] = ACTIONS(637),
    [anon_sym_LT_EQ] = ACTIONS(635),
    [anon_sym_GT] = ACTIONS(637),
    [anon_sym_GT_EQ] = ACTIONS(635),
    [anon_sym_EQ_EQ] = ACTIONS(635),
    [anon_sym_BANG_EQ] = ACTIONS(635),
    [anon_sym_STAR] = ACTIONS(637),
    [anon_sym_SLASH] = ACTIONS(635),
    [anon_sym_STAR_STAR] = ACTIONS(635),
    [anon_sym_CARET] = ACTIONS(635),
    [aux_sym_binary_operator_token1] = ACTIONS(635),
    [anon_sym_PIPE_GT] = ACTIONS(635),
    [anon_sym_COLON] = ACTIONS(637),
    [anon_sym_DOLLAR] = ACTIONS(635),
    [anon_sym_AT] = ACTIONS(635),
    [anon_sym_COLON_COLON] = ACTIONS(637),
    [anon_sym_COLON_COLON_COLON] = ACTIONS(635),
    [sym__hex_literal] = ACTIONS(635),
    [sym__number_literal] = ACTIONS(637),
    [anon_sym_SQUOTE] = ACTIONS(635),
    [anon_sym_DQUOTE] = ACTIONS(635),
    [sym_dots] = ACTIONS(637),
    [sym_dot_dot_i] = ACTIONS(637),
    [sym_next] = ACTIONS(637),
    [sym_break] = ACTIONS(637),
    [sym_true] = ACTIONS(637),
    [sym_false] = ACTIONS(637),
    [sym_null] = ACTIONS(637),
    [sym_inf] = ACTIONS(637),
    [sym_nan] = ACTIONS(637),
    [anon_sym_NA] = ACTIONS(637),
    [anon_sym_NA_integer_] = ACTIONS(637),
    [anon_sym_NA_real_] = ACTIONS(637),
    [anon_sym_NA_complex_] = ACTIONS(637),
    [anon_sym_NA_character_] = ACTIONS(637),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(635),
    [sym__semicolon] = ACTIONS(635),
    [sym__raw_string_open] = ACTIONS(635),
    [sym__external_open_parenthesis] = ACTIONS(635),
    [sym__external_open_brace] = ACTIONS(635),
    [sym__external_close_brace] = ACTIONS(635),
    [sym__external_open_bracket] = ACTIONS(635),
    [sym__external_open_bracket2] = ACTIONS(635),
  },
  [335] = {
    [sym_function_definition] = STATE(189),
    [sym_if_statement] = STATE(189),
    [sym_for_statement] = STATE(189),
    [sym_while_statement] = STATE(189),
    [sym_repeat_statement] = STATE(189),
    [sym_braced_expression] = STATE(189),
    [sym_parenthesized_expression] = STATE(189),
    [sym_call] = STATE(189),
    [sym_subset] = STATE(189),
    [sym_subset2] = STATE(189),
    [sym_unary_operator] = STATE(189),
    [sym_binary_operator] = STATE(189),
    [sym_extract_operator] = STATE(189),
    [sym_namespace_operator] = STATE(189),
    [sym_integer] = STATE(189),
    [sym_complex] = STATE(189),
    [sym_float] = STATE(189),
    [sym__float_literal] = STATE(330),
    [sym_string] = STATE(311),
    [sym__raw_string] = STATE(331),
    [sym__single_quoted_string] = STATE(332),
    [sym__double_quoted_string] = STATE(333),
    [sym_na] = STATE(189),
    [sym__expression] = STATE(189),
    [sym__open_parenthesis] = STATE(1070),
    [sym__open_brace] = STATE(384),
    [sym__close_brace] = STATE(423),
    [aux_sym_braced_expression_repeat1] = STATE(383),
    [sym_identifier] = ACTIONS(687),
    [anon_sym_BSLASH] = ACTIONS(689),
    [anon_sym_function] = ACTIONS(691),
    [anon_sym_if] = ACTIONS(693),
    [anon_sym_for] = ACTIONS(695),
    [anon_sym_while] = ACTIONS(697),
    [anon_sym_repeat] = ACTIONS(699),
    [anon_sym_QMARK] = ACTIONS(701),
    [anon_sym_TILDE] = ACTIONS(703),
    [anon_sym_BANG] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [sym__hex_literal] = ACTIONS(709),
    [sym__number_literal] = ACTIONS(711),
    [anon_sym_SQUOTE] = ACTIONS(435),
    [anon_sym_DQUOTE] = ACTIONS(437),
    [sym_dots] = ACTIONS(687),
    [sym_dot_dot_i] = ACTIONS(687),
    [sym_next] = ACTIONS(713),
    [sym_break] = ACTIONS(713),
    [sym_true] = ACTIONS(713),
    [sym_false] = ACTIONS(713),
    [sym_null] = ACTIONS(713),
    [sym_inf] = ACTIONS(713),
    [sym_nan] = ACTIONS(713),
    [anon_sym_NA] = ACTIONS(715),
    [anon_sym_NA_integer_] = ACTIONS(715),
    [anon_sym_NA_real_] = ACTIONS(715),
    [anon_sym_NA_complex_] = ACTIONS(715),
    [anon_sym_NA_character_] = ACTIONS(715),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(717),
    [sym__semicolon] = ACTIONS(717),
    [sym__raw_string_open] = ACTIONS(439),
    [sym__external_open_parenthesis] = ACTIONS(719),
    [sym__external_open_brace] = ACTIONS(721),
    [sym__external_close_brace] = ACTIONS(723),
  },
  [336] = {
    [sym_identifier] = ACTIONS(725),
    [anon_sym_BSLASH] = ACTIONS(727),
    [anon_sym_function] = ACTIONS(725),
    [anon_sym_EQ] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(725),
    [anon_sym_for] = ACTIONS(725),
    [anon_sym_while] = ACTIONS(725),
    [anon_sym_repeat] = ACTIONS(725),
    [anon_sym_QMARK] = ACTIONS(727),
    [anon_sym_TILDE] = ACTIONS(727),
    [anon_sym_BANG] = ACTIONS(725),
    [anon_sym_PLUS] = ACTIONS(727),
    [anon_sym_DASH] = ACTIONS(725),
    [anon_sym_LT_DASH] = ACTIONS(727),
    [anon_sym_LT_LT_DASH] = ACTIONS(727),
    [anon_sym_COLON_EQ] = ACTIONS(727),
    [anon_sym_DASH_GT] = ACTIONS(725),
    [anon_sym_DASH_GT_GT] = ACTIONS(727),
    [anon_sym_PIPE] = ACTIONS(725),
    [anon_sym_AMP] = ACTIONS(725),
    [anon_sym_PIPE_PIPE] = ACTIONS(727),
    [anon_sym_AMP_AMP] = ACTIONS(727),
    [anon_sym_LT] = ACTIONS(725),
    [anon_sym_LT_EQ] = ACTIONS(727),
    [anon_sym_GT] = ACTIONS(725),
    [anon_sym_GT_EQ] = ACTIONS(727),
    [anon_sym_EQ_EQ] = ACTIONS(727),
    [anon_sym_BANG_EQ] = ACTIONS(727),
    [anon_sym_STAR] = ACTIONS(725),
    [anon_sym_SLASH] = ACTIONS(727),
    [anon_sym_STAR_STAR] = ACTIONS(727),
    [anon_sym_CARET] = ACTIONS(727),
    [aux_sym_binary_operator_token1] = ACTIONS(727),
    [anon_sym_PIPE_GT] = ACTIONS(727),
    [anon_sym_COLON] = ACTIONS(725),
    [anon_sym_DOLLAR] = ACTIONS(727),
    [anon_sym_AT] = ACTIONS(727),
    [sym__hex_literal] = ACTIONS(727),
    [sym__number_literal] = ACTIONS(725),
    [anon_sym_SQUOTE] = ACTIONS(727),
    [anon_sym_DQUOTE] = ACTIONS(727),
    [sym_dots] = ACTIONS(725),
    [sym_dot_dot_i] = ACTIONS(725),
    [sym_next] = ACTIONS(725),
    [sym_break] = ACTIONS(725),
    [sym_true] = ACTIONS(725),
    [sym_false] = ACTIONS(725),
    [sym_null] = ACTIONS(725),
    [sym_inf] = ACTIONS(725),
    [sym_nan] = ACTIONS(725),
    [anon_sym_NA] = ACTIONS(725),
    [anon_sym_NA_integer_] = ACTIONS(725),
    [anon_sym_NA_real_] = ACTIONS(725),
    [anon_sym_NA_complex_] = ACTIONS(725),
    [anon_sym_NA_character_] = ACTIONS(725),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(727),
    [sym__semicolon] = ACTIONS(727),
    [sym__raw_string_open] = ACTIONS(727),
    [sym__external_else] = ACTIONS(727),
    [sym__external_open_parenthesis] = ACTIONS(727),
    [sym__external_open_brace] = ACTIONS(727),
    [sym__external_close_brace] = ACTIONS(727),
    [sym__external_open_bracket] = ACTIONS(727),
    [sym__external_open_bracket2] = ACTIONS(727),
  },
  [337] = {
    [sym_function_definition] = STATE(189),
    [sym_if_statement] = STATE(189),
    [sym_for_statement] = STATE(189),
    [sym_while_statement] = STATE(189),
    [sym_repeat_statement] = STATE(189),
    [sym_braced_expression] = STATE(189),
    [sym_parenthesized_expression] = STATE(189),
    [sym_call] = STATE(189),
    [sym_subset] = STATE(189),
    [sym_subset2] = STATE(189),
    [sym_unary_operator] = STATE(189),
    [sym_binary_operator] = STATE(189),
    [sym_extract_operator] = STATE(189),
    [sym_namespace_operator] = STATE(189),
    [sym_integer] = STATE(189),
    [sym_complex] = STATE(189),
    [sym_float] = STATE(189),
    [sym__float_literal] = STATE(330),
    [sym_string] = STATE(311),
    [sym__raw_string] = STATE(331),
    [sym__single_quoted_string] = STATE(332),
    [sym__double_quoted_string] = STATE(333),
    [sym_na] = STATE(189),
    [sym__expression] = STATE(189),
    [sym__open_parenthesis] = STATE(1070),
    [sym__open_brace] = STATE(384),
    [sym__close_brace] = STATE(347),
    [aux_sym_braced_expression_repeat1] = STATE(415),
    [sym_identifier] = ACTIONS(687),
    [anon_sym_BSLASH] = ACTIONS(689),
    [anon_sym_function] = ACTIONS(691),
    [anon_sym_if] = ACTIONS(693),
    [anon_sym_for] = ACTIONS(695),
    [anon_sym_while] = ACTIONS(697),
    [anon_sym_repeat] = ACTIONS(699),
    [anon_sym_QMARK] = ACTIONS(701),
    [anon_sym_TILDE] = ACTIONS(703),
    [anon_sym_BANG] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [sym__hex_literal] = ACTIONS(709),
    [sym__number_literal] = ACTIONS(711),
    [anon_sym_SQUOTE] = ACTIONS(435),
    [anon_sym_DQUOTE] = ACTIONS(437),
    [sym_dots] = ACTIONS(687),
    [sym_dot_dot_i] = ACTIONS(687),
    [sym_next] = ACTIONS(713),
    [sym_break] = ACTIONS(713),
    [sym_true] = ACTIONS(713),
    [sym_false] = ACTIONS(713),
    [sym_null] = ACTIONS(713),
    [sym_inf] = ACTIONS(713),
    [sym_nan] = ACTIONS(713),
    [anon_sym_NA] = ACTIONS(715),
    [anon_sym_NA_integer_] = ACTIONS(715),
    [anon_sym_NA_real_] = ACTIONS(715),
    [anon_sym_NA_complex_] = ACTIONS(715),
    [anon_sym_NA_character_] = ACTIONS(715),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(717),
    [sym__semicolon] = ACTIONS(717),
    [sym__raw_string_open] = ACTIONS(439),
    [sym__external_open_parenthesis] = ACTIONS(719),
    [sym__external_open_brace] = ACTIONS(721),
    [sym__external_close_brace] = ACTIONS(729),
  },
  [338] = {
    [sym_function_definition] = STATE(189),
    [sym_if_statement] = STATE(189),
    [sym_for_statement] = STATE(189),
    [sym_while_statement] = STATE(189),
    [sym_repeat_statement] = STATE(189),
    [sym_braced_expression] = STATE(189),
    [sym_parenthesized_expression] = STATE(189),
    [sym_call] = STATE(189),
    [sym_subset] = STATE(189),
    [sym_subset2] = STATE(189),
    [sym_unary_operator] = STATE(189),
    [sym_binary_operator] = STATE(189),
    [sym_extract_operator] = STATE(189),
    [sym_namespace_operator] = STATE(189),
    [sym_integer] = STATE(189),
    [sym_complex] = STATE(189),
    [sym_float] = STATE(189),
    [sym__float_literal] = STATE(330),
    [sym_string] = STATE(311),
    [sym__raw_string] = STATE(331),
    [sym__single_quoted_string] = STATE(332),
    [sym__double_quoted_string] = STATE(333),
    [sym_na] = STATE(189),
    [sym__expression] = STATE(189),
    [sym__open_parenthesis] = STATE(1070),
    [sym__open_brace] = STATE(384),
    [sym__close_brace] = STATE(1743),
    [aux_sym_braced_expression_repeat1] = STATE(415),
    [sym_identifier] = ACTIONS(687),
    [anon_sym_BSLASH] = ACTIONS(689),
    [anon_sym_function] = ACTIONS(691),
    [anon_sym_if] = ACTIONS(693),
    [anon_sym_for] = ACTIONS(695),
    [anon_sym_while] = ACTIONS(697),
    [anon_sym_repeat] = ACTIONS(699),
    [anon_sym_QMARK] = ACTIONS(701),
    [anon_sym_TILDE] = ACTIONS(703),
    [anon_sym_BANG] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [sym__hex_literal] = ACTIONS(709),
    [sym__number_literal] = ACTIONS(711),
    [anon_sym_SQUOTE] = ACTIONS(435),
    [anon_sym_DQUOTE] = ACTIONS(437),
    [sym_dots] = ACTIONS(687),
    [sym_dot_dot_i] = ACTIONS(687),
    [sym_next] = ACTIONS(713),
    [sym_break] = ACTIONS(713),
    [sym_true] = ACTIONS(713),
    [sym_false] = ACTIONS(713),
    [sym_null] = ACTIONS(713),
    [sym_inf] = ACTIONS(713),
    [sym_nan] = ACTIONS(713),
    [anon_sym_NA] = ACTIONS(715),
    [anon_sym_NA_integer_] = ACTIONS(715),
    [anon_sym_NA_real_] = ACTIONS(715),
    [anon_sym_NA_complex_] = ACTIONS(715),
    [anon_sym_NA_character_] = ACTIONS(715),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(717),
    [sym__semicolon] = ACTIONS(717),
    [sym__raw_string_open] = ACTIONS(439),
    [sym__external_open_parenthesis] = ACTIONS(719),
    [sym__external_open_brace] = ACTIONS(721),
    [sym__external_close_brace] = ACTIONS(731),
  },
  [339] = {
    [sym_identifier] = ACTIONS(733),
    [anon_sym_BSLASH] = ACTIONS(735),
    [anon_sym_function] = ACTIONS(733),
    [anon_sym_EQ] = ACTIONS(733),
    [anon_sym_if] = ACTIONS(733),
    [anon_sym_for] = ACTIONS(733),
    [anon_sym_while] = ACTIONS(733),
    [anon_sym_repeat] = ACTIONS(733),
    [anon_sym_QMARK] = ACTIONS(735),
    [anon_sym_TILDE] = ACTIONS(735),
    [anon_sym_BANG] = ACTIONS(733),
    [anon_sym_PLUS] = ACTIONS(735),
    [anon_sym_DASH] = ACTIONS(733),
    [anon_sym_LT_DASH] = ACTIONS(735),
    [anon_sym_LT_LT_DASH] = ACTIONS(735),
    [anon_sym_COLON_EQ] = ACTIONS(735),
    [anon_sym_DASH_GT] = ACTIONS(733),
    [anon_sym_DASH_GT_GT] = ACTIONS(735),
    [anon_sym_PIPE] = ACTIONS(733),
    [anon_sym_AMP] = ACTIONS(733),
    [anon_sym_PIPE_PIPE] = ACTIONS(735),
    [anon_sym_AMP_AMP] = ACTIONS(735),
    [anon_sym_LT] = ACTIONS(733),
    [anon_sym_LT_EQ] = ACTIONS(735),
    [anon_sym_GT] = ACTIONS(733),
    [anon_sym_GT_EQ] = ACTIONS(735),
    [anon_sym_EQ_EQ] = ACTIONS(735),
    [anon_sym_BANG_EQ] = ACTIONS(735),
    [anon_sym_STAR] = ACTIONS(733),
    [anon_sym_SLASH] = ACTIONS(735),
    [anon_sym_STAR_STAR] = ACTIONS(735),
    [anon_sym_CARET] = ACTIONS(735),
    [aux_sym_binary_operator_token1] = ACTIONS(735),
    [anon_sym_PIPE_GT] = ACTIONS(735),
    [anon_sym_COLON] = ACTIONS(733),
    [anon_sym_DOLLAR] = ACTIONS(735),
    [anon_sym_AT] = ACTIONS(735),
    [sym__hex_literal] = ACTIONS(735),
    [sym__number_literal] = ACTIONS(733),
    [anon_sym_SQUOTE] = ACTIONS(735),
    [anon_sym_DQUOTE] = ACTIONS(735),
    [sym_dots] = ACTIONS(733),
    [sym_dot_dot_i] = ACTIONS(733),
    [sym_next] = ACTIONS(733),
    [sym_break] = ACTIONS(733),
    [sym_true] = ACTIONS(733),
    [sym_false] = ACTIONS(733),
    [sym_null] = ACTIONS(733),
    [sym_inf] = ACTIONS(733),
    [sym_nan] = ACTIONS(733),
    [anon_sym_NA] = ACTIONS(733),
    [anon_sym_NA_integer_] = ACTIONS(733),
    [anon_sym_NA_real_] = ACTIONS(733),
    [anon_sym_NA_complex_] = ACTIONS(733),
    [anon_sym_NA_character_] = ACTIONS(733),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(735),
    [sym__semicolon] = ACTIONS(735),
    [sym__raw_string_open] = ACTIONS(735),
    [sym__external_else] = ACTIONS(735),
    [sym__external_open_parenthesis] = ACTIONS(735),
    [sym__external_open_brace] = ACTIONS(735),
    [sym__external_close_brace] = ACTIONS(735),
    [sym__external_open_bracket] = ACTIONS(735),
    [sym__external_open_bracket2] = ACTIONS(735),
  },
  [340] = {
    [ts_builtin_sym_end] = ACTIONS(735),
    [sym_identifier] = ACTIONS(733),
    [anon_sym_BSLASH] = ACTIONS(735),
    [anon_sym_function] = ACTIONS(733),
    [anon_sym_EQ] = ACTIONS(733),
    [anon_sym_if] = ACTIONS(733),
    [anon_sym_for] = ACTIONS(733),
    [anon_sym_while] = ACTIONS(733),
    [anon_sym_repeat] = ACTIONS(733),
    [anon_sym_QMARK] = ACTIONS(735),
    [anon_sym_TILDE] = ACTIONS(735),
    [anon_sym_BANG] = ACTIONS(733),
    [anon_sym_PLUS] = ACTIONS(735),
    [anon_sym_DASH] = ACTIONS(733),
    [anon_sym_LT_DASH] = ACTIONS(735),
    [anon_sym_LT_LT_DASH] = ACTIONS(735),
    [anon_sym_COLON_EQ] = ACTIONS(735),
    [anon_sym_DASH_GT] = ACTIONS(733),
    [anon_sym_DASH_GT_GT] = ACTIONS(735),
    [anon_sym_PIPE] = ACTIONS(733),
    [anon_sym_AMP] = ACTIONS(733),
    [anon_sym_PIPE_PIPE] = ACTIONS(735),
    [anon_sym_AMP_AMP] = ACTIONS(735),
    [anon_sym_LT] = ACTIONS(733),
    [anon_sym_LT_EQ] = ACTIONS(735),
    [anon_sym_GT] = ACTIONS(733),
    [anon_sym_GT_EQ] = ACTIONS(735),
    [anon_sym_EQ_EQ] = ACTIONS(735),
    [anon_sym_BANG_EQ] = ACTIONS(735),
    [anon_sym_STAR] = ACTIONS(733),
    [anon_sym_SLASH] = ACTIONS(735),
    [anon_sym_STAR_STAR] = ACTIONS(735),
    [anon_sym_CARET] = ACTIONS(735),
    [aux_sym_binary_operator_token1] = ACTIONS(735),
    [anon_sym_PIPE_GT] = ACTIONS(735),
    [anon_sym_COLON] = ACTIONS(733),
    [anon_sym_DOLLAR] = ACTIONS(735),
    [anon_sym_AT] = ACTIONS(735),
    [sym__hex_literal] = ACTIONS(735),
    [sym__number_literal] = ACTIONS(733),
    [anon_sym_SQUOTE] = ACTIONS(735),
    [anon_sym_DQUOTE] = ACTIONS(735),
    [sym_dots] = ACTIONS(733),
    [sym_dot_dot_i] = ACTIONS(733),
    [sym_next] = ACTIONS(733),
    [sym_break] = ACTIONS(733),
    [sym_true] = ACTIONS(733),
    [sym_false] = ACTIONS(733),
    [sym_null] = ACTIONS(733),
    [sym_inf] = ACTIONS(733),
    [sym_nan] = ACTIONS(733),
    [anon_sym_NA] = ACTIONS(733),
    [anon_sym_NA_integer_] = ACTIONS(733),
    [anon_sym_NA_real_] = ACTIONS(733),
    [anon_sym_NA_complex_] = ACTIONS(733),
    [anon_sym_NA_character_] = ACTIONS(733),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(735),
    [sym__semicolon] = ACTIONS(735),
    [sym__raw_string_open] = ACTIONS(735),
    [sym__external_else] = ACTIONS(735),
    [sym__external_open_parenthesis] = ACTIONS(735),
    [sym__external_open_brace] = ACTIONS(735),
    [sym__external_open_bracket] = ACTIONS(735),
    [sym__external_open_bracket2] = ACTIONS(735),
  },
  [341] = {
    [ts_builtin_sym_end] = ACTIONS(737),
    [sym_identifier] = ACTIONS(739),
    [anon_sym_BSLASH] = ACTIONS(737),
    [anon_sym_function] = ACTIONS(739),
    [anon_sym_EQ] = ACTIONS(739),
    [anon_sym_if] = ACTIONS(739),
    [anon_sym_for] = ACTIONS(739),
    [anon_sym_while] = ACTIONS(739),
    [anon_sym_repeat] = ACTIONS(739),
    [anon_sym_QMARK] = ACTIONS(737),
    [anon_sym_TILDE] = ACTIONS(737),
    [anon_sym_BANG] = ACTIONS(739),
    [anon_sym_PLUS] = ACTIONS(737),
    [anon_sym_DASH] = ACTIONS(739),
    [anon_sym_LT_DASH] = ACTIONS(737),
    [anon_sym_LT_LT_DASH] = ACTIONS(737),
    [anon_sym_COLON_EQ] = ACTIONS(737),
    [anon_sym_DASH_GT] = ACTIONS(739),
    [anon_sym_DASH_GT_GT] = ACTIONS(737),
    [anon_sym_PIPE] = ACTIONS(739),
    [anon_sym_AMP] = ACTIONS(739),
    [anon_sym_PIPE_PIPE] = ACTIONS(737),
    [anon_sym_AMP_AMP] = ACTIONS(737),
    [anon_sym_LT] = ACTIONS(739),
    [anon_sym_LT_EQ] = ACTIONS(737),
    [anon_sym_GT] = ACTIONS(739),
    [anon_sym_GT_EQ] = ACTIONS(737),
    [anon_sym_EQ_EQ] = ACTIONS(737),
    [anon_sym_BANG_EQ] = ACTIONS(737),
    [anon_sym_STAR] = ACTIONS(739),
    [anon_sym_SLASH] = ACTIONS(737),
    [anon_sym_STAR_STAR] = ACTIONS(737),
    [anon_sym_CARET] = ACTIONS(737),
    [aux_sym_binary_operator_token1] = ACTIONS(737),
    [anon_sym_PIPE_GT] = ACTIONS(737),
    [anon_sym_COLON] = ACTIONS(739),
    [anon_sym_DOLLAR] = ACTIONS(737),
    [anon_sym_AT] = ACTIONS(737),
    [sym__hex_literal] = ACTIONS(737),
    [sym__number_literal] = ACTIONS(739),
    [anon_sym_SQUOTE] = ACTIONS(737),
    [anon_sym_DQUOTE] = ACTIONS(737),
    [sym_dots] = ACTIONS(739),
    [sym_dot_dot_i] = ACTIONS(739),
    [sym_next] = ACTIONS(739),
    [sym_break] = ACTIONS(739),
    [sym_true] = ACTIONS(739),
    [sym_false] = ACTIONS(739),
    [sym_null] = ACTIONS(739),
    [sym_inf] = ACTIONS(739),
    [sym_nan] = ACTIONS(739),
    [anon_sym_NA] = ACTIONS(739),
    [anon_sym_NA_integer_] = ACTIONS(739),
    [anon_sym_NA_real_] = ACTIONS(739),
    [anon_sym_NA_complex_] = ACTIONS(739),
    [anon_sym_NA_character_] = ACTIONS(739),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(737),
    [sym__semicolon] = ACTIONS(737),
    [sym__raw_string_open] = ACTIONS(737),
    [sym__external_else] = ACTIONS(737),
    [sym__external_open_parenthesis] = ACTIONS(737),
    [sym__external_open_brace] = ACTIONS(737),
    [sym__external_open_bracket] = ACTIONS(737),
    [sym__external_open_bracket2] = ACTIONS(737),
  },
  [342] = {
    [sym_identifier] = ACTIONS(741),
    [anon_sym_BSLASH] = ACTIONS(743),
    [anon_sym_function] = ACTIONS(741),
    [anon_sym_EQ] = ACTIONS(741),
    [anon_sym_if] = ACTIONS(741),
    [anon_sym_for] = ACTIONS(741),
    [anon_sym_while] = ACTIONS(741),
    [anon_sym_repeat] = ACTIONS(741),
    [anon_sym_QMARK] = ACTIONS(743),
    [anon_sym_TILDE] = ACTIONS(743),
    [anon_sym_BANG] = ACTIONS(741),
    [anon_sym_PLUS] = ACTIONS(743),
    [anon_sym_DASH] = ACTIONS(741),
    [anon_sym_LT_DASH] = ACTIONS(743),
    [anon_sym_LT_LT_DASH] = ACTIONS(743),
    [anon_sym_COLON_EQ] = ACTIONS(743),
    [anon_sym_DASH_GT] = ACTIONS(741),
    [anon_sym_DASH_GT_GT] = ACTIONS(743),
    [anon_sym_PIPE] = ACTIONS(741),
    [anon_sym_AMP] = ACTIONS(741),
    [anon_sym_PIPE_PIPE] = ACTIONS(743),
    [anon_sym_AMP_AMP] = ACTIONS(743),
    [anon_sym_LT] = ACTIONS(741),
    [anon_sym_LT_EQ] = ACTIONS(743),
    [anon_sym_GT] = ACTIONS(741),
    [anon_sym_GT_EQ] = ACTIONS(743),
    [anon_sym_EQ_EQ] = ACTIONS(743),
    [anon_sym_BANG_EQ] = ACTIONS(743),
    [anon_sym_STAR] = ACTIONS(741),
    [anon_sym_SLASH] = ACTIONS(743),
    [anon_sym_STAR_STAR] = ACTIONS(743),
    [anon_sym_CARET] = ACTIONS(743),
    [aux_sym_binary_operator_token1] = ACTIONS(743),
    [anon_sym_PIPE_GT] = ACTIONS(743),
    [anon_sym_COLON] = ACTIONS(741),
    [anon_sym_DOLLAR] = ACTIONS(743),
    [anon_sym_AT] = ACTIONS(743),
    [sym__hex_literal] = ACTIONS(743),
    [sym__number_literal] = ACTIONS(741),
    [anon_sym_SQUOTE] = ACTIONS(743),
    [anon_sym_DQUOTE] = ACTIONS(743),
    [sym_dots] = ACTIONS(741),
    [sym_dot_dot_i] = ACTIONS(741),
    [sym_next] = ACTIONS(741),
    [sym_break] = ACTIONS(741),
    [sym_true] = ACTIONS(741),
    [sym_false] = ACTIONS(741),
    [sym_null] = ACTIONS(741),
    [sym_inf] = ACTIONS(741),
    [sym_nan] = ACTIONS(741),
    [anon_sym_NA] = ACTIONS(741),
    [anon_sym_NA_integer_] = ACTIONS(741),
    [anon_sym_NA_real_] = ACTIONS(741),
    [anon_sym_NA_complex_] = ACTIONS(741),
    [anon_sym_NA_character_] = ACTIONS(741),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(743),
    [sym__semicolon] = ACTIONS(743),
    [sym__raw_string_open] = ACTIONS(743),
    [sym__external_else] = ACTIONS(743),
    [sym__external_open_parenthesis] = ACTIONS(743),
    [sym__external_open_brace] = ACTIONS(743),
    [sym__external_close_brace] = ACTIONS(743),
    [sym__external_open_bracket] = ACTIONS(743),
    [sym__external_open_bracket2] = ACTIONS(743),
  },
  [343] = {
    [sym_identifier] = ACTIONS(745),
    [anon_sym_BSLASH] = ACTIONS(747),
    [anon_sym_function] = ACTIONS(745),
    [anon_sym_EQ] = ACTIONS(745),
    [anon_sym_if] = ACTIONS(745),
    [anon_sym_for] = ACTIONS(745),
    [anon_sym_while] = ACTIONS(745),
    [anon_sym_repeat] = ACTIONS(745),
    [anon_sym_QMARK] = ACTIONS(747),
    [anon_sym_TILDE] = ACTIONS(747),
    [anon_sym_BANG] = ACTIONS(745),
    [anon_sym_PLUS] = ACTIONS(747),
    [anon_sym_DASH] = ACTIONS(745),
    [anon_sym_LT_DASH] = ACTIONS(747),
    [anon_sym_LT_LT_DASH] = ACTIONS(747),
    [anon_sym_COLON_EQ] = ACTIONS(747),
    [anon_sym_DASH_GT] = ACTIONS(745),
    [anon_sym_DASH_GT_GT] = ACTIONS(747),
    [anon_sym_PIPE] = ACTIONS(745),
    [anon_sym_AMP] = ACTIONS(745),
    [anon_sym_PIPE_PIPE] = ACTIONS(747),
    [anon_sym_AMP_AMP] = ACTIONS(747),
    [anon_sym_LT] = ACTIONS(745),
    [anon_sym_LT_EQ] = ACTIONS(747),
    [anon_sym_GT] = ACTIONS(745),
    [anon_sym_GT_EQ] = ACTIONS(747),
    [anon_sym_EQ_EQ] = ACTIONS(747),
    [anon_sym_BANG_EQ] = ACTIONS(747),
    [anon_sym_STAR] = ACTIONS(745),
    [anon_sym_SLASH] = ACTIONS(747),
    [anon_sym_STAR_STAR] = ACTIONS(747),
    [anon_sym_CARET] = ACTIONS(747),
    [aux_sym_binary_operator_token1] = ACTIONS(747),
    [anon_sym_PIPE_GT] = ACTIONS(747),
    [anon_sym_COLON] = ACTIONS(745),
    [anon_sym_DOLLAR] = ACTIONS(747),
    [anon_sym_AT] = ACTIONS(747),
    [sym__hex_literal] = ACTIONS(747),
    [sym__number_literal] = ACTIONS(745),
    [anon_sym_SQUOTE] = ACTIONS(747),
    [anon_sym_DQUOTE] = ACTIONS(747),
    [sym_dots] = ACTIONS(745),
    [sym_dot_dot_i] = ACTIONS(745),
    [sym_next] = ACTIONS(745),
    [sym_break] = ACTIONS(745),
    [sym_true] = ACTIONS(745),
    [sym_false] = ACTIONS(745),
    [sym_null] = ACTIONS(745),
    [sym_inf] = ACTIONS(745),
    [sym_nan] = ACTIONS(745),
    [anon_sym_NA] = ACTIONS(745),
    [anon_sym_NA_integer_] = ACTIONS(745),
    [anon_sym_NA_real_] = ACTIONS(745),
    [anon_sym_NA_complex_] = ACTIONS(745),
    [anon_sym_NA_character_] = ACTIONS(745),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(747),
    [sym__semicolon] = ACTIONS(747),
    [sym__raw_string_open] = ACTIONS(747),
    [sym__external_else] = ACTIONS(747),
    [sym__external_open_parenthesis] = ACTIONS(747),
    [sym__external_open_brace] = ACTIONS(747),
    [sym__external_close_brace] = ACTIONS(747),
    [sym__external_open_bracket] = ACTIONS(747),
    [sym__external_open_bracket2] = ACTIONS(747),
  },
  [344] = {
    [sym_identifier] = ACTIONS(749),
    [anon_sym_BSLASH] = ACTIONS(751),
    [anon_sym_function] = ACTIONS(749),
    [anon_sym_EQ] = ACTIONS(749),
    [anon_sym_if] = ACTIONS(749),
    [anon_sym_for] = ACTIONS(749),
    [anon_sym_while] = ACTIONS(749),
    [anon_sym_repeat] = ACTIONS(749),
    [anon_sym_QMARK] = ACTIONS(751),
    [anon_sym_TILDE] = ACTIONS(751),
    [anon_sym_BANG] = ACTIONS(749),
    [anon_sym_PLUS] = ACTIONS(751),
    [anon_sym_DASH] = ACTIONS(749),
    [anon_sym_LT_DASH] = ACTIONS(751),
    [anon_sym_LT_LT_DASH] = ACTIONS(751),
    [anon_sym_COLON_EQ] = ACTIONS(751),
    [anon_sym_DASH_GT] = ACTIONS(749),
    [anon_sym_DASH_GT_GT] = ACTIONS(751),
    [anon_sym_PIPE] = ACTIONS(749),
    [anon_sym_AMP] = ACTIONS(749),
    [anon_sym_PIPE_PIPE] = ACTIONS(751),
    [anon_sym_AMP_AMP] = ACTIONS(751),
    [anon_sym_LT] = ACTIONS(749),
    [anon_sym_LT_EQ] = ACTIONS(751),
    [anon_sym_GT] = ACTIONS(749),
    [anon_sym_GT_EQ] = ACTIONS(751),
    [anon_sym_EQ_EQ] = ACTIONS(751),
    [anon_sym_BANG_EQ] = ACTIONS(751),
    [anon_sym_STAR] = ACTIONS(749),
    [anon_sym_SLASH] = ACTIONS(751),
    [anon_sym_STAR_STAR] = ACTIONS(751),
    [anon_sym_CARET] = ACTIONS(751),
    [aux_sym_binary_operator_token1] = ACTIONS(751),
    [anon_sym_PIPE_GT] = ACTIONS(751),
    [anon_sym_COLON] = ACTIONS(749),
    [anon_sym_DOLLAR] = ACTIONS(751),
    [anon_sym_AT] = ACTIONS(751),
    [sym__hex_literal] = ACTIONS(751),
    [sym__number_literal] = ACTIONS(749),
    [anon_sym_SQUOTE] = ACTIONS(751),
    [anon_sym_DQUOTE] = ACTIONS(751),
    [sym_dots] = ACTIONS(749),
    [sym_dot_dot_i] = ACTIONS(749),
    [sym_next] = ACTIONS(749),
    [sym_break] = ACTIONS(749),
    [sym_true] = ACTIONS(749),
    [sym_false] = ACTIONS(749),
    [sym_null] = ACTIONS(749),
    [sym_inf] = ACTIONS(749),
    [sym_nan] = ACTIONS(749),
    [anon_sym_NA] = ACTIONS(749),
    [anon_sym_NA_integer_] = ACTIONS(749),
    [anon_sym_NA_real_] = ACTIONS(749),
    [anon_sym_NA_complex_] = ACTIONS(749),
    [anon_sym_NA_character_] = ACTIONS(749),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(751),
    [sym__semicolon] = ACTIONS(751),
    [sym__raw_string_open] = ACTIONS(751),
    [sym__external_else] = ACTIONS(751),
    [sym__external_open_parenthesis] = ACTIONS(751),
    [sym__external_open_brace] = ACTIONS(751),
    [sym__external_close_brace] = ACTIONS(751),
    [sym__external_open_bracket] = ACTIONS(751),
    [sym__external_open_bracket2] = ACTIONS(751),
  },
  [345] = {
    [sym_identifier] = ACTIONS(753),
    [anon_sym_BSLASH] = ACTIONS(755),
    [anon_sym_function] = ACTIONS(753),
    [anon_sym_EQ] = ACTIONS(753),
    [anon_sym_if] = ACTIONS(753),
    [anon_sym_for] = ACTIONS(753),
    [anon_sym_while] = ACTIONS(753),
    [anon_sym_repeat] = ACTIONS(753),
    [anon_sym_QMARK] = ACTIONS(755),
    [anon_sym_TILDE] = ACTIONS(755),
    [anon_sym_BANG] = ACTIONS(753),
    [anon_sym_PLUS] = ACTIONS(755),
    [anon_sym_DASH] = ACTIONS(753),
    [anon_sym_LT_DASH] = ACTIONS(755),
    [anon_sym_LT_LT_DASH] = ACTIONS(755),
    [anon_sym_COLON_EQ] = ACTIONS(755),
    [anon_sym_DASH_GT] = ACTIONS(753),
    [anon_sym_DASH_GT_GT] = ACTIONS(755),
    [anon_sym_PIPE] = ACTIONS(753),
    [anon_sym_AMP] = ACTIONS(753),
    [anon_sym_PIPE_PIPE] = ACTIONS(755),
    [anon_sym_AMP_AMP] = ACTIONS(755),
    [anon_sym_LT] = ACTIONS(753),
    [anon_sym_LT_EQ] = ACTIONS(755),
    [anon_sym_GT] = ACTIONS(753),
    [anon_sym_GT_EQ] = ACTIONS(755),
    [anon_sym_EQ_EQ] = ACTIONS(755),
    [anon_sym_BANG_EQ] = ACTIONS(755),
    [anon_sym_STAR] = ACTIONS(753),
    [anon_sym_SLASH] = ACTIONS(755),
    [anon_sym_STAR_STAR] = ACTIONS(755),
    [anon_sym_CARET] = ACTIONS(755),
    [aux_sym_binary_operator_token1] = ACTIONS(755),
    [anon_sym_PIPE_GT] = ACTIONS(755),
    [anon_sym_COLON] = ACTIONS(753),
    [anon_sym_DOLLAR] = ACTIONS(755),
    [anon_sym_AT] = ACTIONS(755),
    [sym__hex_literal] = ACTIONS(755),
    [sym__number_literal] = ACTIONS(753),
    [anon_sym_SQUOTE] = ACTIONS(755),
    [anon_sym_DQUOTE] = ACTIONS(755),
    [sym_dots] = ACTIONS(753),
    [sym_dot_dot_i] = ACTIONS(753),
    [sym_next] = ACTIONS(753),
    [sym_break] = ACTIONS(753),
    [sym_true] = ACTIONS(753),
    [sym_false] = ACTIONS(753),
    [sym_null] = ACTIONS(753),
    [sym_inf] = ACTIONS(753),
    [sym_nan] = ACTIONS(753),
    [anon_sym_NA] = ACTIONS(753),
    [anon_sym_NA_integer_] = ACTIONS(753),
    [anon_sym_NA_real_] = ACTIONS(753),
    [anon_sym_NA_complex_] = ACTIONS(753),
    [anon_sym_NA_character_] = ACTIONS(753),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(755),
    [sym__semicolon] = ACTIONS(755),
    [sym__raw_string_open] = ACTIONS(755),
    [sym__external_else] = ACTIONS(755),
    [sym__external_open_parenthesis] = ACTIONS(755),
    [sym__external_open_brace] = ACTIONS(755),
    [sym__external_close_brace] = ACTIONS(755),
    [sym__external_open_bracket] = ACTIONS(755),
    [sym__external_open_bracket2] = ACTIONS(755),
  },
  [346] = {
    [sym_identifier] = ACTIONS(757),
    [anon_sym_BSLASH] = ACTIONS(759),
    [anon_sym_function] = ACTIONS(757),
    [anon_sym_EQ] = ACTIONS(757),
    [anon_sym_if] = ACTIONS(757),
    [anon_sym_for] = ACTIONS(757),
    [anon_sym_while] = ACTIONS(757),
    [anon_sym_repeat] = ACTIONS(757),
    [anon_sym_QMARK] = ACTIONS(759),
    [anon_sym_TILDE] = ACTIONS(759),
    [anon_sym_BANG] = ACTIONS(757),
    [anon_sym_PLUS] = ACTIONS(759),
    [anon_sym_DASH] = ACTIONS(757),
    [anon_sym_LT_DASH] = ACTIONS(759),
    [anon_sym_LT_LT_DASH] = ACTIONS(759),
    [anon_sym_COLON_EQ] = ACTIONS(759),
    [anon_sym_DASH_GT] = ACTIONS(757),
    [anon_sym_DASH_GT_GT] = ACTIONS(759),
    [anon_sym_PIPE] = ACTIONS(757),
    [anon_sym_AMP] = ACTIONS(757),
    [anon_sym_PIPE_PIPE] = ACTIONS(759),
    [anon_sym_AMP_AMP] = ACTIONS(759),
    [anon_sym_LT] = ACTIONS(757),
    [anon_sym_LT_EQ] = ACTIONS(759),
    [anon_sym_GT] = ACTIONS(757),
    [anon_sym_GT_EQ] = ACTIONS(759),
    [anon_sym_EQ_EQ] = ACTIONS(759),
    [anon_sym_BANG_EQ] = ACTIONS(759),
    [anon_sym_STAR] = ACTIONS(757),
    [anon_sym_SLASH] = ACTIONS(759),
    [anon_sym_STAR_STAR] = ACTIONS(759),
    [anon_sym_CARET] = ACTIONS(759),
    [aux_sym_binary_operator_token1] = ACTIONS(759),
    [anon_sym_PIPE_GT] = ACTIONS(759),
    [anon_sym_COLON] = ACTIONS(757),
    [anon_sym_DOLLAR] = ACTIONS(759),
    [anon_sym_AT] = ACTIONS(759),
    [sym__hex_literal] = ACTIONS(759),
    [sym__number_literal] = ACTIONS(757),
    [anon_sym_SQUOTE] = ACTIONS(759),
    [anon_sym_DQUOTE] = ACTIONS(759),
    [sym_dots] = ACTIONS(757),
    [sym_dot_dot_i] = ACTIONS(757),
    [sym_next] = ACTIONS(757),
    [sym_break] = ACTIONS(757),
    [sym_true] = ACTIONS(757),
    [sym_false] = ACTIONS(757),
    [sym_null] = ACTIONS(757),
    [sym_inf] = ACTIONS(757),
    [sym_nan] = ACTIONS(757),
    [anon_sym_NA] = ACTIONS(757),
    [anon_sym_NA_integer_] = ACTIONS(757),
    [anon_sym_NA_real_] = ACTIONS(757),
    [anon_sym_NA_complex_] = ACTIONS(757),
    [anon_sym_NA_character_] = ACTIONS(757),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(759),
    [sym__semicolon] = ACTIONS(759),
    [sym__raw_string_open] = ACTIONS(759),
    [sym__external_else] = ACTIONS(759),
    [sym__external_open_parenthesis] = ACTIONS(759),
    [sym__external_open_brace] = ACTIONS(759),
    [sym__external_close_brace] = ACTIONS(759),
    [sym__external_open_bracket] = ACTIONS(759),
    [sym__external_open_bracket2] = ACTIONS(759),
  },
  [347] = {
    [sym_identifier] = ACTIONS(761),
    [anon_sym_BSLASH] = ACTIONS(763),
    [anon_sym_function] = ACTIONS(761),
    [anon_sym_EQ] = ACTIONS(761),
    [anon_sym_if] = ACTIONS(761),
    [anon_sym_for] = ACTIONS(761),
    [anon_sym_while] = ACTIONS(761),
    [anon_sym_repeat] = ACTIONS(761),
    [anon_sym_QMARK] = ACTIONS(763),
    [anon_sym_TILDE] = ACTIONS(763),
    [anon_sym_BANG] = ACTIONS(761),
    [anon_sym_PLUS] = ACTIONS(763),
    [anon_sym_DASH] = ACTIONS(761),
    [anon_sym_LT_DASH] = ACTIONS(763),
    [anon_sym_LT_LT_DASH] = ACTIONS(763),
    [anon_sym_COLON_EQ] = ACTIONS(763),
    [anon_sym_DASH_GT] = ACTIONS(761),
    [anon_sym_DASH_GT_GT] = ACTIONS(763),
    [anon_sym_PIPE] = ACTIONS(761),
    [anon_sym_AMP] = ACTIONS(761),
    [anon_sym_PIPE_PIPE] = ACTIONS(763),
    [anon_sym_AMP_AMP] = ACTIONS(763),
    [anon_sym_LT] = ACTIONS(761),
    [anon_sym_LT_EQ] = ACTIONS(763),
    [anon_sym_GT] = ACTIONS(761),
    [anon_sym_GT_EQ] = ACTIONS(763),
    [anon_sym_EQ_EQ] = ACTIONS(763),
    [anon_sym_BANG_EQ] = ACTIONS(763),
    [anon_sym_STAR] = ACTIONS(761),
    [anon_sym_SLASH] = ACTIONS(763),
    [anon_sym_STAR_STAR] = ACTIONS(763),
    [anon_sym_CARET] = ACTIONS(763),
    [aux_sym_binary_operator_token1] = ACTIONS(763),
    [anon_sym_PIPE_GT] = ACTIONS(763),
    [anon_sym_COLON] = ACTIONS(761),
    [anon_sym_DOLLAR] = ACTIONS(763),
    [anon_sym_AT] = ACTIONS(763),
    [sym__hex_literal] = ACTIONS(763),
    [sym__number_literal] = ACTIONS(761),
    [anon_sym_SQUOTE] = ACTIONS(763),
    [anon_sym_DQUOTE] = ACTIONS(763),
    [sym_dots] = ACTIONS(761),
    [sym_dot_dot_i] = ACTIONS(761),
    [sym_next] = ACTIONS(761),
    [sym_break] = ACTIONS(761),
    [sym_true] = ACTIONS(761),
    [sym_false] = ACTIONS(761),
    [sym_null] = ACTIONS(761),
    [sym_inf] = ACTIONS(761),
    [sym_nan] = ACTIONS(761),
    [anon_sym_NA] = ACTIONS(761),
    [anon_sym_NA_integer_] = ACTIONS(761),
    [anon_sym_NA_real_] = ACTIONS(761),
    [anon_sym_NA_complex_] = ACTIONS(761),
    [anon_sym_NA_character_] = ACTIONS(761),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(763),
    [sym__semicolon] = ACTIONS(763),
    [sym__raw_string_open] = ACTIONS(763),
    [sym__external_else] = ACTIONS(763),
    [sym__external_open_parenthesis] = ACTIONS(763),
    [sym__external_open_brace] = ACTIONS(763),
    [sym__external_close_brace] = ACTIONS(763),
    [sym__external_open_bracket] = ACTIONS(763),
    [sym__external_open_bracket2] = ACTIONS(763),
  },
  [348] = {
    [ts_builtin_sym_end] = ACTIONS(765),
    [sym_identifier] = ACTIONS(767),
    [anon_sym_BSLASH] = ACTIONS(765),
    [anon_sym_function] = ACTIONS(767),
    [anon_sym_EQ] = ACTIONS(767),
    [anon_sym_if] = ACTIONS(767),
    [anon_sym_for] = ACTIONS(767),
    [anon_sym_while] = ACTIONS(767),
    [anon_sym_repeat] = ACTIONS(767),
    [anon_sym_QMARK] = ACTIONS(765),
    [anon_sym_TILDE] = ACTIONS(765),
    [anon_sym_BANG] = ACTIONS(767),
    [anon_sym_PLUS] = ACTIONS(765),
    [anon_sym_DASH] = ACTIONS(767),
    [anon_sym_LT_DASH] = ACTIONS(765),
    [anon_sym_LT_LT_DASH] = ACTIONS(765),
    [anon_sym_COLON_EQ] = ACTIONS(765),
    [anon_sym_DASH_GT] = ACTIONS(767),
    [anon_sym_DASH_GT_GT] = ACTIONS(765),
    [anon_sym_PIPE] = ACTIONS(767),
    [anon_sym_AMP] = ACTIONS(767),
    [anon_sym_PIPE_PIPE] = ACTIONS(765),
    [anon_sym_AMP_AMP] = ACTIONS(765),
    [anon_sym_LT] = ACTIONS(767),
    [anon_sym_LT_EQ] = ACTIONS(765),
    [anon_sym_GT] = ACTIONS(767),
    [anon_sym_GT_EQ] = ACTIONS(765),
    [anon_sym_EQ_EQ] = ACTIONS(765),
    [anon_sym_BANG_EQ] = ACTIONS(765),
    [anon_sym_STAR] = ACTIONS(767),
    [anon_sym_SLASH] = ACTIONS(765),
    [anon_sym_STAR_STAR] = ACTIONS(765),
    [anon_sym_CARET] = ACTIONS(765),
    [aux_sym_binary_operator_token1] = ACTIONS(765),
    [anon_sym_PIPE_GT] = ACTIONS(765),
    [anon_sym_COLON] = ACTIONS(767),
    [anon_sym_DOLLAR] = ACTIONS(765),
    [anon_sym_AT] = ACTIONS(765),
    [sym__hex_literal] = ACTIONS(765),
    [sym__number_literal] = ACTIONS(767),
    [anon_sym_SQUOTE] = ACTIONS(765),
    [anon_sym_DQUOTE] = ACTIONS(765),
    [sym_dots] = ACTIONS(767),
    [sym_dot_dot_i] = ACTIONS(767),
    [sym_next] = ACTIONS(767),
    [sym_break] = ACTIONS(767),
    [sym_true] = ACTIONS(767),
    [sym_false] = ACTIONS(767),
    [sym_null] = ACTIONS(767),
    [sym_inf] = ACTIONS(767),
    [sym_nan] = ACTIONS(767),
    [anon_sym_NA] = ACTIONS(767),
    [anon_sym_NA_integer_] = ACTIONS(767),
    [anon_sym_NA_real_] = ACTIONS(767),
    [anon_sym_NA_complex_] = ACTIONS(767),
    [anon_sym_NA_character_] = ACTIONS(767),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(765),
    [sym__semicolon] = ACTIONS(765),
    [sym__raw_string_open] = ACTIONS(765),
    [sym__external_else] = ACTIONS(765),
    [sym__external_open_parenthesis] = ACTIONS(765),
    [sym__external_open_brace] = ACTIONS(765),
    [sym__external_open_bracket] = ACTIONS(765),
    [sym__external_open_bracket2] = ACTIONS(765),
  },
  [349] = {
    [ts_builtin_sym_end] = ACTIONS(769),
    [sym_identifier] = ACTIONS(771),
    [anon_sym_BSLASH] = ACTIONS(769),
    [anon_sym_function] = ACTIONS(771),
    [anon_sym_EQ] = ACTIONS(771),
    [anon_sym_if] = ACTIONS(771),
    [anon_sym_for] = ACTIONS(771),
    [anon_sym_while] = ACTIONS(771),
    [anon_sym_repeat] = ACTIONS(771),
    [anon_sym_QMARK] = ACTIONS(769),
    [anon_sym_TILDE] = ACTIONS(769),
    [anon_sym_BANG] = ACTIONS(771),
    [anon_sym_PLUS] = ACTIONS(769),
    [anon_sym_DASH] = ACTIONS(771),
    [anon_sym_LT_DASH] = ACTIONS(769),
    [anon_sym_LT_LT_DASH] = ACTIONS(769),
    [anon_sym_COLON_EQ] = ACTIONS(769),
    [anon_sym_DASH_GT] = ACTIONS(771),
    [anon_sym_DASH_GT_GT] = ACTIONS(769),
    [anon_sym_PIPE] = ACTIONS(771),
    [anon_sym_AMP] = ACTIONS(771),
    [anon_sym_PIPE_PIPE] = ACTIONS(769),
    [anon_sym_AMP_AMP] = ACTIONS(769),
    [anon_sym_LT] = ACTIONS(771),
    [anon_sym_LT_EQ] = ACTIONS(769),
    [anon_sym_GT] = ACTIONS(771),
    [anon_sym_GT_EQ] = ACTIONS(769),
    [anon_sym_EQ_EQ] = ACTIONS(769),
    [anon_sym_BANG_EQ] = ACTIONS(769),
    [anon_sym_STAR] = ACTIONS(771),
    [anon_sym_SLASH] = ACTIONS(769),
    [anon_sym_STAR_STAR] = ACTIONS(769),
    [anon_sym_CARET] = ACTIONS(769),
    [aux_sym_binary_operator_token1] = ACTIONS(769),
    [anon_sym_PIPE_GT] = ACTIONS(769),
    [anon_sym_COLON] = ACTIONS(771),
    [anon_sym_DOLLAR] = ACTIONS(769),
    [anon_sym_AT] = ACTIONS(769),
    [sym__hex_literal] = ACTIONS(769),
    [sym__number_literal] = ACTIONS(771),
    [anon_sym_SQUOTE] = ACTIONS(769),
    [anon_sym_DQUOTE] = ACTIONS(769),
    [sym_dots] = ACTIONS(771),
    [sym_dot_dot_i] = ACTIONS(771),
    [sym_next] = ACTIONS(771),
    [sym_break] = ACTIONS(771),
    [sym_true] = ACTIONS(771),
    [sym_false] = ACTIONS(771),
    [sym_null] = ACTIONS(771),
    [sym_inf] = ACTIONS(771),
    [sym_nan] = ACTIONS(771),
    [anon_sym_NA] = ACTIONS(771),
    [anon_sym_NA_integer_] = ACTIONS(771),
    [anon_sym_NA_real_] = ACTIONS(771),
    [anon_sym_NA_complex_] = ACTIONS(771),
    [anon_sym_NA_character_] = ACTIONS(771),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(769),
    [sym__semicolon] = ACTIONS(769),
    [sym__raw_string_open] = ACTIONS(769),
    [sym__external_else] = ACTIONS(769),
    [sym__external_open_parenthesis] = ACTIONS(769),
    [sym__external_open_brace] = ACTIONS(769),
    [sym__external_open_bracket] = ACTIONS(769),
    [sym__external_open_bracket2] = ACTIONS(769),
  },
  [350] = {
    [ts_builtin_sym_end] = ACTIONS(773),
    [sym_identifier] = ACTIONS(775),
    [anon_sym_BSLASH] = ACTIONS(773),
    [anon_sym_function] = ACTIONS(775),
    [anon_sym_EQ] = ACTIONS(775),
    [anon_sym_if] = ACTIONS(775),
    [anon_sym_for] = ACTIONS(775),
    [anon_sym_while] = ACTIONS(775),
    [anon_sym_repeat] = ACTIONS(775),
    [anon_sym_QMARK] = ACTIONS(773),
    [anon_sym_TILDE] = ACTIONS(773),
    [anon_sym_BANG] = ACTIONS(775),
    [anon_sym_PLUS] = ACTIONS(773),
    [anon_sym_DASH] = ACTIONS(775),
    [anon_sym_LT_DASH] = ACTIONS(773),
    [anon_sym_LT_LT_DASH] = ACTIONS(773),
    [anon_sym_COLON_EQ] = ACTIONS(773),
    [anon_sym_DASH_GT] = ACTIONS(775),
    [anon_sym_DASH_GT_GT] = ACTIONS(773),
    [anon_sym_PIPE] = ACTIONS(775),
    [anon_sym_AMP] = ACTIONS(775),
    [anon_sym_PIPE_PIPE] = ACTIONS(773),
    [anon_sym_AMP_AMP] = ACTIONS(773),
    [anon_sym_LT] = ACTIONS(775),
    [anon_sym_LT_EQ] = ACTIONS(773),
    [anon_sym_GT] = ACTIONS(775),
    [anon_sym_GT_EQ] = ACTIONS(773),
    [anon_sym_EQ_EQ] = ACTIONS(773),
    [anon_sym_BANG_EQ] = ACTIONS(773),
    [anon_sym_STAR] = ACTIONS(775),
    [anon_sym_SLASH] = ACTIONS(773),
    [anon_sym_STAR_STAR] = ACTIONS(773),
    [anon_sym_CARET] = ACTIONS(773),
    [aux_sym_binary_operator_token1] = ACTIONS(773),
    [anon_sym_PIPE_GT] = ACTIONS(773),
    [anon_sym_COLON] = ACTIONS(775),
    [anon_sym_DOLLAR] = ACTIONS(773),
    [anon_sym_AT] = ACTIONS(773),
    [sym__hex_literal] = ACTIONS(773),
    [sym__number_literal] = ACTIONS(775),
    [anon_sym_SQUOTE] = ACTIONS(773),
    [anon_sym_DQUOTE] = ACTIONS(773),
    [sym_dots] = ACTIONS(775),
    [sym_dot_dot_i] = ACTIONS(775),
    [sym_next] = ACTIONS(775),
    [sym_break] = ACTIONS(775),
    [sym_true] = ACTIONS(775),
    [sym_false] = ACTIONS(775),
    [sym_null] = ACTIONS(775),
    [sym_inf] = ACTIONS(775),
    [sym_nan] = ACTIONS(775),
    [anon_sym_NA] = ACTIONS(775),
    [anon_sym_NA_integer_] = ACTIONS(775),
    [anon_sym_NA_real_] = ACTIONS(775),
    [anon_sym_NA_complex_] = ACTIONS(775),
    [anon_sym_NA_character_] = ACTIONS(775),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(773),
    [sym__semicolon] = ACTIONS(773),
    [sym__raw_string_open] = ACTIONS(773),
    [sym__external_else] = ACTIONS(773),
    [sym__external_open_parenthesis] = ACTIONS(773),
    [sym__external_open_brace] = ACTIONS(773),
    [sym__external_open_bracket] = ACTIONS(773),
    [sym__external_open_bracket2] = ACTIONS(773),
  },
  [351] = {
    [sym_function_definition] = STATE(189),
    [sym_if_statement] = STATE(189),
    [sym_for_statement] = STATE(189),
    [sym_while_statement] = STATE(189),
    [sym_repeat_statement] = STATE(189),
    [sym_braced_expression] = STATE(189),
    [sym_parenthesized_expression] = STATE(189),
    [sym_call] = STATE(189),
    [sym_subset] = STATE(189),
    [sym_subset2] = STATE(189),
    [sym_unary_operator] = STATE(189),
    [sym_binary_operator] = STATE(189),
    [sym_extract_operator] = STATE(189),
    [sym_namespace_operator] = STATE(189),
    [sym_integer] = STATE(189),
    [sym_complex] = STATE(189),
    [sym_float] = STATE(189),
    [sym__float_literal] = STATE(330),
    [sym_string] = STATE(311),
    [sym__raw_string] = STATE(331),
    [sym__single_quoted_string] = STATE(332),
    [sym__double_quoted_string] = STATE(333),
    [sym_na] = STATE(189),
    [sym__expression] = STATE(189),
    [sym__open_parenthesis] = STATE(1070),
    [sym__open_brace] = STATE(384),
    [sym__close_brace] = STATE(1746),
    [aux_sym_braced_expression_repeat1] = STATE(415),
    [sym_identifier] = ACTIONS(687),
    [anon_sym_BSLASH] = ACTIONS(689),
    [anon_sym_function] = ACTIONS(691),
    [anon_sym_if] = ACTIONS(693),
    [anon_sym_for] = ACTIONS(695),
    [anon_sym_while] = ACTIONS(697),
    [anon_sym_repeat] = ACTIONS(699),
    [anon_sym_QMARK] = ACTIONS(701),
    [anon_sym_TILDE] = ACTIONS(703),
    [anon_sym_BANG] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [sym__hex_literal] = ACTIONS(709),
    [sym__number_literal] = ACTIONS(711),
    [anon_sym_SQUOTE] = ACTIONS(435),
    [anon_sym_DQUOTE] = ACTIONS(437),
    [sym_dots] = ACTIONS(687),
    [sym_dot_dot_i] = ACTIONS(687),
    [sym_next] = ACTIONS(713),
    [sym_break] = ACTIONS(713),
    [sym_true] = ACTIONS(713),
    [sym_false] = ACTIONS(713),
    [sym_null] = ACTIONS(713),
    [sym_inf] = ACTIONS(713),
    [sym_nan] = ACTIONS(713),
    [anon_sym_NA] = ACTIONS(715),
    [anon_sym_NA_integer_] = ACTIONS(715),
    [anon_sym_NA_real_] = ACTIONS(715),
    [anon_sym_NA_complex_] = ACTIONS(715),
    [anon_sym_NA_character_] = ACTIONS(715),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(717),
    [sym__semicolon] = ACTIONS(717),
    [sym__raw_string_open] = ACTIONS(439),
    [sym__external_open_parenthesis] = ACTIONS(719),
    [sym__external_open_brace] = ACTIONS(721),
    [sym__external_close_brace] = ACTIONS(777),
  },
  [352] = {
    [sym_function_definition] = STATE(189),
    [sym_if_statement] = STATE(189),
    [sym_for_statement] = STATE(189),
    [sym_while_statement] = STATE(189),
    [sym_repeat_statement] = STATE(189),
    [sym_braced_expression] = STATE(189),
    [sym_parenthesized_expression] = STATE(189),
    [sym_call] = STATE(189),
    [sym_subset] = STATE(189),
    [sym_subset2] = STATE(189),
    [sym_unary_operator] = STATE(189),
    [sym_binary_operator] = STATE(189),
    [sym_extract_operator] = STATE(189),
    [sym_namespace_operator] = STATE(189),
    [sym_integer] = STATE(189),
    [sym_complex] = STATE(189),
    [sym_float] = STATE(189),
    [sym__float_literal] = STATE(330),
    [sym_string] = STATE(311),
    [sym__raw_string] = STATE(331),
    [sym__single_quoted_string] = STATE(332),
    [sym__double_quoted_string] = STATE(333),
    [sym_na] = STATE(189),
    [sym__expression] = STATE(189),
    [sym__open_parenthesis] = STATE(1070),
    [sym__open_brace] = STATE(384),
    [sym__close_brace] = STATE(1787),
    [aux_sym_braced_expression_repeat1] = STATE(415),
    [sym_identifier] = ACTIONS(687),
    [anon_sym_BSLASH] = ACTIONS(689),
    [anon_sym_function] = ACTIONS(691),
    [anon_sym_if] = ACTIONS(693),
    [anon_sym_for] = ACTIONS(695),
    [anon_sym_while] = ACTIONS(697),
    [anon_sym_repeat] = ACTIONS(699),
    [anon_sym_QMARK] = ACTIONS(701),
    [anon_sym_TILDE] = ACTIONS(703),
    [anon_sym_BANG] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [sym__hex_literal] = ACTIONS(709),
    [sym__number_literal] = ACTIONS(711),
    [anon_sym_SQUOTE] = ACTIONS(435),
    [anon_sym_DQUOTE] = ACTIONS(437),
    [sym_dots] = ACTIONS(687),
    [sym_dot_dot_i] = ACTIONS(687),
    [sym_next] = ACTIONS(713),
    [sym_break] = ACTIONS(713),
    [sym_true] = ACTIONS(713),
    [sym_false] = ACTIONS(713),
    [sym_null] = ACTIONS(713),
    [sym_inf] = ACTIONS(713),
    [sym_nan] = ACTIONS(713),
    [anon_sym_NA] = ACTIONS(715),
    [anon_sym_NA_integer_] = ACTIONS(715),
    [anon_sym_NA_real_] = ACTIONS(715),
    [anon_sym_NA_complex_] = ACTIONS(715),
    [anon_sym_NA_character_] = ACTIONS(715),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(717),
    [sym__semicolon] = ACTIONS(717),
    [sym__raw_string_open] = ACTIONS(439),
    [sym__external_open_parenthesis] = ACTIONS(719),
    [sym__external_open_brace] = ACTIONS(721),
    [sym__external_close_brace] = ACTIONS(779),
  },
  [353] = {
    [aux_sym_function_definition_repeat1] = STATE(353),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_BSLASH] = ACTIONS(671),
    [anon_sym_function] = ACTIONS(669),
    [anon_sym_EQ] = ACTIONS(669),
    [anon_sym_if] = ACTIONS(669),
    [anon_sym_for] = ACTIONS(669),
    [anon_sym_while] = ACTIONS(669),
    [anon_sym_repeat] = ACTIONS(669),
    [anon_sym_QMARK] = ACTIONS(671),
    [anon_sym_TILDE] = ACTIONS(671),
    [anon_sym_BANG] = ACTIONS(669),
    [anon_sym_PLUS] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(669),
    [anon_sym_LT_DASH] = ACTIONS(671),
    [anon_sym_LT_LT_DASH] = ACTIONS(671),
    [anon_sym_COLON_EQ] = ACTIONS(671),
    [anon_sym_DASH_GT] = ACTIONS(669),
    [anon_sym_DASH_GT_GT] = ACTIONS(671),
    [anon_sym_PIPE] = ACTIONS(669),
    [anon_sym_AMP] = ACTIONS(669),
    [anon_sym_PIPE_PIPE] = ACTIONS(671),
    [anon_sym_AMP_AMP] = ACTIONS(671),
    [anon_sym_LT] = ACTIONS(669),
    [anon_sym_LT_EQ] = ACTIONS(671),
    [anon_sym_GT] = ACTIONS(669),
    [anon_sym_GT_EQ] = ACTIONS(671),
    [anon_sym_EQ_EQ] = ACTIONS(671),
    [anon_sym_BANG_EQ] = ACTIONS(671),
    [anon_sym_STAR] = ACTIONS(669),
    [anon_sym_SLASH] = ACTIONS(671),
    [anon_sym_STAR_STAR] = ACTIONS(671),
    [anon_sym_CARET] = ACTIONS(671),
    [aux_sym_binary_operator_token1] = ACTIONS(671),
    [anon_sym_PIPE_GT] = ACTIONS(671),
    [anon_sym_COLON] = ACTIONS(669),
    [anon_sym_DOLLAR] = ACTIONS(671),
    [anon_sym_AT] = ACTIONS(671),
    [sym__hex_literal] = ACTIONS(671),
    [sym__number_literal] = ACTIONS(669),
    [anon_sym_SQUOTE] = ACTIONS(671),
    [anon_sym_DQUOTE] = ACTIONS(671),
    [sym_dots] = ACTIONS(669),
    [sym_dot_dot_i] = ACTIONS(669),
    [sym_next] = ACTIONS(669),
    [sym_break] = ACTIONS(669),
    [sym_true] = ACTIONS(669),
    [sym_false] = ACTIONS(669),
    [sym_null] = ACTIONS(669),
    [sym_inf] = ACTIONS(669),
    [sym_nan] = ACTIONS(669),
    [anon_sym_NA] = ACTIONS(669),
    [anon_sym_NA_integer_] = ACTIONS(669),
    [anon_sym_NA_real_] = ACTIONS(669),
    [anon_sym_NA_complex_] = ACTIONS(669),
    [anon_sym_NA_character_] = ACTIONS(669),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(781),
    [sym__semicolon] = ACTIONS(671),
    [sym__raw_string_open] = ACTIONS(671),
    [sym__external_open_parenthesis] = ACTIONS(671),
    [sym__external_open_brace] = ACTIONS(671),
    [sym__external_close_brace] = ACTIONS(671),
    [sym__external_open_bracket] = ACTIONS(671),
    [sym__external_open_bracket2] = ACTIONS(671),
  },
  [354] = {
    [ts_builtin_sym_end] = ACTIONS(784),
    [sym_identifier] = ACTIONS(786),
    [anon_sym_BSLASH] = ACTIONS(784),
    [anon_sym_function] = ACTIONS(786),
    [anon_sym_EQ] = ACTIONS(786),
    [anon_sym_if] = ACTIONS(786),
    [anon_sym_for] = ACTIONS(786),
    [anon_sym_while] = ACTIONS(786),
    [anon_sym_repeat] = ACTIONS(786),
    [anon_sym_QMARK] = ACTIONS(784),
    [anon_sym_TILDE] = ACTIONS(784),
    [anon_sym_BANG] = ACTIONS(786),
    [anon_sym_PLUS] = ACTIONS(784),
    [anon_sym_DASH] = ACTIONS(786),
    [anon_sym_LT_DASH] = ACTIONS(784),
    [anon_sym_LT_LT_DASH] = ACTIONS(784),
    [anon_sym_COLON_EQ] = ACTIONS(784),
    [anon_sym_DASH_GT] = ACTIONS(786),
    [anon_sym_DASH_GT_GT] = ACTIONS(784),
    [anon_sym_PIPE] = ACTIONS(786),
    [anon_sym_AMP] = ACTIONS(786),
    [anon_sym_PIPE_PIPE] = ACTIONS(784),
    [anon_sym_AMP_AMP] = ACTIONS(784),
    [anon_sym_LT] = ACTIONS(786),
    [anon_sym_LT_EQ] = ACTIONS(784),
    [anon_sym_GT] = ACTIONS(786),
    [anon_sym_GT_EQ] = ACTIONS(784),
    [anon_sym_EQ_EQ] = ACTIONS(784),
    [anon_sym_BANG_EQ] = ACTIONS(784),
    [anon_sym_STAR] = ACTIONS(786),
    [anon_sym_SLASH] = ACTIONS(784),
    [anon_sym_STAR_STAR] = ACTIONS(784),
    [anon_sym_CARET] = ACTIONS(784),
    [aux_sym_binary_operator_token1] = ACTIONS(784),
    [anon_sym_PIPE_GT] = ACTIONS(784),
    [anon_sym_COLON] = ACTIONS(786),
    [anon_sym_DOLLAR] = ACTIONS(784),
    [anon_sym_AT] = ACTIONS(784),
    [sym__hex_literal] = ACTIONS(784),
    [sym__number_literal] = ACTIONS(786),
    [anon_sym_SQUOTE] = ACTIONS(784),
    [anon_sym_DQUOTE] = ACTIONS(784),
    [sym_dots] = ACTIONS(786),
    [sym_dot_dot_i] = ACTIONS(786),
    [sym_next] = ACTIONS(786),
    [sym_break] = ACTIONS(786),
    [sym_true] = ACTIONS(786),
    [sym_false] = ACTIONS(786),
    [sym_null] = ACTIONS(786),
    [sym_inf] = ACTIONS(786),
    [sym_nan] = ACTIONS(786),
    [anon_sym_NA] = ACTIONS(786),
    [anon_sym_NA_integer_] = ACTIONS(786),
    [anon_sym_NA_real_] = ACTIONS(786),
    [anon_sym_NA_complex_] = ACTIONS(786),
    [anon_sym_NA_character_] = ACTIONS(786),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(784),
    [sym__semicolon] = ACTIONS(784),
    [sym__raw_string_open] = ACTIONS(784),
    [sym__external_else] = ACTIONS(784),
    [sym__external_open_parenthesis] = ACTIONS(784),
    [sym__external_open_brace] = ACTIONS(784),
    [sym__external_open_bracket] = ACTIONS(784),
    [sym__external_open_bracket2] = ACTIONS(784),
  },
  [355] = {
    [ts_builtin_sym_end] = ACTIONS(788),
    [sym_identifier] = ACTIONS(790),
    [anon_sym_BSLASH] = ACTIONS(788),
    [anon_sym_function] = ACTIONS(790),
    [anon_sym_EQ] = ACTIONS(790),
    [anon_sym_if] = ACTIONS(790),
    [anon_sym_for] = ACTIONS(790),
    [anon_sym_while] = ACTIONS(790),
    [anon_sym_repeat] = ACTIONS(790),
    [anon_sym_QMARK] = ACTIONS(788),
    [anon_sym_TILDE] = ACTIONS(788),
    [anon_sym_BANG] = ACTIONS(790),
    [anon_sym_PLUS] = ACTIONS(788),
    [anon_sym_DASH] = ACTIONS(790),
    [anon_sym_LT_DASH] = ACTIONS(788),
    [anon_sym_LT_LT_DASH] = ACTIONS(788),
    [anon_sym_COLON_EQ] = ACTIONS(788),
    [anon_sym_DASH_GT] = ACTIONS(790),
    [anon_sym_DASH_GT_GT] = ACTIONS(788),
    [anon_sym_PIPE] = ACTIONS(790),
    [anon_sym_AMP] = ACTIONS(790),
    [anon_sym_PIPE_PIPE] = ACTIONS(788),
    [anon_sym_AMP_AMP] = ACTIONS(788),
    [anon_sym_LT] = ACTIONS(790),
    [anon_sym_LT_EQ] = ACTIONS(788),
    [anon_sym_GT] = ACTIONS(790),
    [anon_sym_GT_EQ] = ACTIONS(788),
    [anon_sym_EQ_EQ] = ACTIONS(788),
    [anon_sym_BANG_EQ] = ACTIONS(788),
    [anon_sym_STAR] = ACTIONS(790),
    [anon_sym_SLASH] = ACTIONS(788),
    [anon_sym_STAR_STAR] = ACTIONS(788),
    [anon_sym_CARET] = ACTIONS(788),
    [aux_sym_binary_operator_token1] = ACTIONS(788),
    [anon_sym_PIPE_GT] = ACTIONS(788),
    [anon_sym_COLON] = ACTIONS(790),
    [anon_sym_DOLLAR] = ACTIONS(788),
    [anon_sym_AT] = ACTIONS(788),
    [sym__hex_literal] = ACTIONS(788),
    [sym__number_literal] = ACTIONS(790),
    [anon_sym_SQUOTE] = ACTIONS(788),
    [anon_sym_DQUOTE] = ACTIONS(788),
    [sym_dots] = ACTIONS(790),
    [sym_dot_dot_i] = ACTIONS(790),
    [sym_next] = ACTIONS(790),
    [sym_break] = ACTIONS(790),
    [sym_true] = ACTIONS(790),
    [sym_false] = ACTIONS(790),
    [sym_null] = ACTIONS(790),
    [sym_inf] = ACTIONS(790),
    [sym_nan] = ACTIONS(790),
    [anon_sym_NA] = ACTIONS(790),
    [anon_sym_NA_integer_] = ACTIONS(790),
    [anon_sym_NA_real_] = ACTIONS(790),
    [anon_sym_NA_complex_] = ACTIONS(790),
    [anon_sym_NA_character_] = ACTIONS(790),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(788),
    [sym__semicolon] = ACTIONS(788),
    [sym__raw_string_open] = ACTIONS(788),
    [sym__external_else] = ACTIONS(788),
    [sym__external_open_parenthesis] = ACTIONS(788),
    [sym__external_open_brace] = ACTIONS(788),
    [sym__external_open_bracket] = ACTIONS(788),
    [sym__external_open_bracket2] = ACTIONS(788),
  },
  [356] = {
    [ts_builtin_sym_end] = ACTIONS(792),
    [sym_identifier] = ACTIONS(794),
    [anon_sym_BSLASH] = ACTIONS(792),
    [anon_sym_function] = ACTIONS(794),
    [anon_sym_EQ] = ACTIONS(794),
    [anon_sym_if] = ACTIONS(794),
    [anon_sym_for] = ACTIONS(794),
    [anon_sym_while] = ACTIONS(794),
    [anon_sym_repeat] = ACTIONS(794),
    [anon_sym_QMARK] = ACTIONS(792),
    [anon_sym_TILDE] = ACTIONS(792),
    [anon_sym_BANG] = ACTIONS(794),
    [anon_sym_PLUS] = ACTIONS(792),
    [anon_sym_DASH] = ACTIONS(794),
    [anon_sym_LT_DASH] = ACTIONS(792),
    [anon_sym_LT_LT_DASH] = ACTIONS(792),
    [anon_sym_COLON_EQ] = ACTIONS(792),
    [anon_sym_DASH_GT] = ACTIONS(794),
    [anon_sym_DASH_GT_GT] = ACTIONS(792),
    [anon_sym_PIPE] = ACTIONS(794),
    [anon_sym_AMP] = ACTIONS(794),
    [anon_sym_PIPE_PIPE] = ACTIONS(792),
    [anon_sym_AMP_AMP] = ACTIONS(792),
    [anon_sym_LT] = ACTIONS(794),
    [anon_sym_LT_EQ] = ACTIONS(792),
    [anon_sym_GT] = ACTIONS(794),
    [anon_sym_GT_EQ] = ACTIONS(792),
    [anon_sym_EQ_EQ] = ACTIONS(792),
    [anon_sym_BANG_EQ] = ACTIONS(792),
    [anon_sym_STAR] = ACTIONS(794),
    [anon_sym_SLASH] = ACTIONS(792),
    [anon_sym_STAR_STAR] = ACTIONS(792),
    [anon_sym_CARET] = ACTIONS(792),
    [aux_sym_binary_operator_token1] = ACTIONS(792),
    [anon_sym_PIPE_GT] = ACTIONS(792),
    [anon_sym_COLON] = ACTIONS(794),
    [anon_sym_DOLLAR] = ACTIONS(792),
    [anon_sym_AT] = ACTIONS(792),
    [sym__hex_literal] = ACTIONS(792),
    [sym__number_literal] = ACTIONS(794),
    [anon_sym_SQUOTE] = ACTIONS(792),
    [anon_sym_DQUOTE] = ACTIONS(792),
    [sym_dots] = ACTIONS(794),
    [sym_dot_dot_i] = ACTIONS(794),
    [sym_next] = ACTIONS(794),
    [sym_break] = ACTIONS(794),
    [sym_true] = ACTIONS(794),
    [sym_false] = ACTIONS(794),
    [sym_null] = ACTIONS(794),
    [sym_inf] = ACTIONS(794),
    [sym_nan] = ACTIONS(794),
    [anon_sym_NA] = ACTIONS(794),
    [anon_sym_NA_integer_] = ACTIONS(794),
    [anon_sym_NA_real_] = ACTIONS(794),
    [anon_sym_NA_complex_] = ACTIONS(794),
    [anon_sym_NA_character_] = ACTIONS(794),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(792),
    [sym__semicolon] = ACTIONS(792),
    [sym__raw_string_open] = ACTIONS(792),
    [sym__external_else] = ACTIONS(792),
    [sym__external_open_parenthesis] = ACTIONS(792),
    [sym__external_open_brace] = ACTIONS(792),
    [sym__external_open_bracket] = ACTIONS(792),
    [sym__external_open_bracket2] = ACTIONS(792),
  },
  [357] = {
    [ts_builtin_sym_end] = ACTIONS(796),
    [sym_identifier] = ACTIONS(798),
    [anon_sym_BSLASH] = ACTIONS(796),
    [anon_sym_function] = ACTIONS(798),
    [anon_sym_EQ] = ACTIONS(798),
    [anon_sym_if] = ACTIONS(798),
    [anon_sym_for] = ACTIONS(798),
    [anon_sym_while] = ACTIONS(798),
    [anon_sym_repeat] = ACTIONS(798),
    [anon_sym_QMARK] = ACTIONS(796),
    [anon_sym_TILDE] = ACTIONS(796),
    [anon_sym_BANG] = ACTIONS(798),
    [anon_sym_PLUS] = ACTIONS(796),
    [anon_sym_DASH] = ACTIONS(798),
    [anon_sym_LT_DASH] = ACTIONS(796),
    [anon_sym_LT_LT_DASH] = ACTIONS(796),
    [anon_sym_COLON_EQ] = ACTIONS(796),
    [anon_sym_DASH_GT] = ACTIONS(798),
    [anon_sym_DASH_GT_GT] = ACTIONS(796),
    [anon_sym_PIPE] = ACTIONS(798),
    [anon_sym_AMP] = ACTIONS(798),
    [anon_sym_PIPE_PIPE] = ACTIONS(796),
    [anon_sym_AMP_AMP] = ACTIONS(796),
    [anon_sym_LT] = ACTIONS(798),
    [anon_sym_LT_EQ] = ACTIONS(796),
    [anon_sym_GT] = ACTIONS(798),
    [anon_sym_GT_EQ] = ACTIONS(796),
    [anon_sym_EQ_EQ] = ACTIONS(796),
    [anon_sym_BANG_EQ] = ACTIONS(796),
    [anon_sym_STAR] = ACTIONS(798),
    [anon_sym_SLASH] = ACTIONS(796),
    [anon_sym_STAR_STAR] = ACTIONS(796),
    [anon_sym_CARET] = ACTIONS(796),
    [aux_sym_binary_operator_token1] = ACTIONS(796),
    [anon_sym_PIPE_GT] = ACTIONS(796),
    [anon_sym_COLON] = ACTIONS(798),
    [anon_sym_DOLLAR] = ACTIONS(796),
    [anon_sym_AT] = ACTIONS(796),
    [sym__hex_literal] = ACTIONS(796),
    [sym__number_literal] = ACTIONS(798),
    [anon_sym_SQUOTE] = ACTIONS(796),
    [anon_sym_DQUOTE] = ACTIONS(796),
    [sym_dots] = ACTIONS(798),
    [sym_dot_dot_i] = ACTIONS(798),
    [sym_next] = ACTIONS(798),
    [sym_break] = ACTIONS(798),
    [sym_true] = ACTIONS(798),
    [sym_false] = ACTIONS(798),
    [sym_null] = ACTIONS(798),
    [sym_inf] = ACTIONS(798),
    [sym_nan] = ACTIONS(798),
    [anon_sym_NA] = ACTIONS(798),
    [anon_sym_NA_integer_] = ACTIONS(798),
    [anon_sym_NA_real_] = ACTIONS(798),
    [anon_sym_NA_complex_] = ACTIONS(798),
    [anon_sym_NA_character_] = ACTIONS(798),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(796),
    [sym__semicolon] = ACTIONS(796),
    [sym__raw_string_open] = ACTIONS(796),
    [sym__external_else] = ACTIONS(796),
    [sym__external_open_parenthesis] = ACTIONS(796),
    [sym__external_open_brace] = ACTIONS(796),
    [sym__external_open_bracket] = ACTIONS(796),
    [sym__external_open_bracket2] = ACTIONS(796),
  },
  [358] = {
    [ts_builtin_sym_end] = ACTIONS(800),
    [sym_identifier] = ACTIONS(802),
    [anon_sym_BSLASH] = ACTIONS(800),
    [anon_sym_function] = ACTIONS(802),
    [anon_sym_EQ] = ACTIONS(802),
    [anon_sym_if] = ACTIONS(802),
    [anon_sym_for] = ACTIONS(802),
    [anon_sym_while] = ACTIONS(802),
    [anon_sym_repeat] = ACTIONS(802),
    [anon_sym_QMARK] = ACTIONS(800),
    [anon_sym_TILDE] = ACTIONS(800),
    [anon_sym_BANG] = ACTIONS(802),
    [anon_sym_PLUS] = ACTIONS(800),
    [anon_sym_DASH] = ACTIONS(802),
    [anon_sym_LT_DASH] = ACTIONS(800),
    [anon_sym_LT_LT_DASH] = ACTIONS(800),
    [anon_sym_COLON_EQ] = ACTIONS(800),
    [anon_sym_DASH_GT] = ACTIONS(802),
    [anon_sym_DASH_GT_GT] = ACTIONS(800),
    [anon_sym_PIPE] = ACTIONS(802),
    [anon_sym_AMP] = ACTIONS(802),
    [anon_sym_PIPE_PIPE] = ACTIONS(800),
    [anon_sym_AMP_AMP] = ACTIONS(800),
    [anon_sym_LT] = ACTIONS(802),
    [anon_sym_LT_EQ] = ACTIONS(800),
    [anon_sym_GT] = ACTIONS(802),
    [anon_sym_GT_EQ] = ACTIONS(800),
    [anon_sym_EQ_EQ] = ACTIONS(800),
    [anon_sym_BANG_EQ] = ACTIONS(800),
    [anon_sym_STAR] = ACTIONS(802),
    [anon_sym_SLASH] = ACTIONS(800),
    [anon_sym_STAR_STAR] = ACTIONS(800),
    [anon_sym_CARET] = ACTIONS(800),
    [aux_sym_binary_operator_token1] = ACTIONS(800),
    [anon_sym_PIPE_GT] = ACTIONS(800),
    [anon_sym_COLON] = ACTIONS(802),
    [anon_sym_DOLLAR] = ACTIONS(800),
    [anon_sym_AT] = ACTIONS(800),
    [sym__hex_literal] = ACTIONS(800),
    [sym__number_literal] = ACTIONS(802),
    [anon_sym_SQUOTE] = ACTIONS(800),
    [anon_sym_DQUOTE] = ACTIONS(800),
    [sym_dots] = ACTIONS(802),
    [sym_dot_dot_i] = ACTIONS(802),
    [sym_next] = ACTIONS(802),
    [sym_break] = ACTIONS(802),
    [sym_true] = ACTIONS(802),
    [sym_false] = ACTIONS(802),
    [sym_null] = ACTIONS(802),
    [sym_inf] = ACTIONS(802),
    [sym_nan] = ACTIONS(802),
    [anon_sym_NA] = ACTIONS(802),
    [anon_sym_NA_integer_] = ACTIONS(802),
    [anon_sym_NA_real_] = ACTIONS(802),
    [anon_sym_NA_complex_] = ACTIONS(802),
    [anon_sym_NA_character_] = ACTIONS(802),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(800),
    [sym__semicolon] = ACTIONS(800),
    [sym__raw_string_open] = ACTIONS(800),
    [sym__external_else] = ACTIONS(800),
    [sym__external_open_parenthesis] = ACTIONS(800),
    [sym__external_open_brace] = ACTIONS(800),
    [sym__external_open_bracket] = ACTIONS(800),
    [sym__external_open_bracket2] = ACTIONS(800),
  },
  [359] = {
    [sym_identifier] = ACTIONS(739),
    [anon_sym_BSLASH] = ACTIONS(737),
    [anon_sym_function] = ACTIONS(739),
    [anon_sym_EQ] = ACTIONS(739),
    [anon_sym_if] = ACTIONS(739),
    [anon_sym_for] = ACTIONS(739),
    [anon_sym_while] = ACTIONS(739),
    [anon_sym_repeat] = ACTIONS(739),
    [anon_sym_QMARK] = ACTIONS(737),
    [anon_sym_TILDE] = ACTIONS(737),
    [anon_sym_BANG] = ACTIONS(739),
    [anon_sym_PLUS] = ACTIONS(737),
    [anon_sym_DASH] = ACTIONS(739),
    [anon_sym_LT_DASH] = ACTIONS(737),
    [anon_sym_LT_LT_DASH] = ACTIONS(737),
    [anon_sym_COLON_EQ] = ACTIONS(737),
    [anon_sym_DASH_GT] = ACTIONS(739),
    [anon_sym_DASH_GT_GT] = ACTIONS(737),
    [anon_sym_PIPE] = ACTIONS(739),
    [anon_sym_AMP] = ACTIONS(739),
    [anon_sym_PIPE_PIPE] = ACTIONS(737),
    [anon_sym_AMP_AMP] = ACTIONS(737),
    [anon_sym_LT] = ACTIONS(739),
    [anon_sym_LT_EQ] = ACTIONS(737),
    [anon_sym_GT] = ACTIONS(739),
    [anon_sym_GT_EQ] = ACTIONS(737),
    [anon_sym_EQ_EQ] = ACTIONS(737),
    [anon_sym_BANG_EQ] = ACTIONS(737),
    [anon_sym_STAR] = ACTIONS(739),
    [anon_sym_SLASH] = ACTIONS(737),
    [anon_sym_STAR_STAR] = ACTIONS(737),
    [anon_sym_CARET] = ACTIONS(737),
    [aux_sym_binary_operator_token1] = ACTIONS(737),
    [anon_sym_PIPE_GT] = ACTIONS(737),
    [anon_sym_COLON] = ACTIONS(739),
    [anon_sym_DOLLAR] = ACTIONS(737),
    [anon_sym_AT] = ACTIONS(737),
    [sym__hex_literal] = ACTIONS(737),
    [sym__number_literal] = ACTIONS(739),
    [anon_sym_SQUOTE] = ACTIONS(737),
    [anon_sym_DQUOTE] = ACTIONS(737),
    [sym_dots] = ACTIONS(739),
    [sym_dot_dot_i] = ACTIONS(739),
    [sym_next] = ACTIONS(739),
    [sym_break] = ACTIONS(739),
    [sym_true] = ACTIONS(739),
    [sym_false] = ACTIONS(739),
    [sym_null] = ACTIONS(739),
    [sym_inf] = ACTIONS(739),
    [sym_nan] = ACTIONS(739),
    [anon_sym_NA] = ACTIONS(739),
    [anon_sym_NA_integer_] = ACTIONS(739),
    [anon_sym_NA_real_] = ACTIONS(739),
    [anon_sym_NA_complex_] = ACTIONS(739),
    [anon_sym_NA_character_] = ACTIONS(739),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(737),
    [sym__semicolon] = ACTIONS(737),
    [sym__raw_string_open] = ACTIONS(737),
    [sym__external_else] = ACTIONS(737),
    [sym__external_open_parenthesis] = ACTIONS(737),
    [sym__external_open_brace] = ACTIONS(737),
    [sym__external_close_brace] = ACTIONS(737),
    [sym__external_open_bracket] = ACTIONS(737),
    [sym__external_open_bracket2] = ACTIONS(737),
  },
  [360] = {
    [sym_identifier] = ACTIONS(767),
    [anon_sym_BSLASH] = ACTIONS(765),
    [anon_sym_function] = ACTIONS(767),
    [anon_sym_EQ] = ACTIONS(767),
    [anon_sym_if] = ACTIONS(767),
    [anon_sym_for] = ACTIONS(767),
    [anon_sym_while] = ACTIONS(767),
    [anon_sym_repeat] = ACTIONS(767),
    [anon_sym_QMARK] = ACTIONS(765),
    [anon_sym_TILDE] = ACTIONS(765),
    [anon_sym_BANG] = ACTIONS(767),
    [anon_sym_PLUS] = ACTIONS(765),
    [anon_sym_DASH] = ACTIONS(767),
    [anon_sym_LT_DASH] = ACTIONS(765),
    [anon_sym_LT_LT_DASH] = ACTIONS(765),
    [anon_sym_COLON_EQ] = ACTIONS(765),
    [anon_sym_DASH_GT] = ACTIONS(767),
    [anon_sym_DASH_GT_GT] = ACTIONS(765),
    [anon_sym_PIPE] = ACTIONS(767),
    [anon_sym_AMP] = ACTIONS(767),
    [anon_sym_PIPE_PIPE] = ACTIONS(765),
    [anon_sym_AMP_AMP] = ACTIONS(765),
    [anon_sym_LT] = ACTIONS(767),
    [anon_sym_LT_EQ] = ACTIONS(765),
    [anon_sym_GT] = ACTIONS(767),
    [anon_sym_GT_EQ] = ACTIONS(765),
    [anon_sym_EQ_EQ] = ACTIONS(765),
    [anon_sym_BANG_EQ] = ACTIONS(765),
    [anon_sym_STAR] = ACTIONS(767),
    [anon_sym_SLASH] = ACTIONS(765),
    [anon_sym_STAR_STAR] = ACTIONS(765),
    [anon_sym_CARET] = ACTIONS(765),
    [aux_sym_binary_operator_token1] = ACTIONS(765),
    [anon_sym_PIPE_GT] = ACTIONS(765),
    [anon_sym_COLON] = ACTIONS(767),
    [anon_sym_DOLLAR] = ACTIONS(765),
    [anon_sym_AT] = ACTIONS(765),
    [sym__hex_literal] = ACTIONS(765),
    [sym__number_literal] = ACTIONS(767),
    [anon_sym_SQUOTE] = ACTIONS(765),
    [anon_sym_DQUOTE] = ACTIONS(765),
    [sym_dots] = ACTIONS(767),
    [sym_dot_dot_i] = ACTIONS(767),
    [sym_next] = ACTIONS(767),
    [sym_break] = ACTIONS(767),
    [sym_true] = ACTIONS(767),
    [sym_false] = ACTIONS(767),
    [sym_null] = ACTIONS(767),
    [sym_inf] = ACTIONS(767),
    [sym_nan] = ACTIONS(767),
    [anon_sym_NA] = ACTIONS(767),
    [anon_sym_NA_integer_] = ACTIONS(767),
    [anon_sym_NA_real_] = ACTIONS(767),
    [anon_sym_NA_complex_] = ACTIONS(767),
    [anon_sym_NA_character_] = ACTIONS(767),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(765),
    [sym__semicolon] = ACTIONS(765),
    [sym__raw_string_open] = ACTIONS(765),
    [sym__external_else] = ACTIONS(765),
    [sym__external_open_parenthesis] = ACTIONS(765),
    [sym__external_open_brace] = ACTIONS(765),
    [sym__external_close_brace] = ACTIONS(765),
    [sym__external_open_bracket] = ACTIONS(765),
    [sym__external_open_bracket2] = ACTIONS(765),
  },
  [361] = {
    [sym_identifier] = ACTIONS(771),
    [anon_sym_BSLASH] = ACTIONS(769),
    [anon_sym_function] = ACTIONS(771),
    [anon_sym_EQ] = ACTIONS(771),
    [anon_sym_if] = ACTIONS(771),
    [anon_sym_for] = ACTIONS(771),
    [anon_sym_while] = ACTIONS(771),
    [anon_sym_repeat] = ACTIONS(771),
    [anon_sym_QMARK] = ACTIONS(769),
    [anon_sym_TILDE] = ACTIONS(769),
    [anon_sym_BANG] = ACTIONS(771),
    [anon_sym_PLUS] = ACTIONS(769),
    [anon_sym_DASH] = ACTIONS(771),
    [anon_sym_LT_DASH] = ACTIONS(769),
    [anon_sym_LT_LT_DASH] = ACTIONS(769),
    [anon_sym_COLON_EQ] = ACTIONS(769),
    [anon_sym_DASH_GT] = ACTIONS(771),
    [anon_sym_DASH_GT_GT] = ACTIONS(769),
    [anon_sym_PIPE] = ACTIONS(771),
    [anon_sym_AMP] = ACTIONS(771),
    [anon_sym_PIPE_PIPE] = ACTIONS(769),
    [anon_sym_AMP_AMP] = ACTIONS(769),
    [anon_sym_LT] = ACTIONS(771),
    [anon_sym_LT_EQ] = ACTIONS(769),
    [anon_sym_GT] = ACTIONS(771),
    [anon_sym_GT_EQ] = ACTIONS(769),
    [anon_sym_EQ_EQ] = ACTIONS(769),
    [anon_sym_BANG_EQ] = ACTIONS(769),
    [anon_sym_STAR] = ACTIONS(771),
    [anon_sym_SLASH] = ACTIONS(769),
    [anon_sym_STAR_STAR] = ACTIONS(769),
    [anon_sym_CARET] = ACTIONS(769),
    [aux_sym_binary_operator_token1] = ACTIONS(769),
    [anon_sym_PIPE_GT] = ACTIONS(769),
    [anon_sym_COLON] = ACTIONS(771),
    [anon_sym_DOLLAR] = ACTIONS(769),
    [anon_sym_AT] = ACTIONS(769),
    [sym__hex_literal] = ACTIONS(769),
    [sym__number_literal] = ACTIONS(771),
    [anon_sym_SQUOTE] = ACTIONS(769),
    [anon_sym_DQUOTE] = ACTIONS(769),
    [sym_dots] = ACTIONS(771),
    [sym_dot_dot_i] = ACTIONS(771),
    [sym_next] = ACTIONS(771),
    [sym_break] = ACTIONS(771),
    [sym_true] = ACTIONS(771),
    [sym_false] = ACTIONS(771),
    [sym_null] = ACTIONS(771),
    [sym_inf] = ACTIONS(771),
    [sym_nan] = ACTIONS(771),
    [anon_sym_NA] = ACTIONS(771),
    [anon_sym_NA_integer_] = ACTIONS(771),
    [anon_sym_NA_real_] = ACTIONS(771),
    [anon_sym_NA_complex_] = ACTIONS(771),
    [anon_sym_NA_character_] = ACTIONS(771),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(769),
    [sym__semicolon] = ACTIONS(769),
    [sym__raw_string_open] = ACTIONS(769),
    [sym__external_else] = ACTIONS(769),
    [sym__external_open_parenthesis] = ACTIONS(769),
    [sym__external_open_brace] = ACTIONS(769),
    [sym__external_close_brace] = ACTIONS(769),
    [sym__external_open_bracket] = ACTIONS(769),
    [sym__external_open_bracket2] = ACTIONS(769),
  },
  [362] = {
    [sym_identifier] = ACTIONS(775),
    [anon_sym_BSLASH] = ACTIONS(773),
    [anon_sym_function] = ACTIONS(775),
    [anon_sym_EQ] = ACTIONS(775),
    [anon_sym_if] = ACTIONS(775),
    [anon_sym_for] = ACTIONS(775),
    [anon_sym_while] = ACTIONS(775),
    [anon_sym_repeat] = ACTIONS(775),
    [anon_sym_QMARK] = ACTIONS(773),
    [anon_sym_TILDE] = ACTIONS(773),
    [anon_sym_BANG] = ACTIONS(775),
    [anon_sym_PLUS] = ACTIONS(773),
    [anon_sym_DASH] = ACTIONS(775),
    [anon_sym_LT_DASH] = ACTIONS(773),
    [anon_sym_LT_LT_DASH] = ACTIONS(773),
    [anon_sym_COLON_EQ] = ACTIONS(773),
    [anon_sym_DASH_GT] = ACTIONS(775),
    [anon_sym_DASH_GT_GT] = ACTIONS(773),
    [anon_sym_PIPE] = ACTIONS(775),
    [anon_sym_AMP] = ACTIONS(775),
    [anon_sym_PIPE_PIPE] = ACTIONS(773),
    [anon_sym_AMP_AMP] = ACTIONS(773),
    [anon_sym_LT] = ACTIONS(775),
    [anon_sym_LT_EQ] = ACTIONS(773),
    [anon_sym_GT] = ACTIONS(775),
    [anon_sym_GT_EQ] = ACTIONS(773),
    [anon_sym_EQ_EQ] = ACTIONS(773),
    [anon_sym_BANG_EQ] = ACTIONS(773),
    [anon_sym_STAR] = ACTIONS(775),
    [anon_sym_SLASH] = ACTIONS(773),
    [anon_sym_STAR_STAR] = ACTIONS(773),
    [anon_sym_CARET] = ACTIONS(773),
    [aux_sym_binary_operator_token1] = ACTIONS(773),
    [anon_sym_PIPE_GT] = ACTIONS(773),
    [anon_sym_COLON] = ACTIONS(775),
    [anon_sym_DOLLAR] = ACTIONS(773),
    [anon_sym_AT] = ACTIONS(773),
    [sym__hex_literal] = ACTIONS(773),
    [sym__number_literal] = ACTIONS(775),
    [anon_sym_SQUOTE] = ACTIONS(773),
    [anon_sym_DQUOTE] = ACTIONS(773),
    [sym_dots] = ACTIONS(775),
    [sym_dot_dot_i] = ACTIONS(775),
    [sym_next] = ACTIONS(775),
    [sym_break] = ACTIONS(775),
    [sym_true] = ACTIONS(775),
    [sym_false] = ACTIONS(775),
    [sym_null] = ACTIONS(775),
    [sym_inf] = ACTIONS(775),
    [sym_nan] = ACTIONS(775),
    [anon_sym_NA] = ACTIONS(775),
    [anon_sym_NA_integer_] = ACTIONS(775),
    [anon_sym_NA_real_] = ACTIONS(775),
    [anon_sym_NA_complex_] = ACTIONS(775),
    [anon_sym_NA_character_] = ACTIONS(775),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(773),
    [sym__semicolon] = ACTIONS(773),
    [sym__raw_string_open] = ACTIONS(773),
    [sym__external_else] = ACTIONS(773),
    [sym__external_open_parenthesis] = ACTIONS(773),
    [sym__external_open_brace] = ACTIONS(773),
    [sym__external_close_brace] = ACTIONS(773),
    [sym__external_open_bracket] = ACTIONS(773),
    [sym__external_open_bracket2] = ACTIONS(773),
  },
  [363] = {
    [sym_identifier] = ACTIONS(786),
    [anon_sym_BSLASH] = ACTIONS(784),
    [anon_sym_function] = ACTIONS(786),
    [anon_sym_EQ] = ACTIONS(786),
    [anon_sym_if] = ACTIONS(786),
    [anon_sym_for] = ACTIONS(786),
    [anon_sym_while] = ACTIONS(786),
    [anon_sym_repeat] = ACTIONS(786),
    [anon_sym_QMARK] = ACTIONS(784),
    [anon_sym_TILDE] = ACTIONS(784),
    [anon_sym_BANG] = ACTIONS(786),
    [anon_sym_PLUS] = ACTIONS(784),
    [anon_sym_DASH] = ACTIONS(786),
    [anon_sym_LT_DASH] = ACTIONS(784),
    [anon_sym_LT_LT_DASH] = ACTIONS(784),
    [anon_sym_COLON_EQ] = ACTIONS(784),
    [anon_sym_DASH_GT] = ACTIONS(786),
    [anon_sym_DASH_GT_GT] = ACTIONS(784),
    [anon_sym_PIPE] = ACTIONS(786),
    [anon_sym_AMP] = ACTIONS(786),
    [anon_sym_PIPE_PIPE] = ACTIONS(784),
    [anon_sym_AMP_AMP] = ACTIONS(784),
    [anon_sym_LT] = ACTIONS(786),
    [anon_sym_LT_EQ] = ACTIONS(784),
    [anon_sym_GT] = ACTIONS(786),
    [anon_sym_GT_EQ] = ACTIONS(784),
    [anon_sym_EQ_EQ] = ACTIONS(784),
    [anon_sym_BANG_EQ] = ACTIONS(784),
    [anon_sym_STAR] = ACTIONS(786),
    [anon_sym_SLASH] = ACTIONS(784),
    [anon_sym_STAR_STAR] = ACTIONS(784),
    [anon_sym_CARET] = ACTIONS(784),
    [aux_sym_binary_operator_token1] = ACTIONS(784),
    [anon_sym_PIPE_GT] = ACTIONS(784),
    [anon_sym_COLON] = ACTIONS(786),
    [anon_sym_DOLLAR] = ACTIONS(784),
    [anon_sym_AT] = ACTIONS(784),
    [sym__hex_literal] = ACTIONS(784),
    [sym__number_literal] = ACTIONS(786),
    [anon_sym_SQUOTE] = ACTIONS(784),
    [anon_sym_DQUOTE] = ACTIONS(784),
    [sym_dots] = ACTIONS(786),
    [sym_dot_dot_i] = ACTIONS(786),
    [sym_next] = ACTIONS(786),
    [sym_break] = ACTIONS(786),
    [sym_true] = ACTIONS(786),
    [sym_false] = ACTIONS(786),
    [sym_null] = ACTIONS(786),
    [sym_inf] = ACTIONS(786),
    [sym_nan] = ACTIONS(786),
    [anon_sym_NA] = ACTIONS(786),
    [anon_sym_NA_integer_] = ACTIONS(786),
    [anon_sym_NA_real_] = ACTIONS(786),
    [anon_sym_NA_complex_] = ACTIONS(786),
    [anon_sym_NA_character_] = ACTIONS(786),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(784),
    [sym__semicolon] = ACTIONS(784),
    [sym__raw_string_open] = ACTIONS(784),
    [sym__external_else] = ACTIONS(784),
    [sym__external_open_parenthesis] = ACTIONS(784),
    [sym__external_open_brace] = ACTIONS(784),
    [sym__external_close_brace] = ACTIONS(784),
    [sym__external_open_bracket] = ACTIONS(784),
    [sym__external_open_bracket2] = ACTIONS(784),
  },
  [364] = {
    [sym_identifier] = ACTIONS(794),
    [anon_sym_BSLASH] = ACTIONS(792),
    [anon_sym_function] = ACTIONS(794),
    [anon_sym_EQ] = ACTIONS(794),
    [anon_sym_if] = ACTIONS(794),
    [anon_sym_for] = ACTIONS(794),
    [anon_sym_while] = ACTIONS(794),
    [anon_sym_repeat] = ACTIONS(794),
    [anon_sym_QMARK] = ACTIONS(792),
    [anon_sym_TILDE] = ACTIONS(792),
    [anon_sym_BANG] = ACTIONS(794),
    [anon_sym_PLUS] = ACTIONS(792),
    [anon_sym_DASH] = ACTIONS(794),
    [anon_sym_LT_DASH] = ACTIONS(792),
    [anon_sym_LT_LT_DASH] = ACTIONS(792),
    [anon_sym_COLON_EQ] = ACTIONS(792),
    [anon_sym_DASH_GT] = ACTIONS(794),
    [anon_sym_DASH_GT_GT] = ACTIONS(792),
    [anon_sym_PIPE] = ACTIONS(794),
    [anon_sym_AMP] = ACTIONS(794),
    [anon_sym_PIPE_PIPE] = ACTIONS(792),
    [anon_sym_AMP_AMP] = ACTIONS(792),
    [anon_sym_LT] = ACTIONS(794),
    [anon_sym_LT_EQ] = ACTIONS(792),
    [anon_sym_GT] = ACTIONS(794),
    [anon_sym_GT_EQ] = ACTIONS(792),
    [anon_sym_EQ_EQ] = ACTIONS(792),
    [anon_sym_BANG_EQ] = ACTIONS(792),
    [anon_sym_STAR] = ACTIONS(794),
    [anon_sym_SLASH] = ACTIONS(792),
    [anon_sym_STAR_STAR] = ACTIONS(792),
    [anon_sym_CARET] = ACTIONS(792),
    [aux_sym_binary_operator_token1] = ACTIONS(792),
    [anon_sym_PIPE_GT] = ACTIONS(792),
    [anon_sym_COLON] = ACTIONS(794),
    [anon_sym_DOLLAR] = ACTIONS(792),
    [anon_sym_AT] = ACTIONS(792),
    [sym__hex_literal] = ACTIONS(792),
    [sym__number_literal] = ACTIONS(794),
    [anon_sym_SQUOTE] = ACTIONS(792),
    [anon_sym_DQUOTE] = ACTIONS(792),
    [sym_dots] = ACTIONS(794),
    [sym_dot_dot_i] = ACTIONS(794),
    [sym_next] = ACTIONS(794),
    [sym_break] = ACTIONS(794),
    [sym_true] = ACTIONS(794),
    [sym_false] = ACTIONS(794),
    [sym_null] = ACTIONS(794),
    [sym_inf] = ACTIONS(794),
    [sym_nan] = ACTIONS(794),
    [anon_sym_NA] = ACTIONS(794),
    [anon_sym_NA_integer_] = ACTIONS(794),
    [anon_sym_NA_real_] = ACTIONS(794),
    [anon_sym_NA_complex_] = ACTIONS(794),
    [anon_sym_NA_character_] = ACTIONS(794),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(792),
    [sym__semicolon] = ACTIONS(792),
    [sym__raw_string_open] = ACTIONS(792),
    [sym__external_else] = ACTIONS(792),
    [sym__external_open_parenthesis] = ACTIONS(792),
    [sym__external_open_brace] = ACTIONS(792),
    [sym__external_close_brace] = ACTIONS(792),
    [sym__external_open_bracket] = ACTIONS(792),
    [sym__external_open_bracket2] = ACTIONS(792),
  },
  [365] = {
    [sym_identifier] = ACTIONS(798),
    [anon_sym_BSLASH] = ACTIONS(796),
    [anon_sym_function] = ACTIONS(798),
    [anon_sym_EQ] = ACTIONS(798),
    [anon_sym_if] = ACTIONS(798),
    [anon_sym_for] = ACTIONS(798),
    [anon_sym_while] = ACTIONS(798),
    [anon_sym_repeat] = ACTIONS(798),
    [anon_sym_QMARK] = ACTIONS(796),
    [anon_sym_TILDE] = ACTIONS(796),
    [anon_sym_BANG] = ACTIONS(798),
    [anon_sym_PLUS] = ACTIONS(796),
    [anon_sym_DASH] = ACTIONS(798),
    [anon_sym_LT_DASH] = ACTIONS(796),
    [anon_sym_LT_LT_DASH] = ACTIONS(796),
    [anon_sym_COLON_EQ] = ACTIONS(796),
    [anon_sym_DASH_GT] = ACTIONS(798),
    [anon_sym_DASH_GT_GT] = ACTIONS(796),
    [anon_sym_PIPE] = ACTIONS(798),
    [anon_sym_AMP] = ACTIONS(798),
    [anon_sym_PIPE_PIPE] = ACTIONS(796),
    [anon_sym_AMP_AMP] = ACTIONS(796),
    [anon_sym_LT] = ACTIONS(798),
    [anon_sym_LT_EQ] = ACTIONS(796),
    [anon_sym_GT] = ACTIONS(798),
    [anon_sym_GT_EQ] = ACTIONS(796),
    [anon_sym_EQ_EQ] = ACTIONS(796),
    [anon_sym_BANG_EQ] = ACTIONS(796),
    [anon_sym_STAR] = ACTIONS(798),
    [anon_sym_SLASH] = ACTIONS(796),
    [anon_sym_STAR_STAR] = ACTIONS(796),
    [anon_sym_CARET] = ACTIONS(796),
    [aux_sym_binary_operator_token1] = ACTIONS(796),
    [anon_sym_PIPE_GT] = ACTIONS(796),
    [anon_sym_COLON] = ACTIONS(798),
    [anon_sym_DOLLAR] = ACTIONS(796),
    [anon_sym_AT] = ACTIONS(796),
    [sym__hex_literal] = ACTIONS(796),
    [sym__number_literal] = ACTIONS(798),
    [anon_sym_SQUOTE] = ACTIONS(796),
    [anon_sym_DQUOTE] = ACTIONS(796),
    [sym_dots] = ACTIONS(798),
    [sym_dot_dot_i] = ACTIONS(798),
    [sym_next] = ACTIONS(798),
    [sym_break] = ACTIONS(798),
    [sym_true] = ACTIONS(798),
    [sym_false] = ACTIONS(798),
    [sym_null] = ACTIONS(798),
    [sym_inf] = ACTIONS(798),
    [sym_nan] = ACTIONS(798),
    [anon_sym_NA] = ACTIONS(798),
    [anon_sym_NA_integer_] = ACTIONS(798),
    [anon_sym_NA_real_] = ACTIONS(798),
    [anon_sym_NA_complex_] = ACTIONS(798),
    [anon_sym_NA_character_] = ACTIONS(798),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(796),
    [sym__semicolon] = ACTIONS(796),
    [sym__raw_string_open] = ACTIONS(796),
    [sym__external_else] = ACTIONS(796),
    [sym__external_open_parenthesis] = ACTIONS(796),
    [sym__external_open_brace] = ACTIONS(796),
    [sym__external_close_brace] = ACTIONS(796),
    [sym__external_open_bracket] = ACTIONS(796),
    [sym__external_open_bracket2] = ACTIONS(796),
  },
  [366] = {
    [ts_builtin_sym_end] = ACTIONS(804),
    [sym_identifier] = ACTIONS(806),
    [anon_sym_BSLASH] = ACTIONS(804),
    [anon_sym_function] = ACTIONS(806),
    [anon_sym_EQ] = ACTIONS(806),
    [anon_sym_if] = ACTIONS(806),
    [anon_sym_for] = ACTIONS(806),
    [anon_sym_while] = ACTIONS(806),
    [anon_sym_repeat] = ACTIONS(806),
    [anon_sym_QMARK] = ACTIONS(804),
    [anon_sym_TILDE] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(806),
    [anon_sym_PLUS] = ACTIONS(804),
    [anon_sym_DASH] = ACTIONS(806),
    [anon_sym_LT_DASH] = ACTIONS(804),
    [anon_sym_LT_LT_DASH] = ACTIONS(804),
    [anon_sym_COLON_EQ] = ACTIONS(804),
    [anon_sym_DASH_GT] = ACTIONS(806),
    [anon_sym_DASH_GT_GT] = ACTIONS(804),
    [anon_sym_PIPE] = ACTIONS(806),
    [anon_sym_AMP] = ACTIONS(806),
    [anon_sym_PIPE_PIPE] = ACTIONS(804),
    [anon_sym_AMP_AMP] = ACTIONS(804),
    [anon_sym_LT] = ACTIONS(806),
    [anon_sym_LT_EQ] = ACTIONS(804),
    [anon_sym_GT] = ACTIONS(806),
    [anon_sym_GT_EQ] = ACTIONS(804),
    [anon_sym_EQ_EQ] = ACTIONS(804),
    [anon_sym_BANG_EQ] = ACTIONS(804),
    [anon_sym_STAR] = ACTIONS(806),
    [anon_sym_SLASH] = ACTIONS(804),
    [anon_sym_STAR_STAR] = ACTIONS(804),
    [anon_sym_CARET] = ACTIONS(804),
    [aux_sym_binary_operator_token1] = ACTIONS(804),
    [anon_sym_PIPE_GT] = ACTIONS(804),
    [anon_sym_COLON] = ACTIONS(806),
    [anon_sym_DOLLAR] = ACTIONS(804),
    [anon_sym_AT] = ACTIONS(804),
    [sym__hex_literal] = ACTIONS(804),
    [sym__number_literal] = ACTIONS(806),
    [anon_sym_SQUOTE] = ACTIONS(804),
    [anon_sym_DQUOTE] = ACTIONS(804),
    [sym_dots] = ACTIONS(806),
    [sym_dot_dot_i] = ACTIONS(806),
    [sym_next] = ACTIONS(806),
    [sym_break] = ACTIONS(806),
    [sym_true] = ACTIONS(806),
    [sym_false] = ACTIONS(806),
    [sym_null] = ACTIONS(806),
    [sym_inf] = ACTIONS(806),
    [sym_nan] = ACTIONS(806),
    [anon_sym_NA] = ACTIONS(806),
    [anon_sym_NA_integer_] = ACTIONS(806),
    [anon_sym_NA_real_] = ACTIONS(806),
    [anon_sym_NA_complex_] = ACTIONS(806),
    [anon_sym_NA_character_] = ACTIONS(806),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(804),
    [sym__semicolon] = ACTIONS(804),
    [sym__raw_string_open] = ACTIONS(804),
    [sym__external_else] = ACTIONS(804),
    [sym__external_open_parenthesis] = ACTIONS(804),
    [sym__external_open_brace] = ACTIONS(804),
    [sym__external_open_bracket] = ACTIONS(804),
    [sym__external_open_bracket2] = ACTIONS(804),
  },
  [367] = {
    [sym_identifier] = ACTIONS(802),
    [anon_sym_BSLASH] = ACTIONS(800),
    [anon_sym_function] = ACTIONS(802),
    [anon_sym_EQ] = ACTIONS(802),
    [anon_sym_if] = ACTIONS(802),
    [anon_sym_for] = ACTIONS(802),
    [anon_sym_while] = ACTIONS(802),
    [anon_sym_repeat] = ACTIONS(802),
    [anon_sym_QMARK] = ACTIONS(800),
    [anon_sym_TILDE] = ACTIONS(800),
    [anon_sym_BANG] = ACTIONS(802),
    [anon_sym_PLUS] = ACTIONS(800),
    [anon_sym_DASH] = ACTIONS(802),
    [anon_sym_LT_DASH] = ACTIONS(800),
    [anon_sym_LT_LT_DASH] = ACTIONS(800),
    [anon_sym_COLON_EQ] = ACTIONS(800),
    [anon_sym_DASH_GT] = ACTIONS(802),
    [anon_sym_DASH_GT_GT] = ACTIONS(800),
    [anon_sym_PIPE] = ACTIONS(802),
    [anon_sym_AMP] = ACTIONS(802),
    [anon_sym_PIPE_PIPE] = ACTIONS(800),
    [anon_sym_AMP_AMP] = ACTIONS(800),
    [anon_sym_LT] = ACTIONS(802),
    [anon_sym_LT_EQ] = ACTIONS(800),
    [anon_sym_GT] = ACTIONS(802),
    [anon_sym_GT_EQ] = ACTIONS(800),
    [anon_sym_EQ_EQ] = ACTIONS(800),
    [anon_sym_BANG_EQ] = ACTIONS(800),
    [anon_sym_STAR] = ACTIONS(802),
    [anon_sym_SLASH] = ACTIONS(800),
    [anon_sym_STAR_STAR] = ACTIONS(800),
    [anon_sym_CARET] = ACTIONS(800),
    [aux_sym_binary_operator_token1] = ACTIONS(800),
    [anon_sym_PIPE_GT] = ACTIONS(800),
    [anon_sym_COLON] = ACTIONS(802),
    [anon_sym_DOLLAR] = ACTIONS(800),
    [anon_sym_AT] = ACTIONS(800),
    [sym__hex_literal] = ACTIONS(800),
    [sym__number_literal] = ACTIONS(802),
    [anon_sym_SQUOTE] = ACTIONS(800),
    [anon_sym_DQUOTE] = ACTIONS(800),
    [sym_dots] = ACTIONS(802),
    [sym_dot_dot_i] = ACTIONS(802),
    [sym_next] = ACTIONS(802),
    [sym_break] = ACTIONS(802),
    [sym_true] = ACTIONS(802),
    [sym_false] = ACTIONS(802),
    [sym_null] = ACTIONS(802),
    [sym_inf] = ACTIONS(802),
    [sym_nan] = ACTIONS(802),
    [anon_sym_NA] = ACTIONS(802),
    [anon_sym_NA_integer_] = ACTIONS(802),
    [anon_sym_NA_real_] = ACTIONS(802),
    [anon_sym_NA_complex_] = ACTIONS(802),
    [anon_sym_NA_character_] = ACTIONS(802),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(800),
    [sym__semicolon] = ACTIONS(800),
    [sym__raw_string_open] = ACTIONS(800),
    [sym__external_else] = ACTIONS(800),
    [sym__external_open_parenthesis] = ACTIONS(800),
    [sym__external_open_brace] = ACTIONS(800),
    [sym__external_close_brace] = ACTIONS(800),
    [sym__external_open_bracket] = ACTIONS(800),
    [sym__external_open_bracket2] = ACTIONS(800),
  },
  [368] = {
    [sym_identifier] = ACTIONS(806),
    [anon_sym_BSLASH] = ACTIONS(804),
    [anon_sym_function] = ACTIONS(806),
    [anon_sym_EQ] = ACTIONS(806),
    [anon_sym_if] = ACTIONS(806),
    [anon_sym_for] = ACTIONS(806),
    [anon_sym_while] = ACTIONS(806),
    [anon_sym_repeat] = ACTIONS(806),
    [anon_sym_QMARK] = ACTIONS(804),
    [anon_sym_TILDE] = ACTIONS(804),
    [anon_sym_BANG] = ACTIONS(806),
    [anon_sym_PLUS] = ACTIONS(804),
    [anon_sym_DASH] = ACTIONS(806),
    [anon_sym_LT_DASH] = ACTIONS(804),
    [anon_sym_LT_LT_DASH] = ACTIONS(804),
    [anon_sym_COLON_EQ] = ACTIONS(804),
    [anon_sym_DASH_GT] = ACTIONS(806),
    [anon_sym_DASH_GT_GT] = ACTIONS(804),
    [anon_sym_PIPE] = ACTIONS(806),
    [anon_sym_AMP] = ACTIONS(806),
    [anon_sym_PIPE_PIPE] = ACTIONS(804),
    [anon_sym_AMP_AMP] = ACTIONS(804),
    [anon_sym_LT] = ACTIONS(806),
    [anon_sym_LT_EQ] = ACTIONS(804),
    [anon_sym_GT] = ACTIONS(806),
    [anon_sym_GT_EQ] = ACTIONS(804),
    [anon_sym_EQ_EQ] = ACTIONS(804),
    [anon_sym_BANG_EQ] = ACTIONS(804),
    [anon_sym_STAR] = ACTIONS(806),
    [anon_sym_SLASH] = ACTIONS(804),
    [anon_sym_STAR_STAR] = ACTIONS(804),
    [anon_sym_CARET] = ACTIONS(804),
    [aux_sym_binary_operator_token1] = ACTIONS(804),
    [anon_sym_PIPE_GT] = ACTIONS(804),
    [anon_sym_COLON] = ACTIONS(806),
    [anon_sym_DOLLAR] = ACTIONS(804),
    [anon_sym_AT] = ACTIONS(804),
    [sym__hex_literal] = ACTIONS(804),
    [sym__number_literal] = ACTIONS(806),
    [anon_sym_SQUOTE] = ACTIONS(804),
    [anon_sym_DQUOTE] = ACTIONS(804),
    [sym_dots] = ACTIONS(806),
    [sym_dot_dot_i] = ACTIONS(806),
    [sym_next] = ACTIONS(806),
    [sym_break] = ACTIONS(806),
    [sym_true] = ACTIONS(806),
    [sym_false] = ACTIONS(806),
    [sym_null] = ACTIONS(806),
    [sym_inf] = ACTIONS(806),
    [sym_nan] = ACTIONS(806),
    [anon_sym_NA] = ACTIONS(806),
    [anon_sym_NA_integer_] = ACTIONS(806),
    [anon_sym_NA_real_] = ACTIONS(806),
    [anon_sym_NA_complex_] = ACTIONS(806),
    [anon_sym_NA_character_] = ACTIONS(806),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(804),
    [sym__semicolon] = ACTIONS(804),
    [sym__raw_string_open] = ACTIONS(804),
    [sym__external_else] = ACTIONS(804),
    [sym__external_open_parenthesis] = ACTIONS(804),
    [sym__external_open_brace] = ACTIONS(804),
    [sym__external_close_brace] = ACTIONS(804),
    [sym__external_open_bracket] = ACTIONS(804),
    [sym__external_open_bracket2] = ACTIONS(804),
  },
  [369] = {
    [sym_identifier] = ACTIONS(808),
    [anon_sym_BSLASH] = ACTIONS(810),
    [anon_sym_function] = ACTIONS(808),
    [anon_sym_EQ] = ACTIONS(808),
    [anon_sym_if] = ACTIONS(808),
    [anon_sym_for] = ACTIONS(808),
    [anon_sym_while] = ACTIONS(808),
    [anon_sym_repeat] = ACTIONS(808),
    [anon_sym_QMARK] = ACTIONS(810),
    [anon_sym_TILDE] = ACTIONS(810),
    [anon_sym_BANG] = ACTIONS(808),
    [anon_sym_PLUS] = ACTIONS(810),
    [anon_sym_DASH] = ACTIONS(808),
    [anon_sym_LT_DASH] = ACTIONS(810),
    [anon_sym_LT_LT_DASH] = ACTIONS(810),
    [anon_sym_COLON_EQ] = ACTIONS(810),
    [anon_sym_DASH_GT] = ACTIONS(808),
    [anon_sym_DASH_GT_GT] = ACTIONS(810),
    [anon_sym_PIPE] = ACTIONS(808),
    [anon_sym_AMP] = ACTIONS(808),
    [anon_sym_PIPE_PIPE] = ACTIONS(810),
    [anon_sym_AMP_AMP] = ACTIONS(810),
    [anon_sym_LT] = ACTIONS(808),
    [anon_sym_LT_EQ] = ACTIONS(810),
    [anon_sym_GT] = ACTIONS(808),
    [anon_sym_GT_EQ] = ACTIONS(810),
    [anon_sym_EQ_EQ] = ACTIONS(810),
    [anon_sym_BANG_EQ] = ACTIONS(810),
    [anon_sym_STAR] = ACTIONS(808),
    [anon_sym_SLASH] = ACTIONS(810),
    [anon_sym_STAR_STAR] = ACTIONS(810),
    [anon_sym_CARET] = ACTIONS(810),
    [aux_sym_binary_operator_token1] = ACTIONS(810),
    [anon_sym_PIPE_GT] = ACTIONS(810),
    [anon_sym_COLON] = ACTIONS(808),
    [anon_sym_DOLLAR] = ACTIONS(810),
    [anon_sym_AT] = ACTIONS(810),
    [sym__hex_literal] = ACTIONS(810),
    [sym__number_literal] = ACTIONS(808),
    [anon_sym_SQUOTE] = ACTIONS(810),
    [anon_sym_DQUOTE] = ACTIONS(810),
    [sym_dots] = ACTIONS(808),
    [sym_dot_dot_i] = ACTIONS(808),
    [sym_next] = ACTIONS(808),
    [sym_break] = ACTIONS(808),
    [sym_true] = ACTIONS(808),
    [sym_false] = ACTIONS(808),
    [sym_null] = ACTIONS(808),
    [sym_inf] = ACTIONS(808),
    [sym_nan] = ACTIONS(808),
    [anon_sym_NA] = ACTIONS(808),
    [anon_sym_NA_integer_] = ACTIONS(808),
    [anon_sym_NA_real_] = ACTIONS(808),
    [anon_sym_NA_complex_] = ACTIONS(808),
    [anon_sym_NA_character_] = ACTIONS(808),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(810),
    [sym__semicolon] = ACTIONS(810),
    [sym__raw_string_open] = ACTIONS(810),
    [sym__external_else] = ACTIONS(810),
    [sym__external_open_parenthesis] = ACTIONS(810),
    [sym__external_open_brace] = ACTIONS(810),
    [sym__external_close_brace] = ACTIONS(810),
    [sym__external_open_bracket] = ACTIONS(810),
    [sym__external_open_bracket2] = ACTIONS(810),
  },
  [370] = {
    [ts_builtin_sym_end] = ACTIONS(810),
    [sym_identifier] = ACTIONS(808),
    [anon_sym_BSLASH] = ACTIONS(810),
    [anon_sym_function] = ACTIONS(808),
    [anon_sym_EQ] = ACTIONS(808),
    [anon_sym_if] = ACTIONS(808),
    [anon_sym_for] = ACTIONS(808),
    [anon_sym_while] = ACTIONS(808),
    [anon_sym_repeat] = ACTIONS(808),
    [anon_sym_QMARK] = ACTIONS(810),
    [anon_sym_TILDE] = ACTIONS(810),
    [anon_sym_BANG] = ACTIONS(808),
    [anon_sym_PLUS] = ACTIONS(810),
    [anon_sym_DASH] = ACTIONS(808),
    [anon_sym_LT_DASH] = ACTIONS(810),
    [anon_sym_LT_LT_DASH] = ACTIONS(810),
    [anon_sym_COLON_EQ] = ACTIONS(810),
    [anon_sym_DASH_GT] = ACTIONS(808),
    [anon_sym_DASH_GT_GT] = ACTIONS(810),
    [anon_sym_PIPE] = ACTIONS(808),
    [anon_sym_AMP] = ACTIONS(808),
    [anon_sym_PIPE_PIPE] = ACTIONS(810),
    [anon_sym_AMP_AMP] = ACTIONS(810),
    [anon_sym_LT] = ACTIONS(808),
    [anon_sym_LT_EQ] = ACTIONS(810),
    [anon_sym_GT] = ACTIONS(808),
    [anon_sym_GT_EQ] = ACTIONS(810),
    [anon_sym_EQ_EQ] = ACTIONS(810),
    [anon_sym_BANG_EQ] = ACTIONS(810),
    [anon_sym_STAR] = ACTIONS(808),
    [anon_sym_SLASH] = ACTIONS(810),
    [anon_sym_STAR_STAR] = ACTIONS(810),
    [anon_sym_CARET] = ACTIONS(810),
    [aux_sym_binary_operator_token1] = ACTIONS(810),
    [anon_sym_PIPE_GT] = ACTIONS(810),
    [anon_sym_COLON] = ACTIONS(808),
    [anon_sym_DOLLAR] = ACTIONS(810),
    [anon_sym_AT] = ACTIONS(810),
    [sym__hex_literal] = ACTIONS(810),
    [sym__number_literal] = ACTIONS(808),
    [anon_sym_SQUOTE] = ACTIONS(810),
    [anon_sym_DQUOTE] = ACTIONS(810),
    [sym_dots] = ACTIONS(808),
    [sym_dot_dot_i] = ACTIONS(808),
    [sym_next] = ACTIONS(808),
    [sym_break] = ACTIONS(808),
    [sym_true] = ACTIONS(808),
    [sym_false] = ACTIONS(808),
    [sym_null] = ACTIONS(808),
    [sym_inf] = ACTIONS(808),
    [sym_nan] = ACTIONS(808),
    [anon_sym_NA] = ACTIONS(808),
    [anon_sym_NA_integer_] = ACTIONS(808),
    [anon_sym_NA_real_] = ACTIONS(808),
    [anon_sym_NA_complex_] = ACTIONS(808),
    [anon_sym_NA_character_] = ACTIONS(808),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(810),
    [sym__semicolon] = ACTIONS(810),
    [sym__raw_string_open] = ACTIONS(810),
    [sym__external_else] = ACTIONS(810),
    [sym__external_open_parenthesis] = ACTIONS(810),
    [sym__external_open_brace] = ACTIONS(810),
    [sym__external_open_bracket] = ACTIONS(810),
    [sym__external_open_bracket2] = ACTIONS(810),
  },
  [371] = {
    [sym_identifier] = ACTIONS(812),
    [anon_sym_BSLASH] = ACTIONS(814),
    [anon_sym_function] = ACTIONS(812),
    [anon_sym_EQ] = ACTIONS(812),
    [anon_sym_if] = ACTIONS(812),
    [anon_sym_for] = ACTIONS(812),
    [anon_sym_while] = ACTIONS(812),
    [anon_sym_repeat] = ACTIONS(812),
    [anon_sym_QMARK] = ACTIONS(814),
    [anon_sym_TILDE] = ACTIONS(814),
    [anon_sym_BANG] = ACTIONS(812),
    [anon_sym_PLUS] = ACTIONS(814),
    [anon_sym_DASH] = ACTIONS(812),
    [anon_sym_LT_DASH] = ACTIONS(814),
    [anon_sym_LT_LT_DASH] = ACTIONS(814),
    [anon_sym_COLON_EQ] = ACTIONS(814),
    [anon_sym_DASH_GT] = ACTIONS(812),
    [anon_sym_DASH_GT_GT] = ACTIONS(814),
    [anon_sym_PIPE] = ACTIONS(812),
    [anon_sym_AMP] = ACTIONS(812),
    [anon_sym_PIPE_PIPE] = ACTIONS(814),
    [anon_sym_AMP_AMP] = ACTIONS(814),
    [anon_sym_LT] = ACTIONS(812),
    [anon_sym_LT_EQ] = ACTIONS(814),
    [anon_sym_GT] = ACTIONS(812),
    [anon_sym_GT_EQ] = ACTIONS(814),
    [anon_sym_EQ_EQ] = ACTIONS(814),
    [anon_sym_BANG_EQ] = ACTIONS(814),
    [anon_sym_STAR] = ACTIONS(812),
    [anon_sym_SLASH] = ACTIONS(814),
    [anon_sym_STAR_STAR] = ACTIONS(814),
    [anon_sym_CARET] = ACTIONS(814),
    [aux_sym_binary_operator_token1] = ACTIONS(814),
    [anon_sym_PIPE_GT] = ACTIONS(814),
    [anon_sym_COLON] = ACTIONS(812),
    [anon_sym_DOLLAR] = ACTIONS(814),
    [anon_sym_AT] = ACTIONS(814),
    [sym__hex_literal] = ACTIONS(814),
    [sym__number_literal] = ACTIONS(812),
    [anon_sym_SQUOTE] = ACTIONS(814),
    [anon_sym_DQUOTE] = ACTIONS(814),
    [sym_dots] = ACTIONS(812),
    [sym_dot_dot_i] = ACTIONS(812),
    [sym_next] = ACTIONS(812),
    [sym_break] = ACTIONS(812),
    [sym_true] = ACTIONS(812),
    [sym_false] = ACTIONS(812),
    [sym_null] = ACTIONS(812),
    [sym_inf] = ACTIONS(812),
    [sym_nan] = ACTIONS(812),
    [anon_sym_NA] = ACTIONS(812),
    [anon_sym_NA_integer_] = ACTIONS(812),
    [anon_sym_NA_real_] = ACTIONS(812),
    [anon_sym_NA_complex_] = ACTIONS(812),
    [anon_sym_NA_character_] = ACTIONS(812),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(814),
    [sym__semicolon] = ACTIONS(814),
    [sym__raw_string_open] = ACTIONS(814),
    [sym__external_else] = ACTIONS(814),
    [sym__external_open_parenthesis] = ACTIONS(814),
    [sym__external_open_brace] = ACTIONS(814),
    [sym__external_close_brace] = ACTIONS(814),
    [sym__external_open_bracket] = ACTIONS(814),
    [sym__external_open_bracket2] = ACTIONS(814),
  },
  [372] = {
    [ts_builtin_sym_end] = ACTIONS(816),
    [sym_identifier] = ACTIONS(818),
    [anon_sym_BSLASH] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(818),
    [anon_sym_EQ] = ACTIONS(818),
    [anon_sym_if] = ACTIONS(818),
    [anon_sym_for] = ACTIONS(818),
    [anon_sym_while] = ACTIONS(818),
    [anon_sym_repeat] = ACTIONS(818),
    [anon_sym_QMARK] = ACTIONS(816),
    [anon_sym_TILDE] = ACTIONS(816),
    [anon_sym_BANG] = ACTIONS(818),
    [anon_sym_PLUS] = ACTIONS(816),
    [anon_sym_DASH] = ACTIONS(818),
    [anon_sym_LT_DASH] = ACTIONS(816),
    [anon_sym_LT_LT_DASH] = ACTIONS(816),
    [anon_sym_COLON_EQ] = ACTIONS(816),
    [anon_sym_DASH_GT] = ACTIONS(818),
    [anon_sym_DASH_GT_GT] = ACTIONS(816),
    [anon_sym_PIPE] = ACTIONS(818),
    [anon_sym_AMP] = ACTIONS(818),
    [anon_sym_PIPE_PIPE] = ACTIONS(816),
    [anon_sym_AMP_AMP] = ACTIONS(816),
    [anon_sym_LT] = ACTIONS(818),
    [anon_sym_LT_EQ] = ACTIONS(816),
    [anon_sym_GT] = ACTIONS(818),
    [anon_sym_GT_EQ] = ACTIONS(816),
    [anon_sym_EQ_EQ] = ACTIONS(816),
    [anon_sym_BANG_EQ] = ACTIONS(816),
    [anon_sym_STAR] = ACTIONS(818),
    [anon_sym_SLASH] = ACTIONS(816),
    [anon_sym_STAR_STAR] = ACTIONS(816),
    [anon_sym_CARET] = ACTIONS(816),
    [aux_sym_binary_operator_token1] = ACTIONS(816),
    [anon_sym_PIPE_GT] = ACTIONS(816),
    [anon_sym_COLON] = ACTIONS(818),
    [anon_sym_DOLLAR] = ACTIONS(816),
    [anon_sym_AT] = ACTIONS(816),
    [sym__hex_literal] = ACTIONS(816),
    [sym__number_literal] = ACTIONS(818),
    [anon_sym_SQUOTE] = ACTIONS(816),
    [anon_sym_DQUOTE] = ACTIONS(816),
    [sym_dots] = ACTIONS(818),
    [sym_dot_dot_i] = ACTIONS(818),
    [sym_next] = ACTIONS(818),
    [sym_break] = ACTIONS(818),
    [sym_true] = ACTIONS(818),
    [sym_false] = ACTIONS(818),
    [sym_null] = ACTIONS(818),
    [sym_inf] = ACTIONS(818),
    [sym_nan] = ACTIONS(818),
    [anon_sym_NA] = ACTIONS(818),
    [anon_sym_NA_integer_] = ACTIONS(818),
    [anon_sym_NA_real_] = ACTIONS(818),
    [anon_sym_NA_complex_] = ACTIONS(818),
    [anon_sym_NA_character_] = ACTIONS(818),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(816),
    [sym__semicolon] = ACTIONS(816),
    [sym__raw_string_open] = ACTIONS(816),
    [sym__external_else] = ACTIONS(816),
    [sym__external_open_parenthesis] = ACTIONS(816),
    [sym__external_open_brace] = ACTIONS(816),
    [sym__external_open_bracket] = ACTIONS(816),
    [sym__external_open_bracket2] = ACTIONS(816),
  },
  [373] = {
    [ts_builtin_sym_end] = ACTIONS(820),
    [sym_identifier] = ACTIONS(822),
    [anon_sym_BSLASH] = ACTIONS(820),
    [anon_sym_function] = ACTIONS(822),
    [anon_sym_EQ] = ACTIONS(822),
    [anon_sym_if] = ACTIONS(822),
    [anon_sym_for] = ACTIONS(822),
    [anon_sym_while] = ACTIONS(822),
    [anon_sym_repeat] = ACTIONS(822),
    [anon_sym_QMARK] = ACTIONS(820),
    [anon_sym_TILDE] = ACTIONS(820),
    [anon_sym_BANG] = ACTIONS(822),
    [anon_sym_PLUS] = ACTIONS(820),
    [anon_sym_DASH] = ACTIONS(822),
    [anon_sym_LT_DASH] = ACTIONS(820),
    [anon_sym_LT_LT_DASH] = ACTIONS(820),
    [anon_sym_COLON_EQ] = ACTIONS(820),
    [anon_sym_DASH_GT] = ACTIONS(822),
    [anon_sym_DASH_GT_GT] = ACTIONS(820),
    [anon_sym_PIPE] = ACTIONS(822),
    [anon_sym_AMP] = ACTIONS(822),
    [anon_sym_PIPE_PIPE] = ACTIONS(820),
    [anon_sym_AMP_AMP] = ACTIONS(820),
    [anon_sym_LT] = ACTIONS(822),
    [anon_sym_LT_EQ] = ACTIONS(820),
    [anon_sym_GT] = ACTIONS(822),
    [anon_sym_GT_EQ] = ACTIONS(820),
    [anon_sym_EQ_EQ] = ACTIONS(820),
    [anon_sym_BANG_EQ] = ACTIONS(820),
    [anon_sym_STAR] = ACTIONS(822),
    [anon_sym_SLASH] = ACTIONS(820),
    [anon_sym_STAR_STAR] = ACTIONS(820),
    [anon_sym_CARET] = ACTIONS(820),
    [aux_sym_binary_operator_token1] = ACTIONS(820),
    [anon_sym_PIPE_GT] = ACTIONS(820),
    [anon_sym_COLON] = ACTIONS(822),
    [anon_sym_DOLLAR] = ACTIONS(820),
    [anon_sym_AT] = ACTIONS(820),
    [sym__hex_literal] = ACTIONS(820),
    [sym__number_literal] = ACTIONS(822),
    [anon_sym_SQUOTE] = ACTIONS(820),
    [anon_sym_DQUOTE] = ACTIONS(820),
    [sym_dots] = ACTIONS(822),
    [sym_dot_dot_i] = ACTIONS(822),
    [sym_next] = ACTIONS(822),
    [sym_break] = ACTIONS(822),
    [sym_true] = ACTIONS(822),
    [sym_false] = ACTIONS(822),
    [sym_null] = ACTIONS(822),
    [sym_inf] = ACTIONS(822),
    [sym_nan] = ACTIONS(822),
    [anon_sym_NA] = ACTIONS(822),
    [anon_sym_NA_integer_] = ACTIONS(822),
    [anon_sym_NA_real_] = ACTIONS(822),
    [anon_sym_NA_complex_] = ACTIONS(822),
    [anon_sym_NA_character_] = ACTIONS(822),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(820),
    [sym__semicolon] = ACTIONS(820),
    [sym__raw_string_open] = ACTIONS(820),
    [sym__external_else] = ACTIONS(820),
    [sym__external_open_parenthesis] = ACTIONS(820),
    [sym__external_open_brace] = ACTIONS(820),
    [sym__external_open_bracket] = ACTIONS(820),
    [sym__external_open_bracket2] = ACTIONS(820),
  },
  [374] = {
    [ts_builtin_sym_end] = ACTIONS(824),
    [sym_identifier] = ACTIONS(826),
    [anon_sym_BSLASH] = ACTIONS(824),
    [anon_sym_function] = ACTIONS(826),
    [anon_sym_EQ] = ACTIONS(826),
    [anon_sym_if] = ACTIONS(826),
    [anon_sym_for] = ACTIONS(826),
    [anon_sym_while] = ACTIONS(826),
    [anon_sym_repeat] = ACTIONS(826),
    [anon_sym_QMARK] = ACTIONS(824),
    [anon_sym_TILDE] = ACTIONS(824),
    [anon_sym_BANG] = ACTIONS(826),
    [anon_sym_PLUS] = ACTIONS(824),
    [anon_sym_DASH] = ACTIONS(826),
    [anon_sym_LT_DASH] = ACTIONS(824),
    [anon_sym_LT_LT_DASH] = ACTIONS(824),
    [anon_sym_COLON_EQ] = ACTIONS(824),
    [anon_sym_DASH_GT] = ACTIONS(826),
    [anon_sym_DASH_GT_GT] = ACTIONS(824),
    [anon_sym_PIPE] = ACTIONS(826),
    [anon_sym_AMP] = ACTIONS(826),
    [anon_sym_PIPE_PIPE] = ACTIONS(824),
    [anon_sym_AMP_AMP] = ACTIONS(824),
    [anon_sym_LT] = ACTIONS(826),
    [anon_sym_LT_EQ] = ACTIONS(824),
    [anon_sym_GT] = ACTIONS(826),
    [anon_sym_GT_EQ] = ACTIONS(824),
    [anon_sym_EQ_EQ] = ACTIONS(824),
    [anon_sym_BANG_EQ] = ACTIONS(824),
    [anon_sym_STAR] = ACTIONS(826),
    [anon_sym_SLASH] = ACTIONS(824),
    [anon_sym_STAR_STAR] = ACTIONS(824),
    [anon_sym_CARET] = ACTIONS(824),
    [aux_sym_binary_operator_token1] = ACTIONS(824),
    [anon_sym_PIPE_GT] = ACTIONS(824),
    [anon_sym_COLON] = ACTIONS(826),
    [anon_sym_DOLLAR] = ACTIONS(824),
    [anon_sym_AT] = ACTIONS(824),
    [sym__hex_literal] = ACTIONS(824),
    [sym__number_literal] = ACTIONS(826),
    [anon_sym_SQUOTE] = ACTIONS(824),
    [anon_sym_DQUOTE] = ACTIONS(824),
    [sym_dots] = ACTIONS(826),
    [sym_dot_dot_i] = ACTIONS(826),
    [sym_next] = ACTIONS(826),
    [sym_break] = ACTIONS(826),
    [sym_true] = ACTIONS(826),
    [sym_false] = ACTIONS(826),
    [sym_null] = ACTIONS(826),
    [sym_inf] = ACTIONS(826),
    [sym_nan] = ACTIONS(826),
    [anon_sym_NA] = ACTIONS(826),
    [anon_sym_NA_integer_] = ACTIONS(826),
    [anon_sym_NA_real_] = ACTIONS(826),
    [anon_sym_NA_complex_] = ACTIONS(826),
    [anon_sym_NA_character_] = ACTIONS(826),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(824),
    [sym__semicolon] = ACTIONS(824),
    [sym__raw_string_open] = ACTIONS(824),
    [sym__external_else] = ACTIONS(824),
    [sym__external_open_parenthesis] = ACTIONS(824),
    [sym__external_open_brace] = ACTIONS(824),
    [sym__external_open_bracket] = ACTIONS(824),
    [sym__external_open_bracket2] = ACTIONS(824),
  },
  [375] = {
    [ts_builtin_sym_end] = ACTIONS(828),
    [sym_identifier] = ACTIONS(830),
    [anon_sym_BSLASH] = ACTIONS(828),
    [anon_sym_function] = ACTIONS(830),
    [anon_sym_EQ] = ACTIONS(830),
    [anon_sym_if] = ACTIONS(830),
    [anon_sym_for] = ACTIONS(830),
    [anon_sym_while] = ACTIONS(830),
    [anon_sym_repeat] = ACTIONS(830),
    [anon_sym_QMARK] = ACTIONS(828),
    [anon_sym_TILDE] = ACTIONS(828),
    [anon_sym_BANG] = ACTIONS(830),
    [anon_sym_PLUS] = ACTIONS(828),
    [anon_sym_DASH] = ACTIONS(830),
    [anon_sym_LT_DASH] = ACTIONS(828),
    [anon_sym_LT_LT_DASH] = ACTIONS(828),
    [anon_sym_COLON_EQ] = ACTIONS(828),
    [anon_sym_DASH_GT] = ACTIONS(830),
    [anon_sym_DASH_GT_GT] = ACTIONS(828),
    [anon_sym_PIPE] = ACTIONS(830),
    [anon_sym_AMP] = ACTIONS(830),
    [anon_sym_PIPE_PIPE] = ACTIONS(828),
    [anon_sym_AMP_AMP] = ACTIONS(828),
    [anon_sym_LT] = ACTIONS(830),
    [anon_sym_LT_EQ] = ACTIONS(828),
    [anon_sym_GT] = ACTIONS(830),
    [anon_sym_GT_EQ] = ACTIONS(828),
    [anon_sym_EQ_EQ] = ACTIONS(828),
    [anon_sym_BANG_EQ] = ACTIONS(828),
    [anon_sym_STAR] = ACTIONS(830),
    [anon_sym_SLASH] = ACTIONS(828),
    [anon_sym_STAR_STAR] = ACTIONS(828),
    [anon_sym_CARET] = ACTIONS(828),
    [aux_sym_binary_operator_token1] = ACTIONS(828),
    [anon_sym_PIPE_GT] = ACTIONS(828),
    [anon_sym_COLON] = ACTIONS(830),
    [anon_sym_DOLLAR] = ACTIONS(828),
    [anon_sym_AT] = ACTIONS(828),
    [sym__hex_literal] = ACTIONS(828),
    [sym__number_literal] = ACTIONS(830),
    [anon_sym_SQUOTE] = ACTIONS(828),
    [anon_sym_DQUOTE] = ACTIONS(828),
    [sym_dots] = ACTIONS(830),
    [sym_dot_dot_i] = ACTIONS(830),
    [sym_next] = ACTIONS(830),
    [sym_break] = ACTIONS(830),
    [sym_true] = ACTIONS(830),
    [sym_false] = ACTIONS(830),
    [sym_null] = ACTIONS(830),
    [sym_inf] = ACTIONS(830),
    [sym_nan] = ACTIONS(830),
    [anon_sym_NA] = ACTIONS(830),
    [anon_sym_NA_integer_] = ACTIONS(830),
    [anon_sym_NA_real_] = ACTIONS(830),
    [anon_sym_NA_complex_] = ACTIONS(830),
    [anon_sym_NA_character_] = ACTIONS(830),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(828),
    [sym__semicolon] = ACTIONS(828),
    [sym__raw_string_open] = ACTIONS(828),
    [sym__external_else] = ACTIONS(828),
    [sym__external_open_parenthesis] = ACTIONS(828),
    [sym__external_open_brace] = ACTIONS(828),
    [sym__external_open_bracket] = ACTIONS(828),
    [sym__external_open_bracket2] = ACTIONS(828),
  },
  [376] = {
    [ts_builtin_sym_end] = ACTIONS(814),
    [sym_identifier] = ACTIONS(812),
    [anon_sym_BSLASH] = ACTIONS(814),
    [anon_sym_function] = ACTIONS(812),
    [anon_sym_EQ] = ACTIONS(812),
    [anon_sym_if] = ACTIONS(812),
    [anon_sym_for] = ACTIONS(812),
    [anon_sym_while] = ACTIONS(812),
    [anon_sym_repeat] = ACTIONS(812),
    [anon_sym_QMARK] = ACTIONS(814),
    [anon_sym_TILDE] = ACTIONS(814),
    [anon_sym_BANG] = ACTIONS(812),
    [anon_sym_PLUS] = ACTIONS(814),
    [anon_sym_DASH] = ACTIONS(812),
    [anon_sym_LT_DASH] = ACTIONS(814),
    [anon_sym_LT_LT_DASH] = ACTIONS(814),
    [anon_sym_COLON_EQ] = ACTIONS(814),
    [anon_sym_DASH_GT] = ACTIONS(812),
    [anon_sym_DASH_GT_GT] = ACTIONS(814),
    [anon_sym_PIPE] = ACTIONS(812),
    [anon_sym_AMP] = ACTIONS(812),
    [anon_sym_PIPE_PIPE] = ACTIONS(814),
    [anon_sym_AMP_AMP] = ACTIONS(814),
    [anon_sym_LT] = ACTIONS(812),
    [anon_sym_LT_EQ] = ACTIONS(814),
    [anon_sym_GT] = ACTIONS(812),
    [anon_sym_GT_EQ] = ACTIONS(814),
    [anon_sym_EQ_EQ] = ACTIONS(814),
    [anon_sym_BANG_EQ] = ACTIONS(814),
    [anon_sym_STAR] = ACTIONS(812),
    [anon_sym_SLASH] = ACTIONS(814),
    [anon_sym_STAR_STAR] = ACTIONS(814),
    [anon_sym_CARET] = ACTIONS(814),
    [aux_sym_binary_operator_token1] = ACTIONS(814),
    [anon_sym_PIPE_GT] = ACTIONS(814),
    [anon_sym_COLON] = ACTIONS(812),
    [anon_sym_DOLLAR] = ACTIONS(814),
    [anon_sym_AT] = ACTIONS(814),
    [sym__hex_literal] = ACTIONS(814),
    [sym__number_literal] = ACTIONS(812),
    [anon_sym_SQUOTE] = ACTIONS(814),
    [anon_sym_DQUOTE] = ACTIONS(814),
    [sym_dots] = ACTIONS(812),
    [sym_dot_dot_i] = ACTIONS(812),
    [sym_next] = ACTIONS(812),
    [sym_break] = ACTIONS(812),
    [sym_true] = ACTIONS(812),
    [sym_false] = ACTIONS(812),
    [sym_null] = ACTIONS(812),
    [sym_inf] = ACTIONS(812),
    [sym_nan] = ACTIONS(812),
    [anon_sym_NA] = ACTIONS(812),
    [anon_sym_NA_integer_] = ACTIONS(812),
    [anon_sym_NA_real_] = ACTIONS(812),
    [anon_sym_NA_complex_] = ACTIONS(812),
    [anon_sym_NA_character_] = ACTIONS(812),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(814),
    [sym__semicolon] = ACTIONS(814),
    [sym__raw_string_open] = ACTIONS(814),
    [sym__external_else] = ACTIONS(814),
    [sym__external_open_parenthesis] = ACTIONS(814),
    [sym__external_open_brace] = ACTIONS(814),
    [sym__external_open_bracket] = ACTIONS(814),
    [sym__external_open_bracket2] = ACTIONS(814),
  },
  [377] = {
    [ts_builtin_sym_end] = ACTIONS(727),
    [sym_identifier] = ACTIONS(725),
    [anon_sym_BSLASH] = ACTIONS(727),
    [anon_sym_function] = ACTIONS(725),
    [anon_sym_EQ] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(725),
    [anon_sym_for] = ACTIONS(725),
    [anon_sym_while] = ACTIONS(725),
    [anon_sym_repeat] = ACTIONS(725),
    [anon_sym_QMARK] = ACTIONS(727),
    [anon_sym_TILDE] = ACTIONS(727),
    [anon_sym_BANG] = ACTIONS(725),
    [anon_sym_PLUS] = ACTIONS(727),
    [anon_sym_DASH] = ACTIONS(725),
    [anon_sym_LT_DASH] = ACTIONS(727),
    [anon_sym_LT_LT_DASH] = ACTIONS(727),
    [anon_sym_COLON_EQ] = ACTIONS(727),
    [anon_sym_DASH_GT] = ACTIONS(725),
    [anon_sym_DASH_GT_GT] = ACTIONS(727),
    [anon_sym_PIPE] = ACTIONS(725),
    [anon_sym_AMP] = ACTIONS(725),
    [anon_sym_PIPE_PIPE] = ACTIONS(727),
    [anon_sym_AMP_AMP] = ACTIONS(727),
    [anon_sym_LT] = ACTIONS(725),
    [anon_sym_LT_EQ] = ACTIONS(727),
    [anon_sym_GT] = ACTIONS(725),
    [anon_sym_GT_EQ] = ACTIONS(727),
    [anon_sym_EQ_EQ] = ACTIONS(727),
    [anon_sym_BANG_EQ] = ACTIONS(727),
    [anon_sym_STAR] = ACTIONS(725),
    [anon_sym_SLASH] = ACTIONS(727),
    [anon_sym_STAR_STAR] = ACTIONS(727),
    [anon_sym_CARET] = ACTIONS(727),
    [aux_sym_binary_operator_token1] = ACTIONS(727),
    [anon_sym_PIPE_GT] = ACTIONS(727),
    [anon_sym_COLON] = ACTIONS(725),
    [anon_sym_DOLLAR] = ACTIONS(727),
    [anon_sym_AT] = ACTIONS(727),
    [sym__hex_literal] = ACTIONS(727),
    [sym__number_literal] = ACTIONS(725),
    [anon_sym_SQUOTE] = ACTIONS(727),
    [anon_sym_DQUOTE] = ACTIONS(727),
    [sym_dots] = ACTIONS(725),
    [sym_dot_dot_i] = ACTIONS(725),
    [sym_next] = ACTIONS(725),
    [sym_break] = ACTIONS(725),
    [sym_true] = ACTIONS(725),
    [sym_false] = ACTIONS(725),
    [sym_null] = ACTIONS(725),
    [sym_inf] = ACTIONS(725),
    [sym_nan] = ACTIONS(725),
    [anon_sym_NA] = ACTIONS(725),
    [anon_sym_NA_integer_] = ACTIONS(725),
    [anon_sym_NA_real_] = ACTIONS(725),
    [anon_sym_NA_complex_] = ACTIONS(725),
    [anon_sym_NA_character_] = ACTIONS(725),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(727),
    [sym__semicolon] = ACTIONS(727),
    [sym__raw_string_open] = ACTIONS(727),
    [sym__external_else] = ACTIONS(727),
    [sym__external_open_parenthesis] = ACTIONS(727),
    [sym__external_open_brace] = ACTIONS(727),
    [sym__external_open_bracket] = ACTIONS(727),
    [sym__external_open_bracket2] = ACTIONS(727),
  },
  [378] = {
    [sym_function_definition] = STATE(189),
    [sym_if_statement] = STATE(189),
    [sym_for_statement] = STATE(189),
    [sym_while_statement] = STATE(189),
    [sym_repeat_statement] = STATE(189),
    [sym_braced_expression] = STATE(189),
    [sym_parenthesized_expression] = STATE(189),
    [sym_call] = STATE(189),
    [sym_subset] = STATE(189),
    [sym_subset2] = STATE(189),
    [sym_unary_operator] = STATE(189),
    [sym_binary_operator] = STATE(189),
    [sym_extract_operator] = STATE(189),
    [sym_namespace_operator] = STATE(189),
    [sym_integer] = STATE(189),
    [sym_complex] = STATE(189),
    [sym_float] = STATE(189),
    [sym__float_literal] = STATE(330),
    [sym_string] = STATE(311),
    [sym__raw_string] = STATE(331),
    [sym__single_quoted_string] = STATE(332),
    [sym__double_quoted_string] = STATE(333),
    [sym_na] = STATE(189),
    [sym__expression] = STATE(189),
    [sym__open_parenthesis] = STATE(1070),
    [sym__open_brace] = STATE(384),
    [sym__close_brace] = STATE(397),
    [aux_sym_braced_expression_repeat1] = STATE(415),
    [sym_identifier] = ACTIONS(687),
    [anon_sym_BSLASH] = ACTIONS(689),
    [anon_sym_function] = ACTIONS(691),
    [anon_sym_if] = ACTIONS(693),
    [anon_sym_for] = ACTIONS(695),
    [anon_sym_while] = ACTIONS(697),
    [anon_sym_repeat] = ACTIONS(699),
    [anon_sym_QMARK] = ACTIONS(701),
    [anon_sym_TILDE] = ACTIONS(703),
    [anon_sym_BANG] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [sym__hex_literal] = ACTIONS(709),
    [sym__number_literal] = ACTIONS(711),
    [anon_sym_SQUOTE] = ACTIONS(435),
    [anon_sym_DQUOTE] = ACTIONS(437),
    [sym_dots] = ACTIONS(687),
    [sym_dot_dot_i] = ACTIONS(687),
    [sym_next] = ACTIONS(713),
    [sym_break] = ACTIONS(713),
    [sym_true] = ACTIONS(713),
    [sym_false] = ACTIONS(713),
    [sym_null] = ACTIONS(713),
    [sym_inf] = ACTIONS(713),
    [sym_nan] = ACTIONS(713),
    [anon_sym_NA] = ACTIONS(715),
    [anon_sym_NA_integer_] = ACTIONS(715),
    [anon_sym_NA_real_] = ACTIONS(715),
    [anon_sym_NA_complex_] = ACTIONS(715),
    [anon_sym_NA_character_] = ACTIONS(715),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(717),
    [sym__semicolon] = ACTIONS(717),
    [sym__raw_string_open] = ACTIONS(439),
    [sym__external_open_parenthesis] = ACTIONS(719),
    [sym__external_open_brace] = ACTIONS(721),
    [sym__external_close_brace] = ACTIONS(832),
  },
  [379] = {
    [sym_function_definition] = STATE(189),
    [sym_if_statement] = STATE(189),
    [sym_for_statement] = STATE(189),
    [sym_while_statement] = STATE(189),
    [sym_repeat_statement] = STATE(189),
    [sym_braced_expression] = STATE(189),
    [sym_parenthesized_expression] = STATE(189),
    [sym_call] = STATE(189),
    [sym_subset] = STATE(189),
    [sym_subset2] = STATE(189),
    [sym_unary_operator] = STATE(189),
    [sym_binary_operator] = STATE(189),
    [sym_extract_operator] = STATE(189),
    [sym_namespace_operator] = STATE(189),
    [sym_integer] = STATE(189),
    [sym_complex] = STATE(189),
    [sym_float] = STATE(189),
    [sym__float_literal] = STATE(330),
    [sym_string] = STATE(311),
    [sym__raw_string] = STATE(331),
    [sym__single_quoted_string] = STATE(332),
    [sym__double_quoted_string] = STATE(333),
    [sym_na] = STATE(189),
    [sym__expression] = STATE(189),
    [sym__open_parenthesis] = STATE(1070),
    [sym__open_brace] = STATE(384),
    [sym__close_brace] = STATE(1674),
    [aux_sym_braced_expression_repeat1] = STATE(415),
    [sym_identifier] = ACTIONS(687),
    [anon_sym_BSLASH] = ACTIONS(689),
    [anon_sym_function] = ACTIONS(691),
    [anon_sym_if] = ACTIONS(693),
    [anon_sym_for] = ACTIONS(695),
    [anon_sym_while] = ACTIONS(697),
    [anon_sym_repeat] = ACTIONS(699),
    [anon_sym_QMARK] = ACTIONS(701),
    [anon_sym_TILDE] = ACTIONS(703),
    [anon_sym_BANG] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [sym__hex_literal] = ACTIONS(709),
    [sym__number_literal] = ACTIONS(711),
    [anon_sym_SQUOTE] = ACTIONS(435),
    [anon_sym_DQUOTE] = ACTIONS(437),
    [sym_dots] = ACTIONS(687),
    [sym_dot_dot_i] = ACTIONS(687),
    [sym_next] = ACTIONS(713),
    [sym_break] = ACTIONS(713),
    [sym_true] = ACTIONS(713),
    [sym_false] = ACTIONS(713),
    [sym_null] = ACTIONS(713),
    [sym_inf] = ACTIONS(713),
    [sym_nan] = ACTIONS(713),
    [anon_sym_NA] = ACTIONS(715),
    [anon_sym_NA_integer_] = ACTIONS(715),
    [anon_sym_NA_real_] = ACTIONS(715),
    [anon_sym_NA_complex_] = ACTIONS(715),
    [anon_sym_NA_character_] = ACTIONS(715),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(717),
    [sym__semicolon] = ACTIONS(717),
    [sym__raw_string_open] = ACTIONS(439),
    [sym__external_open_parenthesis] = ACTIONS(719),
    [sym__external_open_brace] = ACTIONS(721),
    [sym__external_close_brace] = ACTIONS(834),
  },
  [380] = {
    [sym_function_definition] = STATE(189),
    [sym_if_statement] = STATE(189),
    [sym_for_statement] = STATE(189),
    [sym_while_statement] = STATE(189),
    [sym_repeat_statement] = STATE(189),
    [sym_braced_expression] = STATE(189),
    [sym_parenthesized_expression] = STATE(189),
    [sym_call] = STATE(189),
    [sym_subset] = STATE(189),
    [sym_subset2] = STATE(189),
    [sym_unary_operator] = STATE(189),
    [sym_binary_operator] = STATE(189),
    [sym_extract_operator] = STATE(189),
    [sym_namespace_operator] = STATE(189),
    [sym_integer] = STATE(189),
    [sym_complex] = STATE(189),
    [sym_float] = STATE(189),
    [sym__float_literal] = STATE(330),
    [sym_string] = STATE(311),
    [sym__raw_string] = STATE(331),
    [sym__single_quoted_string] = STATE(332),
    [sym__double_quoted_string] = STATE(333),
    [sym_na] = STATE(189),
    [sym__expression] = STATE(189),
    [sym__open_parenthesis] = STATE(1070),
    [sym__open_brace] = STATE(384),
    [sym__close_brace] = STATE(1707),
    [aux_sym_braced_expression_repeat1] = STATE(415),
    [sym_identifier] = ACTIONS(687),
    [anon_sym_BSLASH] = ACTIONS(689),
    [anon_sym_function] = ACTIONS(691),
    [anon_sym_if] = ACTIONS(693),
    [anon_sym_for] = ACTIONS(695),
    [anon_sym_while] = ACTIONS(697),
    [anon_sym_repeat] = ACTIONS(699),
    [anon_sym_QMARK] = ACTIONS(701),
    [anon_sym_TILDE] = ACTIONS(703),
    [anon_sym_BANG] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [sym__hex_literal] = ACTIONS(709),
    [sym__number_literal] = ACTIONS(711),
    [anon_sym_SQUOTE] = ACTIONS(435),
    [anon_sym_DQUOTE] = ACTIONS(437),
    [sym_dots] = ACTIONS(687),
    [sym_dot_dot_i] = ACTIONS(687),
    [sym_next] = ACTIONS(713),
    [sym_break] = ACTIONS(713),
    [sym_true] = ACTIONS(713),
    [sym_false] = ACTIONS(713),
    [sym_null] = ACTIONS(713),
    [sym_inf] = ACTIONS(713),
    [sym_nan] = ACTIONS(713),
    [anon_sym_NA] = ACTIONS(715),
    [anon_sym_NA_integer_] = ACTIONS(715),
    [anon_sym_NA_real_] = ACTIONS(715),
    [anon_sym_NA_complex_] = ACTIONS(715),
    [anon_sym_NA_character_] = ACTIONS(715),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(717),
    [sym__semicolon] = ACTIONS(717),
    [sym__raw_string_open] = ACTIONS(439),
    [sym__external_open_parenthesis] = ACTIONS(719),
    [sym__external_open_brace] = ACTIONS(721),
    [sym__external_close_brace] = ACTIONS(836),
  },
  [381] = {
    [sym_function_definition] = STATE(189),
    [sym_if_statement] = STATE(189),
    [sym_for_statement] = STATE(189),
    [sym_while_statement] = STATE(189),
    [sym_repeat_statement] = STATE(189),
    [sym_braced_expression] = STATE(189),
    [sym_parenthesized_expression] = STATE(189),
    [sym_call] = STATE(189),
    [sym_subset] = STATE(189),
    [sym_subset2] = STATE(189),
    [sym_unary_operator] = STATE(189),
    [sym_binary_operator] = STATE(189),
    [sym_extract_operator] = STATE(189),
    [sym_namespace_operator] = STATE(189),
    [sym_integer] = STATE(189),
    [sym_complex] = STATE(189),
    [sym_float] = STATE(189),
    [sym__float_literal] = STATE(330),
    [sym_string] = STATE(311),
    [sym__raw_string] = STATE(331),
    [sym__single_quoted_string] = STATE(332),
    [sym__double_quoted_string] = STATE(333),
    [sym_na] = STATE(189),
    [sym__expression] = STATE(189),
    [sym__open_parenthesis] = STATE(1070),
    [sym__open_brace] = STATE(384),
    [sym__close_brace] = STATE(1760),
    [aux_sym_braced_expression_repeat1] = STATE(338),
    [sym_identifier] = ACTIONS(687),
    [anon_sym_BSLASH] = ACTIONS(689),
    [anon_sym_function] = ACTIONS(691),
    [anon_sym_if] = ACTIONS(693),
    [anon_sym_for] = ACTIONS(695),
    [anon_sym_while] = ACTIONS(697),
    [anon_sym_repeat] = ACTIONS(699),
    [anon_sym_QMARK] = ACTIONS(701),
    [anon_sym_TILDE] = ACTIONS(703),
    [anon_sym_BANG] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [sym__hex_literal] = ACTIONS(709),
    [sym__number_literal] = ACTIONS(711),
    [anon_sym_SQUOTE] = ACTIONS(435),
    [anon_sym_DQUOTE] = ACTIONS(437),
    [sym_dots] = ACTIONS(687),
    [sym_dot_dot_i] = ACTIONS(687),
    [sym_next] = ACTIONS(713),
    [sym_break] = ACTIONS(713),
    [sym_true] = ACTIONS(713),
    [sym_false] = ACTIONS(713),
    [sym_null] = ACTIONS(713),
    [sym_inf] = ACTIONS(713),
    [sym_nan] = ACTIONS(713),
    [anon_sym_NA] = ACTIONS(715),
    [anon_sym_NA_integer_] = ACTIONS(715),
    [anon_sym_NA_real_] = ACTIONS(715),
    [anon_sym_NA_complex_] = ACTIONS(715),
    [anon_sym_NA_character_] = ACTIONS(715),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(717),
    [sym__semicolon] = ACTIONS(717),
    [sym__raw_string_open] = ACTIONS(439),
    [sym__external_open_parenthesis] = ACTIONS(719),
    [sym__external_open_brace] = ACTIONS(721),
    [sym__external_close_brace] = ACTIONS(838),
  },
  [382] = {
    [sym_function_definition] = STATE(189),
    [sym_if_statement] = STATE(189),
    [sym_for_statement] = STATE(189),
    [sym_while_statement] = STATE(189),
    [sym_repeat_statement] = STATE(189),
    [sym_braced_expression] = STATE(189),
    [sym_parenthesized_expression] = STATE(189),
    [sym_call] = STATE(189),
    [sym_subset] = STATE(189),
    [sym_subset2] = STATE(189),
    [sym_unary_operator] = STATE(189),
    [sym_binary_operator] = STATE(189),
    [sym_extract_operator] = STATE(189),
    [sym_namespace_operator] = STATE(189),
    [sym_integer] = STATE(189),
    [sym_complex] = STATE(189),
    [sym_float] = STATE(189),
    [sym__float_literal] = STATE(330),
    [sym_string] = STATE(311),
    [sym__raw_string] = STATE(331),
    [sym__single_quoted_string] = STATE(332),
    [sym__double_quoted_string] = STATE(333),
    [sym_na] = STATE(189),
    [sym__expression] = STATE(189),
    [sym__open_parenthesis] = STATE(1070),
    [sym__open_brace] = STATE(384),
    [sym__close_brace] = STATE(414),
    [aux_sym_braced_expression_repeat1] = STATE(415),
    [sym_identifier] = ACTIONS(687),
    [anon_sym_BSLASH] = ACTIONS(689),
    [anon_sym_function] = ACTIONS(691),
    [anon_sym_if] = ACTIONS(693),
    [anon_sym_for] = ACTIONS(695),
    [anon_sym_while] = ACTIONS(697),
    [anon_sym_repeat] = ACTIONS(699),
    [anon_sym_QMARK] = ACTIONS(701),
    [anon_sym_TILDE] = ACTIONS(703),
    [anon_sym_BANG] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [sym__hex_literal] = ACTIONS(709),
    [sym__number_literal] = ACTIONS(711),
    [anon_sym_SQUOTE] = ACTIONS(435),
    [anon_sym_DQUOTE] = ACTIONS(437),
    [sym_dots] = ACTIONS(687),
    [sym_dot_dot_i] = ACTIONS(687),
    [sym_next] = ACTIONS(713),
    [sym_break] = ACTIONS(713),
    [sym_true] = ACTIONS(713),
    [sym_false] = ACTIONS(713),
    [sym_null] = ACTIONS(713),
    [sym_inf] = ACTIONS(713),
    [sym_nan] = ACTIONS(713),
    [anon_sym_NA] = ACTIONS(715),
    [anon_sym_NA_integer_] = ACTIONS(715),
    [anon_sym_NA_real_] = ACTIONS(715),
    [anon_sym_NA_complex_] = ACTIONS(715),
    [anon_sym_NA_character_] = ACTIONS(715),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(717),
    [sym__semicolon] = ACTIONS(717),
    [sym__raw_string_open] = ACTIONS(439),
    [sym__external_open_parenthesis] = ACTIONS(719),
    [sym__external_open_brace] = ACTIONS(721),
    [sym__external_close_brace] = ACTIONS(840),
  },
  [383] = {
    [sym_function_definition] = STATE(189),
    [sym_if_statement] = STATE(189),
    [sym_for_statement] = STATE(189),
    [sym_while_statement] = STATE(189),
    [sym_repeat_statement] = STATE(189),
    [sym_braced_expression] = STATE(189),
    [sym_parenthesized_expression] = STATE(189),
    [sym_call] = STATE(189),
    [sym_subset] = STATE(189),
    [sym_subset2] = STATE(189),
    [sym_unary_operator] = STATE(189),
    [sym_binary_operator] = STATE(189),
    [sym_extract_operator] = STATE(189),
    [sym_namespace_operator] = STATE(189),
    [sym_integer] = STATE(189),
    [sym_complex] = STATE(189),
    [sym_float] = STATE(189),
    [sym__float_literal] = STATE(330),
    [sym_string] = STATE(311),
    [sym__raw_string] = STATE(331),
    [sym__single_quoted_string] = STATE(332),
    [sym__double_quoted_string] = STATE(333),
    [sym_na] = STATE(189),
    [sym__expression] = STATE(189),
    [sym__open_parenthesis] = STATE(1070),
    [sym__open_brace] = STATE(384),
    [sym__close_brace] = STATE(413),
    [aux_sym_braced_expression_repeat1] = STATE(415),
    [sym_identifier] = ACTIONS(687),
    [anon_sym_BSLASH] = ACTIONS(689),
    [anon_sym_function] = ACTIONS(691),
    [anon_sym_if] = ACTIONS(693),
    [anon_sym_for] = ACTIONS(695),
    [anon_sym_while] = ACTIONS(697),
    [anon_sym_repeat] = ACTIONS(699),
    [anon_sym_QMARK] = ACTIONS(701),
    [anon_sym_TILDE] = ACTIONS(703),
    [anon_sym_BANG] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [sym__hex_literal] = ACTIONS(709),
    [sym__number_literal] = ACTIONS(711),
    [anon_sym_SQUOTE] = ACTIONS(435),
    [anon_sym_DQUOTE] = ACTIONS(437),
    [sym_dots] = ACTIONS(687),
    [sym_dot_dot_i] = ACTIONS(687),
    [sym_next] = ACTIONS(713),
    [sym_break] = ACTIONS(713),
    [sym_true] = ACTIONS(713),
    [sym_false] = ACTIONS(713),
    [sym_null] = ACTIONS(713),
    [sym_inf] = ACTIONS(713),
    [sym_nan] = ACTIONS(713),
    [anon_sym_NA] = ACTIONS(715),
    [anon_sym_NA_integer_] = ACTIONS(715),
    [anon_sym_NA_real_] = ACTIONS(715),
    [anon_sym_NA_complex_] = ACTIONS(715),
    [anon_sym_NA_character_] = ACTIONS(715),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(717),
    [sym__semicolon] = ACTIONS(717),
    [sym__raw_string_open] = ACTIONS(439),
    [sym__external_open_parenthesis] = ACTIONS(719),
    [sym__external_open_brace] = ACTIONS(721),
    [sym__external_close_brace] = ACTIONS(842),
  },
  [384] = {
    [sym_function_definition] = STATE(189),
    [sym_if_statement] = STATE(189),
    [sym_for_statement] = STATE(189),
    [sym_while_statement] = STATE(189),
    [sym_repeat_statement] = STATE(189),
    [sym_braced_expression] = STATE(189),
    [sym_parenthesized_expression] = STATE(189),
    [sym_call] = STATE(189),
    [sym_subset] = STATE(189),
    [sym_subset2] = STATE(189),
    [sym_unary_operator] = STATE(189),
    [sym_binary_operator] = STATE(189),
    [sym_extract_operator] = STATE(189),
    [sym_namespace_operator] = STATE(189),
    [sym_integer] = STATE(189),
    [sym_complex] = STATE(189),
    [sym_float] = STATE(189),
    [sym__float_literal] = STATE(330),
    [sym_string] = STATE(311),
    [sym__raw_string] = STATE(331),
    [sym__single_quoted_string] = STATE(332),
    [sym__double_quoted_string] = STATE(333),
    [sym_na] = STATE(189),
    [sym__expression] = STATE(189),
    [sym__open_parenthesis] = STATE(1070),
    [sym__open_brace] = STATE(384),
    [sym__close_brace] = STATE(419),
    [aux_sym_braced_expression_repeat1] = STATE(382),
    [sym_identifier] = ACTIONS(687),
    [anon_sym_BSLASH] = ACTIONS(689),
    [anon_sym_function] = ACTIONS(691),
    [anon_sym_if] = ACTIONS(693),
    [anon_sym_for] = ACTIONS(695),
    [anon_sym_while] = ACTIONS(697),
    [anon_sym_repeat] = ACTIONS(699),
    [anon_sym_QMARK] = ACTIONS(701),
    [anon_sym_TILDE] = ACTIONS(703),
    [anon_sym_BANG] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [sym__hex_literal] = ACTIONS(709),
    [sym__number_literal] = ACTIONS(711),
    [anon_sym_SQUOTE] = ACTIONS(435),
    [anon_sym_DQUOTE] = ACTIONS(437),
    [sym_dots] = ACTIONS(687),
    [sym_dot_dot_i] = ACTIONS(687),
    [sym_next] = ACTIONS(713),
    [sym_break] = ACTIONS(713),
    [sym_true] = ACTIONS(713),
    [sym_false] = ACTIONS(713),
    [sym_null] = ACTIONS(713),
    [sym_inf] = ACTIONS(713),
    [sym_nan] = ACTIONS(713),
    [anon_sym_NA] = ACTIONS(715),
    [anon_sym_NA_integer_] = ACTIONS(715),
    [anon_sym_NA_real_] = ACTIONS(715),
    [anon_sym_NA_complex_] = ACTIONS(715),
    [anon_sym_NA_character_] = ACTIONS(715),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(717),
    [sym__semicolon] = ACTIONS(717),
    [sym__raw_string_open] = ACTIONS(439),
    [sym__external_open_parenthesis] = ACTIONS(719),
    [sym__external_open_brace] = ACTIONS(721),
    [sym__external_close_brace] = ACTIONS(844),
  },
  [385] = {
    [sym_function_definition] = STATE(189),
    [sym_if_statement] = STATE(189),
    [sym_for_statement] = STATE(189),
    [sym_while_statement] = STATE(189),
    [sym_repeat_statement] = STATE(189),
    [sym_braced_expression] = STATE(189),
    [sym_parenthesized_expression] = STATE(189),
    [sym_call] = STATE(189),
    [sym_subset] = STATE(189),
    [sym_subset2] = STATE(189),
    [sym_unary_operator] = STATE(189),
    [sym_binary_operator] = STATE(189),
    [sym_extract_operator] = STATE(189),
    [sym_namespace_operator] = STATE(189),
    [sym_integer] = STATE(189),
    [sym_complex] = STATE(189),
    [sym_float] = STATE(189),
    [sym__float_literal] = STATE(330),
    [sym_string] = STATE(311),
    [sym__raw_string] = STATE(331),
    [sym__single_quoted_string] = STATE(332),
    [sym__double_quoted_string] = STATE(333),
    [sym_na] = STATE(189),
    [sym__expression] = STATE(189),
    [sym__open_parenthesis] = STATE(1070),
    [sym__open_brace] = STATE(384),
    [sym__close_brace] = STATE(1655),
    [aux_sym_braced_expression_repeat1] = STATE(415),
    [sym_identifier] = ACTIONS(687),
    [anon_sym_BSLASH] = ACTIONS(689),
    [anon_sym_function] = ACTIONS(691),
    [anon_sym_if] = ACTIONS(693),
    [anon_sym_for] = ACTIONS(695),
    [anon_sym_while] = ACTIONS(697),
    [anon_sym_repeat] = ACTIONS(699),
    [anon_sym_QMARK] = ACTIONS(701),
    [anon_sym_TILDE] = ACTIONS(703),
    [anon_sym_BANG] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [sym__hex_literal] = ACTIONS(709),
    [sym__number_literal] = ACTIONS(711),
    [anon_sym_SQUOTE] = ACTIONS(435),
    [anon_sym_DQUOTE] = ACTIONS(437),
    [sym_dots] = ACTIONS(687),
    [sym_dot_dot_i] = ACTIONS(687),
    [sym_next] = ACTIONS(713),
    [sym_break] = ACTIONS(713),
    [sym_true] = ACTIONS(713),
    [sym_false] = ACTIONS(713),
    [sym_null] = ACTIONS(713),
    [sym_inf] = ACTIONS(713),
    [sym_nan] = ACTIONS(713),
    [anon_sym_NA] = ACTIONS(715),
    [anon_sym_NA_integer_] = ACTIONS(715),
    [anon_sym_NA_real_] = ACTIONS(715),
    [anon_sym_NA_complex_] = ACTIONS(715),
    [anon_sym_NA_character_] = ACTIONS(715),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(717),
    [sym__semicolon] = ACTIONS(717),
    [sym__raw_string_open] = ACTIONS(439),
    [sym__external_open_parenthesis] = ACTIONS(719),
    [sym__external_open_brace] = ACTIONS(721),
    [sym__external_close_brace] = ACTIONS(846),
  },
  [386] = {
    [sym_function_definition] = STATE(189),
    [sym_if_statement] = STATE(189),
    [sym_for_statement] = STATE(189),
    [sym_while_statement] = STATE(189),
    [sym_repeat_statement] = STATE(189),
    [sym_braced_expression] = STATE(189),
    [sym_parenthesized_expression] = STATE(189),
    [sym_call] = STATE(189),
    [sym_subset] = STATE(189),
    [sym_subset2] = STATE(189),
    [sym_unary_operator] = STATE(189),
    [sym_binary_operator] = STATE(189),
    [sym_extract_operator] = STATE(189),
    [sym_namespace_operator] = STATE(189),
    [sym_integer] = STATE(189),
    [sym_complex] = STATE(189),
    [sym_float] = STATE(189),
    [sym__float_literal] = STATE(330),
    [sym_string] = STATE(311),
    [sym__raw_string] = STATE(331),
    [sym__single_quoted_string] = STATE(332),
    [sym__double_quoted_string] = STATE(333),
    [sym_na] = STATE(189),
    [sym__expression] = STATE(189),
    [sym__open_parenthesis] = STATE(1070),
    [sym__open_brace] = STATE(384),
    [sym__close_brace] = STATE(1790),
    [aux_sym_braced_expression_repeat1] = STATE(351),
    [sym_identifier] = ACTIONS(687),
    [anon_sym_BSLASH] = ACTIONS(689),
    [anon_sym_function] = ACTIONS(691),
    [anon_sym_if] = ACTIONS(693),
    [anon_sym_for] = ACTIONS(695),
    [anon_sym_while] = ACTIONS(697),
    [anon_sym_repeat] = ACTIONS(699),
    [anon_sym_QMARK] = ACTIONS(701),
    [anon_sym_TILDE] = ACTIONS(703),
    [anon_sym_BANG] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [sym__hex_literal] = ACTIONS(709),
    [sym__number_literal] = ACTIONS(711),
    [anon_sym_SQUOTE] = ACTIONS(435),
    [anon_sym_DQUOTE] = ACTIONS(437),
    [sym_dots] = ACTIONS(687),
    [sym_dot_dot_i] = ACTIONS(687),
    [sym_next] = ACTIONS(713),
    [sym_break] = ACTIONS(713),
    [sym_true] = ACTIONS(713),
    [sym_false] = ACTIONS(713),
    [sym_null] = ACTIONS(713),
    [sym_inf] = ACTIONS(713),
    [sym_nan] = ACTIONS(713),
    [anon_sym_NA] = ACTIONS(715),
    [anon_sym_NA_integer_] = ACTIONS(715),
    [anon_sym_NA_real_] = ACTIONS(715),
    [anon_sym_NA_complex_] = ACTIONS(715),
    [anon_sym_NA_character_] = ACTIONS(715),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(717),
    [sym__semicolon] = ACTIONS(717),
    [sym__raw_string_open] = ACTIONS(439),
    [sym__external_open_parenthesis] = ACTIONS(719),
    [sym__external_open_brace] = ACTIONS(721),
    [sym__external_close_brace] = ACTIONS(848),
  },
  [387] = {
    [ts_builtin_sym_end] = ACTIONS(743),
    [sym_identifier] = ACTIONS(741),
    [anon_sym_BSLASH] = ACTIONS(743),
    [anon_sym_function] = ACTIONS(741),
    [anon_sym_EQ] = ACTIONS(741),
    [anon_sym_if] = ACTIONS(741),
    [anon_sym_for] = ACTIONS(741),
    [anon_sym_while] = ACTIONS(741),
    [anon_sym_repeat] = ACTIONS(741),
    [anon_sym_QMARK] = ACTIONS(743),
    [anon_sym_TILDE] = ACTIONS(743),
    [anon_sym_BANG] = ACTIONS(741),
    [anon_sym_PLUS] = ACTIONS(743),
    [anon_sym_DASH] = ACTIONS(741),
    [anon_sym_LT_DASH] = ACTIONS(743),
    [anon_sym_LT_LT_DASH] = ACTIONS(743),
    [anon_sym_COLON_EQ] = ACTIONS(743),
    [anon_sym_DASH_GT] = ACTIONS(741),
    [anon_sym_DASH_GT_GT] = ACTIONS(743),
    [anon_sym_PIPE] = ACTIONS(741),
    [anon_sym_AMP] = ACTIONS(741),
    [anon_sym_PIPE_PIPE] = ACTIONS(743),
    [anon_sym_AMP_AMP] = ACTIONS(743),
    [anon_sym_LT] = ACTIONS(741),
    [anon_sym_LT_EQ] = ACTIONS(743),
    [anon_sym_GT] = ACTIONS(741),
    [anon_sym_GT_EQ] = ACTIONS(743),
    [anon_sym_EQ_EQ] = ACTIONS(743),
    [anon_sym_BANG_EQ] = ACTIONS(743),
    [anon_sym_STAR] = ACTIONS(741),
    [anon_sym_SLASH] = ACTIONS(743),
    [anon_sym_STAR_STAR] = ACTIONS(743),
    [anon_sym_CARET] = ACTIONS(743),
    [aux_sym_binary_operator_token1] = ACTIONS(743),
    [anon_sym_PIPE_GT] = ACTIONS(743),
    [anon_sym_COLON] = ACTIONS(741),
    [anon_sym_DOLLAR] = ACTIONS(743),
    [anon_sym_AT] = ACTIONS(743),
    [sym__hex_literal] = ACTIONS(743),
    [sym__number_literal] = ACTIONS(741),
    [anon_sym_SQUOTE] = ACTIONS(743),
    [anon_sym_DQUOTE] = ACTIONS(743),
    [sym_dots] = ACTIONS(741),
    [sym_dot_dot_i] = ACTIONS(741),
    [sym_next] = ACTIONS(741),
    [sym_break] = ACTIONS(741),
    [sym_true] = ACTIONS(741),
    [sym_false] = ACTIONS(741),
    [sym_null] = ACTIONS(741),
    [sym_inf] = ACTIONS(741),
    [sym_nan] = ACTIONS(741),
    [anon_sym_NA] = ACTIONS(741),
    [anon_sym_NA_integer_] = ACTIONS(741),
    [anon_sym_NA_real_] = ACTIONS(741),
    [anon_sym_NA_complex_] = ACTIONS(741),
    [anon_sym_NA_character_] = ACTIONS(741),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(743),
    [sym__semicolon] = ACTIONS(743),
    [sym__raw_string_open] = ACTIONS(743),
    [sym__external_else] = ACTIONS(743),
    [sym__external_open_parenthesis] = ACTIONS(743),
    [sym__external_open_brace] = ACTIONS(743),
    [sym__external_open_bracket] = ACTIONS(743),
    [sym__external_open_bracket2] = ACTIONS(743),
  },
  [388] = {
    [sym_identifier] = ACTIONS(790),
    [anon_sym_BSLASH] = ACTIONS(788),
    [anon_sym_function] = ACTIONS(790),
    [anon_sym_EQ] = ACTIONS(790),
    [anon_sym_if] = ACTIONS(790),
    [anon_sym_for] = ACTIONS(790),
    [anon_sym_while] = ACTIONS(790),
    [anon_sym_repeat] = ACTIONS(790),
    [anon_sym_QMARK] = ACTIONS(788),
    [anon_sym_TILDE] = ACTIONS(788),
    [anon_sym_BANG] = ACTIONS(790),
    [anon_sym_PLUS] = ACTIONS(788),
    [anon_sym_DASH] = ACTIONS(790),
    [anon_sym_LT_DASH] = ACTIONS(788),
    [anon_sym_LT_LT_DASH] = ACTIONS(788),
    [anon_sym_COLON_EQ] = ACTIONS(788),
    [anon_sym_DASH_GT] = ACTIONS(790),
    [anon_sym_DASH_GT_GT] = ACTIONS(788),
    [anon_sym_PIPE] = ACTIONS(790),
    [anon_sym_AMP] = ACTIONS(790),
    [anon_sym_PIPE_PIPE] = ACTIONS(788),
    [anon_sym_AMP_AMP] = ACTIONS(788),
    [anon_sym_LT] = ACTIONS(790),
    [anon_sym_LT_EQ] = ACTIONS(788),
    [anon_sym_GT] = ACTIONS(790),
    [anon_sym_GT_EQ] = ACTIONS(788),
    [anon_sym_EQ_EQ] = ACTIONS(788),
    [anon_sym_BANG_EQ] = ACTIONS(788),
    [anon_sym_STAR] = ACTIONS(790),
    [anon_sym_SLASH] = ACTIONS(788),
    [anon_sym_STAR_STAR] = ACTIONS(788),
    [anon_sym_CARET] = ACTIONS(788),
    [aux_sym_binary_operator_token1] = ACTIONS(788),
    [anon_sym_PIPE_GT] = ACTIONS(788),
    [anon_sym_COLON] = ACTIONS(790),
    [anon_sym_DOLLAR] = ACTIONS(788),
    [anon_sym_AT] = ACTIONS(788),
    [sym__hex_literal] = ACTIONS(788),
    [sym__number_literal] = ACTIONS(790),
    [anon_sym_SQUOTE] = ACTIONS(788),
    [anon_sym_DQUOTE] = ACTIONS(788),
    [sym_dots] = ACTIONS(790),
    [sym_dot_dot_i] = ACTIONS(790),
    [sym_next] = ACTIONS(790),
    [sym_break] = ACTIONS(790),
    [sym_true] = ACTIONS(790),
    [sym_false] = ACTIONS(790),
    [sym_null] = ACTIONS(790),
    [sym_inf] = ACTIONS(790),
    [sym_nan] = ACTIONS(790),
    [anon_sym_NA] = ACTIONS(790),
    [anon_sym_NA_integer_] = ACTIONS(790),
    [anon_sym_NA_real_] = ACTIONS(790),
    [anon_sym_NA_complex_] = ACTIONS(790),
    [anon_sym_NA_character_] = ACTIONS(790),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(788),
    [sym__semicolon] = ACTIONS(788),
    [sym__raw_string_open] = ACTIONS(788),
    [sym__external_else] = ACTIONS(788),
    [sym__external_open_parenthesis] = ACTIONS(788),
    [sym__external_open_brace] = ACTIONS(788),
    [sym__external_close_brace] = ACTIONS(788),
    [sym__external_open_bracket] = ACTIONS(788),
    [sym__external_open_bracket2] = ACTIONS(788),
  },
  [389] = {
    [sym_function_definition] = STATE(189),
    [sym_if_statement] = STATE(189),
    [sym_for_statement] = STATE(189),
    [sym_while_statement] = STATE(189),
    [sym_repeat_statement] = STATE(189),
    [sym_braced_expression] = STATE(189),
    [sym_parenthesized_expression] = STATE(189),
    [sym_call] = STATE(189),
    [sym_subset] = STATE(189),
    [sym_subset2] = STATE(189),
    [sym_unary_operator] = STATE(189),
    [sym_binary_operator] = STATE(189),
    [sym_extract_operator] = STATE(189),
    [sym_namespace_operator] = STATE(189),
    [sym_integer] = STATE(189),
    [sym_complex] = STATE(189),
    [sym_float] = STATE(189),
    [sym__float_literal] = STATE(330),
    [sym_string] = STATE(311),
    [sym__raw_string] = STATE(331),
    [sym__single_quoted_string] = STATE(332),
    [sym__double_quoted_string] = STATE(333),
    [sym_na] = STATE(189),
    [sym__expression] = STATE(189),
    [sym__open_parenthesis] = STATE(1070),
    [sym__open_brace] = STATE(384),
    [sym__close_brace] = STATE(1764),
    [aux_sym_braced_expression_repeat1] = STATE(352),
    [sym_identifier] = ACTIONS(687),
    [anon_sym_BSLASH] = ACTIONS(689),
    [anon_sym_function] = ACTIONS(691),
    [anon_sym_if] = ACTIONS(693),
    [anon_sym_for] = ACTIONS(695),
    [anon_sym_while] = ACTIONS(697),
    [anon_sym_repeat] = ACTIONS(699),
    [anon_sym_QMARK] = ACTIONS(701),
    [anon_sym_TILDE] = ACTIONS(703),
    [anon_sym_BANG] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [sym__hex_literal] = ACTIONS(709),
    [sym__number_literal] = ACTIONS(711),
    [anon_sym_SQUOTE] = ACTIONS(435),
    [anon_sym_DQUOTE] = ACTIONS(437),
    [sym_dots] = ACTIONS(687),
    [sym_dot_dot_i] = ACTIONS(687),
    [sym_next] = ACTIONS(713),
    [sym_break] = ACTIONS(713),
    [sym_true] = ACTIONS(713),
    [sym_false] = ACTIONS(713),
    [sym_null] = ACTIONS(713),
    [sym_inf] = ACTIONS(713),
    [sym_nan] = ACTIONS(713),
    [anon_sym_NA] = ACTIONS(715),
    [anon_sym_NA_integer_] = ACTIONS(715),
    [anon_sym_NA_real_] = ACTIONS(715),
    [anon_sym_NA_complex_] = ACTIONS(715),
    [anon_sym_NA_character_] = ACTIONS(715),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(717),
    [sym__semicolon] = ACTIONS(717),
    [sym__raw_string_open] = ACTIONS(439),
    [sym__external_open_parenthesis] = ACTIONS(719),
    [sym__external_open_brace] = ACTIONS(721),
    [sym__external_close_brace] = ACTIONS(850),
  },
  [390] = {
    [ts_builtin_sym_end] = ACTIONS(747),
    [sym_identifier] = ACTIONS(745),
    [anon_sym_BSLASH] = ACTIONS(747),
    [anon_sym_function] = ACTIONS(745),
    [anon_sym_EQ] = ACTIONS(745),
    [anon_sym_if] = ACTIONS(745),
    [anon_sym_for] = ACTIONS(745),
    [anon_sym_while] = ACTIONS(745),
    [anon_sym_repeat] = ACTIONS(745),
    [anon_sym_QMARK] = ACTIONS(747),
    [anon_sym_TILDE] = ACTIONS(747),
    [anon_sym_BANG] = ACTIONS(745),
    [anon_sym_PLUS] = ACTIONS(747),
    [anon_sym_DASH] = ACTIONS(745),
    [anon_sym_LT_DASH] = ACTIONS(747),
    [anon_sym_LT_LT_DASH] = ACTIONS(747),
    [anon_sym_COLON_EQ] = ACTIONS(747),
    [anon_sym_DASH_GT] = ACTIONS(745),
    [anon_sym_DASH_GT_GT] = ACTIONS(747),
    [anon_sym_PIPE] = ACTIONS(745),
    [anon_sym_AMP] = ACTIONS(745),
    [anon_sym_PIPE_PIPE] = ACTIONS(747),
    [anon_sym_AMP_AMP] = ACTIONS(747),
    [anon_sym_LT] = ACTIONS(745),
    [anon_sym_LT_EQ] = ACTIONS(747),
    [anon_sym_GT] = ACTIONS(745),
    [anon_sym_GT_EQ] = ACTIONS(747),
    [anon_sym_EQ_EQ] = ACTIONS(747),
    [anon_sym_BANG_EQ] = ACTIONS(747),
    [anon_sym_STAR] = ACTIONS(745),
    [anon_sym_SLASH] = ACTIONS(747),
    [anon_sym_STAR_STAR] = ACTIONS(747),
    [anon_sym_CARET] = ACTIONS(747),
    [aux_sym_binary_operator_token1] = ACTIONS(747),
    [anon_sym_PIPE_GT] = ACTIONS(747),
    [anon_sym_COLON] = ACTIONS(745),
    [anon_sym_DOLLAR] = ACTIONS(747),
    [anon_sym_AT] = ACTIONS(747),
    [sym__hex_literal] = ACTIONS(747),
    [sym__number_literal] = ACTIONS(745),
    [anon_sym_SQUOTE] = ACTIONS(747),
    [anon_sym_DQUOTE] = ACTIONS(747),
    [sym_dots] = ACTIONS(745),
    [sym_dot_dot_i] = ACTIONS(745),
    [sym_next] = ACTIONS(745),
    [sym_break] = ACTIONS(745),
    [sym_true] = ACTIONS(745),
    [sym_false] = ACTIONS(745),
    [sym_null] = ACTIONS(745),
    [sym_inf] = ACTIONS(745),
    [sym_nan] = ACTIONS(745),
    [anon_sym_NA] = ACTIONS(745),
    [anon_sym_NA_integer_] = ACTIONS(745),
    [anon_sym_NA_real_] = ACTIONS(745),
    [anon_sym_NA_complex_] = ACTIONS(745),
    [anon_sym_NA_character_] = ACTIONS(745),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(747),
    [sym__semicolon] = ACTIONS(747),
    [sym__raw_string_open] = ACTIONS(747),
    [sym__external_else] = ACTIONS(747),
    [sym__external_open_parenthesis] = ACTIONS(747),
    [sym__external_open_brace] = ACTIONS(747),
    [sym__external_open_bracket] = ACTIONS(747),
    [sym__external_open_bracket2] = ACTIONS(747),
  },
  [391] = {
    [ts_builtin_sym_end] = ACTIONS(751),
    [sym_identifier] = ACTIONS(749),
    [anon_sym_BSLASH] = ACTIONS(751),
    [anon_sym_function] = ACTIONS(749),
    [anon_sym_EQ] = ACTIONS(749),
    [anon_sym_if] = ACTIONS(749),
    [anon_sym_for] = ACTIONS(749),
    [anon_sym_while] = ACTIONS(749),
    [anon_sym_repeat] = ACTIONS(749),
    [anon_sym_QMARK] = ACTIONS(751),
    [anon_sym_TILDE] = ACTIONS(751),
    [anon_sym_BANG] = ACTIONS(749),
    [anon_sym_PLUS] = ACTIONS(751),
    [anon_sym_DASH] = ACTIONS(749),
    [anon_sym_LT_DASH] = ACTIONS(751),
    [anon_sym_LT_LT_DASH] = ACTIONS(751),
    [anon_sym_COLON_EQ] = ACTIONS(751),
    [anon_sym_DASH_GT] = ACTIONS(749),
    [anon_sym_DASH_GT_GT] = ACTIONS(751),
    [anon_sym_PIPE] = ACTIONS(749),
    [anon_sym_AMP] = ACTIONS(749),
    [anon_sym_PIPE_PIPE] = ACTIONS(751),
    [anon_sym_AMP_AMP] = ACTIONS(751),
    [anon_sym_LT] = ACTIONS(749),
    [anon_sym_LT_EQ] = ACTIONS(751),
    [anon_sym_GT] = ACTIONS(749),
    [anon_sym_GT_EQ] = ACTIONS(751),
    [anon_sym_EQ_EQ] = ACTIONS(751),
    [anon_sym_BANG_EQ] = ACTIONS(751),
    [anon_sym_STAR] = ACTIONS(749),
    [anon_sym_SLASH] = ACTIONS(751),
    [anon_sym_STAR_STAR] = ACTIONS(751),
    [anon_sym_CARET] = ACTIONS(751),
    [aux_sym_binary_operator_token1] = ACTIONS(751),
    [anon_sym_PIPE_GT] = ACTIONS(751),
    [anon_sym_COLON] = ACTIONS(749),
    [anon_sym_DOLLAR] = ACTIONS(751),
    [anon_sym_AT] = ACTIONS(751),
    [sym__hex_literal] = ACTIONS(751),
    [sym__number_literal] = ACTIONS(749),
    [anon_sym_SQUOTE] = ACTIONS(751),
    [anon_sym_DQUOTE] = ACTIONS(751),
    [sym_dots] = ACTIONS(749),
    [sym_dot_dot_i] = ACTIONS(749),
    [sym_next] = ACTIONS(749),
    [sym_break] = ACTIONS(749),
    [sym_true] = ACTIONS(749),
    [sym_false] = ACTIONS(749),
    [sym_null] = ACTIONS(749),
    [sym_inf] = ACTIONS(749),
    [sym_nan] = ACTIONS(749),
    [anon_sym_NA] = ACTIONS(749),
    [anon_sym_NA_integer_] = ACTIONS(749),
    [anon_sym_NA_real_] = ACTIONS(749),
    [anon_sym_NA_complex_] = ACTIONS(749),
    [anon_sym_NA_character_] = ACTIONS(749),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(751),
    [sym__semicolon] = ACTIONS(751),
    [sym__raw_string_open] = ACTIONS(751),
    [sym__external_else] = ACTIONS(751),
    [sym__external_open_parenthesis] = ACTIONS(751),
    [sym__external_open_brace] = ACTIONS(751),
    [sym__external_open_bracket] = ACTIONS(751),
    [sym__external_open_bracket2] = ACTIONS(751),
  },
  [392] = {
    [ts_builtin_sym_end] = ACTIONS(755),
    [sym_identifier] = ACTIONS(753),
    [anon_sym_BSLASH] = ACTIONS(755),
    [anon_sym_function] = ACTIONS(753),
    [anon_sym_EQ] = ACTIONS(753),
    [anon_sym_if] = ACTIONS(753),
    [anon_sym_for] = ACTIONS(753),
    [anon_sym_while] = ACTIONS(753),
    [anon_sym_repeat] = ACTIONS(753),
    [anon_sym_QMARK] = ACTIONS(755),
    [anon_sym_TILDE] = ACTIONS(755),
    [anon_sym_BANG] = ACTIONS(753),
    [anon_sym_PLUS] = ACTIONS(755),
    [anon_sym_DASH] = ACTIONS(753),
    [anon_sym_LT_DASH] = ACTIONS(755),
    [anon_sym_LT_LT_DASH] = ACTIONS(755),
    [anon_sym_COLON_EQ] = ACTIONS(755),
    [anon_sym_DASH_GT] = ACTIONS(753),
    [anon_sym_DASH_GT_GT] = ACTIONS(755),
    [anon_sym_PIPE] = ACTIONS(753),
    [anon_sym_AMP] = ACTIONS(753),
    [anon_sym_PIPE_PIPE] = ACTIONS(755),
    [anon_sym_AMP_AMP] = ACTIONS(755),
    [anon_sym_LT] = ACTIONS(753),
    [anon_sym_LT_EQ] = ACTIONS(755),
    [anon_sym_GT] = ACTIONS(753),
    [anon_sym_GT_EQ] = ACTIONS(755),
    [anon_sym_EQ_EQ] = ACTIONS(755),
    [anon_sym_BANG_EQ] = ACTIONS(755),
    [anon_sym_STAR] = ACTIONS(753),
    [anon_sym_SLASH] = ACTIONS(755),
    [anon_sym_STAR_STAR] = ACTIONS(755),
    [anon_sym_CARET] = ACTIONS(755),
    [aux_sym_binary_operator_token1] = ACTIONS(755),
    [anon_sym_PIPE_GT] = ACTIONS(755),
    [anon_sym_COLON] = ACTIONS(753),
    [anon_sym_DOLLAR] = ACTIONS(755),
    [anon_sym_AT] = ACTIONS(755),
    [sym__hex_literal] = ACTIONS(755),
    [sym__number_literal] = ACTIONS(753),
    [anon_sym_SQUOTE] = ACTIONS(755),
    [anon_sym_DQUOTE] = ACTIONS(755),
    [sym_dots] = ACTIONS(753),
    [sym_dot_dot_i] = ACTIONS(753),
    [sym_next] = ACTIONS(753),
    [sym_break] = ACTIONS(753),
    [sym_true] = ACTIONS(753),
    [sym_false] = ACTIONS(753),
    [sym_null] = ACTIONS(753),
    [sym_inf] = ACTIONS(753),
    [sym_nan] = ACTIONS(753),
    [anon_sym_NA] = ACTIONS(753),
    [anon_sym_NA_integer_] = ACTIONS(753),
    [anon_sym_NA_real_] = ACTIONS(753),
    [anon_sym_NA_complex_] = ACTIONS(753),
    [anon_sym_NA_character_] = ACTIONS(753),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(755),
    [sym__semicolon] = ACTIONS(755),
    [sym__raw_string_open] = ACTIONS(755),
    [sym__external_else] = ACTIONS(755),
    [sym__external_open_parenthesis] = ACTIONS(755),
    [sym__external_open_brace] = ACTIONS(755),
    [sym__external_open_bracket] = ACTIONS(755),
    [sym__external_open_bracket2] = ACTIONS(755),
  },
  [393] = {
    [sym_function_definition] = STATE(189),
    [sym_if_statement] = STATE(189),
    [sym_for_statement] = STATE(189),
    [sym_while_statement] = STATE(189),
    [sym_repeat_statement] = STATE(189),
    [sym_braced_expression] = STATE(189),
    [sym_parenthesized_expression] = STATE(189),
    [sym_call] = STATE(189),
    [sym_subset] = STATE(189),
    [sym_subset2] = STATE(189),
    [sym_unary_operator] = STATE(189),
    [sym_binary_operator] = STATE(189),
    [sym_extract_operator] = STATE(189),
    [sym_namespace_operator] = STATE(189),
    [sym_integer] = STATE(189),
    [sym_complex] = STATE(189),
    [sym_float] = STATE(189),
    [sym__float_literal] = STATE(330),
    [sym_string] = STATE(311),
    [sym__raw_string] = STATE(331),
    [sym__single_quoted_string] = STATE(332),
    [sym__double_quoted_string] = STATE(333),
    [sym_na] = STATE(189),
    [sym__expression] = STATE(189),
    [sym__open_parenthesis] = STATE(1070),
    [sym__open_brace] = STATE(384),
    [sym__close_brace] = STATE(377),
    [aux_sym_braced_expression_repeat1] = STATE(378),
    [sym_identifier] = ACTIONS(687),
    [anon_sym_BSLASH] = ACTIONS(689),
    [anon_sym_function] = ACTIONS(691),
    [anon_sym_if] = ACTIONS(693),
    [anon_sym_for] = ACTIONS(695),
    [anon_sym_while] = ACTIONS(697),
    [anon_sym_repeat] = ACTIONS(699),
    [anon_sym_QMARK] = ACTIONS(701),
    [anon_sym_TILDE] = ACTIONS(703),
    [anon_sym_BANG] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [sym__hex_literal] = ACTIONS(709),
    [sym__number_literal] = ACTIONS(711),
    [anon_sym_SQUOTE] = ACTIONS(435),
    [anon_sym_DQUOTE] = ACTIONS(437),
    [sym_dots] = ACTIONS(687),
    [sym_dot_dot_i] = ACTIONS(687),
    [sym_next] = ACTIONS(713),
    [sym_break] = ACTIONS(713),
    [sym_true] = ACTIONS(713),
    [sym_false] = ACTIONS(713),
    [sym_null] = ACTIONS(713),
    [sym_inf] = ACTIONS(713),
    [sym_nan] = ACTIONS(713),
    [anon_sym_NA] = ACTIONS(715),
    [anon_sym_NA_integer_] = ACTIONS(715),
    [anon_sym_NA_real_] = ACTIONS(715),
    [anon_sym_NA_complex_] = ACTIONS(715),
    [anon_sym_NA_character_] = ACTIONS(715),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(717),
    [sym__semicolon] = ACTIONS(717),
    [sym__raw_string_open] = ACTIONS(439),
    [sym__external_open_parenthesis] = ACTIONS(719),
    [sym__external_open_brace] = ACTIONS(721),
    [sym__external_close_brace] = ACTIONS(852),
  },
  [394] = {
    [ts_builtin_sym_end] = ACTIONS(759),
    [sym_identifier] = ACTIONS(757),
    [anon_sym_BSLASH] = ACTIONS(759),
    [anon_sym_function] = ACTIONS(757),
    [anon_sym_EQ] = ACTIONS(757),
    [anon_sym_if] = ACTIONS(757),
    [anon_sym_for] = ACTIONS(757),
    [anon_sym_while] = ACTIONS(757),
    [anon_sym_repeat] = ACTIONS(757),
    [anon_sym_QMARK] = ACTIONS(759),
    [anon_sym_TILDE] = ACTIONS(759),
    [anon_sym_BANG] = ACTIONS(757),
    [anon_sym_PLUS] = ACTIONS(759),
    [anon_sym_DASH] = ACTIONS(757),
    [anon_sym_LT_DASH] = ACTIONS(759),
    [anon_sym_LT_LT_DASH] = ACTIONS(759),
    [anon_sym_COLON_EQ] = ACTIONS(759),
    [anon_sym_DASH_GT] = ACTIONS(757),
    [anon_sym_DASH_GT_GT] = ACTIONS(759),
    [anon_sym_PIPE] = ACTIONS(757),
    [anon_sym_AMP] = ACTIONS(757),
    [anon_sym_PIPE_PIPE] = ACTIONS(759),
    [anon_sym_AMP_AMP] = ACTIONS(759),
    [anon_sym_LT] = ACTIONS(757),
    [anon_sym_LT_EQ] = ACTIONS(759),
    [anon_sym_GT] = ACTIONS(757),
    [anon_sym_GT_EQ] = ACTIONS(759),
    [anon_sym_EQ_EQ] = ACTIONS(759),
    [anon_sym_BANG_EQ] = ACTIONS(759),
    [anon_sym_STAR] = ACTIONS(757),
    [anon_sym_SLASH] = ACTIONS(759),
    [anon_sym_STAR_STAR] = ACTIONS(759),
    [anon_sym_CARET] = ACTIONS(759),
    [aux_sym_binary_operator_token1] = ACTIONS(759),
    [anon_sym_PIPE_GT] = ACTIONS(759),
    [anon_sym_COLON] = ACTIONS(757),
    [anon_sym_DOLLAR] = ACTIONS(759),
    [anon_sym_AT] = ACTIONS(759),
    [sym__hex_literal] = ACTIONS(759),
    [sym__number_literal] = ACTIONS(757),
    [anon_sym_SQUOTE] = ACTIONS(759),
    [anon_sym_DQUOTE] = ACTIONS(759),
    [sym_dots] = ACTIONS(757),
    [sym_dot_dot_i] = ACTIONS(757),
    [sym_next] = ACTIONS(757),
    [sym_break] = ACTIONS(757),
    [sym_true] = ACTIONS(757),
    [sym_false] = ACTIONS(757),
    [sym_null] = ACTIONS(757),
    [sym_inf] = ACTIONS(757),
    [sym_nan] = ACTIONS(757),
    [anon_sym_NA] = ACTIONS(757),
    [anon_sym_NA_integer_] = ACTIONS(757),
    [anon_sym_NA_real_] = ACTIONS(757),
    [anon_sym_NA_complex_] = ACTIONS(757),
    [anon_sym_NA_character_] = ACTIONS(757),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(759),
    [sym__semicolon] = ACTIONS(759),
    [sym__raw_string_open] = ACTIONS(759),
    [sym__external_else] = ACTIONS(759),
    [sym__external_open_parenthesis] = ACTIONS(759),
    [sym__external_open_brace] = ACTIONS(759),
    [sym__external_open_bracket] = ACTIONS(759),
    [sym__external_open_bracket2] = ACTIONS(759),
  },
  [395] = {
    [sym_function_definition] = STATE(189),
    [sym_if_statement] = STATE(189),
    [sym_for_statement] = STATE(189),
    [sym_while_statement] = STATE(189),
    [sym_repeat_statement] = STATE(189),
    [sym_braced_expression] = STATE(189),
    [sym_parenthesized_expression] = STATE(189),
    [sym_call] = STATE(189),
    [sym_subset] = STATE(189),
    [sym_subset2] = STATE(189),
    [sym_unary_operator] = STATE(189),
    [sym_binary_operator] = STATE(189),
    [sym_extract_operator] = STATE(189),
    [sym_namespace_operator] = STATE(189),
    [sym_integer] = STATE(189),
    [sym_complex] = STATE(189),
    [sym_float] = STATE(189),
    [sym__float_literal] = STATE(330),
    [sym_string] = STATE(311),
    [sym__raw_string] = STATE(331),
    [sym__single_quoted_string] = STATE(332),
    [sym__double_quoted_string] = STATE(333),
    [sym_na] = STATE(189),
    [sym__expression] = STATE(189),
    [sym__open_parenthesis] = STATE(1070),
    [sym__open_brace] = STATE(384),
    [sym__close_brace] = STATE(1695),
    [aux_sym_braced_expression_repeat1] = STATE(385),
    [sym_identifier] = ACTIONS(687),
    [anon_sym_BSLASH] = ACTIONS(689),
    [anon_sym_function] = ACTIONS(691),
    [anon_sym_if] = ACTIONS(693),
    [anon_sym_for] = ACTIONS(695),
    [anon_sym_while] = ACTIONS(697),
    [anon_sym_repeat] = ACTIONS(699),
    [anon_sym_QMARK] = ACTIONS(701),
    [anon_sym_TILDE] = ACTIONS(703),
    [anon_sym_BANG] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [sym__hex_literal] = ACTIONS(709),
    [sym__number_literal] = ACTIONS(711),
    [anon_sym_SQUOTE] = ACTIONS(435),
    [anon_sym_DQUOTE] = ACTIONS(437),
    [sym_dots] = ACTIONS(687),
    [sym_dot_dot_i] = ACTIONS(687),
    [sym_next] = ACTIONS(713),
    [sym_break] = ACTIONS(713),
    [sym_true] = ACTIONS(713),
    [sym_false] = ACTIONS(713),
    [sym_null] = ACTIONS(713),
    [sym_inf] = ACTIONS(713),
    [sym_nan] = ACTIONS(713),
    [anon_sym_NA] = ACTIONS(715),
    [anon_sym_NA_integer_] = ACTIONS(715),
    [anon_sym_NA_real_] = ACTIONS(715),
    [anon_sym_NA_complex_] = ACTIONS(715),
    [anon_sym_NA_character_] = ACTIONS(715),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(717),
    [sym__semicolon] = ACTIONS(717),
    [sym__raw_string_open] = ACTIONS(439),
    [sym__external_open_parenthesis] = ACTIONS(719),
    [sym__external_open_brace] = ACTIONS(721),
    [sym__external_close_brace] = ACTIONS(854),
  },
  [396] = {
    [sym_function_definition] = STATE(189),
    [sym_if_statement] = STATE(189),
    [sym_for_statement] = STATE(189),
    [sym_while_statement] = STATE(189),
    [sym_repeat_statement] = STATE(189),
    [sym_braced_expression] = STATE(189),
    [sym_parenthesized_expression] = STATE(189),
    [sym_call] = STATE(189),
    [sym_subset] = STATE(189),
    [sym_subset2] = STATE(189),
    [sym_unary_operator] = STATE(189),
    [sym_binary_operator] = STATE(189),
    [sym_extract_operator] = STATE(189),
    [sym_namespace_operator] = STATE(189),
    [sym_integer] = STATE(189),
    [sym_complex] = STATE(189),
    [sym_float] = STATE(189),
    [sym__float_literal] = STATE(330),
    [sym_string] = STATE(311),
    [sym__raw_string] = STATE(331),
    [sym__single_quoted_string] = STATE(332),
    [sym__double_quoted_string] = STATE(333),
    [sym_na] = STATE(189),
    [sym__expression] = STATE(189),
    [sym__open_parenthesis] = STATE(1070),
    [sym__open_brace] = STATE(384),
    [sym__close_brace] = STATE(336),
    [aux_sym_braced_expression_repeat1] = STATE(337),
    [sym_identifier] = ACTIONS(687),
    [anon_sym_BSLASH] = ACTIONS(689),
    [anon_sym_function] = ACTIONS(691),
    [anon_sym_if] = ACTIONS(693),
    [anon_sym_for] = ACTIONS(695),
    [anon_sym_while] = ACTIONS(697),
    [anon_sym_repeat] = ACTIONS(699),
    [anon_sym_QMARK] = ACTIONS(701),
    [anon_sym_TILDE] = ACTIONS(703),
    [anon_sym_BANG] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [sym__hex_literal] = ACTIONS(709),
    [sym__number_literal] = ACTIONS(711),
    [anon_sym_SQUOTE] = ACTIONS(435),
    [anon_sym_DQUOTE] = ACTIONS(437),
    [sym_dots] = ACTIONS(687),
    [sym_dot_dot_i] = ACTIONS(687),
    [sym_next] = ACTIONS(713),
    [sym_break] = ACTIONS(713),
    [sym_true] = ACTIONS(713),
    [sym_false] = ACTIONS(713),
    [sym_null] = ACTIONS(713),
    [sym_inf] = ACTIONS(713),
    [sym_nan] = ACTIONS(713),
    [anon_sym_NA] = ACTIONS(715),
    [anon_sym_NA_integer_] = ACTIONS(715),
    [anon_sym_NA_real_] = ACTIONS(715),
    [anon_sym_NA_complex_] = ACTIONS(715),
    [anon_sym_NA_character_] = ACTIONS(715),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(717),
    [sym__semicolon] = ACTIONS(717),
    [sym__raw_string_open] = ACTIONS(439),
    [sym__external_open_parenthesis] = ACTIONS(719),
    [sym__external_open_brace] = ACTIONS(721),
    [sym__external_close_brace] = ACTIONS(856),
  },
  [397] = {
    [ts_builtin_sym_end] = ACTIONS(763),
    [sym_identifier] = ACTIONS(761),
    [anon_sym_BSLASH] = ACTIONS(763),
    [anon_sym_function] = ACTIONS(761),
    [anon_sym_EQ] = ACTIONS(761),
    [anon_sym_if] = ACTIONS(761),
    [anon_sym_for] = ACTIONS(761),
    [anon_sym_while] = ACTIONS(761),
    [anon_sym_repeat] = ACTIONS(761),
    [anon_sym_QMARK] = ACTIONS(763),
    [anon_sym_TILDE] = ACTIONS(763),
    [anon_sym_BANG] = ACTIONS(761),
    [anon_sym_PLUS] = ACTIONS(763),
    [anon_sym_DASH] = ACTIONS(761),
    [anon_sym_LT_DASH] = ACTIONS(763),
    [anon_sym_LT_LT_DASH] = ACTIONS(763),
    [anon_sym_COLON_EQ] = ACTIONS(763),
    [anon_sym_DASH_GT] = ACTIONS(761),
    [anon_sym_DASH_GT_GT] = ACTIONS(763),
    [anon_sym_PIPE] = ACTIONS(761),
    [anon_sym_AMP] = ACTIONS(761),
    [anon_sym_PIPE_PIPE] = ACTIONS(763),
    [anon_sym_AMP_AMP] = ACTIONS(763),
    [anon_sym_LT] = ACTIONS(761),
    [anon_sym_LT_EQ] = ACTIONS(763),
    [anon_sym_GT] = ACTIONS(761),
    [anon_sym_GT_EQ] = ACTIONS(763),
    [anon_sym_EQ_EQ] = ACTIONS(763),
    [anon_sym_BANG_EQ] = ACTIONS(763),
    [anon_sym_STAR] = ACTIONS(761),
    [anon_sym_SLASH] = ACTIONS(763),
    [anon_sym_STAR_STAR] = ACTIONS(763),
    [anon_sym_CARET] = ACTIONS(763),
    [aux_sym_binary_operator_token1] = ACTIONS(763),
    [anon_sym_PIPE_GT] = ACTIONS(763),
    [anon_sym_COLON] = ACTIONS(761),
    [anon_sym_DOLLAR] = ACTIONS(763),
    [anon_sym_AT] = ACTIONS(763),
    [sym__hex_literal] = ACTIONS(763),
    [sym__number_literal] = ACTIONS(761),
    [anon_sym_SQUOTE] = ACTIONS(763),
    [anon_sym_DQUOTE] = ACTIONS(763),
    [sym_dots] = ACTIONS(761),
    [sym_dot_dot_i] = ACTIONS(761),
    [sym_next] = ACTIONS(761),
    [sym_break] = ACTIONS(761),
    [sym_true] = ACTIONS(761),
    [sym_false] = ACTIONS(761),
    [sym_null] = ACTIONS(761),
    [sym_inf] = ACTIONS(761),
    [sym_nan] = ACTIONS(761),
    [anon_sym_NA] = ACTIONS(761),
    [anon_sym_NA_integer_] = ACTIONS(761),
    [anon_sym_NA_real_] = ACTIONS(761),
    [anon_sym_NA_complex_] = ACTIONS(761),
    [anon_sym_NA_character_] = ACTIONS(761),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(763),
    [sym__semicolon] = ACTIONS(763),
    [sym__raw_string_open] = ACTIONS(763),
    [sym__external_else] = ACTIONS(763),
    [sym__external_open_parenthesis] = ACTIONS(763),
    [sym__external_open_brace] = ACTIONS(763),
    [sym__external_open_bracket] = ACTIONS(763),
    [sym__external_open_bracket2] = ACTIONS(763),
  },
  [398] = {
    [sym_function_definition] = STATE(189),
    [sym_if_statement] = STATE(189),
    [sym_for_statement] = STATE(189),
    [sym_while_statement] = STATE(189),
    [sym_repeat_statement] = STATE(189),
    [sym_braced_expression] = STATE(189),
    [sym_parenthesized_expression] = STATE(189),
    [sym_call] = STATE(189),
    [sym_subset] = STATE(189),
    [sym_subset2] = STATE(189),
    [sym_unary_operator] = STATE(189),
    [sym_binary_operator] = STATE(189),
    [sym_extract_operator] = STATE(189),
    [sym_namespace_operator] = STATE(189),
    [sym_integer] = STATE(189),
    [sym_complex] = STATE(189),
    [sym_float] = STATE(189),
    [sym__float_literal] = STATE(330),
    [sym_string] = STATE(311),
    [sym__raw_string] = STATE(331),
    [sym__single_quoted_string] = STATE(332),
    [sym__double_quoted_string] = STATE(333),
    [sym_na] = STATE(189),
    [sym__expression] = STATE(189),
    [sym__open_parenthesis] = STATE(1070),
    [sym__open_brace] = STATE(384),
    [sym__close_brace] = STATE(1668),
    [aux_sym_braced_expression_repeat1] = STATE(379),
    [sym_identifier] = ACTIONS(687),
    [anon_sym_BSLASH] = ACTIONS(689),
    [anon_sym_function] = ACTIONS(691),
    [anon_sym_if] = ACTIONS(693),
    [anon_sym_for] = ACTIONS(695),
    [anon_sym_while] = ACTIONS(697),
    [anon_sym_repeat] = ACTIONS(699),
    [anon_sym_QMARK] = ACTIONS(701),
    [anon_sym_TILDE] = ACTIONS(703),
    [anon_sym_BANG] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [sym__hex_literal] = ACTIONS(709),
    [sym__number_literal] = ACTIONS(711),
    [anon_sym_SQUOTE] = ACTIONS(435),
    [anon_sym_DQUOTE] = ACTIONS(437),
    [sym_dots] = ACTIONS(687),
    [sym_dot_dot_i] = ACTIONS(687),
    [sym_next] = ACTIONS(713),
    [sym_break] = ACTIONS(713),
    [sym_true] = ACTIONS(713),
    [sym_false] = ACTIONS(713),
    [sym_null] = ACTIONS(713),
    [sym_inf] = ACTIONS(713),
    [sym_nan] = ACTIONS(713),
    [anon_sym_NA] = ACTIONS(715),
    [anon_sym_NA_integer_] = ACTIONS(715),
    [anon_sym_NA_real_] = ACTIONS(715),
    [anon_sym_NA_complex_] = ACTIONS(715),
    [anon_sym_NA_character_] = ACTIONS(715),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(717),
    [sym__semicolon] = ACTIONS(717),
    [sym__raw_string_open] = ACTIONS(439),
    [sym__external_open_parenthesis] = ACTIONS(719),
    [sym__external_open_brace] = ACTIONS(721),
    [sym__external_close_brace] = ACTIONS(858),
  },
  [399] = {
    [sym_identifier] = ACTIONS(818),
    [anon_sym_BSLASH] = ACTIONS(816),
    [anon_sym_function] = ACTIONS(818),
    [anon_sym_EQ] = ACTIONS(818),
    [anon_sym_if] = ACTIONS(818),
    [anon_sym_for] = ACTIONS(818),
    [anon_sym_while] = ACTIONS(818),
    [anon_sym_repeat] = ACTIONS(818),
    [anon_sym_QMARK] = ACTIONS(816),
    [anon_sym_TILDE] = ACTIONS(816),
    [anon_sym_BANG] = ACTIONS(818),
    [anon_sym_PLUS] = ACTIONS(816),
    [anon_sym_DASH] = ACTIONS(818),
    [anon_sym_LT_DASH] = ACTIONS(816),
    [anon_sym_LT_LT_DASH] = ACTIONS(816),
    [anon_sym_COLON_EQ] = ACTIONS(816),
    [anon_sym_DASH_GT] = ACTIONS(818),
    [anon_sym_DASH_GT_GT] = ACTIONS(816),
    [anon_sym_PIPE] = ACTIONS(818),
    [anon_sym_AMP] = ACTIONS(818),
    [anon_sym_PIPE_PIPE] = ACTIONS(816),
    [anon_sym_AMP_AMP] = ACTIONS(816),
    [anon_sym_LT] = ACTIONS(818),
    [anon_sym_LT_EQ] = ACTIONS(816),
    [anon_sym_GT] = ACTIONS(818),
    [anon_sym_GT_EQ] = ACTIONS(816),
    [anon_sym_EQ_EQ] = ACTIONS(816),
    [anon_sym_BANG_EQ] = ACTIONS(816),
    [anon_sym_STAR] = ACTIONS(818),
    [anon_sym_SLASH] = ACTIONS(816),
    [anon_sym_STAR_STAR] = ACTIONS(816),
    [anon_sym_CARET] = ACTIONS(816),
    [aux_sym_binary_operator_token1] = ACTIONS(816),
    [anon_sym_PIPE_GT] = ACTIONS(816),
    [anon_sym_COLON] = ACTIONS(818),
    [anon_sym_DOLLAR] = ACTIONS(816),
    [anon_sym_AT] = ACTIONS(816),
    [sym__hex_literal] = ACTIONS(816),
    [sym__number_literal] = ACTIONS(818),
    [anon_sym_SQUOTE] = ACTIONS(816),
    [anon_sym_DQUOTE] = ACTIONS(816),
    [sym_dots] = ACTIONS(818),
    [sym_dot_dot_i] = ACTIONS(818),
    [sym_next] = ACTIONS(818),
    [sym_break] = ACTIONS(818),
    [sym_true] = ACTIONS(818),
    [sym_false] = ACTIONS(818),
    [sym_null] = ACTIONS(818),
    [sym_inf] = ACTIONS(818),
    [sym_nan] = ACTIONS(818),
    [anon_sym_NA] = ACTIONS(818),
    [anon_sym_NA_integer_] = ACTIONS(818),
    [anon_sym_NA_real_] = ACTIONS(818),
    [anon_sym_NA_complex_] = ACTIONS(818),
    [anon_sym_NA_character_] = ACTIONS(818),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(816),
    [sym__semicolon] = ACTIONS(816),
    [sym__raw_string_open] = ACTIONS(816),
    [sym__external_else] = ACTIONS(816),
    [sym__external_open_parenthesis] = ACTIONS(816),
    [sym__external_open_brace] = ACTIONS(816),
    [sym__external_close_brace] = ACTIONS(816),
    [sym__external_open_bracket] = ACTIONS(816),
    [sym__external_open_bracket2] = ACTIONS(816),
  },
  [400] = {
    [sym_identifier] = ACTIONS(822),
    [anon_sym_BSLASH] = ACTIONS(820),
    [anon_sym_function] = ACTIONS(822),
    [anon_sym_EQ] = ACTIONS(822),
    [anon_sym_if] = ACTIONS(822),
    [anon_sym_for] = ACTIONS(822),
    [anon_sym_while] = ACTIONS(822),
    [anon_sym_repeat] = ACTIONS(822),
    [anon_sym_QMARK] = ACTIONS(820),
    [anon_sym_TILDE] = ACTIONS(820),
    [anon_sym_BANG] = ACTIONS(822),
    [anon_sym_PLUS] = ACTIONS(820),
    [anon_sym_DASH] = ACTIONS(822),
    [anon_sym_LT_DASH] = ACTIONS(820),
    [anon_sym_LT_LT_DASH] = ACTIONS(820),
    [anon_sym_COLON_EQ] = ACTIONS(820),
    [anon_sym_DASH_GT] = ACTIONS(822),
    [anon_sym_DASH_GT_GT] = ACTIONS(820),
    [anon_sym_PIPE] = ACTIONS(822),
    [anon_sym_AMP] = ACTIONS(822),
    [anon_sym_PIPE_PIPE] = ACTIONS(820),
    [anon_sym_AMP_AMP] = ACTIONS(820),
    [anon_sym_LT] = ACTIONS(822),
    [anon_sym_LT_EQ] = ACTIONS(820),
    [anon_sym_GT] = ACTIONS(822),
    [anon_sym_GT_EQ] = ACTIONS(820),
    [anon_sym_EQ_EQ] = ACTIONS(820),
    [anon_sym_BANG_EQ] = ACTIONS(820),
    [anon_sym_STAR] = ACTIONS(822),
    [anon_sym_SLASH] = ACTIONS(820),
    [anon_sym_STAR_STAR] = ACTIONS(820),
    [anon_sym_CARET] = ACTIONS(820),
    [aux_sym_binary_operator_token1] = ACTIONS(820),
    [anon_sym_PIPE_GT] = ACTIONS(820),
    [anon_sym_COLON] = ACTIONS(822),
    [anon_sym_DOLLAR] = ACTIONS(820),
    [anon_sym_AT] = ACTIONS(820),
    [sym__hex_literal] = ACTIONS(820),
    [sym__number_literal] = ACTIONS(822),
    [anon_sym_SQUOTE] = ACTIONS(820),
    [anon_sym_DQUOTE] = ACTIONS(820),
    [sym_dots] = ACTIONS(822),
    [sym_dot_dot_i] = ACTIONS(822),
    [sym_next] = ACTIONS(822),
    [sym_break] = ACTIONS(822),
    [sym_true] = ACTIONS(822),
    [sym_false] = ACTIONS(822),
    [sym_null] = ACTIONS(822),
    [sym_inf] = ACTIONS(822),
    [sym_nan] = ACTIONS(822),
    [anon_sym_NA] = ACTIONS(822),
    [anon_sym_NA_integer_] = ACTIONS(822),
    [anon_sym_NA_real_] = ACTIONS(822),
    [anon_sym_NA_complex_] = ACTIONS(822),
    [anon_sym_NA_character_] = ACTIONS(822),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(820),
    [sym__semicolon] = ACTIONS(820),
    [sym__raw_string_open] = ACTIONS(820),
    [sym__external_else] = ACTIONS(820),
    [sym__external_open_parenthesis] = ACTIONS(820),
    [sym__external_open_brace] = ACTIONS(820),
    [sym__external_close_brace] = ACTIONS(820),
    [sym__external_open_bracket] = ACTIONS(820),
    [sym__external_open_bracket2] = ACTIONS(820),
  },
  [401] = {
    [sym_function_definition] = STATE(189),
    [sym_if_statement] = STATE(189),
    [sym_for_statement] = STATE(189),
    [sym_while_statement] = STATE(189),
    [sym_repeat_statement] = STATE(189),
    [sym_braced_expression] = STATE(189),
    [sym_parenthesized_expression] = STATE(189),
    [sym_call] = STATE(189),
    [sym_subset] = STATE(189),
    [sym_subset2] = STATE(189),
    [sym_unary_operator] = STATE(189),
    [sym_binary_operator] = STATE(189),
    [sym_extract_operator] = STATE(189),
    [sym_namespace_operator] = STATE(189),
    [sym_integer] = STATE(189),
    [sym_complex] = STATE(189),
    [sym_float] = STATE(189),
    [sym__float_literal] = STATE(330),
    [sym_string] = STATE(311),
    [sym__raw_string] = STATE(331),
    [sym__single_quoted_string] = STATE(332),
    [sym__double_quoted_string] = STATE(333),
    [sym_na] = STATE(189),
    [sym__expression] = STATE(189),
    [sym__open_parenthesis] = STATE(1070),
    [sym__open_brace] = STATE(384),
    [sym__close_brace] = STATE(1682),
    [aux_sym_braced_expression_repeat1] = STATE(380),
    [sym_identifier] = ACTIONS(687),
    [anon_sym_BSLASH] = ACTIONS(689),
    [anon_sym_function] = ACTIONS(691),
    [anon_sym_if] = ACTIONS(693),
    [anon_sym_for] = ACTIONS(695),
    [anon_sym_while] = ACTIONS(697),
    [anon_sym_repeat] = ACTIONS(699),
    [anon_sym_QMARK] = ACTIONS(701),
    [anon_sym_TILDE] = ACTIONS(703),
    [anon_sym_BANG] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [sym__hex_literal] = ACTIONS(709),
    [sym__number_literal] = ACTIONS(711),
    [anon_sym_SQUOTE] = ACTIONS(435),
    [anon_sym_DQUOTE] = ACTIONS(437),
    [sym_dots] = ACTIONS(687),
    [sym_dot_dot_i] = ACTIONS(687),
    [sym_next] = ACTIONS(713),
    [sym_break] = ACTIONS(713),
    [sym_true] = ACTIONS(713),
    [sym_false] = ACTIONS(713),
    [sym_null] = ACTIONS(713),
    [sym_inf] = ACTIONS(713),
    [sym_nan] = ACTIONS(713),
    [anon_sym_NA] = ACTIONS(715),
    [anon_sym_NA_integer_] = ACTIONS(715),
    [anon_sym_NA_real_] = ACTIONS(715),
    [anon_sym_NA_complex_] = ACTIONS(715),
    [anon_sym_NA_character_] = ACTIONS(715),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(717),
    [sym__semicolon] = ACTIONS(717),
    [sym__raw_string_open] = ACTIONS(439),
    [sym__external_open_parenthesis] = ACTIONS(719),
    [sym__external_open_brace] = ACTIONS(721),
    [sym__external_close_brace] = ACTIONS(860),
  },
  [402] = {
    [sym_identifier] = ACTIONS(826),
    [anon_sym_BSLASH] = ACTIONS(824),
    [anon_sym_function] = ACTIONS(826),
    [anon_sym_EQ] = ACTIONS(826),
    [anon_sym_if] = ACTIONS(826),
    [anon_sym_for] = ACTIONS(826),
    [anon_sym_while] = ACTIONS(826),
    [anon_sym_repeat] = ACTIONS(826),
    [anon_sym_QMARK] = ACTIONS(824),
    [anon_sym_TILDE] = ACTIONS(824),
    [anon_sym_BANG] = ACTIONS(826),
    [anon_sym_PLUS] = ACTIONS(824),
    [anon_sym_DASH] = ACTIONS(826),
    [anon_sym_LT_DASH] = ACTIONS(824),
    [anon_sym_LT_LT_DASH] = ACTIONS(824),
    [anon_sym_COLON_EQ] = ACTIONS(824),
    [anon_sym_DASH_GT] = ACTIONS(826),
    [anon_sym_DASH_GT_GT] = ACTIONS(824),
    [anon_sym_PIPE] = ACTIONS(826),
    [anon_sym_AMP] = ACTIONS(826),
    [anon_sym_PIPE_PIPE] = ACTIONS(824),
    [anon_sym_AMP_AMP] = ACTIONS(824),
    [anon_sym_LT] = ACTIONS(826),
    [anon_sym_LT_EQ] = ACTIONS(824),
    [anon_sym_GT] = ACTIONS(826),
    [anon_sym_GT_EQ] = ACTIONS(824),
    [anon_sym_EQ_EQ] = ACTIONS(824),
    [anon_sym_BANG_EQ] = ACTIONS(824),
    [anon_sym_STAR] = ACTIONS(826),
    [anon_sym_SLASH] = ACTIONS(824),
    [anon_sym_STAR_STAR] = ACTIONS(824),
    [anon_sym_CARET] = ACTIONS(824),
    [aux_sym_binary_operator_token1] = ACTIONS(824),
    [anon_sym_PIPE_GT] = ACTIONS(824),
    [anon_sym_COLON] = ACTIONS(826),
    [anon_sym_DOLLAR] = ACTIONS(824),
    [anon_sym_AT] = ACTIONS(824),
    [sym__hex_literal] = ACTIONS(824),
    [sym__number_literal] = ACTIONS(826),
    [anon_sym_SQUOTE] = ACTIONS(824),
    [anon_sym_DQUOTE] = ACTIONS(824),
    [sym_dots] = ACTIONS(826),
    [sym_dot_dot_i] = ACTIONS(826),
    [sym_next] = ACTIONS(826),
    [sym_break] = ACTIONS(826),
    [sym_true] = ACTIONS(826),
    [sym_false] = ACTIONS(826),
    [sym_null] = ACTIONS(826),
    [sym_inf] = ACTIONS(826),
    [sym_nan] = ACTIONS(826),
    [anon_sym_NA] = ACTIONS(826),
    [anon_sym_NA_integer_] = ACTIONS(826),
    [anon_sym_NA_real_] = ACTIONS(826),
    [anon_sym_NA_complex_] = ACTIONS(826),
    [anon_sym_NA_character_] = ACTIONS(826),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(824),
    [sym__semicolon] = ACTIONS(824),
    [sym__raw_string_open] = ACTIONS(824),
    [sym__external_else] = ACTIONS(824),
    [sym__external_open_parenthesis] = ACTIONS(824),
    [sym__external_open_brace] = ACTIONS(824),
    [sym__external_close_brace] = ACTIONS(824),
    [sym__external_open_bracket] = ACTIONS(824),
    [sym__external_open_bracket2] = ACTIONS(824),
  },
  [403] = {
    [sym_identifier] = ACTIONS(830),
    [anon_sym_BSLASH] = ACTIONS(828),
    [anon_sym_function] = ACTIONS(830),
    [anon_sym_EQ] = ACTIONS(830),
    [anon_sym_if] = ACTIONS(830),
    [anon_sym_for] = ACTIONS(830),
    [anon_sym_while] = ACTIONS(830),
    [anon_sym_repeat] = ACTIONS(830),
    [anon_sym_QMARK] = ACTIONS(828),
    [anon_sym_TILDE] = ACTIONS(828),
    [anon_sym_BANG] = ACTIONS(830),
    [anon_sym_PLUS] = ACTIONS(828),
    [anon_sym_DASH] = ACTIONS(830),
    [anon_sym_LT_DASH] = ACTIONS(828),
    [anon_sym_LT_LT_DASH] = ACTIONS(828),
    [anon_sym_COLON_EQ] = ACTIONS(828),
    [anon_sym_DASH_GT] = ACTIONS(830),
    [anon_sym_DASH_GT_GT] = ACTIONS(828),
    [anon_sym_PIPE] = ACTIONS(830),
    [anon_sym_AMP] = ACTIONS(830),
    [anon_sym_PIPE_PIPE] = ACTIONS(828),
    [anon_sym_AMP_AMP] = ACTIONS(828),
    [anon_sym_LT] = ACTIONS(830),
    [anon_sym_LT_EQ] = ACTIONS(828),
    [anon_sym_GT] = ACTIONS(830),
    [anon_sym_GT_EQ] = ACTIONS(828),
    [anon_sym_EQ_EQ] = ACTIONS(828),
    [anon_sym_BANG_EQ] = ACTIONS(828),
    [anon_sym_STAR] = ACTIONS(830),
    [anon_sym_SLASH] = ACTIONS(828),
    [anon_sym_STAR_STAR] = ACTIONS(828),
    [anon_sym_CARET] = ACTIONS(828),
    [aux_sym_binary_operator_token1] = ACTIONS(828),
    [anon_sym_PIPE_GT] = ACTIONS(828),
    [anon_sym_COLON] = ACTIONS(830),
    [anon_sym_DOLLAR] = ACTIONS(828),
    [anon_sym_AT] = ACTIONS(828),
    [sym__hex_literal] = ACTIONS(828),
    [sym__number_literal] = ACTIONS(830),
    [anon_sym_SQUOTE] = ACTIONS(828),
    [anon_sym_DQUOTE] = ACTIONS(828),
    [sym_dots] = ACTIONS(830),
    [sym_dot_dot_i] = ACTIONS(830),
    [sym_next] = ACTIONS(830),
    [sym_break] = ACTIONS(830),
    [sym_true] = ACTIONS(830),
    [sym_false] = ACTIONS(830),
    [sym_null] = ACTIONS(830),
    [sym_inf] = ACTIONS(830),
    [sym_nan] = ACTIONS(830),
    [anon_sym_NA] = ACTIONS(830),
    [anon_sym_NA_integer_] = ACTIONS(830),
    [anon_sym_NA_real_] = ACTIONS(830),
    [anon_sym_NA_complex_] = ACTIONS(830),
    [anon_sym_NA_character_] = ACTIONS(830),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(828),
    [sym__semicolon] = ACTIONS(828),
    [sym__raw_string_open] = ACTIONS(828),
    [sym__external_else] = ACTIONS(828),
    [sym__external_open_parenthesis] = ACTIONS(828),
    [sym__external_open_brace] = ACTIONS(828),
    [sym__external_close_brace] = ACTIONS(828),
    [sym__external_open_bracket] = ACTIONS(828),
    [sym__external_open_bracket2] = ACTIONS(828),
  },
  [404] = {
    [aux_sym_function_definition_repeat1] = STATE(404),
    [ts_builtin_sym_end] = ACTIONS(671),
    [sym_identifier] = ACTIONS(669),
    [anon_sym_BSLASH] = ACTIONS(671),
    [anon_sym_function] = ACTIONS(669),
    [anon_sym_EQ] = ACTIONS(669),
    [anon_sym_if] = ACTIONS(669),
    [anon_sym_for] = ACTIONS(669),
    [anon_sym_while] = ACTIONS(669),
    [anon_sym_repeat] = ACTIONS(669),
    [anon_sym_QMARK] = ACTIONS(671),
    [anon_sym_TILDE] = ACTIONS(671),
    [anon_sym_BANG] = ACTIONS(669),
    [anon_sym_PLUS] = ACTIONS(671),
    [anon_sym_DASH] = ACTIONS(669),
    [anon_sym_LT_DASH] = ACTIONS(671),
    [anon_sym_LT_LT_DASH] = ACTIONS(671),
    [anon_sym_COLON_EQ] = ACTIONS(671),
    [anon_sym_DASH_GT] = ACTIONS(669),
    [anon_sym_DASH_GT_GT] = ACTIONS(671),
    [anon_sym_PIPE] = ACTIONS(669),
    [anon_sym_AMP] = ACTIONS(669),
    [anon_sym_PIPE_PIPE] = ACTIONS(671),
    [anon_sym_AMP_AMP] = ACTIONS(671),
    [anon_sym_LT] = ACTIONS(669),
    [anon_sym_LT_EQ] = ACTIONS(671),
    [anon_sym_GT] = ACTIONS(669),
    [anon_sym_GT_EQ] = ACTIONS(671),
    [anon_sym_EQ_EQ] = ACTIONS(671),
    [anon_sym_BANG_EQ] = ACTIONS(671),
    [anon_sym_STAR] = ACTIONS(669),
    [anon_sym_SLASH] = ACTIONS(671),
    [anon_sym_STAR_STAR] = ACTIONS(671),
    [anon_sym_CARET] = ACTIONS(671),
    [aux_sym_binary_operator_token1] = ACTIONS(671),
    [anon_sym_PIPE_GT] = ACTIONS(671),
    [anon_sym_COLON] = ACTIONS(669),
    [anon_sym_DOLLAR] = ACTIONS(671),
    [anon_sym_AT] = ACTIONS(671),
    [sym__hex_literal] = ACTIONS(671),
    [sym__number_literal] = ACTIONS(669),
    [anon_sym_SQUOTE] = ACTIONS(671),
    [anon_sym_DQUOTE] = ACTIONS(671),
    [sym_dots] = ACTIONS(669),
    [sym_dot_dot_i] = ACTIONS(669),
    [sym_next] = ACTIONS(669),
    [sym_break] = ACTIONS(669),
    [sym_true] = ACTIONS(669),
    [sym_false] = ACTIONS(669),
    [sym_null] = ACTIONS(669),
    [sym_inf] = ACTIONS(669),
    [sym_nan] = ACTIONS(669),
    [anon_sym_NA] = ACTIONS(669),
    [anon_sym_NA_integer_] = ACTIONS(669),
    [anon_sym_NA_real_] = ACTIONS(669),
    [anon_sym_NA_complex_] = ACTIONS(669),
    [anon_sym_NA_character_] = ACTIONS(669),
    [sym_comment] = ACTIONS(3),
    [sym__newline] = ACTIONS(862),
    [sym__semicolon] = ACTIONS(671),
    [sym__raw_string_open] = ACTIONS(671),
    [sym__external_open_parenthesis] = ACTIONS(671),
    [sym__external_open_brace] = ACTIONS(671),
    [sym__external_open_bracket] = ACTIONS(671),
    [sym__external_open_bracket2] = ACTIONS(671),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(753), 31,
      anon_sym_function,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(755), 32,
      sym__newline,
      sym__semicolon,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      ts_builtin_sym_end,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
  [71] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(818), 31,
      anon_sym_function,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(816), 32,
      sym__newline,
      sym__semicolon,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      ts_builtin_sym_end,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
  [142] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(806), 31,
      anon_sym_function,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(804), 32,
      sym__newline,
      sym__semicolon,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      ts_builtin_sym_end,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
  [213] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(790), 31,
      anon_sym_function,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(788), 32,
      sym__newline,
      sym__semicolon,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      sym__external_close_brace,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
  [284] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(865), 1,
      ts_builtin_sym_end,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(425), 1,
      aux_sym_program_repeat1,
    STATE(1058), 1,
      sym__open_parenthesis,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(897), 2,
      sym__newline,
      sym__semicolon,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(893), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(225), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [413] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(757), 31,
      anon_sym_function,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(759), 32,
      sym__newline,
      sym__semicolon,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      ts_builtin_sym_end,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
  [484] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(733), 31,
      anon_sym_function,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(735), 32,
      sym__newline,
      sym__semicolon,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      sym__external_close_brace,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
  [555] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(745), 31,
      anon_sym_function,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(747), 32,
      sym__newline,
      sym__semicolon,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      sym__external_close_brace,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
  [626] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(761), 31,
      anon_sym_function,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(763), 32,
      sym__newline,
      sym__semicolon,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      ts_builtin_sym_end,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
  [697] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(761), 31,
      anon_sym_function,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(763), 32,
      sym__newline,
      sym__semicolon,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      sym__external_close_brace,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
  [768] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(906), 1,
      anon_sym_BSLASH,
    ACTIONS(909), 1,
      anon_sym_function,
    ACTIONS(912), 1,
      anon_sym_if,
    ACTIONS(915), 1,
      anon_sym_for,
    ACTIONS(918), 1,
      anon_sym_while,
    ACTIONS(921), 1,
      anon_sym_repeat,
    ACTIONS(924), 1,
      anon_sym_QMARK,
    ACTIONS(927), 1,
      anon_sym_TILDE,
    ACTIONS(930), 1,
      anon_sym_BANG,
    ACTIONS(936), 1,
      sym__hex_literal,
    ACTIONS(939), 1,
      sym__number_literal,
    ACTIONS(942), 1,
      anon_sym_SQUOTE,
    ACTIONS(945), 1,
      anon_sym_DQUOTE,
    ACTIONS(957), 1,
      sym__raw_string_open,
    ACTIONS(960), 1,
      sym__external_open_parenthesis,
    ACTIONS(963), 1,
      sym__external_open_brace,
    ACTIONS(966), 1,
      sym__external_close_brace,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(415), 1,
      aux_sym_braced_expression_repeat1,
    STATE(1070), 1,
      sym__open_parenthesis,
    ACTIONS(933), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(954), 2,
      sym__newline,
      sym__semicolon,
    ACTIONS(903), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(951), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(948), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(189), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [897] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(786), 31,
      anon_sym_function,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(784), 32,
      sym__newline,
      sym__semicolon,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      ts_builtin_sym_end,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
  [968] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(733), 31,
      anon_sym_function,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(735), 32,
      sym__newline,
      sym__semicolon,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      ts_builtin_sym_end,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
  [1039] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(812), 31,
      anon_sym_function,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(814), 32,
      sym__newline,
      sym__semicolon,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      sym__external_close_brace,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
  [1110] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(725), 31,
      anon_sym_function,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(727), 32,
      sym__newline,
      sym__semicolon,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      sym__external_close_brace,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
  [1181] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(745), 31,
      anon_sym_function,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(747), 32,
      sym__newline,
      sym__semicolon,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      ts_builtin_sym_end,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
  [1252] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(794), 31,
      anon_sym_function,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(792), 32,
      sym__newline,
      sym__semicolon,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      ts_builtin_sym_end,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
  [1323] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(822), 31,
      anon_sym_function,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(820), 32,
      sym__newline,
      sym__semicolon,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      ts_builtin_sym_end,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
  [1394] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(725), 31,
      anon_sym_function,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(727), 32,
      sym__newline,
      sym__semicolon,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      ts_builtin_sym_end,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
  [1465] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(749), 31,
      anon_sym_function,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(751), 32,
      sym__newline,
      sym__semicolon,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      sym__external_close_brace,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
  [1536] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(968), 1,
      ts_builtin_sym_end,
    ACTIONS(973), 1,
      anon_sym_BSLASH,
    ACTIONS(976), 1,
      anon_sym_function,
    ACTIONS(979), 1,
      anon_sym_if,
    ACTIONS(982), 1,
      anon_sym_for,
    ACTIONS(985), 1,
      anon_sym_while,
    ACTIONS(988), 1,
      anon_sym_repeat,
    ACTIONS(991), 1,
      anon_sym_QMARK,
    ACTIONS(994), 1,
      anon_sym_TILDE,
    ACTIONS(997), 1,
      anon_sym_BANG,
    ACTIONS(1003), 1,
      sym__hex_literal,
    ACTIONS(1006), 1,
      sym__number_literal,
    ACTIONS(1009), 1,
      anon_sym_SQUOTE,
    ACTIONS(1012), 1,
      anon_sym_DQUOTE,
    ACTIONS(1024), 1,
      sym__raw_string_open,
    ACTIONS(1027), 1,
      sym__external_open_parenthesis,
    ACTIONS(1030), 1,
      sym__external_open_brace,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(425), 1,
      aux_sym_program_repeat1,
    STATE(1058), 1,
      sym__open_parenthesis,
    ACTIONS(1000), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1021), 2,
      sym__newline,
      sym__semicolon,
    ACTIONS(970), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1018), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1015), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(225), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [1665] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(753), 31,
      anon_sym_function,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(755), 32,
      sym__newline,
      sym__semicolon,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      sym__external_close_brace,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
  [1736] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(798), 31,
      anon_sym_function,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(796), 32,
      sym__newline,
      sym__semicolon,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      ts_builtin_sym_end,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
  [1807] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(830), 31,
      anon_sym_function,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(828), 32,
      sym__newline,
      sym__semicolon,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      sym__external_close_brace,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
  [1878] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(757), 31,
      anon_sym_function,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(759), 32,
      sym__newline,
      sym__semicolon,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      sym__external_close_brace,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
  [1949] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(808), 31,
      anon_sym_function,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(810), 32,
      sym__newline,
      sym__semicolon,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      ts_builtin_sym_end,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
  [2020] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(790), 31,
      anon_sym_function,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(788), 32,
      sym__newline,
      sym__semicolon,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      ts_builtin_sym_end,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
  [2091] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(826), 31,
      anon_sym_function,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(824), 32,
      sym__newline,
      sym__semicolon,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      ts_builtin_sym_end,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
  [2162] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(741), 31,
      anon_sym_function,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(743), 32,
      sym__newline,
      sym__semicolon,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      ts_builtin_sym_end,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
  [2233] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(802), 31,
      anon_sym_function,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(800), 32,
      sym__newline,
      sym__semicolon,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      ts_builtin_sym_end,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
  [2304] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(802), 31,
      anon_sym_function,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(800), 32,
      sym__newline,
      sym__semicolon,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      sym__external_close_brace,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
  [2375] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(806), 31,
      anon_sym_function,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(804), 32,
      sym__newline,
      sym__semicolon,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      sym__external_close_brace,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
  [2446] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(818), 31,
      anon_sym_function,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(816), 32,
      sym__newline,
      sym__semicolon,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      sym__external_close_brace,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
  [2517] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(771), 31,
      anon_sym_function,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(769), 32,
      sym__newline,
      sym__semicolon,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      ts_builtin_sym_end,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
  [2588] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(739), 31,
      anon_sym_function,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(737), 32,
      sym__newline,
      sym__semicolon,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      ts_builtin_sym_end,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
  [2659] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(767), 31,
      anon_sym_function,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(765), 32,
      sym__newline,
      sym__semicolon,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      sym__external_close_brace,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
  [2730] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(830), 31,
      anon_sym_function,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(828), 32,
      sym__newline,
      sym__semicolon,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      ts_builtin_sym_end,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
  [2801] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(771), 31,
      anon_sym_function,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(769), 32,
      sym__newline,
      sym__semicolon,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      sym__external_close_brace,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
  [2872] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1033), 1,
      ts_builtin_sym_end,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(409), 1,
      aux_sym_program_repeat1,
    STATE(1058), 1,
      sym__open_parenthesis,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1035), 2,
      sym__newline,
      sym__semicolon,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(893), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(225), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [3001] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(775), 31,
      anon_sym_function,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(773), 32,
      sym__newline,
      sym__semicolon,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      sym__external_close_brace,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
  [3072] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(822), 31,
      anon_sym_function,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(820), 32,
      sym__newline,
      sym__semicolon,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      sym__external_close_brace,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
  [3143] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(786), 31,
      anon_sym_function,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(784), 32,
      sym__newline,
      sym__semicolon,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      sym__external_close_brace,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
  [3214] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(812), 31,
      anon_sym_function,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(814), 32,
      sym__newline,
      sym__semicolon,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      ts_builtin_sym_end,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
  [3285] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(767), 31,
      anon_sym_function,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(765), 32,
      sym__newline,
      sym__semicolon,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      ts_builtin_sym_end,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
  [3356] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(826), 31,
      anon_sym_function,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(824), 32,
      sym__newline,
      sym__semicolon,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      sym__external_close_brace,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
  [3427] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(749), 31,
      anon_sym_function,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(751), 32,
      sym__newline,
      sym__semicolon,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      ts_builtin_sym_end,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
  [3498] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(775), 31,
      anon_sym_function,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(773), 32,
      sym__newline,
      sym__semicolon,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      ts_builtin_sym_end,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
  [3569] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(798), 31,
      anon_sym_function,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(796), 32,
      sym__newline,
      sym__semicolon,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      sym__external_close_brace,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
  [3640] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(794), 31,
      anon_sym_function,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(792), 32,
      sym__newline,
      sym__semicolon,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      sym__external_close_brace,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
  [3711] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(808), 31,
      anon_sym_function,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(810), 32,
      sym__newline,
      sym__semicolon,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      sym__external_close_brace,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
  [3782] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(741), 31,
      anon_sym_function,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(743), 32,
      sym__newline,
      sym__semicolon,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      sym__external_close_brace,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
  [3853] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(739), 31,
      anon_sym_function,
      anon_sym_EQ,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(737), 32,
      sym__newline,
      sym__semicolon,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      sym__external_close_brace,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
  [3924] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    STATE(389), 1,
      sym__open_brace,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    STATE(2076), 1,
      sym__argument_value,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1039), 2,
      sym__external_close_bracket2,
      sym_comma,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(471), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1552), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [4050] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    STATE(386), 1,
      sym__open_brace,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    STATE(2059), 1,
      sym__argument_value,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1039), 2,
      sym__external_close_bracket,
      sym_comma,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(409), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1490), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [4176] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    STATE(2057), 1,
      sym__argument_value,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1039), 2,
      sym__external_close_parenthesis,
      sym_comma,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(527), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1372), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [4302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1045), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1380), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [4427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1051), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(944), 1,
      aux_sym_function_definition_repeat1,
    STATE(1058), 1,
      sym__open_parenthesis,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1049), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(140), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [4552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(1070), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1053), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(209), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [4677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1057), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(945), 1,
      aux_sym_function_definition_repeat1,
    STATE(1058), 1,
      sym__open_parenthesis,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1055), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(141), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [4802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(1070), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1059), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(211), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [4927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(1070), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1061), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(212), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [5052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1065), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(950), 1,
      aux_sym_function_definition_repeat1,
    STATE(1058), 1,
      sym__open_parenthesis,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1063), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(143), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [5177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(1070), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1067), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(213), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [5302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1071), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(954), 1,
      aux_sym_function_definition_repeat1,
    STATE(1058), 1,
      sym__open_parenthesis,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1069), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(144), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [5427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(1070), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1073), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(214), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [5552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1077), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(962), 1,
      aux_sym_function_definition_repeat1,
    STATE(1058), 1,
      sym__open_parenthesis,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1075), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(145), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [5677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(1070), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1079), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(215), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [5802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1083), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(973), 1,
      aux_sym_function_definition_repeat1,
    STATE(1058), 1,
      sym__open_parenthesis,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1081), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(146), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [5927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(1070), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1085), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(216), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [6052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(1070), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1087), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(217), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [6177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(1070), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1089), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(218), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [6302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(1070), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1091), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(219), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [6427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(1070), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1093), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(220), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [6552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1097), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(975), 1,
      aux_sym_function_definition_repeat1,
    STATE(1058), 1,
      sym__open_parenthesis,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1095), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(147), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [6677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(1070), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1099), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(221), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [6802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(1058), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1101), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(165), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [6927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(1070), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1103), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(222), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [7052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1135), 1,
      sym__newline,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(495), 1,
      aux_sym_function_definition_repeat1,
    STATE(1085), 1,
      sym__open_parenthesis,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1131), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(2), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [7177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1143), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(503), 1,
      aux_sym_function_definition_repeat1,
    STATE(1058), 1,
      sym__open_parenthesis,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1141), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(166), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [7302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1147), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(1026), 1,
      aux_sym_function_definition_repeat1,
    STATE(1058), 1,
      sym__open_parenthesis,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1145), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(148), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [7427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1151), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(628), 1,
      aux_sym_function_definition_repeat1,
    STATE(1058), 1,
      sym__open_parenthesis,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1149), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(244), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [7552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1155), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(635), 1,
      aux_sym_function_definition_repeat1,
    STATE(1058), 1,
      sym__open_parenthesis,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1153), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(245), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [7677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(1070), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1157), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(223), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [7802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(1161), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(492), 1,
      aux_sym_function_definition_repeat1,
    STATE(1070), 1,
      sym__open_parenthesis,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1159), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(224), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [7927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1165), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(649), 1,
      aux_sym_function_definition_repeat1,
    STATE(1058), 1,
      sym__open_parenthesis,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1163), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(246), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [8052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1169), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(491), 1,
      aux_sym_function_definition_repeat1,
    STATE(1058), 1,
      sym__open_parenthesis,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1167), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(241), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [8177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(1058), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1171), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(149), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [8302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(1070), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1173), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(226), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [8427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(1177), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(498), 1,
      aux_sym_function_definition_repeat1,
    STATE(1070), 1,
      sym__open_parenthesis,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1175), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(227), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [8552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(1181), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(499), 1,
      aux_sym_function_definition_repeat1,
    STATE(1070), 1,
      sym__open_parenthesis,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1179), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(228), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [8677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(1085), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1183), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(6), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [8802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(1187), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(504), 1,
      aux_sym_function_definition_repeat1,
    STATE(1070), 1,
      sym__open_parenthesis,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1185), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(229), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [8927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    ACTIONS(1191), 1,
      sym__newline,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(512), 1,
      aux_sym_function_definition_repeat1,
    STATE(1085), 1,
      sym__open_parenthesis,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1189), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(4), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [9052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(1070), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1193), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(230), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [9177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(1070), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1195), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(231), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [9302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(1199), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(507), 1,
      aux_sym_function_definition_repeat1,
    STATE(1070), 1,
      sym__open_parenthesis,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1197), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(232), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [9427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(1203), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(508), 1,
      aux_sym_function_definition_repeat1,
    STATE(1070), 1,
      sym__open_parenthesis,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1201), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(233), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [9552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1207), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(480), 1,
      aux_sym_function_definition_repeat1,
    STATE(1058), 1,
      sym__open_parenthesis,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1205), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(150), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [9677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(1058), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1209), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(167), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [9802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(1070), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1211), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(234), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [9927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(1215), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(511), 1,
      aux_sym_function_definition_repeat1,
    STATE(1070), 1,
      sym__open_parenthesis,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1213), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(235), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [10052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1219), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(587), 1,
      aux_sym_function_definition_repeat1,
    STATE(1058), 1,
      sym__open_parenthesis,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1217), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(168), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [10177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(1070), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1221), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(236), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [10302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(1070), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1223), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(237), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [10427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(1227), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(513), 1,
      aux_sym_function_definition_repeat1,
    STATE(1070), 1,
      sym__open_parenthesis,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1225), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(238), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [10552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1231), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(618), 1,
      aux_sym_function_definition_repeat1,
    STATE(1058), 1,
      sym__open_parenthesis,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1229), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(169), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [10677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(1070), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1233), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(239), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [10802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(1085), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1235), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(5), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [10927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(1070), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1237), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(240), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [11052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1241), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(623), 1,
      aux_sym_function_definition_repeat1,
    STATE(1058), 1,
      sym__open_parenthesis,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1239), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(170), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [11177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1245), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(534), 1,
      aux_sym_function_definition_repeat1,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1243), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1467), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [11302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1247), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1476), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [11427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1249), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1477), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [11552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1251), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1478), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [11677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1253), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1481), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [11802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1255), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1485), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [11927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1259), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(536), 1,
      aux_sym_function_definition_repeat1,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1257), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1493), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [12052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1263), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(537), 1,
      aux_sym_function_definition_repeat1,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1261), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1511), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [12177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1267), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(538), 1,
      aux_sym_function_definition_repeat1,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1265), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1518), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [12302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1271), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(539), 1,
      aux_sym_function_definition_repeat1,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1269), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1539), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [12427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1275), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(540), 1,
      aux_sym_function_definition_repeat1,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1273), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1549), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [12552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1279), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(541), 1,
      aux_sym_function_definition_repeat1,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1277), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1554), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [12677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1283), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(542), 1,
      aux_sym_function_definition_repeat1,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1281), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1557), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [12802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1287), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(543), 1,
      aux_sym_function_definition_repeat1,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1285), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1558), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [12927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1291), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(544), 1,
      aux_sym_function_definition_repeat1,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1289), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1567), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [13052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1295), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(545), 1,
      aux_sym_function_definition_repeat1,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1293), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1568), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [13177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1299), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(546), 1,
      aux_sym_function_definition_repeat1,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1297), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1342), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [13302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1303), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(547), 1,
      aux_sym_function_definition_repeat1,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1301), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1573), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [13427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1307), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(548), 1,
      aux_sym_function_definition_repeat1,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1305), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1579), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [13552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1309), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1345), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [13677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1313), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(549), 1,
      aux_sym_function_definition_repeat1,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1311), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1348), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [13802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1315), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1349), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [13927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1317), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1350), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [14052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1319), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1351), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [14177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1321), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1352), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [14302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1323), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1353), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [14427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1325), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1355), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [14552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1327), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1356), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [14677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1329), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1358), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [14802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1331), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1359), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [14927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1333), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1360), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [15052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1335), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1362), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [15177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1337), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1363), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [15302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1339), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1364), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [15427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1341), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1367), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [15552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1345), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(551), 1,
      aux_sym_function_definition_repeat1,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1343), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1368), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [15677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1347), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1370), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [15802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1351), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(555), 1,
      aux_sym_function_definition_repeat1,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1349), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1371), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [15927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1355), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(556), 1,
      aux_sym_function_definition_repeat1,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1353), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1373), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [16052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1359), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(559), 1,
      aux_sym_function_definition_repeat1,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1357), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1377), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [16177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1361), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1384), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [16302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1363), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1385), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [16427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1367), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(561), 1,
      aux_sym_function_definition_repeat1,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1365), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1386), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [16552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1371), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(562), 1,
      aux_sym_function_definition_repeat1,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1369), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1388), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [16677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1373), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1390), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [16802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1377), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(564), 1,
      aux_sym_function_definition_repeat1,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1375), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1392), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [16927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1379), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1393), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [17052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1381), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1395), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [17177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1385), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(565), 1,
      aux_sym_function_definition_repeat1,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1383), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1396), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [17302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1387), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1398), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [17427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1389), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1399), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [17552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1393), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(585), 1,
      aux_sym_function_definition_repeat1,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1391), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1414), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [17677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1395), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1415), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [17802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1397), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1416), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [17927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1399), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1417), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [18052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1401), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1418), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [18177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1403), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1419), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [18302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1407), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(588), 1,
      aux_sym_function_definition_repeat1,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1405), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1420), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [18427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1411), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(589), 1,
      aux_sym_function_definition_repeat1,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1409), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1421), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [18552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1415), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(590), 1,
      aux_sym_function_definition_repeat1,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1413), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1422), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [18677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1419), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(591), 1,
      aux_sym_function_definition_repeat1,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1417), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1423), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [18802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1423), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(592), 1,
      aux_sym_function_definition_repeat1,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1421), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1424), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [18927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1427), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(593), 1,
      aux_sym_function_definition_repeat1,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1425), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1425), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [19052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1431), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(594), 1,
      aux_sym_function_definition_repeat1,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1429), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1426), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [19177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1435), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(595), 1,
      aux_sym_function_definition_repeat1,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1433), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1427), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [19302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1439), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(596), 1,
      aux_sym_function_definition_repeat1,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1437), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1428), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [19427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1443), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(597), 1,
      aux_sym_function_definition_repeat1,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1441), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1429), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [19552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1447), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(598), 1,
      aux_sym_function_definition_repeat1,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1445), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1430), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [19677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1451), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(599), 1,
      aux_sym_function_definition_repeat1,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1449), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1431), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [19802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1455), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(600), 1,
      aux_sym_function_definition_repeat1,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1453), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1432), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [19927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1457), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1438), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [20052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1461), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(601), 1,
      aux_sym_function_definition_repeat1,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1459), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1439), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [20177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(1058), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1463), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(171), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [20302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1465), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1441), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [20427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1467), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1442), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [20552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1469), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1443), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [20677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1471), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1583), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [20802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1473), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1445), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [20927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1475), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1446), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [21052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1477), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1447), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [21177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1479), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1448), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [21302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1481), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1449), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [21427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1483), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1450), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [21552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1485), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1453), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [21677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1487), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1455), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [21802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1489), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1456), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [21927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1491), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1465), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [22052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1495), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(603), 1,
      aux_sym_function_definition_repeat1,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1493), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1470), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [22177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1497), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1479), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [22302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1501), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(607), 1,
      aux_sym_function_definition_repeat1,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1499), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1480), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [22427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1505), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(608), 1,
      aux_sym_function_definition_repeat1,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1503), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1482), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [22552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1509), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(611), 1,
      aux_sym_function_definition_repeat1,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1507), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1489), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [22677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1511), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1500), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [22802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1513), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1501), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [22927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1517), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(613), 1,
      aux_sym_function_definition_repeat1,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1515), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1506), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [23052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1521), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(614), 1,
      aux_sym_function_definition_repeat1,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1519), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1514), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [23177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1523), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1520), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [23302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1527), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(616), 1,
      aux_sym_function_definition_repeat1,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1525), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1525), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [23427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1529), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1530), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [23552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1531), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1532), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [23677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1535), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(617), 1,
      aux_sym_function_definition_repeat1,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1533), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1533), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [23802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1537), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1541), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [23927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1539), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1542), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [24052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(1058), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1541), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(172), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [24177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1545), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(631), 1,
      aux_sym_function_definition_repeat1,
    STATE(1058), 1,
      sym__open_parenthesis,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1543), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(173), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [24302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1549), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(633), 1,
      aux_sym_function_definition_repeat1,
    STATE(1058), 1,
      sym__open_parenthesis,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1547), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(174), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [24427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1553), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(662), 1,
      aux_sym_function_definition_repeat1,
    STATE(1058), 1,
      sym__open_parenthesis,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1551), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(142), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [24552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(1058), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1555), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(242), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [24677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(1058), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1557), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(175), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [24802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    ACTIONS(1561), 1,
      sym__newline,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(653), 1,
      aux_sym_function_definition_repeat1,
    STATE(1085), 1,
      sym__open_parenthesis,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1559), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(25), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [24927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1565), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(648), 1,
      aux_sym_function_definition_repeat1,
    STATE(1058), 1,
      sym__open_parenthesis,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1563), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(176), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [25052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(1085), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1567), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(26), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [25177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(1085), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1569), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(27), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [25302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(1058), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1571), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(190), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [25427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(1085), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1573), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(28), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [25552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(1085), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1575), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(29), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [25677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(1058), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1577), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(177), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [25802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(1085), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1579), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(30), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [25927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(1058), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1581), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(178), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [26052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1585), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(651), 1,
      aux_sym_function_definition_repeat1,
    STATE(1058), 1,
      sym__open_parenthesis,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1583), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(179), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [26177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(1058), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1587), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(131), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [26302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    ACTIONS(1591), 1,
      sym__newline,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(657), 1,
      aux_sym_function_definition_repeat1,
    STATE(1085), 1,
      sym__open_parenthesis,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1589), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(31), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [26427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    ACTIONS(1595), 1,
      sym__newline,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(660), 1,
      aux_sym_function_definition_repeat1,
    STATE(1085), 1,
      sym__open_parenthesis,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1593), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(18), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [26552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    ACTIONS(1599), 1,
      sym__newline,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(661), 1,
      aux_sym_function_definition_repeat1,
    STATE(1085), 1,
      sym__open_parenthesis,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1597), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(129), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [26677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    ACTIONS(1603), 1,
      sym__newline,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(663), 1,
      aux_sym_function_definition_repeat1,
    STATE(1085), 1,
      sym__open_parenthesis,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1601), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(33), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [26802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    ACTIONS(1607), 1,
      sym__newline,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(664), 1,
      aux_sym_function_definition_repeat1,
    STATE(1085), 1,
      sym__open_parenthesis,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1605), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(34), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [26927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    ACTIONS(1611), 1,
      sym__newline,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(666), 1,
      aux_sym_function_definition_repeat1,
    STATE(1085), 1,
      sym__open_parenthesis,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1609), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(35), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [27052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    ACTIONS(1615), 1,
      sym__newline,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(667), 1,
      aux_sym_function_definition_repeat1,
    STATE(1085), 1,
      sym__open_parenthesis,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1613), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(36), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [27177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    ACTIONS(1619), 1,
      sym__newline,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(669), 1,
      aux_sym_function_definition_repeat1,
    STATE(1085), 1,
      sym__open_parenthesis,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1617), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(37), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [27302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    ACTIONS(1623), 1,
      sym__newline,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(670), 1,
      aux_sym_function_definition_repeat1,
    STATE(1085), 1,
      sym__open_parenthesis,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1621), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(38), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [27427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    ACTIONS(1627), 1,
      sym__newline,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(671), 1,
      aux_sym_function_definition_repeat1,
    STATE(1085), 1,
      sym__open_parenthesis,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1625), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(39), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [27552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    ACTIONS(1631), 1,
      sym__newline,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(672), 1,
      aux_sym_function_definition_repeat1,
    STATE(1085), 1,
      sym__open_parenthesis,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1629), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(40), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [27677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    ACTIONS(1635), 1,
      sym__newline,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(673), 1,
      aux_sym_function_definition_repeat1,
    STATE(1085), 1,
      sym__open_parenthesis,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1633), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(41), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [27802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(1058), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1637), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(180), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [27927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(1058), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1639), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(132), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [28052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(1058), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1641), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(151), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [28177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(1058), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1643), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(181), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [28302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(1058), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1645), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(153), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [28427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(1085), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1647), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(42), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [28552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    ACTIONS(1651), 1,
      sym__newline,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(682), 1,
      aux_sym_function_definition_repeat1,
    STATE(1085), 1,
      sym__open_parenthesis,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1649), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(43), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [28677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(1655), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(690), 1,
      aux_sym_function_definition_repeat1,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1653), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1376), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [28802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1657), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1378), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [28927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(1085), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1659), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(44), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [29052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(1085), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1661), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(45), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [29177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1663), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1379), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [29302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(1085), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1665), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(46), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [29427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(1085), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1667), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(47), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [29552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(1058), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1669), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(134), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [29677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(1085), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1671), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(48), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [29802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(1085), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1673), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(49), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [29927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1675), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1381), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [30052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(1085), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1677), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(50), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [30177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(1085), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1679), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(51), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [30302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1681), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1382), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [30427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(1085), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1683), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(52), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [30552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(1085), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1685), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(53), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [30677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(1085), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1687), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(54), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [30802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(1085), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1689), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(55), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [30927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(1085), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1691), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(56), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [31052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(1695), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(696), 1,
      aux_sym_function_definition_repeat1,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1693), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1383), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [31177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(1699), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(698), 1,
      aux_sym_function_definition_repeat1,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1697), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1387), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [31302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(1703), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(704), 1,
      aux_sym_function_definition_repeat1,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1701), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1391), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [31427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(1707), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(705), 1,
      aux_sym_function_definition_repeat1,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1705), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1394), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [31552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(1711), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(709), 1,
      aux_sym_function_definition_repeat1,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1709), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1397), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [31677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(1715), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(711), 1,
      aux_sym_function_definition_repeat1,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1713), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1400), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [31802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(1719), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(712), 1,
      aux_sym_function_definition_repeat1,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1717), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1401), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [31927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(1723), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(714), 1,
      aux_sym_function_definition_repeat1,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1721), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1402), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [32052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(1085), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1725), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(57), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [32177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    ACTIONS(1729), 1,
      sym__newline,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(692), 1,
      aux_sym_function_definition_repeat1,
    STATE(1085), 1,
      sym__open_parenthesis,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1727), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(58), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [32302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(1733), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(765), 1,
      aux_sym_function_definition_repeat1,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1731), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1412), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [32427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(1737), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(766), 1,
      aux_sym_function_definition_repeat1,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1735), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1459), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [32552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(1741), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(767), 1,
      aux_sym_function_definition_repeat1,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1739), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1460), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [32677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(1745), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(768), 1,
      aux_sym_function_definition_repeat1,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1743), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1464), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [32802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(1749), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(771), 1,
      aux_sym_function_definition_repeat1,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1747), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1469), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [32927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(1058), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1751), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(154), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [33052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1753), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1498), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [33177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(1757), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(790), 1,
      aux_sym_function_definition_repeat1,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1755), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1499), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [33302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(1085), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1759), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(59), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [33427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    ACTIONS(1763), 1,
      sym__newline,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(697), 1,
      aux_sym_function_definition_repeat1,
    STATE(1085), 1,
      sym__open_parenthesis,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1761), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(60), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [33552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    ACTIONS(1767), 1,
      sym__newline,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(699), 1,
      aux_sym_function_definition_repeat1,
    STATE(1085), 1,
      sym__open_parenthesis,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1765), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(61), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [33677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    ACTIONS(1771), 1,
      sym__newline,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(702), 1,
      aux_sym_function_definition_repeat1,
    STATE(1085), 1,
      sym__open_parenthesis,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1769), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(62), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [33802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1773), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1502), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [33927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(1085), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1775), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(63), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [34052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1777), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1503), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [34177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(1085), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1779), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(64), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [34302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    ACTIONS(1783), 1,
      sym__newline,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(706), 1,
      aux_sym_function_definition_repeat1,
    STATE(1085), 1,
      sym__open_parenthesis,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1781), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(65), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [34427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    ACTIONS(1787), 1,
      sym__newline,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(707), 1,
      aux_sym_function_definition_repeat1,
    STATE(1085), 1,
      sym__open_parenthesis,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1785), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(66), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [34552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(1085), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1789), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(67), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [34677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    ACTIONS(1793), 1,
      sym__newline,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(710), 1,
      aux_sym_function_definition_repeat1,
    STATE(1085), 1,
      sym__open_parenthesis,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1791), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(68), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [34802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1795), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1504), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [34927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1797), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1505), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [35052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(1085), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1799), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(69), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [35177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(1085), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1801), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(70), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [35302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    ACTIONS(1805), 1,
      sym__newline,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(713), 1,
      aux_sym_function_definition_repeat1,
    STATE(1085), 1,
      sym__open_parenthesis,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1803), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(71), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [35427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1807), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1509), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [35552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(1085), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1809), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(72), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [35677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1811), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1512), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [35802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1813), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1516), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [35927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(1085), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1815), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(73), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [36052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1817), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1517), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [36177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1853), 1,
      sym__newline,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    STATE(395), 1,
      sym__open_brace,
    STATE(733), 1,
      aux_sym_function_definition_repeat1,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1849), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1328), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [36302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    STATE(395), 1,
      sym__open_brace,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1861), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1338), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [36427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    STATE(395), 1,
      sym__open_brace,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1863), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1181), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [36552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    STATE(395), 1,
      sym__open_brace,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1865), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1189), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [36677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    STATE(395), 1,
      sym__open_brace,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1867), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1191), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [36802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    STATE(395), 1,
      sym__open_brace,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1869), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1195), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [36927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    ACTIONS(1873), 1,
      sym__newline,
    STATE(395), 1,
      sym__open_brace,
    STATE(735), 1,
      aux_sym_function_definition_repeat1,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1871), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1197), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [37052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    ACTIONS(1877), 1,
      sym__newline,
    STATE(395), 1,
      sym__open_brace,
    STATE(737), 1,
      aux_sym_function_definition_repeat1,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1875), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1205), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [37177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    ACTIONS(1881), 1,
      sym__newline,
    STATE(395), 1,
      sym__open_brace,
    STATE(738), 1,
      aux_sym_function_definition_repeat1,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1879), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1209), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [37302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    ACTIONS(1885), 1,
      sym__newline,
    STATE(395), 1,
      sym__open_brace,
    STATE(739), 1,
      aux_sym_function_definition_repeat1,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1883), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1213), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [37427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    ACTIONS(1889), 1,
      sym__newline,
    STATE(395), 1,
      sym__open_brace,
    STATE(740), 1,
      aux_sym_function_definition_repeat1,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1887), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1218), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [37552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    ACTIONS(1893), 1,
      sym__newline,
    STATE(395), 1,
      sym__open_brace,
    STATE(741), 1,
      aux_sym_function_definition_repeat1,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1891), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1235), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [37677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    ACTIONS(1897), 1,
      sym__newline,
    STATE(395), 1,
      sym__open_brace,
    STATE(742), 1,
      aux_sym_function_definition_repeat1,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1895), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1237), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [37802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    ACTIONS(1901), 1,
      sym__newline,
    STATE(395), 1,
      sym__open_brace,
    STATE(743), 1,
      aux_sym_function_definition_repeat1,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1899), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1242), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [37927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    ACTIONS(1905), 1,
      sym__newline,
    STATE(395), 1,
      sym__open_brace,
    STATE(744), 1,
      aux_sym_function_definition_repeat1,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1903), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1244), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [38052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    ACTIONS(1909), 1,
      sym__newline,
    STATE(395), 1,
      sym__open_brace,
    STATE(745), 1,
      aux_sym_function_definition_repeat1,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1907), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1247), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [38177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    ACTIONS(1913), 1,
      sym__newline,
    STATE(395), 1,
      sym__open_brace,
    STATE(746), 1,
      aux_sym_function_definition_repeat1,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1911), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1253), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [38302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    ACTIONS(1917), 1,
      sym__newline,
    STATE(395), 1,
      sym__open_brace,
    STATE(747), 1,
      aux_sym_function_definition_repeat1,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1915), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1257), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [38427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    STATE(395), 1,
      sym__open_brace,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1919), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1266), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [38552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    ACTIONS(1923), 1,
      sym__newline,
    STATE(395), 1,
      sym__open_brace,
    STATE(748), 1,
      aux_sym_function_definition_repeat1,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1921), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1268), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [38677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    STATE(395), 1,
      sym__open_brace,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1925), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1274), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [38802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    STATE(395), 1,
      sym__open_brace,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1927), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1280), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [38927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    STATE(395), 1,
      sym__open_brace,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1929), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1283), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [39052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    STATE(395), 1,
      sym__open_brace,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1931), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1223), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [39177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    STATE(395), 1,
      sym__open_brace,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1933), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1262), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [39302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    STATE(395), 1,
      sym__open_brace,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1935), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1178), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [39427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    STATE(395), 1,
      sym__open_brace,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1937), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1193), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [39552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    STATE(395), 1,
      sym__open_brace,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1939), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1332), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [39677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    STATE(395), 1,
      sym__open_brace,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1941), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1334), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [39802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    STATE(395), 1,
      sym__open_brace,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1943), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1336), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [39927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    STATE(395), 1,
      sym__open_brace,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1945), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1207), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [40052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    STATE(395), 1,
      sym__open_brace,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1947), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1217), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [40177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    STATE(395), 1,
      sym__open_brace,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1949), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1317), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [40302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    STATE(395), 1,
      sym__open_brace,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1951), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1320), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [40427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    ACTIONS(1955), 1,
      sym__newline,
    STATE(395), 1,
      sym__open_brace,
    STATE(750), 1,
      aux_sym_function_definition_repeat1,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1953), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1327), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [40552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    STATE(395), 1,
      sym__open_brace,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1957), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1340), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [40677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    ACTIONS(1961), 1,
      sym__newline,
    STATE(395), 1,
      sym__open_brace,
    STATE(754), 1,
      aux_sym_function_definition_repeat1,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1959), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1176), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [40802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    ACTIONS(1965), 1,
      sym__newline,
    STATE(395), 1,
      sym__open_brace,
    STATE(755), 1,
      aux_sym_function_definition_repeat1,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1963), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1180), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [40927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    ACTIONS(1969), 1,
      sym__newline,
    STATE(395), 1,
      sym__open_brace,
    STATE(758), 1,
      aux_sym_function_definition_repeat1,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1967), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1234), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [41052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    STATE(395), 1,
      sym__open_brace,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1971), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1288), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [41177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    STATE(395), 1,
      sym__open_brace,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1973), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1289), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [41302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    ACTIONS(1977), 1,
      sym__newline,
    STATE(395), 1,
      sym__open_brace,
    STATE(760), 1,
      aux_sym_function_definition_repeat1,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1975), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1292), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [41427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    ACTIONS(1981), 1,
      sym__newline,
    STATE(395), 1,
      sym__open_brace,
    STATE(761), 1,
      aux_sym_function_definition_repeat1,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1979), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1296), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [41552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    STATE(395), 1,
      sym__open_brace,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1983), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1309), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [41677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    ACTIONS(1987), 1,
      sym__newline,
    STATE(395), 1,
      sym__open_brace,
    STATE(763), 1,
      aux_sym_function_definition_repeat1,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1985), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1318), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [41802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    STATE(395), 1,
      sym__open_brace,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1989), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1321), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [41927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    STATE(395), 1,
      sym__open_brace,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1991), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1322), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [42052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    ACTIONS(1995), 1,
      sym__newline,
    STATE(395), 1,
      sym__open_brace,
    STATE(764), 1,
      aux_sym_function_definition_repeat1,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1993), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1323), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [42177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    STATE(395), 1,
      sym__open_brace,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1997), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1325), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [42302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    STATE(395), 1,
      sym__open_brace,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(1999), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1326), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [42427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2001), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1519), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [42552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2003), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1523), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [42677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2005), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1526), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [42802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2007), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1529), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [42927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2039), 1,
      sym__newline,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(788), 1,
      aux_sym_function_definition_repeat1,
    STATE(1095), 1,
      sym__open_parenthesis,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2035), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(79), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [43052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(1095), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2045), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(80), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [43177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2047), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1531), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [43302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(1095), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2049), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(81), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [43427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(1095), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2051), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(82), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [43552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(1095), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2053), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(83), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [43677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(1095), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2055), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(84), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [43802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    ACTIONS(2059), 1,
      sym__newline,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(792), 1,
      aux_sym_function_definition_repeat1,
    STATE(1095), 1,
      sym__open_parenthesis,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2057), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(85), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [43927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    ACTIONS(2063), 1,
      sym__newline,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(794), 1,
      aux_sym_function_definition_repeat1,
    STATE(1095), 1,
      sym__open_parenthesis,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2061), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(87), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [44052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    ACTIONS(2067), 1,
      sym__newline,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(795), 1,
      aux_sym_function_definition_repeat1,
    STATE(1095), 1,
      sym__open_parenthesis,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2065), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(88), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [44177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    ACTIONS(2071), 1,
      sym__newline,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(1054), 1,
      aux_sym_function_definition_repeat1,
    STATE(1095), 1,
      sym__open_parenthesis,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2069), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(89), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [44302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    ACTIONS(2075), 1,
      sym__newline,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(797), 1,
      aux_sym_function_definition_repeat1,
    STATE(1095), 1,
      sym__open_parenthesis,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2073), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(90), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [44427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    ACTIONS(2079), 1,
      sym__newline,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(798), 1,
      aux_sym_function_definition_repeat1,
    STATE(1095), 1,
      sym__open_parenthesis,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2077), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(91), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [44552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    ACTIONS(2083), 1,
      sym__newline,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(799), 1,
      aux_sym_function_definition_repeat1,
    STATE(1095), 1,
      sym__open_parenthesis,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2081), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(92), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [44677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    ACTIONS(2087), 1,
      sym__newline,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(800), 1,
      aux_sym_function_definition_repeat1,
    STATE(1095), 1,
      sym__open_parenthesis,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2085), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(93), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [44802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    ACTIONS(2091), 1,
      sym__newline,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(801), 1,
      aux_sym_function_definition_repeat1,
    STATE(1095), 1,
      sym__open_parenthesis,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2089), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(94), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [44927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    ACTIONS(2095), 1,
      sym__newline,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(802), 1,
      aux_sym_function_definition_repeat1,
    STATE(1095), 1,
      sym__open_parenthesis,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2093), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(95), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [45052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    ACTIONS(2099), 1,
      sym__newline,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(803), 1,
      aux_sym_function_definition_repeat1,
    STATE(1095), 1,
      sym__open_parenthesis,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2097), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(96), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [45177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    ACTIONS(2103), 1,
      sym__newline,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(804), 1,
      aux_sym_function_definition_repeat1,
    STATE(1095), 1,
      sym__open_parenthesis,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2101), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(97), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [45302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(1095), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2105), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(98), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [45427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    ACTIONS(2109), 1,
      sym__newline,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(806), 1,
      aux_sym_function_definition_repeat1,
    STATE(1095), 1,
      sym__open_parenthesis,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2107), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(99), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [45552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2111), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1548), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [45677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(2115), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(808), 1,
      aux_sym_function_definition_repeat1,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2113), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1550), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [45802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(1095), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2117), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(100), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [45927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(1095), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2119), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(101), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [46052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(1095), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2121), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(102), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [46177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(1095), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2123), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(103), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [46302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(2127), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(906), 1,
      aux_sym_function_definition_repeat1,
    STATE(1058), 1,
      sym__open_parenthesis,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2125), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(139), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [46427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(1095), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2129), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(105), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [46552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(1095), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2131), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(106), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [46677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(1095), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2133), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(107), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [46802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(1095), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2135), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(108), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [46927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(1095), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2137), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(109), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [47052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(1095), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2139), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(110), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [47177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(1095), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2141), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(111), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [47302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(1095), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2143), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(112), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [47427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(1058), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2145), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(155), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [47552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(1095), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2147), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(113), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [47677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    ACTIONS(2151), 1,
      sym__newline,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(816), 1,
      aux_sym_function_definition_repeat1,
    STATE(1095), 1,
      sym__open_parenthesis,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2149), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(114), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [47802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2153), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1560), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [47927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(2157), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(812), 1,
      aux_sym_function_definition_repeat1,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2155), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1562), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [48052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(2161), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(813), 1,
      aux_sym_function_definition_repeat1,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2159), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1564), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [48177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(2165), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(818), 1,
      aux_sym_function_definition_repeat1,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2163), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1570), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [48302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2167), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1572), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [48427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2169), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1574), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [48552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(2173), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(823), 1,
      aux_sym_function_definition_repeat1,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2171), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1576), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [48677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(2177), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(829), 1,
      aux_sym_function_definition_repeat1,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2175), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1580), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [48802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(1095), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2179), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(115), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [48927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    ACTIONS(2183), 1,
      sym__newline,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(822), 1,
      aux_sym_function_definition_repeat1,
    STATE(1095), 1,
      sym__open_parenthesis,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2181), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(116), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [49052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2185), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1581), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [49177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(2189), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(834), 1,
      aux_sym_function_definition_repeat1,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2187), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1582), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [49302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    ACTIONS(2193), 1,
      sym__newline,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(824), 1,
      aux_sym_function_definition_repeat1,
    STATE(1095), 1,
      sym__open_parenthesis,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2191), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(117), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [49427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    ACTIONS(2197), 1,
      sym__newline,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(827), 1,
      aux_sym_function_definition_repeat1,
    STATE(1095), 1,
      sym__open_parenthesis,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2195), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(118), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [49552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(1095), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2199), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(119), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [49677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2201), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1444), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [49802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(1095), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2203), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(120), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [49927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    ACTIONS(2207), 1,
      sym__newline,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(831), 1,
      aux_sym_function_definition_repeat1,
    STATE(1095), 1,
      sym__open_parenthesis,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2205), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(121), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [50052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    ACTIONS(2211), 1,
      sym__newline,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(832), 1,
      aux_sym_function_definition_repeat1,
    STATE(1095), 1,
      sym__open_parenthesis,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2209), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(122), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [50177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(1095), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2213), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(123), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [50302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    ACTIONS(2217), 1,
      sym__newline,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(835), 1,
      aux_sym_function_definition_repeat1,
    STATE(1095), 1,
      sym__open_parenthesis,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2215), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(124), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [50427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2219), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1343), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [50552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(2223), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(836), 1,
      aux_sym_function_definition_repeat1,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2221), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1344), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [50677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(1095), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2225), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(125), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [50802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(1095), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2227), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(126), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [50927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    ACTIONS(2231), 1,
      sym__newline,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(837), 1,
      aux_sym_function_definition_repeat1,
    STATE(1095), 1,
      sym__open_parenthesis,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2229), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(127), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [51052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2233), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1346), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [51177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(1095), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2235), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(128), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [51302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2237), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1347), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [51427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(1095), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2239), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(19), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [51552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2275), 1,
      sym__newline,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    STATE(398), 1,
      sym__open_brace,
    STATE(856), 1,
      aux_sym_function_definition_repeat1,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2271), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1337), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [51677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    STATE(398), 1,
      sym__open_brace,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2283), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1183), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [51802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    STATE(398), 1,
      sym__open_brace,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2285), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1184), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [51927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    STATE(398), 1,
      sym__open_brace,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2287), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1185), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [52052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    STATE(398), 1,
      sym__open_brace,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2289), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1186), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [52177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    STATE(398), 1,
      sym__open_brace,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2291), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1187), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [52302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    ACTIONS(2295), 1,
      sym__newline,
    STATE(398), 1,
      sym__open_brace,
    STATE(858), 1,
      aux_sym_function_definition_repeat1,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2293), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1188), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [52427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    ACTIONS(2299), 1,
      sym__newline,
    STATE(398), 1,
      sym__open_brace,
    STATE(860), 1,
      aux_sym_function_definition_repeat1,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2297), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1192), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [52552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    ACTIONS(2303), 1,
      sym__newline,
    STATE(398), 1,
      sym__open_brace,
    STATE(861), 1,
      aux_sym_function_definition_repeat1,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2301), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1194), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [52677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    ACTIONS(2307), 1,
      sym__newline,
    STATE(398), 1,
      sym__open_brace,
    STATE(862), 1,
      aux_sym_function_definition_repeat1,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2305), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1196), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [52802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    ACTIONS(2311), 1,
      sym__newline,
    STATE(398), 1,
      sym__open_brace,
    STATE(863), 1,
      aux_sym_function_definition_repeat1,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2309), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1198), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [52927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    ACTIONS(2315), 1,
      sym__newline,
    STATE(398), 1,
      sym__open_brace,
    STATE(864), 1,
      aux_sym_function_definition_repeat1,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2313), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1200), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [53052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    ACTIONS(2319), 1,
      sym__newline,
    STATE(398), 1,
      sym__open_brace,
    STATE(865), 1,
      aux_sym_function_definition_repeat1,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2317), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1202), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [53177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    ACTIONS(2323), 1,
      sym__newline,
    STATE(398), 1,
      sym__open_brace,
    STATE(866), 1,
      aux_sym_function_definition_repeat1,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2321), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1204), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [53302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    ACTIONS(2327), 1,
      sym__newline,
    STATE(398), 1,
      sym__open_brace,
    STATE(867), 1,
      aux_sym_function_definition_repeat1,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2325), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1206), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [53427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    ACTIONS(2331), 1,
      sym__newline,
    STATE(398), 1,
      sym__open_brace,
    STATE(868), 1,
      aux_sym_function_definition_repeat1,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2329), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1208), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [53552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    ACTIONS(2335), 1,
      sym__newline,
    STATE(398), 1,
      sym__open_brace,
    STATE(869), 1,
      aux_sym_function_definition_repeat1,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2333), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1210), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [53677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    ACTIONS(2339), 1,
      sym__newline,
    STATE(398), 1,
      sym__open_brace,
    STATE(870), 1,
      aux_sym_function_definition_repeat1,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2337), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1212), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [53802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    STATE(398), 1,
      sym__open_brace,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2341), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1215), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [53927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    ACTIONS(2345), 1,
      sym__newline,
    STATE(398), 1,
      sym__open_brace,
    STATE(871), 1,
      aux_sym_function_definition_repeat1,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2343), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1216), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [54052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    STATE(398), 1,
      sym__open_brace,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2347), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1219), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [54177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    STATE(398), 1,
      sym__open_brace,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2349), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1220), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [54302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    STATE(398), 1,
      sym__open_brace,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2351), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1221), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [54427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    STATE(398), 1,
      sym__open_brace,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2353), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1222), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [54552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    STATE(398), 1,
      sym__open_brace,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2355), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1174), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [54677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    STATE(398), 1,
      sym__open_brace,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2357), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1224), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [54802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    STATE(398), 1,
      sym__open_brace,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2359), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1225), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [54927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    STATE(398), 1,
      sym__open_brace,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2361), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1226), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [55052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    STATE(398), 1,
      sym__open_brace,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2363), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1227), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [55177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    STATE(398), 1,
      sym__open_brace,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2365), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1228), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [55302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    STATE(398), 1,
      sym__open_brace,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2367), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1229), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [55427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    STATE(398), 1,
      sym__open_brace,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2369), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1230), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [55552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    STATE(398), 1,
      sym__open_brace,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2371), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1231), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [55677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    STATE(398), 1,
      sym__open_brace,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2373), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1232), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [55802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    ACTIONS(2377), 1,
      sym__newline,
    STATE(398), 1,
      sym__open_brace,
    STATE(873), 1,
      aux_sym_function_definition_repeat1,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2375), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1233), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [55927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    STATE(398), 1,
      sym__open_brace,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2379), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1238), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [56052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    ACTIONS(2383), 1,
      sym__newline,
    STATE(398), 1,
      sym__open_brace,
    STATE(877), 1,
      aux_sym_function_definition_repeat1,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2381), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1239), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [56177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    ACTIONS(2387), 1,
      sym__newline,
    STATE(398), 1,
      sym__open_brace,
    STATE(878), 1,
      aux_sym_function_definition_repeat1,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2385), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1241), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [56302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    ACTIONS(2391), 1,
      sym__newline,
    STATE(398), 1,
      sym__open_brace,
    STATE(881), 1,
      aux_sym_function_definition_repeat1,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2389), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1245), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [56427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    STATE(398), 1,
      sym__open_brace,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2393), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1248), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [56552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    STATE(398), 1,
      sym__open_brace,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2395), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1249), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [56677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    ACTIONS(2399), 1,
      sym__newline,
    STATE(398), 1,
      sym__open_brace,
    STATE(883), 1,
      aux_sym_function_definition_repeat1,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2397), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1250), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [56802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    ACTIONS(2403), 1,
      sym__newline,
    STATE(398), 1,
      sym__open_brace,
    STATE(884), 1,
      aux_sym_function_definition_repeat1,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2401), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1252), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [56927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    STATE(398), 1,
      sym__open_brace,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2405), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1255), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [57052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    ACTIONS(2409), 1,
      sym__newline,
    STATE(398), 1,
      sym__open_brace,
    STATE(886), 1,
      aux_sym_function_definition_repeat1,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2407), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1256), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [57177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    STATE(398), 1,
      sym__open_brace,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2411), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1258), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [57302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    STATE(398), 1,
      sym__open_brace,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2413), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1259), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [57427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    ACTIONS(2417), 1,
      sym__newline,
    STATE(398), 1,
      sym__open_brace,
    STATE(887), 1,
      aux_sym_function_definition_repeat1,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2415), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1260), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [57552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    STATE(398), 1,
      sym__open_brace,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2419), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1341), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [57677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    STATE(398), 1,
      sym__open_brace,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2421), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1263), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [57802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2457), 1,
      sym__newline,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    STATE(401), 1,
      sym__open_brace,
    STATE(907), 1,
      aux_sym_function_definition_repeat1,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2453), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1203), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [57927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    STATE(401), 1,
      sym__open_brace,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2465), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1286), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [58052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    STATE(401), 1,
      sym__open_brace,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2467), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1287), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [58177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    STATE(401), 1,
      sym__open_brace,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2469), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1294), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [58302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    STATE(401), 1,
      sym__open_brace,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2471), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1299), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [58427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    STATE(401), 1,
      sym__open_brace,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2473), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1305), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [58552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    ACTIONS(2477), 1,
      sym__newline,
    STATE(401), 1,
      sym__open_brace,
    STATE(909), 1,
      aux_sym_function_definition_repeat1,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2475), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1316), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [58677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    ACTIONS(2481), 1,
      sym__newline,
    STATE(401), 1,
      sym__open_brace,
    STATE(911), 1,
      aux_sym_function_definition_repeat1,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2479), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1324), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [58802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    ACTIONS(2485), 1,
      sym__newline,
    STATE(401), 1,
      sym__open_brace,
    STATE(912), 1,
      aux_sym_function_definition_repeat1,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2483), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1329), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [58927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    ACTIONS(2489), 1,
      sym__newline,
    STATE(401), 1,
      sym__open_brace,
    STATE(913), 1,
      aux_sym_function_definition_repeat1,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2487), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1331), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [59052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    ACTIONS(2493), 1,
      sym__newline,
    STATE(401), 1,
      sym__open_brace,
    STATE(914), 1,
      aux_sym_function_definition_repeat1,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2491), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1333), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [59177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    ACTIONS(2497), 1,
      sym__newline,
    STATE(401), 1,
      sym__open_brace,
    STATE(915), 1,
      aux_sym_function_definition_repeat1,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2495), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1335), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [59302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    ACTIONS(2501), 1,
      sym__newline,
    STATE(401), 1,
      sym__open_brace,
    STATE(916), 1,
      aux_sym_function_definition_repeat1,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2499), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1339), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [59427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    ACTIONS(2505), 1,
      sym__newline,
    STATE(401), 1,
      sym__open_brace,
    STATE(917), 1,
      aux_sym_function_definition_repeat1,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2503), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1175), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [59552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    ACTIONS(2509), 1,
      sym__newline,
    STATE(401), 1,
      sym__open_brace,
    STATE(918), 1,
      aux_sym_function_definition_repeat1,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2507), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1177), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [59677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    ACTIONS(2513), 1,
      sym__newline,
    STATE(401), 1,
      sym__open_brace,
    STATE(919), 1,
      aux_sym_function_definition_repeat1,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2511), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1179), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [59802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    ACTIONS(2517), 1,
      sym__newline,
    STATE(401), 1,
      sym__open_brace,
    STATE(920), 1,
      aux_sym_function_definition_repeat1,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2515), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1182), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [59927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    ACTIONS(2521), 1,
      sym__newline,
    STATE(401), 1,
      sym__open_brace,
    STATE(921), 1,
      aux_sym_function_definition_repeat1,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2519), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1199), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [60052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(1058), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2523), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(156), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [60177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    STATE(401), 1,
      sym__open_brace,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2525), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1211), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [60302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    ACTIONS(2529), 1,
      sym__newline,
    STATE(401), 1,
      sym__open_brace,
    STATE(922), 1,
      aux_sym_function_definition_repeat1,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2527), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1214), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [60427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    STATE(401), 1,
      sym__open_brace,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2531), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1236), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [60552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    STATE(401), 1,
      sym__open_brace,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2533), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1243), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [60677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    STATE(401), 1,
      sym__open_brace,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2535), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1251), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [60802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    STATE(401), 1,
      sym__open_brace,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2537), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1261), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [60927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    STATE(401), 1,
      sym__open_brace,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2539), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1264), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [61052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    STATE(401), 1,
      sym__open_brace,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2541), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1272), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [61177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    STATE(401), 1,
      sym__open_brace,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2543), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1275), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [61302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    STATE(401), 1,
      sym__open_brace,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2545), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1276), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [61427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    STATE(401), 1,
      sym__open_brace,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2547), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1277), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [61552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    STATE(401), 1,
      sym__open_brace,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2549), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1278), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [61677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    STATE(401), 1,
      sym__open_brace,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2551), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1279), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [61802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    STATE(401), 1,
      sym__open_brace,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2553), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1281), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [61927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    STATE(401), 1,
      sym__open_brace,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2555), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1282), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [62052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    STATE(401), 1,
      sym__open_brace,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2557), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1284), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [62177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    ACTIONS(2561), 1,
      sym__newline,
    STATE(401), 1,
      sym__open_brace,
    STATE(924), 1,
      aux_sym_function_definition_repeat1,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2559), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1285), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [62302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    STATE(401), 1,
      sym__open_brace,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2563), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1290), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [62427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    ACTIONS(2567), 1,
      sym__newline,
    STATE(401), 1,
      sym__open_brace,
    STATE(928), 1,
      aux_sym_function_definition_repeat1,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2565), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1291), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [62552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    ACTIONS(2571), 1,
      sym__newline,
    STATE(401), 1,
      sym__open_brace,
    STATE(929), 1,
      aux_sym_function_definition_repeat1,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2569), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1293), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [62677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    ACTIONS(2575), 1,
      sym__newline,
    STATE(401), 1,
      sym__open_brace,
    STATE(932), 1,
      aux_sym_function_definition_repeat1,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2573), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1297), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [62802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    STATE(401), 1,
      sym__open_brace,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2577), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1300), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [62927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    STATE(401), 1,
      sym__open_brace,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2579), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1301), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [63052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    ACTIONS(2583), 1,
      sym__newline,
    STATE(401), 1,
      sym__open_brace,
    STATE(934), 1,
      aux_sym_function_definition_repeat1,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2581), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1302), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [63177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    ACTIONS(2587), 1,
      sym__newline,
    STATE(401), 1,
      sym__open_brace,
    STATE(935), 1,
      aux_sym_function_definition_repeat1,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2585), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1304), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [63302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    STATE(401), 1,
      sym__open_brace,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2589), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1307), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [63427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    ACTIONS(2593), 1,
      sym__newline,
    STATE(401), 1,
      sym__open_brace,
    STATE(937), 1,
      aux_sym_function_definition_repeat1,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2591), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1308), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [63552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    STATE(401), 1,
      sym__open_brace,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2595), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1310), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [63677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    STATE(401), 1,
      sym__open_brace,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2597), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1311), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [63802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    ACTIONS(2601), 1,
      sym__newline,
    STATE(401), 1,
      sym__open_brace,
    STATE(938), 1,
      aux_sym_function_definition_repeat1,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2599), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1312), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [63927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    STATE(401), 1,
      sym__open_brace,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2603), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1314), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [64052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    STATE(401), 1,
      sym__open_brace,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2605), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1315), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [64177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(2609), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(656), 1,
      aux_sym_function_definition_repeat1,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2607), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1354), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [64302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(2613), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(659), 1,
      aux_sym_function_definition_repeat1,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2611), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1357), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [64427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(2617), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(460), 1,
      aux_sym_function_definition_repeat1,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2615), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1361), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [64552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(2621), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(665), 1,
      aux_sym_function_definition_repeat1,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2619), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1365), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [64677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    ACTIONS(2625), 1,
      sym__newline,
    STATE(381), 1,
      sym__open_brace,
    STATE(668), 1,
      aux_sym_function_definition_repeat1,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2623), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1366), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [64802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(1058), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2627), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(157), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [64927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(1058), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2629), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(158), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [65052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    ACTIONS(2633), 1,
      sym__newline,
    STATE(395), 1,
      sym__open_brace,
    STATE(948), 1,
      aux_sym_function_definition_repeat1,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2631), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1163), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [65177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(2637), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(1048), 1,
      aux_sym_function_definition_repeat1,
    STATE(1070), 1,
      sym__open_parenthesis,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2635), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(187), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [65302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    STATE(395), 1,
      sym__open_brace,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2639), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1150), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [65427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    ACTIONS(2643), 1,
      sym__newline,
    STATE(395), 1,
      sym__open_brace,
    STATE(952), 1,
      aux_sym_function_definition_repeat1,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2641), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1167), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [65552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(1058), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2645), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(159), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [65677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(1070), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2647), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(188), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [65802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    STATE(395), 1,
      sym__open_brace,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2649), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1165), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [65927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(1070), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2651), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(130), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [66052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(1058), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2653), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(160), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [66177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(1070), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2655), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(191), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [66302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(2659), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(951), 1,
      aux_sym_function_definition_repeat1,
    STATE(1070), 1,
      sym__open_parenthesis,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2657), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(182), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [66427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(2663), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(953), 1,
      aux_sym_function_definition_repeat1,
    STATE(1070), 1,
      sym__open_parenthesis,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2661), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(183), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [66552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(2667), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(955), 1,
      aux_sym_function_definition_repeat1,
    STATE(1070), 1,
      sym__open_parenthesis,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2665), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(184), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [66677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(2671), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(961), 1,
      aux_sym_function_definition_repeat1,
    STATE(1070), 1,
      sym__open_parenthesis,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2669), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(185), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [66802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(2675), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(963), 1,
      aux_sym_function_definition_repeat1,
    STATE(1070), 1,
      sym__open_parenthesis,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2673), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(186), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [66927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(1070), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2677), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(192), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [67052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(1058), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2679), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(161), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [67177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(1070), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2681), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(193), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [67302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    ACTIONS(2685), 1,
      sym__newline,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(965), 1,
      aux_sym_function_definition_repeat1,
    STATE(1095), 1,
      sym__open_parenthesis,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2683), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(7), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [67427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(1095), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2687), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(8), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [67552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    ACTIONS(2691), 1,
      sym__newline,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(967), 1,
      aux_sym_function_definition_repeat1,
    STATE(1095), 1,
      sym__open_parenthesis,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2689), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(9), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [67677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(1095), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2693), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(10), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [67802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(2697), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(516), 1,
      aux_sym_function_definition_repeat1,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2695), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1408), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [67927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(2701), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(517), 1,
      aux_sym_function_definition_repeat1,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2699), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1409), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [68052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(2705), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(518), 1,
      aux_sym_function_definition_repeat1,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2703), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1410), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [68177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(2709), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(519), 1,
      aux_sym_function_definition_repeat1,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2707), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1411), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [68302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(381), 1,
      anon_sym_BSLASH,
    ACTIONS(383), 1,
      anon_sym_function,
    ACTIONS(385), 1,
      anon_sym_if,
    ACTIONS(387), 1,
      anon_sym_for,
    ACTIONS(389), 1,
      anon_sym_while,
    ACTIONS(391), 1,
      anon_sym_repeat,
    ACTIONS(393), 1,
      anon_sym_QMARK,
    ACTIONS(395), 1,
      anon_sym_TILDE,
    ACTIONS(397), 1,
      anon_sym_BANG,
    ACTIONS(401), 1,
      sym__hex_literal,
    ACTIONS(403), 1,
      sym__number_literal,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(419), 1,
      sym__external_open_parenthesis,
    ACTIONS(421), 1,
      sym__external_open_brace,
    ACTIONS(2713), 1,
      sym__newline,
    STATE(386), 1,
      sym__open_brace,
    STATE(520), 1,
      aux_sym_function_definition_repeat1,
    STATE(1075), 1,
      sym__open_parenthesis,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1633), 1,
      sym_string,
    STATE(1649), 1,
      sym__float_literal,
    ACTIONS(399), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1041), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(413), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2711), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1413), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [68427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(1058), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2715), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(162), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [68552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(2719), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(622), 1,
      aux_sym_function_definition_repeat1,
    STATE(1058), 1,
      sym__open_parenthesis,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2717), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(243), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [68677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(1058), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2721), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(163), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [68802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(2725), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(650), 1,
      aux_sym_function_definition_repeat1,
    STATE(1058), 1,
      sym__open_parenthesis,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2723), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(135), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [68927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    ACTIONS(2729), 1,
      sym__newline,
    STATE(398), 1,
      sym__open_brace,
    STATE(978), 1,
      aux_sym_function_definition_repeat1,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2727), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1172), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [69052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    STATE(398), 1,
      sym__open_brace,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2731), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1170), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [69177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    ACTIONS(2735), 1,
      sym__newline,
    STATE(398), 1,
      sym__open_brace,
    STATE(980), 1,
      aux_sym_function_definition_repeat1,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2733), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1173), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [69302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    STATE(398), 1,
      sym__open_brace,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2737), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1162), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [69427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(2741), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(567), 1,
      aux_sym_function_definition_repeat1,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2739), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1403), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [69552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(2745), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(568), 1,
      aux_sym_function_definition_repeat1,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2743), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1404), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [69677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(2749), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(569), 1,
      aux_sym_function_definition_repeat1,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2747), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1405), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [69802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(2753), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(570), 1,
      aux_sym_function_definition_repeat1,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2751), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1406), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [69927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 1,
      anon_sym_BSLASH,
    ACTIONS(445), 1,
      anon_sym_function,
    ACTIONS(447), 1,
      anon_sym_if,
    ACTIONS(449), 1,
      anon_sym_for,
    ACTIONS(451), 1,
      anon_sym_while,
    ACTIONS(453), 1,
      anon_sym_repeat,
    ACTIONS(455), 1,
      anon_sym_QMARK,
    ACTIONS(457), 1,
      anon_sym_TILDE,
    ACTIONS(459), 1,
      anon_sym_BANG,
    ACTIONS(463), 1,
      sym__hex_literal,
    ACTIONS(465), 1,
      sym__number_literal,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(481), 1,
      sym__external_open_parenthesis,
    ACTIONS(483), 1,
      sym__external_open_brace,
    ACTIONS(2757), 1,
      sym__newline,
    STATE(389), 1,
      sym__open_brace,
    STATE(571), 1,
      aux_sym_function_definition_repeat1,
    STATE(1080), 1,
      sym__open_parenthesis,
    STATE(1630), 1,
      sym_string,
    STATE(1638), 1,
      sym__float_literal,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    ACTIONS(461), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1037), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(475), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2755), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1407), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [70052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(2761), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(462), 1,
      aux_sym_function_definition_repeat1,
    STATE(1070), 1,
      sym__open_parenthesis,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2759), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(194), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [70177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(2765), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(464), 1,
      aux_sym_function_definition_repeat1,
    STATE(1070), 1,
      sym__open_parenthesis,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2763), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(195), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [70302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(2769), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(465), 1,
      aux_sym_function_definition_repeat1,
    STATE(1070), 1,
      sym__open_parenthesis,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2767), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(196), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [70427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(2773), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(467), 1,
      aux_sym_function_definition_repeat1,
    STATE(1070), 1,
      sym__open_parenthesis,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2771), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(197), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [70552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    ACTIONS(2777), 1,
      sym__newline,
    STATE(401), 1,
      sym__open_brace,
    STATE(991), 1,
      aux_sym_function_definition_repeat1,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2775), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1155), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [70677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    STATE(401), 1,
      sym__open_brace,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2779), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1154), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [70802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    ACTIONS(2783), 1,
      sym__newline,
    STATE(401), 1,
      sym__open_brace,
    STATE(993), 1,
      aux_sym_function_definition_repeat1,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2781), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1158), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [70927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    STATE(401), 1,
      sym__open_brace,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2785), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1171), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [71052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    ACTIONS(2789), 1,
      sym__newline,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(626), 1,
      aux_sym_function_definition_repeat1,
    STATE(1085), 1,
      sym__open_parenthesis,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2787), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(20), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [71177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    ACTIONS(2793), 1,
      sym__newline,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(627), 1,
      aux_sym_function_definition_repeat1,
    STATE(1085), 1,
      sym__open_parenthesis,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2791), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(21), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [71302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    ACTIONS(2797), 1,
      sym__newline,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(629), 1,
      aux_sym_function_definition_repeat1,
    STATE(1085), 1,
      sym__open_parenthesis,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2795), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(22), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [71427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    ACTIONS(2801), 1,
      sym__newline,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(630), 1,
      aux_sym_function_definition_repeat1,
    STATE(1085), 1,
      sym__open_parenthesis,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2799), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(23), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [71552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    ACTIONS(2805), 1,
      sym__newline,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(632), 1,
      aux_sym_function_definition_repeat1,
    STATE(1085), 1,
      sym__open_parenthesis,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2803), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(24), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [71677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(2809), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(469), 1,
      aux_sym_function_definition_repeat1,
    STATE(1070), 1,
      sym__open_parenthesis,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2807), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(198), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [71802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(2813), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(471), 1,
      aux_sym_function_definition_repeat1,
    STATE(1070), 1,
      sym__open_parenthesis,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2811), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(199), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [71927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(2817), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(473), 1,
      aux_sym_function_definition_repeat1,
    STATE(1070), 1,
      sym__open_parenthesis,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2815), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(200), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [72052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(2821), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(474), 1,
      aux_sym_function_definition_repeat1,
    STATE(1070), 1,
      sym__open_parenthesis,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2819), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(201), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [72177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    ACTIONS(2825), 1,
      sym__newline,
    STATE(395), 1,
      sym__open_brace,
    STATE(1004), 1,
      aux_sym_function_definition_repeat1,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2823), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1164), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [72302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    STATE(395), 1,
      sym__open_brace,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2827), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1168), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [72427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    ACTIONS(2831), 1,
      sym__newline,
    STATE(395), 1,
      sym__open_brace,
    STATE(1006), 1,
      aux_sym_function_definition_repeat1,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2829), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1169), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [72552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    STATE(395), 1,
      sym__open_brace,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2833), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1148), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [72677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    ACTIONS(2837), 1,
      sym__newline,
    STATE(395), 1,
      sym__open_brace,
    STATE(716), 1,
      aux_sym_function_definition_repeat1,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2835), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1240), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [72802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    ACTIONS(2841), 1,
      sym__newline,
    STATE(395), 1,
      sym__open_brace,
    STATE(717), 1,
      aux_sym_function_definition_repeat1,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2839), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1246), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [72927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    ACTIONS(2845), 1,
      sym__newline,
    STATE(395), 1,
      sym__open_brace,
    STATE(718), 1,
      aux_sym_function_definition_repeat1,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2843), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1254), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [73052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    ACTIONS(2849), 1,
      sym__newline,
    STATE(395), 1,
      sym__open_brace,
    STATE(719), 1,
      aux_sym_function_definition_repeat1,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2847), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1270), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [73177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1821), 1,
      anon_sym_BSLASH,
    ACTIONS(1823), 1,
      anon_sym_function,
    ACTIONS(1825), 1,
      anon_sym_if,
    ACTIONS(1827), 1,
      anon_sym_for,
    ACTIONS(1829), 1,
      anon_sym_while,
    ACTIONS(1831), 1,
      anon_sym_repeat,
    ACTIONS(1833), 1,
      anon_sym_QMARK,
    ACTIONS(1835), 1,
      anon_sym_TILDE,
    ACTIONS(1837), 1,
      anon_sym_BANG,
    ACTIONS(1841), 1,
      sym__hex_literal,
    ACTIONS(1843), 1,
      sym__number_literal,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(1857), 1,
      sym__external_open_parenthesis,
    ACTIONS(1859), 1,
      sym__external_open_brace,
    ACTIONS(2853), 1,
      sym__newline,
    STATE(395), 1,
      sym__open_brace,
    STATE(720), 1,
      aux_sym_function_definition_repeat1,
    STATE(1090), 1,
      sym__open_parenthesis,
    STATE(1609), 1,
      sym_string,
    STATE(1610), 1,
      sym__float_literal,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    ACTIONS(1839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1819), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1851), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2851), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1330), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [73302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(2857), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(475), 1,
      aux_sym_function_definition_repeat1,
    STATE(1070), 1,
      sym__open_parenthesis,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2855), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(202), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [73427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(2861), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(476), 1,
      aux_sym_function_definition_repeat1,
    STATE(1070), 1,
      sym__open_parenthesis,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2859), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(203), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [73552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(2865), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(477), 1,
      aux_sym_function_definition_repeat1,
    STATE(1070), 1,
      sym__open_parenthesis,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2863), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(204), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [73677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(2869), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(479), 1,
      aux_sym_function_definition_repeat1,
    STATE(1070), 1,
      sym__open_parenthesis,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2867), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(205), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [73802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    ACTIONS(2873), 1,
      sym__newline,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(1017), 1,
      aux_sym_function_definition_repeat1,
    STATE(1095), 1,
      sym__open_parenthesis,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2871), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(15), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [73927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(1095), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2875), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(16), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [74052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    ACTIONS(2879), 1,
      sym__newline,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(1019), 1,
      aux_sym_function_definition_repeat1,
    STATE(1095), 1,
      sym__open_parenthesis,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2877), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(17), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [74177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(1095), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2881), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(3), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [74302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    ACTIONS(2885), 1,
      sym__newline,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(770), 1,
      aux_sym_function_definition_repeat1,
    STATE(1095), 1,
      sym__open_parenthesis,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2883), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(74), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [74427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    ACTIONS(2889), 1,
      sym__newline,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(772), 1,
      aux_sym_function_definition_repeat1,
    STATE(1095), 1,
      sym__open_parenthesis,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2887), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(75), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [74552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    ACTIONS(2893), 1,
      sym__newline,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(773), 1,
      aux_sym_function_definition_repeat1,
    STATE(1095), 1,
      sym__open_parenthesis,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2891), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(76), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [74677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    ACTIONS(2897), 1,
      sym__newline,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(774), 1,
      aux_sym_function_definition_repeat1,
    STATE(1095), 1,
      sym__open_parenthesis,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2895), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(77), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [74802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    ACTIONS(2901), 1,
      sym__newline,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(775), 1,
      aux_sym_function_definition_repeat1,
    STATE(1095), 1,
      sym__open_parenthesis,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2899), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(78), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [74927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(2905), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(481), 1,
      aux_sym_function_definition_repeat1,
    STATE(1070), 1,
      sym__open_parenthesis,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2903), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(206), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [75052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(1058), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2907), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(164), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [75177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(2911), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(652), 1,
      aux_sym_function_definition_repeat1,
    STATE(1058), 1,
      sym__open_parenthesis,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2909), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(136), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [75302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(2915), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(689), 1,
      aux_sym_function_definition_repeat1,
    STATE(1058), 1,
      sym__open_parenthesis,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2913), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(137), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [75427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    ACTIONS(2919), 1,
      sym__newline,
    STATE(398), 1,
      sym__open_brace,
    STATE(1030), 1,
      aux_sym_function_definition_repeat1,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2917), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1151), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [75552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    STATE(398), 1,
      sym__open_brace,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2921), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1152), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [75677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    ACTIONS(2925), 1,
      sym__newline,
    STATE(398), 1,
      sym__open_brace,
    STATE(1032), 1,
      aux_sym_function_definition_repeat1,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2923), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1153), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [75802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    STATE(398), 1,
      sym__open_brace,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2927), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1156), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [75927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    ACTIONS(2931), 1,
      sym__newline,
    STATE(398), 1,
      sym__open_brace,
    STATE(839), 1,
      aux_sym_function_definition_repeat1,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2929), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1295), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [76052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    ACTIONS(2935), 1,
      sym__newline,
    STATE(398), 1,
      sym__open_brace,
    STATE(840), 1,
      aux_sym_function_definition_repeat1,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2933), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1298), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [76177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    ACTIONS(2939), 1,
      sym__newline,
    STATE(398), 1,
      sym__open_brace,
    STATE(841), 1,
      aux_sym_function_definition_repeat1,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2937), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1303), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [76302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    ACTIONS(2943), 1,
      sym__newline,
    STATE(398), 1,
      sym__open_brace,
    STATE(842), 1,
      aux_sym_function_definition_repeat1,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2941), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1306), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [76427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2243), 1,
      anon_sym_BSLASH,
    ACTIONS(2245), 1,
      anon_sym_function,
    ACTIONS(2247), 1,
      anon_sym_if,
    ACTIONS(2249), 1,
      anon_sym_for,
    ACTIONS(2251), 1,
      anon_sym_while,
    ACTIONS(2253), 1,
      anon_sym_repeat,
    ACTIONS(2255), 1,
      anon_sym_QMARK,
    ACTIONS(2257), 1,
      anon_sym_TILDE,
    ACTIONS(2259), 1,
      anon_sym_BANG,
    ACTIONS(2263), 1,
      sym__hex_literal,
    ACTIONS(2265), 1,
      sym__number_literal,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(2279), 1,
      sym__external_open_parenthesis,
    ACTIONS(2281), 1,
      sym__external_open_brace,
    ACTIONS(2947), 1,
      sym__newline,
    STATE(398), 1,
      sym__open_brace,
    STATE(843), 1,
      aux_sym_function_definition_repeat1,
    STATE(1100), 1,
      sym__open_parenthesis,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1593), 1,
      sym_string,
    STATE(1594), 1,
      sym__float_literal,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    ACTIONS(2261), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2241), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2273), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2945), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1313), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [76552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_SQUOTE,
    ACTIONS(429), 1,
      anon_sym_DQUOTE,
    ACTIONS(431), 1,
      sym__raw_string_open,
    ACTIONS(869), 1,
      anon_sym_BSLASH,
    ACTIONS(871), 1,
      anon_sym_function,
    ACTIONS(873), 1,
      anon_sym_if,
    ACTIONS(875), 1,
      anon_sym_for,
    ACTIONS(877), 1,
      anon_sym_while,
    ACTIONS(879), 1,
      anon_sym_repeat,
    ACTIONS(881), 1,
      anon_sym_QMARK,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_BANG,
    ACTIONS(889), 1,
      sym__hex_literal,
    ACTIONS(891), 1,
      sym__number_literal,
    ACTIONS(899), 1,
      sym__external_open_parenthesis,
    ACTIONS(901), 1,
      sym__external_open_brace,
    ACTIONS(2951), 1,
      sym__newline,
    STATE(316), 1,
      sym__float_literal,
    STATE(318), 1,
      sym_string,
    STATE(319), 1,
      sym__raw_string,
    STATE(324), 1,
      sym__single_quoted_string,
    STATE(325), 1,
      sym__double_quoted_string,
    STATE(335), 1,
      sym__open_brace,
    STATE(805), 1,
      aux_sym_function_definition_repeat1,
    STATE(1058), 1,
      sym__open_parenthesis,
    ACTIONS(887), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(867), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(895), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2949), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(138), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [76677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    ACTIONS(2955), 1,
      sym__newline,
    STATE(401), 1,
      sym__open_brace,
    STATE(1040), 1,
      aux_sym_function_definition_repeat1,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2953), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1157), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [76802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    STATE(401), 1,
      sym__open_brace,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2957), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1159), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [76927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    ACTIONS(2961), 1,
      sym__newline,
    STATE(401), 1,
      sym__open_brace,
    STATE(1042), 1,
      aux_sym_function_definition_repeat1,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2959), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1160), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [77052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    STATE(401), 1,
      sym__open_brace,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2963), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1161), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [77177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    ACTIONS(2967), 1,
      sym__newline,
    STATE(401), 1,
      sym__open_brace,
    STATE(889), 1,
      aux_sym_function_definition_repeat1,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2965), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1265), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [77302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    ACTIONS(2971), 1,
      sym__newline,
    STATE(401), 1,
      sym__open_brace,
    STATE(890), 1,
      aux_sym_function_definition_repeat1,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2969), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1267), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [77427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    ACTIONS(2975), 1,
      sym__newline,
    STATE(401), 1,
      sym__open_brace,
    STATE(891), 1,
      aux_sym_function_definition_repeat1,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2973), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1269), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [77552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    ACTIONS(2979), 1,
      sym__newline,
    STATE(401), 1,
      sym__open_brace,
    STATE(892), 1,
      aux_sym_function_definition_repeat1,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2977), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1271), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [77677] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2425), 1,
      anon_sym_BSLASH,
    ACTIONS(2427), 1,
      anon_sym_function,
    ACTIONS(2429), 1,
      anon_sym_if,
    ACTIONS(2431), 1,
      anon_sym_for,
    ACTIONS(2433), 1,
      anon_sym_while,
    ACTIONS(2435), 1,
      anon_sym_repeat,
    ACTIONS(2437), 1,
      anon_sym_QMARK,
    ACTIONS(2439), 1,
      anon_sym_TILDE,
    ACTIONS(2441), 1,
      anon_sym_BANG,
    ACTIONS(2445), 1,
      sym__hex_literal,
    ACTIONS(2447), 1,
      sym__number_literal,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(2461), 1,
      sym__external_open_parenthesis,
    ACTIONS(2463), 1,
      sym__external_open_brace,
    ACTIONS(2983), 1,
      sym__newline,
    STATE(401), 1,
      sym__open_brace,
    STATE(893), 1,
      aux_sym_function_definition_repeat1,
    STATE(1105), 1,
      sym__open_parenthesis,
    STATE(1602), 1,
      sym_string,
    STATE(1603), 1,
      sym__float_literal,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    ACTIONS(2443), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2423), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2455), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2981), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1273), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [77802] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(1047), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(1070), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2985), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(207), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [77927] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_SQUOTE,
    ACTIONS(437), 1,
      anon_sym_DQUOTE,
    ACTIONS(439), 1,
      sym__raw_string_open,
    ACTIONS(689), 1,
      anon_sym_BSLASH,
    ACTIONS(691), 1,
      anon_sym_function,
    ACTIONS(693), 1,
      anon_sym_if,
    ACTIONS(695), 1,
      anon_sym_for,
    ACTIONS(697), 1,
      anon_sym_while,
    ACTIONS(699), 1,
      anon_sym_repeat,
    ACTIONS(701), 1,
      anon_sym_QMARK,
    ACTIONS(703), 1,
      anon_sym_TILDE,
    ACTIONS(705), 1,
      anon_sym_BANG,
    ACTIONS(709), 1,
      sym__hex_literal,
    ACTIONS(711), 1,
      sym__number_literal,
    ACTIONS(719), 1,
      sym__external_open_parenthesis,
    ACTIONS(721), 1,
      sym__external_open_brace,
    ACTIONS(2989), 1,
      sym__newline,
    STATE(311), 1,
      sym_string,
    STATE(330), 1,
      sym__float_literal,
    STATE(331), 1,
      sym__raw_string,
    STATE(332), 1,
      sym__single_quoted_string,
    STATE(333), 1,
      sym__double_quoted_string,
    STATE(384), 1,
      sym__open_brace,
    STATE(487), 1,
      aux_sym_function_definition_repeat1,
    STATE(1070), 1,
      sym__open_parenthesis,
    ACTIONS(707), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(687), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(715), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2987), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(208), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [78052] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    ACTIONS(2993), 1,
      sym__newline,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(1051), 1,
      aux_sym_function_definition_repeat1,
    STATE(1085), 1,
      sym__open_parenthesis,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2991), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(11), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [78177] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(1085), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2995), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(12), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [78302] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    ACTIONS(2999), 1,
      sym__newline,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(1053), 1,
      aux_sym_function_definition_repeat1,
    STATE(1085), 1,
      sym__open_parenthesis,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(2997), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(13), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [78427] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(331), 1,
      anon_sym_SQUOTE,
    ACTIONS(333), 1,
      anon_sym_DQUOTE,
    ACTIONS(337), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(1107), 1,
      anon_sym_BSLASH,
    ACTIONS(1109), 1,
      anon_sym_function,
    ACTIONS(1111), 1,
      anon_sym_if,
    ACTIONS(1113), 1,
      anon_sym_for,
    ACTIONS(1115), 1,
      anon_sym_while,
    ACTIONS(1117), 1,
      anon_sym_repeat,
    ACTIONS(1119), 1,
      anon_sym_QMARK,
    ACTIONS(1121), 1,
      anon_sym_TILDE,
    ACTIONS(1123), 1,
      anon_sym_BANG,
    ACTIONS(1127), 1,
      sym__hex_literal,
    ACTIONS(1129), 1,
      sym__number_literal,
    ACTIONS(1137), 1,
      sym__external_open_parenthesis,
    ACTIONS(1139), 1,
      sym__external_open_brace,
    STATE(286), 1,
      sym__double_quoted_string,
    STATE(288), 1,
      sym_string,
    STATE(289), 1,
      sym__float_literal,
    STATE(290), 1,
      sym__raw_string,
    STATE(291), 1,
      sym__single_quoted_string,
    STATE(393), 1,
      sym__open_brace,
    STATE(1085), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1105), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(1133), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3001), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(14), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [78552] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_SQUOTE,
    ACTIONS(365), 1,
      anon_sym_DQUOTE,
    ACTIONS(367), 1,
      sym__raw_string_open,
    ACTIONS(1047), 1,
      sym__newline,
    ACTIONS(2011), 1,
      anon_sym_BSLASH,
    ACTIONS(2013), 1,
      anon_sym_function,
    ACTIONS(2015), 1,
      anon_sym_if,
    ACTIONS(2017), 1,
      anon_sym_for,
    ACTIONS(2019), 1,
      anon_sym_while,
    ACTIONS(2021), 1,
      anon_sym_repeat,
    ACTIONS(2023), 1,
      anon_sym_QMARK,
    ACTIONS(2025), 1,
      anon_sym_TILDE,
    ACTIONS(2027), 1,
      anon_sym_BANG,
    ACTIONS(2031), 1,
      sym__hex_literal,
    ACTIONS(2033), 1,
      sym__number_literal,
    ACTIONS(2041), 1,
      sym__external_open_parenthesis,
    ACTIONS(2043), 1,
      sym__external_open_brace,
    STATE(299), 1,
      sym_string,
    STATE(300), 1,
      sym__float_literal,
    STATE(301), 1,
      sym__raw_string,
    STATE(302), 1,
      sym__single_quoted_string,
    STATE(303), 1,
      sym__double_quoted_string,
    STATE(396), 1,
      sym__open_brace,
    STATE(1095), 1,
      sym__open_parenthesis,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(2029), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2009), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(2037), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3003), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(104), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [78677] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3005), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1543), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [78796] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3007), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1571), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [78915] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3009), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1563), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [79034] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3011), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1375), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [79153] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3013), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1374), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [79272] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3015), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1389), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [79391] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3017), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1369), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [79510] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3019), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1440), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [79629] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3021), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1495), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [79748] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3023), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1578), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [79867] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3025), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1433), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [79986] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3027), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1575), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [80105] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3029), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1435), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [80224] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3031), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1436), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [80343] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3033), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1437), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [80462] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3035), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1451), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [80581] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3037), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1452), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [80700] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3039), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1454), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [80819] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3041), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1457), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [80938] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3043), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1458), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [81057] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3045), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1461), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [81176] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3047), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1462), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [81295] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3049), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1463), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [81414] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3051), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1466), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [81533] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3053), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1468), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [81652] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3055), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1471), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [81771] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3057), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1472), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [81890] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3059), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1473), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [82009] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3061), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1474), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [82128] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3063), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1475), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [82247] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3065), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1483), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [82366] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3067), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1484), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [82485] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3069), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1486), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [82604] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3071), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1487), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [82723] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3073), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1488), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [82842] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3075), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1491), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [82961] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3077), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1492), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [83080] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3079), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1494), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [83199] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3081), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1496), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [83318] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3083), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1497), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [83437] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3085), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1507), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [83556] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3087), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1508), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [83675] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3089), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1510), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [83794] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3091), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1513), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [83913] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3093), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1515), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [84032] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3095), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1521), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [84151] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3097), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1522), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [84270] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3099), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1524), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [84389] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3101), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1527), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [84508] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3103), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1528), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [84627] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3105), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1534), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [84746] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3107), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1535), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [84865] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3109), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1536), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [84984] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3111), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1537), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [85103] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3113), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1538), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [85222] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3115), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1540), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [85341] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3117), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1577), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [85460] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3119), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1544), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [85579] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3121), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1545), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [85698] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3123), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1546), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [85817] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3125), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1547), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [85936] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3127), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1551), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [86055] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3129), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1553), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [86174] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3131), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1555), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [86293] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3133), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1556), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [86412] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3135), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1559), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [86531] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3137), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1561), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [86650] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3139), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1565), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [86769] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3141), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1566), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [86888] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3143), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1569), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [87007] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(499), 1,
      anon_sym_BSLASH,
    ACTIONS(501), 1,
      anon_sym_function,
    ACTIONS(503), 1,
      anon_sym_if,
    ACTIONS(505), 1,
      anon_sym_for,
    ACTIONS(507), 1,
      anon_sym_while,
    ACTIONS(509), 1,
      anon_sym_repeat,
    ACTIONS(511), 1,
      anon_sym_QMARK,
    ACTIONS(513), 1,
      anon_sym_TILDE,
    ACTIONS(515), 1,
      anon_sym_BANG,
    ACTIONS(519), 1,
      sym__hex_literal,
    ACTIONS(521), 1,
      sym__number_literal,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(537), 1,
      sym__external_open_parenthesis,
    ACTIONS(541), 1,
      sym__external_open_brace,
    STATE(381), 1,
      sym__open_brace,
    STATE(1065), 1,
      sym__open_parenthesis,
    STATE(1626), 1,
      sym__float_literal,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1640), 1,
      sym_string,
    ACTIONS(517), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1043), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(531), 5,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
    ACTIONS(3145), 7,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
    STATE(1434), 19,
      sym_function_definition,
      sym_if_statement,
      sym_for_statement,
      sym_while_statement,
      sym_repeat_statement,
      sym_braced_expression,
      sym_parenthesized_expression,
      sym_call,
      sym_subset,
      sym_subset2,
      sym_unary_operator,
      sym_binary_operator,
      sym_extract_operator,
      sym_namespace_operator,
      sym_integer,
      sym_complex,
      sym_float,
      sym_na,
      sym__expression,
  [87126] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(3149), 1,
      sym__newline,
    STATE(1127), 1,
      aux_sym_function_definition_repeat1,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    STATE(1669), 1,
      sym_string,
    ACTIONS(3147), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(329), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(325), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [87201] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    ACTIONS(3153), 1,
      sym__newline,
    STATE(1145), 1,
      aux_sym_function_definition_repeat1,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    STATE(1683), 1,
      sym_string,
    ACTIONS(3151), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(353), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(349), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [87276] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(3157), 1,
      sym__newline,
    STATE(1146), 1,
      aux_sym_function_definition_repeat1,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    STATE(1710), 1,
      sym_string,
    ACTIONS(3155), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(353), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(349), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [87351] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(3161), 1,
      sym__newline,
    STATE(1144), 1,
      aux_sym_function_definition_repeat1,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    STATE(1656), 1,
      sym_string,
    ACTIONS(3159), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(353), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(349), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [87426] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    ACTIONS(3165), 1,
      sym__newline,
    STATE(1128), 1,
      aux_sym_function_definition_repeat1,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    STATE(1702), 1,
      sym_string,
    ACTIONS(3163), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(329), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(325), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [87501] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    ACTIONS(3169), 1,
      sym__newline,
    STATE(1129), 1,
      aux_sym_function_definition_repeat1,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    STATE(1721), 1,
      sym_string,
    ACTIONS(3167), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(329), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(325), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [87576] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(3173), 1,
      sym__newline,
    STATE(1137), 1,
      aux_sym_function_definition_repeat1,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1797), 1,
      sym_string,
    ACTIONS(3171), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(329), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(325), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [87650] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(3177), 1,
      sym__newline,
    STATE(1134), 1,
      aux_sym_function_definition_repeat1,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1776), 1,
      sym_string,
    ACTIONS(3175), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(329), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(325), 25,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [87724] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    ACTIONS(3181), 1,
      sym__newline,
    STATE(1147), 1,
      aux_sym_function_definition_repeat1,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1768), 1,
      sym_string,
    ACTIONS(3179), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(353), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(349), 25,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [87798] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(3185), 1,
      sym__newline,
    STATE(1149), 1,
      aux_sym_function_definition_repeat1,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    STATE(1742), 1,
      sym_string,
    ACTIONS(3183), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(353), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(349), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [87872] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    ACTIONS(3189), 1,
      sym__newline,
    STATE(1135), 1,
      aux_sym_function_definition_repeat1,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    STATE(1735), 1,
      sym_string,
    ACTIONS(3187), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(329), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(325), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [87946] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    ACTIONS(3193), 1,
      sym__newline,
    STATE(1166), 1,
      aux_sym_function_definition_repeat1,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1769), 1,
      sym_string,
    ACTIONS(3191), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(353), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(349), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [88020] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1845), 1,
      anon_sym_SQUOTE,
    ACTIONS(1847), 1,
      anon_sym_DQUOTE,
    ACTIONS(1855), 1,
      sym__raw_string_open,
    STATE(1611), 1,
      sym__raw_string,
    STATE(1612), 1,
      sym__single_quoted_string,
    STATE(1615), 1,
      sym__double_quoted_string,
    STATE(1701), 1,
      sym_string,
    ACTIONS(3195), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(491), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(489), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [88089] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2449), 1,
      anon_sym_SQUOTE,
    ACTIONS(2451), 1,
      anon_sym_DQUOTE,
    ACTIONS(2459), 1,
      sym__raw_string_open,
    STATE(1604), 1,
      sym__raw_string,
    STATE(1605), 1,
      sym__single_quoted_string,
    STATE(1606), 1,
      sym__double_quoted_string,
    STATE(1691), 1,
      sym_string,
    ACTIONS(3197), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(491), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(489), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [88158] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2267), 1,
      anon_sym_SQUOTE,
    ACTIONS(2269), 1,
      anon_sym_DQUOTE,
    ACTIONS(2277), 1,
      sym__raw_string_open,
    STATE(1584), 1,
      sym__single_quoted_string,
    STATE(1598), 1,
      sym__raw_string,
    STATE(1616), 1,
      sym__double_quoted_string,
    STATE(1700), 1,
      sym_string,
    ACTIONS(3199), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(491), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(489), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [88227] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(523), 1,
      anon_sym_SQUOTE,
    ACTIONS(525), 1,
      anon_sym_DQUOTE,
    ACTIONS(535), 1,
      sym__raw_string_open,
    STATE(1627), 1,
      sym__raw_string,
    STATE(1628), 1,
      sym__single_quoted_string,
    STATE(1629), 1,
      sym__double_quoted_string,
    STATE(1766), 1,
      sym_string,
    ACTIONS(3201), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(491), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(489), 25,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [88295] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(467), 1,
      anon_sym_SQUOTE,
    ACTIONS(469), 1,
      anon_sym_DQUOTE,
    ACTIONS(479), 1,
      sym__raw_string_open,
    STATE(1639), 1,
      sym__raw_string,
    STATE(1641), 1,
      sym__single_quoted_string,
    STATE(1651), 1,
      sym__double_quoted_string,
    STATE(1771), 1,
      sym_string,
    ACTIONS(3203), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(491), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(489), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [88363] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(405), 1,
      anon_sym_SQUOTE,
    ACTIONS(407), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      sym__raw_string_open,
    STATE(1617), 1,
      sym__single_quoted_string,
    STATE(1619), 1,
      sym__double_quoted_string,
    STATE(1632), 1,
      sym__raw_string,
    STATE(1734), 1,
      sym_string,
    ACTIONS(3205), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(491), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(489), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [88431] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3207), 1,
      sym__newline,
    STATE(1144), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(669), 12,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(671), 29,
      sym__raw_string_open,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_comma,
  [88486] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3210), 1,
      sym__newline,
    STATE(1145), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(669), 12,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(671), 29,
      sym__raw_string_open,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_comma,
  [88541] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3213), 1,
      sym__newline,
    STATE(1146), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(669), 12,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(671), 29,
      sym__raw_string_open,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_comma,
  [88596] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3216), 1,
      sym__newline,
    STATE(1147), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(669), 12,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(671), 28,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_comma,
  [88650] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3219), 1,
      anon_sym_EQ,
    ACTIONS(3221), 1,
      anon_sym_TILDE,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3229), 1,
      anon_sym_DASH_GT,
    ACTIONS(3231), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3233), 1,
      anon_sym_PIPE,
    ACTIONS(3235), 1,
      anon_sym_AMP,
    ACTIONS(3237), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3257), 1,
      sym__external_else,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(762), 1,
      sym__else,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(59), 3,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3227), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [88758] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3265), 1,
      sym__newline,
    STATE(1149), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(669), 12,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(671), 28,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_comma,
  [88812] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3219), 1,
      anon_sym_EQ,
    ACTIONS(3221), 1,
      anon_sym_TILDE,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3229), 1,
      anon_sym_DASH_GT,
    ACTIONS(3231), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3233), 1,
      anon_sym_PIPE,
    ACTIONS(3235), 1,
      anon_sym_AMP,
    ACTIONS(3237), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    ACTIONS(3268), 1,
      sym__external_else,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(814), 1,
      sym__else,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(115), 3,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3227), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [88920] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3270), 1,
      anon_sym_EQ,
    ACTIONS(3272), 1,
      anon_sym_TILDE,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3280), 1,
      anon_sym_DASH_GT,
    ACTIONS(3282), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3284), 1,
      anon_sym_PIPE,
    ACTIONS(3286), 1,
      anon_sym_AMP,
    ACTIONS(3288), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3290), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3308), 1,
      sym__external_else,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(875), 1,
      sym__else,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(7), 3,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3278), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [89028] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3270), 1,
      anon_sym_EQ,
    ACTIONS(3272), 1,
      anon_sym_TILDE,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3280), 1,
      anon_sym_DASH_GT,
    ACTIONS(3282), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3284), 1,
      anon_sym_PIPE,
    ACTIONS(3286), 1,
      anon_sym_AMP,
    ACTIONS(3288), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3290), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    ACTIONS(3316), 1,
      sym__external_else,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(879), 1,
      sym__else,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(115), 3,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3278), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [89136] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3270), 1,
      anon_sym_EQ,
    ACTIONS(3272), 1,
      anon_sym_TILDE,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3280), 1,
      anon_sym_DASH_GT,
    ACTIONS(3282), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3284), 1,
      anon_sym_PIPE,
    ACTIONS(3286), 1,
      anon_sym_AMP,
    ACTIONS(3288), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3290), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    ACTIONS(3318), 1,
      sym__external_else,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(880), 1,
      sym__else,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(107), 3,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3278), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [89244] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3320), 1,
      anon_sym_EQ,
    ACTIONS(3322), 1,
      anon_sym_TILDE,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3330), 1,
      anon_sym_DASH_GT,
    ACTIONS(3332), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3334), 1,
      anon_sym_PIPE,
    ACTIONS(3336), 1,
      anon_sym_AMP,
    ACTIONS(3338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3358), 1,
      sym__external_else,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(609), 1,
      sym__else,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(115), 3,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3328), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [89352] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3320), 1,
      anon_sym_EQ,
    ACTIONS(3322), 1,
      anon_sym_TILDE,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3330), 1,
      anon_sym_DASH_GT,
    ACTIONS(3332), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3334), 1,
      anon_sym_PIPE,
    ACTIONS(3336), 1,
      anon_sym_AMP,
    ACTIONS(3338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    ACTIONS(3366), 1,
      sym__external_else,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(605), 1,
      sym__else,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(7), 3,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3328), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [89460] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3270), 1,
      anon_sym_EQ,
    ACTIONS(3272), 1,
      anon_sym_TILDE,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3280), 1,
      anon_sym_DASH_GT,
    ACTIONS(3282), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3284), 1,
      anon_sym_PIPE,
    ACTIONS(3286), 1,
      anon_sym_AMP,
    ACTIONS(3288), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3290), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    ACTIONS(3368), 1,
      sym__external_else,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(885), 1,
      sym__else,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(59), 3,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3278), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [89568] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3320), 1,
      anon_sym_EQ,
    ACTIONS(3322), 1,
      anon_sym_TILDE,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3330), 1,
      anon_sym_DASH_GT,
    ACTIONS(3332), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3334), 1,
      anon_sym_PIPE,
    ACTIONS(3336), 1,
      anon_sym_AMP,
    ACTIONS(3338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    ACTIONS(3370), 1,
      sym__external_else,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(926), 1,
      sym__else,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(7), 3,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3328), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [89676] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3320), 1,
      anon_sym_EQ,
    ACTIONS(3322), 1,
      anon_sym_TILDE,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3330), 1,
      anon_sym_DASH_GT,
    ACTIONS(3332), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3334), 1,
      anon_sym_PIPE,
    ACTIONS(3336), 1,
      anon_sym_AMP,
    ACTIONS(3338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    ACTIONS(3372), 1,
      sym__external_else,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(610), 1,
      sym__else,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(107), 3,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3328), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [89784] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3320), 1,
      anon_sym_EQ,
    ACTIONS(3322), 1,
      anon_sym_TILDE,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3330), 1,
      anon_sym_DASH_GT,
    ACTIONS(3332), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3334), 1,
      anon_sym_PIPE,
    ACTIONS(3336), 1,
      anon_sym_AMP,
    ACTIONS(3338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    ACTIONS(3374), 1,
      sym__external_else,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(930), 1,
      sym__else,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(115), 3,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3328), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [89892] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3320), 1,
      anon_sym_EQ,
    ACTIONS(3322), 1,
      anon_sym_TILDE,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3330), 1,
      anon_sym_DASH_GT,
    ACTIONS(3332), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3334), 1,
      anon_sym_PIPE,
    ACTIONS(3336), 1,
      anon_sym_AMP,
    ACTIONS(3338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    ACTIONS(3376), 1,
      sym__external_else,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(931), 1,
      sym__else,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(107), 3,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3328), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [90000] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3320), 1,
      anon_sym_EQ,
    ACTIONS(3322), 1,
      anon_sym_TILDE,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3330), 1,
      anon_sym_DASH_GT,
    ACTIONS(3332), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3334), 1,
      anon_sym_PIPE,
    ACTIONS(3336), 1,
      anon_sym_AMP,
    ACTIONS(3338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    ACTIONS(3378), 1,
      sym__external_else,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(936), 1,
      sym__else,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(59), 3,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3328), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [90108] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3270), 1,
      anon_sym_EQ,
    ACTIONS(3272), 1,
      anon_sym_TILDE,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3280), 1,
      anon_sym_DASH_GT,
    ACTIONS(3282), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3284), 1,
      anon_sym_PIPE,
    ACTIONS(3286), 1,
      anon_sym_AMP,
    ACTIONS(3288), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3290), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    ACTIONS(3380), 1,
      sym__external_else,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(563), 1,
      sym__else,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(59), 3,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3278), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [90216] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3219), 1,
      anon_sym_EQ,
    ACTIONS(3221), 1,
      anon_sym_TILDE,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3229), 1,
      anon_sym_DASH_GT,
    ACTIONS(3231), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3233), 1,
      anon_sym_PIPE,
    ACTIONS(3235), 1,
      anon_sym_AMP,
    ACTIONS(3237), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    ACTIONS(3382), 1,
      sym__external_else,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(810), 1,
      sym__else,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(7), 3,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3227), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [90324] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3219), 1,
      anon_sym_EQ,
    ACTIONS(3221), 1,
      anon_sym_TILDE,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3229), 1,
      anon_sym_DASH_GT,
    ACTIONS(3231), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3233), 1,
      anon_sym_PIPE,
    ACTIONS(3235), 1,
      anon_sym_AMP,
    ACTIONS(3237), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    ACTIONS(3384), 1,
      sym__external_else,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(752), 1,
      sym__else,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(7), 3,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3227), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [90432] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3219), 1,
      anon_sym_EQ,
    ACTIONS(3221), 1,
      anon_sym_TILDE,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3229), 1,
      anon_sym_DASH_GT,
    ACTIONS(3231), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3233), 1,
      anon_sym_PIPE,
    ACTIONS(3235), 1,
      anon_sym_AMP,
    ACTIONS(3237), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    ACTIONS(3386), 1,
      sym__external_else,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(830), 1,
      sym__else,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(59), 3,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3227), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [90540] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3388), 1,
      sym__newline,
    STATE(1166), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(669), 12,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
    ACTIONS(671), 28,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_comma,
  [90594] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3219), 1,
      anon_sym_EQ,
    ACTIONS(3221), 1,
      anon_sym_TILDE,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3229), 1,
      anon_sym_DASH_GT,
    ACTIONS(3231), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3233), 1,
      anon_sym_PIPE,
    ACTIONS(3235), 1,
      anon_sym_AMP,
    ACTIONS(3237), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    ACTIONS(3391), 1,
      sym__external_else,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(815), 1,
      sym__else,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(107), 3,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3227), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [90702] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3219), 1,
      anon_sym_EQ,
    ACTIONS(3221), 1,
      anon_sym_TILDE,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3229), 1,
      anon_sym_DASH_GT,
    ACTIONS(3231), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3233), 1,
      anon_sym_PIPE,
    ACTIONS(3235), 1,
      anon_sym_AMP,
    ACTIONS(3237), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    ACTIONS(3393), 1,
      sym__external_else,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(756), 1,
      sym__else,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(115), 3,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3227), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [90810] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3219), 1,
      anon_sym_EQ,
    ACTIONS(3221), 1,
      anon_sym_TILDE,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3229), 1,
      anon_sym_DASH_GT,
    ACTIONS(3231), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3233), 1,
      anon_sym_PIPE,
    ACTIONS(3235), 1,
      anon_sym_AMP,
    ACTIONS(3237), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    ACTIONS(3395), 1,
      sym__external_else,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(757), 1,
      sym__else,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(107), 3,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3227), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [90918] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3270), 1,
      anon_sym_EQ,
    ACTIONS(3272), 1,
      anon_sym_TILDE,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3280), 1,
      anon_sym_DASH_GT,
    ACTIONS(3282), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3284), 1,
      anon_sym_PIPE,
    ACTIONS(3286), 1,
      anon_sym_AMP,
    ACTIONS(3288), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3290), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    ACTIONS(3397), 1,
      sym__external_else,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(557), 1,
      sym__else,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(115), 3,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3278), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [91026] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3320), 1,
      anon_sym_EQ,
    ACTIONS(3322), 1,
      anon_sym_TILDE,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3330), 1,
      anon_sym_DASH_GT,
    ACTIONS(3332), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3334), 1,
      anon_sym_PIPE,
    ACTIONS(3336), 1,
      anon_sym_AMP,
    ACTIONS(3338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    ACTIONS(3399), 1,
      sym__external_else,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(615), 1,
      sym__else,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(59), 3,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3328), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [91134] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3270), 1,
      anon_sym_EQ,
    ACTIONS(3272), 1,
      anon_sym_TILDE,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3280), 1,
      anon_sym_DASH_GT,
    ACTIONS(3282), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3284), 1,
      anon_sym_PIPE,
    ACTIONS(3286), 1,
      anon_sym_AMP,
    ACTIONS(3288), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3290), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    ACTIONS(3401), 1,
      sym__external_else,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(553), 1,
      sym__else,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(7), 3,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3278), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [91242] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3270), 1,
      anon_sym_EQ,
    ACTIONS(3272), 1,
      anon_sym_TILDE,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3280), 1,
      anon_sym_DASH_GT,
    ACTIONS(3282), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3284), 1,
      anon_sym_PIPE,
    ACTIONS(3286), 1,
      anon_sym_AMP,
    ACTIONS(3288), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3290), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    ACTIONS(3403), 1,
      sym__external_else,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(558), 1,
      sym__else,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(107), 3,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3278), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [91350] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3270), 1,
      anon_sym_EQ,
    ACTIONS(3272), 1,
      anon_sym_TILDE,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3280), 1,
      anon_sym_DASH_GT,
    ACTIONS(3282), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3284), 1,
      anon_sym_PIPE,
    ACTIONS(3286), 1,
      anon_sym_AMP,
    ACTIONS(3288), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3290), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3278), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(179), 4,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [91453] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(145), 6,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(143), 15,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      sym_comma,
  [91536] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3219), 1,
      anon_sym_EQ,
    ACTIONS(3221), 1,
      anon_sym_TILDE,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3229), 1,
      anon_sym_DASH_GT,
    ACTIONS(3231), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3233), 1,
      anon_sym_PIPE,
    ACTIONS(3235), 1,
      anon_sym_AMP,
    ACTIONS(3237), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3227), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(195), 4,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [91639] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(145), 8,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
    ACTIONS(143), 17,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      sym_comma,
  [91714] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3221), 1,
      anon_sym_TILDE,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3233), 1,
      anon_sym_PIPE,
    ACTIONS(3235), 1,
      anon_sym_AMP,
    ACTIONS(3237), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(181), 2,
      anon_sym_EQ,
      anon_sym_DASH_GT,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(179), 8,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      sym_comma,
  [91811] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(145), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(143), 19,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      sym_comma,
  [91882] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3219), 1,
      anon_sym_EQ,
    ACTIONS(3221), 1,
      anon_sym_TILDE,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3229), 1,
      anon_sym_DASH_GT,
    ACTIONS(3231), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3233), 1,
      anon_sym_PIPE,
    ACTIONS(3235), 1,
      anon_sym_AMP,
    ACTIONS(3237), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3227), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(199), 4,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [91985] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3219), 1,
      anon_sym_EQ,
    ACTIONS(3221), 1,
      anon_sym_TILDE,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3229), 1,
      anon_sym_DASH_GT,
    ACTIONS(3231), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3233), 1,
      anon_sym_PIPE,
    ACTIONS(3235), 1,
      anon_sym_AMP,
    ACTIONS(3237), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3227), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(167), 4,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [92088] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(145), 8,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
    ACTIONS(143), 19,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      sym_comma,
  [92161] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3270), 1,
      anon_sym_EQ,
    ACTIONS(3272), 1,
      anon_sym_TILDE,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3280), 1,
      anon_sym_DASH_GT,
    ACTIONS(3282), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3284), 1,
      anon_sym_PIPE,
    ACTIONS(3286), 1,
      anon_sym_AMP,
    ACTIONS(3288), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3290), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3278), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(163), 4,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [92264] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3270), 1,
      anon_sym_EQ,
    ACTIONS(3272), 1,
      anon_sym_TILDE,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3280), 1,
      anon_sym_DASH_GT,
    ACTIONS(3282), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3284), 1,
      anon_sym_PIPE,
    ACTIONS(3286), 1,
      anon_sym_AMP,
    ACTIONS(3288), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3290), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3278), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(167), 4,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [92367] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3284), 1,
      anon_sym_PIPE,
    ACTIONS(3286), 1,
      anon_sym_AMP,
    ACTIONS(3288), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3290), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(169), 2,
      anon_sym_EQ,
      anon_sym_DASH_GT,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(167), 9,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      sym_comma,
  [92462] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(169), 4,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(167), 11,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      sym_comma,
  [92549] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(169), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(167), 19,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      sym_comma,
  [92620] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3270), 1,
      anon_sym_EQ,
    ACTIONS(3272), 1,
      anon_sym_TILDE,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3280), 1,
      anon_sym_DASH_GT,
    ACTIONS(3282), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3284), 1,
      anon_sym_PIPE,
    ACTIONS(3286), 1,
      anon_sym_AMP,
    ACTIONS(3288), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3290), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(143), 7,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      sym_comma,
  [92721] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3233), 1,
      anon_sym_PIPE,
    ACTIONS(3235), 1,
      anon_sym_AMP,
    ACTIONS(3237), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(169), 2,
      anon_sym_EQ,
      anon_sym_DASH_GT,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(167), 9,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      sym_comma,
  [92816] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3270), 1,
      anon_sym_EQ,
    ACTIONS(3272), 1,
      anon_sym_TILDE,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3280), 1,
      anon_sym_DASH_GT,
    ACTIONS(3282), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3284), 1,
      anon_sym_PIPE,
    ACTIONS(3286), 1,
      anon_sym_AMP,
    ACTIONS(3288), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3290), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3278), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(143), 4,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [92919] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(169), 4,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(167), 11,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      sym_comma,
  [93006] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3284), 1,
      anon_sym_PIPE,
    ACTIONS(3286), 1,
      anon_sym_AMP,
    ACTIONS(3288), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3290), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(145), 2,
      anon_sym_EQ,
      anon_sym_DASH_GT,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(143), 9,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      sym_comma,
  [93101] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3235), 1,
      anon_sym_AMP,
    ACTIONS(3239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(181), 3,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(179), 10,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      sym_comma,
  [93192] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(145), 7,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(143), 16,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      sym_comma,
  [93271] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(169), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(167), 19,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      sym_comma,
  [93342] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3270), 1,
      anon_sym_EQ,
    ACTIONS(3272), 1,
      anon_sym_TILDE,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3280), 1,
      anon_sym_DASH_GT,
    ACTIONS(3282), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3284), 1,
      anon_sym_PIPE,
    ACTIONS(3286), 1,
      anon_sym_AMP,
    ACTIONS(3288), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3290), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3278), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(143), 4,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [93445] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3219), 1,
      anon_sym_EQ,
    ACTIONS(3221), 1,
      anon_sym_TILDE,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3229), 1,
      anon_sym_DASH_GT,
    ACTIONS(3231), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3233), 1,
      anon_sym_PIPE,
    ACTIONS(3235), 1,
      anon_sym_AMP,
    ACTIONS(3237), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(143), 7,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      sym_comma,
  [93546] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3272), 1,
      anon_sym_TILDE,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3284), 1,
      anon_sym_PIPE,
    ACTIONS(3286), 1,
      anon_sym_AMP,
    ACTIONS(3288), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3290), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(145), 2,
      anon_sym_EQ,
      anon_sym_DASH_GT,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(143), 8,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      sym_comma,
  [93643] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(145), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(143), 19,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      sym_comma,
  [93714] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3286), 1,
      anon_sym_AMP,
    ACTIONS(3290), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(145), 3,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(143), 10,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      sym_comma,
  [93805] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3219), 1,
      anon_sym_EQ,
    ACTIONS(3221), 1,
      anon_sym_TILDE,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3229), 1,
      anon_sym_DASH_GT,
    ACTIONS(3231), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3233), 1,
      anon_sym_PIPE,
    ACTIONS(3235), 1,
      anon_sym_AMP,
    ACTIONS(3237), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3227), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(143), 4,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [93908] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(145), 4,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(143), 11,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      sym_comma,
  [93995] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3320), 1,
      anon_sym_EQ,
    ACTIONS(3322), 1,
      anon_sym_TILDE,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3330), 1,
      anon_sym_DASH_GT,
    ACTIONS(3332), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3334), 1,
      anon_sym_PIPE,
    ACTIONS(3336), 1,
      anon_sym_AMP,
    ACTIONS(3338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3328), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(159), 4,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [94098] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(145), 6,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(143), 15,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      sym_comma,
  [94181] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3233), 1,
      anon_sym_PIPE,
    ACTIONS(3235), 1,
      anon_sym_AMP,
    ACTIONS(3237), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(145), 2,
      anon_sym_EQ,
      anon_sym_DASH_GT,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(143), 9,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      sym_comma,
  [94276] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(145), 8,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
    ACTIONS(143), 17,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      sym_comma,
  [94351] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(181), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(179), 19,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      sym_comma,
  [94422] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(145), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(143), 19,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      sym_comma,
  [94493] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(145), 7,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(143), 16,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      sym_comma,
  [94572] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(145), 8,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
    ACTIONS(143), 19,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      sym_comma,
  [94645] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3320), 1,
      anon_sym_EQ,
    ACTIONS(3322), 1,
      anon_sym_TILDE,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3330), 1,
      anon_sym_DASH_GT,
    ACTIONS(3332), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3334), 1,
      anon_sym_PIPE,
    ACTIONS(3336), 1,
      anon_sym_AMP,
    ACTIONS(3338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3328), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(171), 4,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [94748] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(145), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(143), 19,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      sym_comma,
  [94819] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3219), 1,
      anon_sym_EQ,
    ACTIONS(3221), 1,
      anon_sym_TILDE,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3229), 1,
      anon_sym_DASH_GT,
    ACTIONS(3231), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3233), 1,
      anon_sym_PIPE,
    ACTIONS(3235), 1,
      anon_sym_AMP,
    ACTIONS(3237), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3227), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(143), 4,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [94922] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3320), 1,
      anon_sym_EQ,
    ACTIONS(3322), 1,
      anon_sym_TILDE,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3330), 1,
      anon_sym_DASH_GT,
    ACTIONS(3332), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3334), 1,
      anon_sym_PIPE,
    ACTIONS(3336), 1,
      anon_sym_AMP,
    ACTIONS(3338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3328), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(175), 4,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [95025] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3270), 1,
      anon_sym_EQ,
    ACTIONS(3272), 1,
      anon_sym_TILDE,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3280), 1,
      anon_sym_DASH_GT,
    ACTIONS(3282), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3284), 1,
      anon_sym_PIPE,
    ACTIONS(3286), 1,
      anon_sym_AMP,
    ACTIONS(3288), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3290), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3278), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(171), 4,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [95128] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3270), 1,
      anon_sym_EQ,
    ACTIONS(3272), 1,
      anon_sym_TILDE,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3280), 1,
      anon_sym_DASH_GT,
    ACTIONS(3282), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3284), 1,
      anon_sym_PIPE,
    ACTIONS(3286), 1,
      anon_sym_AMP,
    ACTIONS(3288), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3290), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3278), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(175), 4,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [95231] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(181), 8,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
    ACTIONS(179), 19,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      sym_comma,
  [95304] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3221), 1,
      anon_sym_TILDE,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3233), 1,
      anon_sym_PIPE,
    ACTIONS(3235), 1,
      anon_sym_AMP,
    ACTIONS(3237), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(145), 2,
      anon_sym_EQ,
      anon_sym_DASH_GT,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(143), 8,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      sym_comma,
  [95401] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3270), 1,
      anon_sym_EQ,
    ACTIONS(3272), 1,
      anon_sym_TILDE,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3280), 1,
      anon_sym_DASH_GT,
    ACTIONS(3282), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3284), 1,
      anon_sym_PIPE,
    ACTIONS(3286), 1,
      anon_sym_AMP,
    ACTIONS(3288), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3290), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(179), 7,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      sym_comma,
  [95502] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3270), 1,
      anon_sym_EQ,
    ACTIONS(3272), 1,
      anon_sym_TILDE,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3280), 1,
      anon_sym_DASH_GT,
    ACTIONS(3282), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3284), 1,
      anon_sym_PIPE,
    ACTIONS(3286), 1,
      anon_sym_AMP,
    ACTIONS(3288), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3290), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3278), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(179), 4,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [95605] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3284), 1,
      anon_sym_PIPE,
    ACTIONS(3286), 1,
      anon_sym_AMP,
    ACTIONS(3288), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3290), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(181), 2,
      anon_sym_EQ,
      anon_sym_DASH_GT,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(179), 9,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      sym_comma,
  [95700] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(181), 7,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(179), 16,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      sym_comma,
  [95779] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(181), 7,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(179), 16,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      sym_comma,
  [95858] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3272), 1,
      anon_sym_TILDE,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3284), 1,
      anon_sym_PIPE,
    ACTIONS(3286), 1,
      anon_sym_AMP,
    ACTIONS(3288), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3290), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(181), 2,
      anon_sym_EQ,
      anon_sym_DASH_GT,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(179), 8,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      sym_comma,
  [95955] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3286), 1,
      anon_sym_AMP,
    ACTIONS(3290), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(181), 3,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(179), 10,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      sym_comma,
  [96046] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(181), 4,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(179), 11,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      sym_comma,
  [96133] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(181), 6,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(179), 15,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      sym_comma,
  [96216] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(181), 8,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
    ACTIONS(179), 17,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      sym_comma,
  [96291] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(181), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(179), 19,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      sym_comma,
  [96362] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(181), 8,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
    ACTIONS(179), 19,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      sym_comma,
  [96435] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(181), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(179), 19,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      sym_comma,
  [96506] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3270), 1,
      anon_sym_EQ,
    ACTIONS(3272), 1,
      anon_sym_TILDE,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3280), 1,
      anon_sym_DASH_GT,
    ACTIONS(3282), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3284), 1,
      anon_sym_PIPE,
    ACTIONS(3286), 1,
      anon_sym_AMP,
    ACTIONS(3288), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3290), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3278), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(183), 4,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [96609] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3270), 1,
      anon_sym_EQ,
    ACTIONS(3272), 1,
      anon_sym_TILDE,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3280), 1,
      anon_sym_DASH_GT,
    ACTIONS(3282), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3284), 1,
      anon_sym_PIPE,
    ACTIONS(3286), 1,
      anon_sym_AMP,
    ACTIONS(3288), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3290), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3278), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(187), 4,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [96712] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3219), 1,
      anon_sym_EQ,
    ACTIONS(3221), 1,
      anon_sym_TILDE,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3229), 1,
      anon_sym_DASH_GT,
    ACTIONS(3231), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3233), 1,
      anon_sym_PIPE,
    ACTIONS(3235), 1,
      anon_sym_AMP,
    ACTIONS(3237), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3227), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(203), 4,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [96815] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3235), 1,
      anon_sym_AMP,
    ACTIONS(3239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(145), 3,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(143), 10,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      sym_comma,
  [96906] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3320), 1,
      anon_sym_EQ,
    ACTIONS(3322), 1,
      anon_sym_TILDE,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3330), 1,
      anon_sym_DASH_GT,
    ACTIONS(3332), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3334), 1,
      anon_sym_PIPE,
    ACTIONS(3336), 1,
      anon_sym_AMP,
    ACTIONS(3338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(179), 7,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      sym_comma,
  [97007] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(145), 4,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(143), 11,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      sym_comma,
  [97094] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3270), 1,
      anon_sym_EQ,
    ACTIONS(3272), 1,
      anon_sym_TILDE,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3280), 1,
      anon_sym_DASH_GT,
    ACTIONS(3282), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3284), 1,
      anon_sym_PIPE,
    ACTIONS(3286), 1,
      anon_sym_AMP,
    ACTIONS(3288), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3290), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3278), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(191), 4,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [97197] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3270), 1,
      anon_sym_EQ,
    ACTIONS(3272), 1,
      anon_sym_TILDE,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3280), 1,
      anon_sym_DASH_GT,
    ACTIONS(3282), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3284), 1,
      anon_sym_PIPE,
    ACTIONS(3286), 1,
      anon_sym_AMP,
    ACTIONS(3288), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3290), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3278), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(195), 4,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [97300] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3219), 1,
      anon_sym_EQ,
    ACTIONS(3221), 1,
      anon_sym_TILDE,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3229), 1,
      anon_sym_DASH_GT,
    ACTIONS(3231), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3233), 1,
      anon_sym_PIPE,
    ACTIONS(3235), 1,
      anon_sym_AMP,
    ACTIONS(3237), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3227), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(151), 4,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [97403] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3270), 1,
      anon_sym_EQ,
    ACTIONS(3272), 1,
      anon_sym_TILDE,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3280), 1,
      anon_sym_DASH_GT,
    ACTIONS(3282), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3284), 1,
      anon_sym_PIPE,
    ACTIONS(3286), 1,
      anon_sym_AMP,
    ACTIONS(3288), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3290), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3278), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(199), 4,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [97506] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(145), 6,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(143), 15,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      sym_comma,
  [97589] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3320), 1,
      anon_sym_EQ,
    ACTIONS(3322), 1,
      anon_sym_TILDE,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3330), 1,
      anon_sym_DASH_GT,
    ACTIONS(3332), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3334), 1,
      anon_sym_PIPE,
    ACTIONS(3336), 1,
      anon_sym_AMP,
    ACTIONS(3338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3328), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(179), 4,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [97692] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(145), 8,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
    ACTIONS(143), 17,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      sym_comma,
  [97767] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3270), 1,
      anon_sym_EQ,
    ACTIONS(3272), 1,
      anon_sym_TILDE,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3280), 1,
      anon_sym_DASH_GT,
    ACTIONS(3282), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3284), 1,
      anon_sym_PIPE,
    ACTIONS(3286), 1,
      anon_sym_AMP,
    ACTIONS(3288), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3290), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3278), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(203), 4,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [97870] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3219), 1,
      anon_sym_EQ,
    ACTIONS(3221), 1,
      anon_sym_TILDE,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3229), 1,
      anon_sym_DASH_GT,
    ACTIONS(3231), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3233), 1,
      anon_sym_PIPE,
    ACTIONS(3235), 1,
      anon_sym_AMP,
    ACTIONS(3237), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3227), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(155), 4,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [97973] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(145), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(143), 19,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      sym_comma,
  [98044] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3270), 1,
      anon_sym_EQ,
    ACTIONS(3272), 1,
      anon_sym_TILDE,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3280), 1,
      anon_sym_DASH_GT,
    ACTIONS(3282), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3284), 1,
      anon_sym_PIPE,
    ACTIONS(3286), 1,
      anon_sym_AMP,
    ACTIONS(3288), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3290), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3278), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(207), 4,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [98147] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3270), 1,
      anon_sym_EQ,
    ACTIONS(3272), 1,
      anon_sym_TILDE,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3280), 1,
      anon_sym_DASH_GT,
    ACTIONS(3282), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3284), 1,
      anon_sym_PIPE,
    ACTIONS(3286), 1,
      anon_sym_AMP,
    ACTIONS(3288), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3290), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3278), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(211), 4,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [98250] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3270), 1,
      anon_sym_EQ,
    ACTIONS(3272), 1,
      anon_sym_TILDE,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3280), 1,
      anon_sym_DASH_GT,
    ACTIONS(3282), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3284), 1,
      anon_sym_PIPE,
    ACTIONS(3286), 1,
      anon_sym_AMP,
    ACTIONS(3288), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3290), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3278), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(215), 4,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [98353] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3334), 1,
      anon_sym_PIPE,
    ACTIONS(3336), 1,
      anon_sym_AMP,
    ACTIONS(3338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(181), 2,
      anon_sym_EQ,
      anon_sym_DASH_GT,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(179), 9,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      sym_comma,
  [98448] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3270), 1,
      anon_sym_EQ,
    ACTIONS(3272), 1,
      anon_sym_TILDE,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3280), 1,
      anon_sym_DASH_GT,
    ACTIONS(3282), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3284), 1,
      anon_sym_PIPE,
    ACTIONS(3286), 1,
      anon_sym_AMP,
    ACTIONS(3288), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3290), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3278), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(219), 4,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [98551] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(145), 8,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
    ACTIONS(143), 19,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      sym_comma,
  [98624] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3233), 1,
      anon_sym_PIPE,
    ACTIONS(3235), 1,
      anon_sym_AMP,
    ACTIONS(3237), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(157), 2,
      anon_sym_EQ,
      anon_sym_DASH_GT,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(155), 9,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      sym_comma,
  [98719] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3270), 1,
      anon_sym_EQ,
    ACTIONS(3272), 1,
      anon_sym_TILDE,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3280), 1,
      anon_sym_DASH_GT,
    ACTIONS(3282), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3284), 1,
      anon_sym_PIPE,
    ACTIONS(3286), 1,
      anon_sym_AMP,
    ACTIONS(3288), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3290), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3278), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(223), 4,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [98822] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3270), 1,
      anon_sym_EQ,
    ACTIONS(3272), 1,
      anon_sym_TILDE,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3280), 1,
      anon_sym_DASH_GT,
    ACTIONS(3282), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3284), 1,
      anon_sym_PIPE,
    ACTIONS(3286), 1,
      anon_sym_AMP,
    ACTIONS(3288), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3290), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3278), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(227), 4,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [98925] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(145), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(143), 19,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      sym_comma,
  [98996] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3270), 1,
      anon_sym_EQ,
    ACTIONS(3272), 1,
      anon_sym_TILDE,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3280), 1,
      anon_sym_DASH_GT,
    ACTIONS(3282), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3284), 1,
      anon_sym_PIPE,
    ACTIONS(3286), 1,
      anon_sym_AMP,
    ACTIONS(3288), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3290), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3278), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(231), 4,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [99099] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3270), 1,
      anon_sym_EQ,
    ACTIONS(3272), 1,
      anon_sym_TILDE,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3280), 1,
      anon_sym_DASH_GT,
    ACTIONS(3282), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3284), 1,
      anon_sym_PIPE,
    ACTIONS(3286), 1,
      anon_sym_AMP,
    ACTIONS(3288), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3290), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3278), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(235), 4,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [99202] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3270), 1,
      anon_sym_EQ,
    ACTIONS(3272), 1,
      anon_sym_TILDE,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3280), 1,
      anon_sym_DASH_GT,
    ACTIONS(3282), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3284), 1,
      anon_sym_PIPE,
    ACTIONS(3286), 1,
      anon_sym_AMP,
    ACTIONS(3288), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3290), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3278), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(239), 4,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [99305] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(181), 7,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(179), 16,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      sym_comma,
  [99384] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3219), 1,
      anon_sym_EQ,
    ACTIONS(3221), 1,
      anon_sym_TILDE,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3229), 1,
      anon_sym_DASH_GT,
    ACTIONS(3231), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3233), 1,
      anon_sym_PIPE,
    ACTIONS(3235), 1,
      anon_sym_AMP,
    ACTIONS(3237), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3227), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(179), 4,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [99487] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3270), 1,
      anon_sym_EQ,
    ACTIONS(3272), 1,
      anon_sym_TILDE,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3280), 1,
      anon_sym_DASH_GT,
    ACTIONS(3282), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3284), 1,
      anon_sym_PIPE,
    ACTIONS(3286), 1,
      anon_sym_AMP,
    ACTIONS(3288), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3290), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3278), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(149), 4,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [99590] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3320), 1,
      anon_sym_EQ,
    ACTIONS(3322), 1,
      anon_sym_TILDE,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3330), 1,
      anon_sym_DASH_GT,
    ACTIONS(3332), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3334), 1,
      anon_sym_PIPE,
    ACTIONS(3336), 1,
      anon_sym_AMP,
    ACTIONS(3338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3328), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(179), 4,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [99693] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3320), 1,
      anon_sym_EQ,
    ACTIONS(3322), 1,
      anon_sym_TILDE,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3330), 1,
      anon_sym_DASH_GT,
    ACTIONS(3332), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3334), 1,
      anon_sym_PIPE,
    ACTIONS(3336), 1,
      anon_sym_AMP,
    ACTIONS(3338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3328), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(151), 4,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [99796] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3219), 1,
      anon_sym_EQ,
    ACTIONS(3221), 1,
      anon_sym_TILDE,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3229), 1,
      anon_sym_DASH_GT,
    ACTIONS(3231), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3233), 1,
      anon_sym_PIPE,
    ACTIONS(3235), 1,
      anon_sym_AMP,
    ACTIONS(3237), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3227), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(171), 4,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [99899] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3320), 1,
      anon_sym_EQ,
    ACTIONS(3322), 1,
      anon_sym_TILDE,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3330), 1,
      anon_sym_DASH_GT,
    ACTIONS(3332), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3334), 1,
      anon_sym_PIPE,
    ACTIONS(3336), 1,
      anon_sym_AMP,
    ACTIONS(3338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3328), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(155), 4,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [100002] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3219), 1,
      anon_sym_EQ,
    ACTIONS(3221), 1,
      anon_sym_TILDE,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3229), 1,
      anon_sym_DASH_GT,
    ACTIONS(3231), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3233), 1,
      anon_sym_PIPE,
    ACTIONS(3235), 1,
      anon_sym_AMP,
    ACTIONS(3237), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3227), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(175), 4,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [100105] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3334), 1,
      anon_sym_PIPE,
    ACTIONS(3336), 1,
      anon_sym_AMP,
    ACTIONS(3338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(157), 2,
      anon_sym_EQ,
      anon_sym_DASH_GT,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(155), 9,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      sym_comma,
  [100200] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(157), 4,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(155), 11,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      sym_comma,
  [100287] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(157), 4,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(155), 11,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      sym_comma,
  [100374] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3322), 1,
      anon_sym_TILDE,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3334), 1,
      anon_sym_PIPE,
    ACTIONS(3336), 1,
      anon_sym_AMP,
    ACTIONS(3338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(181), 2,
      anon_sym_EQ,
      anon_sym_DASH_GT,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(179), 8,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      sym_comma,
  [100471] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(157), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(155), 19,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      sym_comma,
  [100542] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3219), 1,
      anon_sym_EQ,
    ACTIONS(3221), 1,
      anon_sym_TILDE,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3229), 1,
      anon_sym_DASH_GT,
    ACTIONS(3231), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3233), 1,
      anon_sym_PIPE,
    ACTIONS(3235), 1,
      anon_sym_AMP,
    ACTIONS(3237), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(179), 7,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      sym_comma,
  [100643] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3336), 1,
      anon_sym_AMP,
    ACTIONS(3340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(181), 3,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(179), 10,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      sym_comma,
  [100734] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(181), 4,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(179), 11,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      sym_comma,
  [100821] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(181), 6,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(179), 15,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      sym_comma,
  [100904] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(181), 8,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
    ACTIONS(179), 17,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      sym_comma,
  [100979] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(181), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(179), 19,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      sym_comma,
  [101050] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3219), 1,
      anon_sym_EQ,
    ACTIONS(3221), 1,
      anon_sym_TILDE,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3229), 1,
      anon_sym_DASH_GT,
    ACTIONS(3231), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3233), 1,
      anon_sym_PIPE,
    ACTIONS(3235), 1,
      anon_sym_AMP,
    ACTIONS(3237), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3227), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(179), 4,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [101153] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(181), 8,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
    ACTIONS(179), 19,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      sym_comma,
  [101226] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(181), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(179), 19,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      sym_comma,
  [101297] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3233), 1,
      anon_sym_PIPE,
    ACTIONS(3235), 1,
      anon_sym_AMP,
    ACTIONS(3237), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(181), 2,
      anon_sym_EQ,
      anon_sym_DASH_GT,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(179), 9,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      sym_comma,
  [101392] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3320), 1,
      anon_sym_EQ,
    ACTIONS(3322), 1,
      anon_sym_TILDE,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3330), 1,
      anon_sym_DASH_GT,
    ACTIONS(3332), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3334), 1,
      anon_sym_PIPE,
    ACTIONS(3336), 1,
      anon_sym_AMP,
    ACTIONS(3338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3328), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(183), 4,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [101495] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3320), 1,
      anon_sym_EQ,
    ACTIONS(3322), 1,
      anon_sym_TILDE,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3330), 1,
      anon_sym_DASH_GT,
    ACTIONS(3332), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3334), 1,
      anon_sym_PIPE,
    ACTIONS(3336), 1,
      anon_sym_AMP,
    ACTIONS(3338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3328), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(187), 4,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [101598] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3320), 1,
      anon_sym_EQ,
    ACTIONS(3322), 1,
      anon_sym_TILDE,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3330), 1,
      anon_sym_DASH_GT,
    ACTIONS(3332), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3334), 1,
      anon_sym_PIPE,
    ACTIONS(3336), 1,
      anon_sym_AMP,
    ACTIONS(3338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3328), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(163), 4,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [101701] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3320), 1,
      anon_sym_EQ,
    ACTIONS(3322), 1,
      anon_sym_TILDE,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3330), 1,
      anon_sym_DASH_GT,
    ACTIONS(3332), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3334), 1,
      anon_sym_PIPE,
    ACTIONS(3336), 1,
      anon_sym_AMP,
    ACTIONS(3338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3328), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(167), 4,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [101804] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3219), 1,
      anon_sym_EQ,
    ACTIONS(3221), 1,
      anon_sym_TILDE,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3229), 1,
      anon_sym_DASH_GT,
    ACTIONS(3231), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3233), 1,
      anon_sym_PIPE,
    ACTIONS(3235), 1,
      anon_sym_AMP,
    ACTIONS(3237), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3227), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(207), 4,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [101907] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3219), 1,
      anon_sym_EQ,
    ACTIONS(3221), 1,
      anon_sym_TILDE,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3229), 1,
      anon_sym_DASH_GT,
    ACTIONS(3231), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3233), 1,
      anon_sym_PIPE,
    ACTIONS(3235), 1,
      anon_sym_AMP,
    ACTIONS(3237), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3227), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(211), 4,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [102010] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3320), 1,
      anon_sym_EQ,
    ACTIONS(3322), 1,
      anon_sym_TILDE,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3330), 1,
      anon_sym_DASH_GT,
    ACTIONS(3332), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3334), 1,
      anon_sym_PIPE,
    ACTIONS(3336), 1,
      anon_sym_AMP,
    ACTIONS(3338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3328), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(191), 4,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [102113] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3320), 1,
      anon_sym_EQ,
    ACTIONS(3322), 1,
      anon_sym_TILDE,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3330), 1,
      anon_sym_DASH_GT,
    ACTIONS(3332), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3334), 1,
      anon_sym_PIPE,
    ACTIONS(3336), 1,
      anon_sym_AMP,
    ACTIONS(3338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3328), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(195), 4,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [102216] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3219), 1,
      anon_sym_EQ,
    ACTIONS(3221), 1,
      anon_sym_TILDE,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3229), 1,
      anon_sym_DASH_GT,
    ACTIONS(3231), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3233), 1,
      anon_sym_PIPE,
    ACTIONS(3235), 1,
      anon_sym_AMP,
    ACTIONS(3237), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3227), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(215), 4,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [102319] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3320), 1,
      anon_sym_EQ,
    ACTIONS(3322), 1,
      anon_sym_TILDE,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3330), 1,
      anon_sym_DASH_GT,
    ACTIONS(3332), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3334), 1,
      anon_sym_PIPE,
    ACTIONS(3336), 1,
      anon_sym_AMP,
    ACTIONS(3338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3328), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(199), 4,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [102422] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3334), 1,
      anon_sym_PIPE,
    ACTIONS(3336), 1,
      anon_sym_AMP,
    ACTIONS(3338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(169), 2,
      anon_sym_EQ,
      anon_sym_DASH_GT,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(167), 9,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      sym_comma,
  [102517] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3270), 1,
      anon_sym_EQ,
    ACTIONS(3272), 1,
      anon_sym_TILDE,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3280), 1,
      anon_sym_DASH_GT,
    ACTIONS(3282), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3284), 1,
      anon_sym_PIPE,
    ACTIONS(3286), 1,
      anon_sym_AMP,
    ACTIONS(3288), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3290), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3278), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(151), 4,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [102620] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3219), 1,
      anon_sym_EQ,
    ACTIONS(3221), 1,
      anon_sym_TILDE,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3229), 1,
      anon_sym_DASH_GT,
    ACTIONS(3231), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3233), 1,
      anon_sym_PIPE,
    ACTIONS(3235), 1,
      anon_sym_AMP,
    ACTIONS(3237), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3227), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(219), 4,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [102723] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3320), 1,
      anon_sym_EQ,
    ACTIONS(3322), 1,
      anon_sym_TILDE,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3330), 1,
      anon_sym_DASH_GT,
    ACTIONS(3332), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3334), 1,
      anon_sym_PIPE,
    ACTIONS(3336), 1,
      anon_sym_AMP,
    ACTIONS(3338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3328), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(203), 4,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [102826] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3270), 1,
      anon_sym_EQ,
    ACTIONS(3272), 1,
      anon_sym_TILDE,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3280), 1,
      anon_sym_DASH_GT,
    ACTIONS(3282), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3284), 1,
      anon_sym_PIPE,
    ACTIONS(3286), 1,
      anon_sym_AMP,
    ACTIONS(3288), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3290), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3278), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(155), 4,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [102929] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(169), 4,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(167), 11,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      sym_comma,
  [103016] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3320), 1,
      anon_sym_EQ,
    ACTIONS(3322), 1,
      anon_sym_TILDE,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3330), 1,
      anon_sym_DASH_GT,
    ACTIONS(3332), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3334), 1,
      anon_sym_PIPE,
    ACTIONS(3336), 1,
      anon_sym_AMP,
    ACTIONS(3338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3328), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(207), 4,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [103119] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3320), 1,
      anon_sym_EQ,
    ACTIONS(3322), 1,
      anon_sym_TILDE,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3330), 1,
      anon_sym_DASH_GT,
    ACTIONS(3332), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3334), 1,
      anon_sym_PIPE,
    ACTIONS(3336), 1,
      anon_sym_AMP,
    ACTIONS(3338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3328), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(211), 4,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [103222] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3320), 1,
      anon_sym_EQ,
    ACTIONS(3322), 1,
      anon_sym_TILDE,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3330), 1,
      anon_sym_DASH_GT,
    ACTIONS(3332), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3334), 1,
      anon_sym_PIPE,
    ACTIONS(3336), 1,
      anon_sym_AMP,
    ACTIONS(3338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3328), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(215), 4,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [103325] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3284), 1,
      anon_sym_PIPE,
    ACTIONS(3286), 1,
      anon_sym_AMP,
    ACTIONS(3288), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3290), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(157), 2,
      anon_sym_EQ,
      anon_sym_DASH_GT,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(155), 9,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      sym_comma,
  [103420] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3320), 1,
      anon_sym_EQ,
    ACTIONS(3322), 1,
      anon_sym_TILDE,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3330), 1,
      anon_sym_DASH_GT,
    ACTIONS(3332), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3334), 1,
      anon_sym_PIPE,
    ACTIONS(3336), 1,
      anon_sym_AMP,
    ACTIONS(3338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3328), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(219), 4,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [103523] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(169), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(167), 19,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      sym_comma,
  [103594] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(157), 4,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(155), 11,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      sym_comma,
  [103681] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3320), 1,
      anon_sym_EQ,
    ACTIONS(3322), 1,
      anon_sym_TILDE,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3330), 1,
      anon_sym_DASH_GT,
    ACTIONS(3332), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3334), 1,
      anon_sym_PIPE,
    ACTIONS(3336), 1,
      anon_sym_AMP,
    ACTIONS(3338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3328), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(223), 4,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [103784] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3320), 1,
      anon_sym_EQ,
    ACTIONS(3322), 1,
      anon_sym_TILDE,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3330), 1,
      anon_sym_DASH_GT,
    ACTIONS(3332), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3334), 1,
      anon_sym_PIPE,
    ACTIONS(3336), 1,
      anon_sym_AMP,
    ACTIONS(3338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3328), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(227), 4,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [103887] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3219), 1,
      anon_sym_EQ,
    ACTIONS(3221), 1,
      anon_sym_TILDE,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3229), 1,
      anon_sym_DASH_GT,
    ACTIONS(3231), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3233), 1,
      anon_sym_PIPE,
    ACTIONS(3235), 1,
      anon_sym_AMP,
    ACTIONS(3237), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3227), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(223), 4,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [103990] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3320), 1,
      anon_sym_EQ,
    ACTIONS(3322), 1,
      anon_sym_TILDE,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3330), 1,
      anon_sym_DASH_GT,
    ACTIONS(3332), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3334), 1,
      anon_sym_PIPE,
    ACTIONS(3336), 1,
      anon_sym_AMP,
    ACTIONS(3338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3328), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(231), 4,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [104093] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3320), 1,
      anon_sym_EQ,
    ACTIONS(3322), 1,
      anon_sym_TILDE,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3330), 1,
      anon_sym_DASH_GT,
    ACTIONS(3332), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3334), 1,
      anon_sym_PIPE,
    ACTIONS(3336), 1,
      anon_sym_AMP,
    ACTIONS(3338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3328), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(235), 4,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [104196] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3320), 1,
      anon_sym_EQ,
    ACTIONS(3322), 1,
      anon_sym_TILDE,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3330), 1,
      anon_sym_DASH_GT,
    ACTIONS(3332), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3334), 1,
      anon_sym_PIPE,
    ACTIONS(3336), 1,
      anon_sym_AMP,
    ACTIONS(3338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3328), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(239), 4,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [104299] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(157), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(155), 19,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      sym_comma,
  [104370] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3320), 1,
      anon_sym_EQ,
    ACTIONS(3322), 1,
      anon_sym_TILDE,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3330), 1,
      anon_sym_DASH_GT,
    ACTIONS(3332), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3334), 1,
      anon_sym_PIPE,
    ACTIONS(3336), 1,
      anon_sym_AMP,
    ACTIONS(3338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3328), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(243), 4,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [104473] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3320), 1,
      anon_sym_EQ,
    ACTIONS(3322), 1,
      anon_sym_TILDE,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3330), 1,
      anon_sym_DASH_GT,
    ACTIONS(3332), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3334), 1,
      anon_sym_PIPE,
    ACTIONS(3336), 1,
      anon_sym_AMP,
    ACTIONS(3338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3328), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(149), 4,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [104576] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3320), 1,
      anon_sym_EQ,
    ACTIONS(3322), 1,
      anon_sym_TILDE,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3330), 1,
      anon_sym_DASH_GT,
    ACTIONS(3332), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3334), 1,
      anon_sym_PIPE,
    ACTIONS(3336), 1,
      anon_sym_AMP,
    ACTIONS(3338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(143), 7,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      sym_comma,
  [104677] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(181), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(179), 19,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      sym_comma,
  [104748] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3219), 1,
      anon_sym_EQ,
    ACTIONS(3221), 1,
      anon_sym_TILDE,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3229), 1,
      anon_sym_DASH_GT,
    ACTIONS(3231), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3233), 1,
      anon_sym_PIPE,
    ACTIONS(3235), 1,
      anon_sym_AMP,
    ACTIONS(3237), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3227), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(227), 4,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [104851] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3320), 1,
      anon_sym_EQ,
    ACTIONS(3322), 1,
      anon_sym_TILDE,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3330), 1,
      anon_sym_DASH_GT,
    ACTIONS(3332), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3334), 1,
      anon_sym_PIPE,
    ACTIONS(3336), 1,
      anon_sym_AMP,
    ACTIONS(3338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3328), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(143), 4,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [104954] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3219), 1,
      anon_sym_EQ,
    ACTIONS(3221), 1,
      anon_sym_TILDE,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3229), 1,
      anon_sym_DASH_GT,
    ACTIONS(3231), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3233), 1,
      anon_sym_PIPE,
    ACTIONS(3235), 1,
      anon_sym_AMP,
    ACTIONS(3237), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3227), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(183), 4,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [105057] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3219), 1,
      anon_sym_EQ,
    ACTIONS(3221), 1,
      anon_sym_TILDE,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3229), 1,
      anon_sym_DASH_GT,
    ACTIONS(3231), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3233), 1,
      anon_sym_PIPE,
    ACTIONS(3235), 1,
      anon_sym_AMP,
    ACTIONS(3237), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3227), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(231), 4,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [105160] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3219), 1,
      anon_sym_EQ,
    ACTIONS(3221), 1,
      anon_sym_TILDE,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3229), 1,
      anon_sym_DASH_GT,
    ACTIONS(3231), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3233), 1,
      anon_sym_PIPE,
    ACTIONS(3235), 1,
      anon_sym_AMP,
    ACTIONS(3237), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3227), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(235), 4,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [105263] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3219), 1,
      anon_sym_EQ,
    ACTIONS(3221), 1,
      anon_sym_TILDE,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3229), 1,
      anon_sym_DASH_GT,
    ACTIONS(3231), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3233), 1,
      anon_sym_PIPE,
    ACTIONS(3235), 1,
      anon_sym_AMP,
    ACTIONS(3237), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3227), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(239), 4,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [105366] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3334), 1,
      anon_sym_PIPE,
    ACTIONS(3336), 1,
      anon_sym_AMP,
    ACTIONS(3338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(145), 2,
      anon_sym_EQ,
      anon_sym_DASH_GT,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(143), 9,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      sym_comma,
  [105461] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3219), 1,
      anon_sym_EQ,
    ACTIONS(3221), 1,
      anon_sym_TILDE,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3229), 1,
      anon_sym_DASH_GT,
    ACTIONS(3231), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3233), 1,
      anon_sym_PIPE,
    ACTIONS(3235), 1,
      anon_sym_AMP,
    ACTIONS(3237), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3227), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(243), 4,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [105564] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3219), 1,
      anon_sym_EQ,
    ACTIONS(3221), 1,
      anon_sym_TILDE,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3229), 1,
      anon_sym_DASH_GT,
    ACTIONS(3231), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3233), 1,
      anon_sym_PIPE,
    ACTIONS(3235), 1,
      anon_sym_AMP,
    ACTIONS(3237), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3227), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(149), 4,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [105667] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3219), 1,
      anon_sym_EQ,
    ACTIONS(3221), 1,
      anon_sym_TILDE,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3229), 1,
      anon_sym_DASH_GT,
    ACTIONS(3231), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3233), 1,
      anon_sym_PIPE,
    ACTIONS(3235), 1,
      anon_sym_AMP,
    ACTIONS(3237), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3227), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(187), 4,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [105770] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3219), 1,
      anon_sym_EQ,
    ACTIONS(3221), 1,
      anon_sym_TILDE,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3229), 1,
      anon_sym_DASH_GT,
    ACTIONS(3231), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3233), 1,
      anon_sym_PIPE,
    ACTIONS(3235), 1,
      anon_sym_AMP,
    ACTIONS(3237), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3227), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(159), 4,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [105873] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(145), 7,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(143), 16,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      sym_comma,
  [105952] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(157), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(155), 19,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      sym_comma,
  [106023] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3320), 1,
      anon_sym_EQ,
    ACTIONS(3322), 1,
      anon_sym_TILDE,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3330), 1,
      anon_sym_DASH_GT,
    ACTIONS(3332), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3334), 1,
      anon_sym_PIPE,
    ACTIONS(3336), 1,
      anon_sym_AMP,
    ACTIONS(3338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3328), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(143), 4,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [106126] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(181), 4,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(179), 11,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      sym_comma,
  [106213] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3322), 1,
      anon_sym_TILDE,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3334), 1,
      anon_sym_PIPE,
    ACTIONS(3336), 1,
      anon_sym_AMP,
    ACTIONS(3338), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(145), 2,
      anon_sym_EQ,
      anon_sym_DASH_GT,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(143), 8,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      sym_comma,
  [106310] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(181), 6,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(179), 15,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      sym_comma,
  [106393] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3336), 1,
      anon_sym_AMP,
    ACTIONS(3340), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(145), 3,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(143), 10,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      sym_comma,
  [106484] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(181), 8,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
    ACTIONS(179), 17,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      sym_comma,
  [106559] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3270), 1,
      anon_sym_EQ,
    ACTIONS(3272), 1,
      anon_sym_TILDE,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3280), 1,
      anon_sym_DASH_GT,
    ACTIONS(3282), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3284), 1,
      anon_sym_PIPE,
    ACTIONS(3286), 1,
      anon_sym_AMP,
    ACTIONS(3288), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3290), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3278), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(159), 4,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [106662] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3219), 1,
      anon_sym_EQ,
    ACTIONS(3221), 1,
      anon_sym_TILDE,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3229), 1,
      anon_sym_DASH_GT,
    ACTIONS(3231), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3233), 1,
      anon_sym_PIPE,
    ACTIONS(3235), 1,
      anon_sym_AMP,
    ACTIONS(3237), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3227), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(163), 4,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [106765] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3324), 1,
      anon_sym_PLUS,
    ACTIONS(3326), 1,
      anon_sym_DASH,
    ACTIONS(3346), 1,
      anon_sym_STAR,
    ACTIONS(3348), 1,
      anon_sym_SLASH,
    ACTIONS(3354), 1,
      anon_sym_COLON,
    ACTIONS(3360), 1,
      sym__external_open_parenthesis,
    ACTIONS(3362), 1,
      sym__external_open_bracket,
    ACTIONS(3364), 1,
      sym__external_open_bracket2,
    STATE(255), 1,
      sym__open_bracket2,
    STATE(262), 1,
      sym__open_bracket,
    STATE(282), 1,
      sym__open_parenthesis,
    STATE(1679), 1,
      sym_call_arguments,
    STATE(1680), 1,
      sym_subset_arguments,
    STATE(1681), 1,
      sym_subset2_arguments,
    ACTIONS(3342), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3350), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3352), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3356), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(145), 4,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(3344), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(143), 11,
      sym__external_else,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      sym_comma,
  [106852] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3219), 1,
      anon_sym_EQ,
    ACTIONS(3221), 1,
      anon_sym_TILDE,
    ACTIONS(3223), 1,
      anon_sym_PLUS,
    ACTIONS(3225), 1,
      anon_sym_DASH,
    ACTIONS(3229), 1,
      anon_sym_DASH_GT,
    ACTIONS(3231), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3233), 1,
      anon_sym_PIPE,
    ACTIONS(3235), 1,
      anon_sym_AMP,
    ACTIONS(3237), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3239), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3245), 1,
      anon_sym_STAR,
    ACTIONS(3247), 1,
      anon_sym_SLASH,
    ACTIONS(3253), 1,
      anon_sym_COLON,
    ACTIONS(3259), 1,
      sym__external_open_parenthesis,
    ACTIONS(3261), 1,
      sym__external_open_bracket,
    ACTIONS(3263), 1,
      sym__external_open_bracket2,
    STATE(248), 1,
      sym__open_bracket,
    STATE(274), 1,
      sym__open_parenthesis,
    STATE(275), 1,
      sym__open_bracket2,
    STATE(1693), 1,
      sym_subset_arguments,
    STATE(1694), 1,
      sym_subset2_arguments,
    STATE(1726), 1,
      sym_call_arguments,
    ACTIONS(3241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3249), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3251), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3255), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3227), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(191), 4,
      sym__external_else,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3243), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [106955] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3270), 1,
      anon_sym_EQ,
    ACTIONS(3272), 1,
      anon_sym_TILDE,
    ACTIONS(3274), 1,
      anon_sym_PLUS,
    ACTIONS(3276), 1,
      anon_sym_DASH,
    ACTIONS(3280), 1,
      anon_sym_DASH_GT,
    ACTIONS(3282), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3284), 1,
      anon_sym_PIPE,
    ACTIONS(3286), 1,
      anon_sym_AMP,
    ACTIONS(3288), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3290), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3296), 1,
      anon_sym_STAR,
    ACTIONS(3298), 1,
      anon_sym_SLASH,
    ACTIONS(3304), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      sym__external_open_parenthesis,
    ACTIONS(3312), 1,
      sym__external_open_bracket,
    ACTIONS(3314), 1,
      sym__external_open_bracket2,
    STATE(279), 1,
      sym__open_parenthesis,
    STATE(280), 1,
      sym__open_bracket,
    STATE(281), 1,
      sym__open_bracket2,
    STATE(1663), 1,
      sym_subset2_arguments,
    STATE(1709), 1,
      sym_call_arguments,
    STATE(1720), 1,
      sym_subset_arguments,
    ACTIONS(3292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3300), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3302), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3306), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3278), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(243), 4,
      sym__external_else,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3294), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [107058] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(145), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(143), 18,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      sym_comma,
  [107128] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(235), 3,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [107230] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(239), 3,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [107332] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3459), 1,
      anon_sym_EQ,
    ACTIONS(3461), 1,
      anon_sym_TILDE,
    ACTIONS(3463), 1,
      anon_sym_PLUS,
    ACTIONS(3465), 1,
      anon_sym_DASH,
    ACTIONS(3469), 1,
      anon_sym_DASH_GT,
    ACTIONS(3471), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3473), 1,
      anon_sym_PIPE,
    ACTIONS(3475), 1,
      anon_sym_AMP,
    ACTIONS(3477), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3479), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3485), 1,
      anon_sym_STAR,
    ACTIONS(3487), 1,
      anon_sym_SLASH,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3481), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3489), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(171), 3,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3467), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3483), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [107434] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(243), 3,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [107536] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(149), 3,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [107638] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3459), 1,
      anon_sym_EQ,
    ACTIONS(3461), 1,
      anon_sym_TILDE,
    ACTIONS(3463), 1,
      anon_sym_PLUS,
    ACTIONS(3465), 1,
      anon_sym_DASH,
    ACTIONS(3469), 1,
      anon_sym_DASH_GT,
    ACTIONS(3471), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3473), 1,
      anon_sym_PIPE,
    ACTIONS(3475), 1,
      anon_sym_AMP,
    ACTIONS(3477), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3479), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3485), 1,
      anon_sym_STAR,
    ACTIONS(3487), 1,
      anon_sym_SLASH,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3481), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3489), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(175), 3,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3467), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3483), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [107740] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3459), 1,
      anon_sym_EQ,
    ACTIONS(3461), 1,
      anon_sym_TILDE,
    ACTIONS(3463), 1,
      anon_sym_PLUS,
    ACTIONS(3465), 1,
      anon_sym_DASH,
    ACTIONS(3469), 1,
      anon_sym_DASH_GT,
    ACTIONS(3471), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3473), 1,
      anon_sym_PIPE,
    ACTIONS(3475), 1,
      anon_sym_AMP,
    ACTIONS(3477), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3479), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3485), 1,
      anon_sym_STAR,
    ACTIONS(3487), 1,
      anon_sym_SLASH,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3481), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3489), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3483), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(179), 6,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      sym_comma,
  [107840] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3459), 1,
      anon_sym_EQ,
    ACTIONS(3461), 1,
      anon_sym_TILDE,
    ACTIONS(3463), 1,
      anon_sym_PLUS,
    ACTIONS(3465), 1,
      anon_sym_DASH,
    ACTIONS(3469), 1,
      anon_sym_DASH_GT,
    ACTIONS(3471), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3473), 1,
      anon_sym_PIPE,
    ACTIONS(3475), 1,
      anon_sym_AMP,
    ACTIONS(3477), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3479), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3485), 1,
      anon_sym_STAR,
    ACTIONS(3487), 1,
      anon_sym_SLASH,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3481), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3489), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(179), 3,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3467), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3483), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [107942] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3463), 1,
      anon_sym_PLUS,
    ACTIONS(3465), 1,
      anon_sym_DASH,
    ACTIONS(3473), 1,
      anon_sym_PIPE,
    ACTIONS(3475), 1,
      anon_sym_AMP,
    ACTIONS(3477), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3479), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3485), 1,
      anon_sym_STAR,
    ACTIONS(3487), 1,
      anon_sym_SLASH,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(181), 2,
      anon_sym_EQ,
      anon_sym_DASH_GT,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3481), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3489), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3483), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(179), 8,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      sym_comma,
  [108036] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3485), 1,
      anon_sym_STAR,
    ACTIONS(3487), 1,
      anon_sym_SLASH,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3489), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(181), 7,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(179), 15,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      sym_comma,
  [108114] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3459), 1,
      anon_sym_EQ,
    ACTIONS(3461), 1,
      anon_sym_TILDE,
    ACTIONS(3463), 1,
      anon_sym_PLUS,
    ACTIONS(3465), 1,
      anon_sym_DASH,
    ACTIONS(3469), 1,
      anon_sym_DASH_GT,
    ACTIONS(3471), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3473), 1,
      anon_sym_PIPE,
    ACTIONS(3475), 1,
      anon_sym_AMP,
    ACTIONS(3477), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3479), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3485), 1,
      anon_sym_STAR,
    ACTIONS(3487), 1,
      anon_sym_SLASH,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3481), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3489), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(179), 3,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3467), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3483), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [108216] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(151), 3,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [108318] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3461), 1,
      anon_sym_TILDE,
    ACTIONS(3463), 1,
      anon_sym_PLUS,
    ACTIONS(3465), 1,
      anon_sym_DASH,
    ACTIONS(3473), 1,
      anon_sym_PIPE,
    ACTIONS(3475), 1,
      anon_sym_AMP,
    ACTIONS(3477), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3479), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3485), 1,
      anon_sym_STAR,
    ACTIONS(3487), 1,
      anon_sym_SLASH,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(181), 2,
      anon_sym_EQ,
      anon_sym_DASH_GT,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3481), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3489), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3483), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(179), 7,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      sym_comma,
  [108414] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3463), 1,
      anon_sym_PLUS,
    ACTIONS(3465), 1,
      anon_sym_DASH,
    ACTIONS(3475), 1,
      anon_sym_AMP,
    ACTIONS(3479), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3485), 1,
      anon_sym_STAR,
    ACTIONS(3487), 1,
      anon_sym_SLASH,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3481), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3489), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(181), 3,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
    ACTIONS(3483), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(179), 9,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      sym_comma,
  [108504] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(155), 3,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [108606] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3463), 1,
      anon_sym_PLUS,
    ACTIONS(3465), 1,
      anon_sym_DASH,
    ACTIONS(3485), 1,
      anon_sym_STAR,
    ACTIONS(3487), 1,
      anon_sym_SLASH,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3481), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3489), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(181), 4,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(3483), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(179), 10,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      sym_comma,
  [108692] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3463), 1,
      anon_sym_PLUS,
    ACTIONS(3465), 1,
      anon_sym_DASH,
    ACTIONS(3485), 1,
      anon_sym_STAR,
    ACTIONS(3487), 1,
      anon_sym_SLASH,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3489), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(181), 6,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(179), 14,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      sym_comma,
  [108774] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3489), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(181), 8,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
    ACTIONS(179), 16,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      sym_comma,
  [108848] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(157), 2,
      anon_sym_EQ,
      anon_sym_DASH_GT,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(155), 8,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      sym_comma,
  [108942] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(181), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(179), 18,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      sym_comma,
  [109012] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(181), 8,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
    ACTIONS(179), 18,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      sym_comma,
  [109084] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(181), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(179), 18,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      sym_comma,
  [109154] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(157), 4,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(155), 10,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      sym_comma,
  [109240] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(157), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(155), 18,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      sym_comma,
  [109310] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3459), 1,
      anon_sym_EQ,
    ACTIONS(3461), 1,
      anon_sym_TILDE,
    ACTIONS(3463), 1,
      anon_sym_PLUS,
    ACTIONS(3465), 1,
      anon_sym_DASH,
    ACTIONS(3469), 1,
      anon_sym_DASH_GT,
    ACTIONS(3471), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3473), 1,
      anon_sym_PIPE,
    ACTIONS(3475), 1,
      anon_sym_AMP,
    ACTIONS(3477), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3479), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3485), 1,
      anon_sym_STAR,
    ACTIONS(3487), 1,
      anon_sym_SLASH,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3481), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3489), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(183), 3,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3467), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3483), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [109412] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3459), 1,
      anon_sym_EQ,
    ACTIONS(3461), 1,
      anon_sym_TILDE,
    ACTIONS(3463), 1,
      anon_sym_PLUS,
    ACTIONS(3465), 1,
      anon_sym_DASH,
    ACTIONS(3469), 1,
      anon_sym_DASH_GT,
    ACTIONS(3471), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3473), 1,
      anon_sym_PIPE,
    ACTIONS(3475), 1,
      anon_sym_AMP,
    ACTIONS(3477), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3479), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3485), 1,
      anon_sym_STAR,
    ACTIONS(3487), 1,
      anon_sym_SLASH,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3481), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3489), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(187), 3,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3467), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3483), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [109514] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3495), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(482), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [109620] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3459), 1,
      anon_sym_EQ,
    ACTIONS(3461), 1,
      anon_sym_TILDE,
    ACTIONS(3463), 1,
      anon_sym_PLUS,
    ACTIONS(3465), 1,
      anon_sym_DASH,
    ACTIONS(3469), 1,
      anon_sym_DASH_GT,
    ACTIONS(3471), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3473), 1,
      anon_sym_PIPE,
    ACTIONS(3475), 1,
      anon_sym_AMP,
    ACTIONS(3477), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3479), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3485), 1,
      anon_sym_STAR,
    ACTIONS(3487), 1,
      anon_sym_SLASH,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3481), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3489), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(191), 3,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3467), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3483), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [109722] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3459), 1,
      anon_sym_EQ,
    ACTIONS(3461), 1,
      anon_sym_TILDE,
    ACTIONS(3463), 1,
      anon_sym_PLUS,
    ACTIONS(3465), 1,
      anon_sym_DASH,
    ACTIONS(3469), 1,
      anon_sym_DASH_GT,
    ACTIONS(3471), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3473), 1,
      anon_sym_PIPE,
    ACTIONS(3475), 1,
      anon_sym_AMP,
    ACTIONS(3477), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3479), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3485), 1,
      anon_sym_STAR,
    ACTIONS(3487), 1,
      anon_sym_SLASH,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3481), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3489), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(195), 3,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3467), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3483), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [109824] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3497), 2,
      sym__external_close_parenthesis,
      sym_comma,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [109928] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3459), 1,
      anon_sym_EQ,
    ACTIONS(3461), 1,
      anon_sym_TILDE,
    ACTIONS(3463), 1,
      anon_sym_PLUS,
    ACTIONS(3465), 1,
      anon_sym_DASH,
    ACTIONS(3469), 1,
      anon_sym_DASH_GT,
    ACTIONS(3471), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3473), 1,
      anon_sym_PIPE,
    ACTIONS(3475), 1,
      anon_sym_AMP,
    ACTIONS(3477), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3479), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3485), 1,
      anon_sym_STAR,
    ACTIONS(3487), 1,
      anon_sym_SLASH,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3481), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3489), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(199), 3,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3467), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3483), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [110030] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3499), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(497), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [110136] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3501), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(410), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [110242] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(159), 3,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [110344] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3459), 1,
      anon_sym_EQ,
    ACTIONS(3461), 1,
      anon_sym_TILDE,
    ACTIONS(3463), 1,
      anon_sym_PLUS,
    ACTIONS(3465), 1,
      anon_sym_DASH,
    ACTIONS(3469), 1,
      anon_sym_DASH_GT,
    ACTIONS(3471), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3473), 1,
      anon_sym_PIPE,
    ACTIONS(3475), 1,
      anon_sym_AMP,
    ACTIONS(3477), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3479), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3485), 1,
      anon_sym_STAR,
    ACTIONS(3487), 1,
      anon_sym_SLASH,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3481), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3489), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(203), 3,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3467), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3483), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [110446] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(163), 3,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [110548] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(167), 3,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [110650] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(169), 2,
      anon_sym_EQ,
      anon_sym_DASH_GT,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(167), 8,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      sym_comma,
  [110744] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(169), 4,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(167), 10,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      sym_comma,
  [110830] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(169), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(167), 18,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      sym_comma,
  [110900] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(143), 6,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      sym_comma,
  [111000] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3459), 1,
      anon_sym_EQ,
    ACTIONS(3461), 1,
      anon_sym_TILDE,
    ACTIONS(3463), 1,
      anon_sym_PLUS,
    ACTIONS(3465), 1,
      anon_sym_DASH,
    ACTIONS(3469), 1,
      anon_sym_DASH_GT,
    ACTIONS(3471), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3473), 1,
      anon_sym_PIPE,
    ACTIONS(3475), 1,
      anon_sym_AMP,
    ACTIONS(3477), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3479), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3485), 1,
      anon_sym_STAR,
    ACTIONS(3487), 1,
      anon_sym_SLASH,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3481), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3489), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(207), 3,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3467), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3483), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [111102] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3459), 1,
      anon_sym_EQ,
    ACTIONS(3461), 1,
      anon_sym_TILDE,
    ACTIONS(3463), 1,
      anon_sym_PLUS,
    ACTIONS(3465), 1,
      anon_sym_DASH,
    ACTIONS(3469), 1,
      anon_sym_DASH_GT,
    ACTIONS(3471), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3473), 1,
      anon_sym_PIPE,
    ACTIONS(3475), 1,
      anon_sym_AMP,
    ACTIONS(3477), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3479), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3485), 1,
      anon_sym_STAR,
    ACTIONS(3487), 1,
      anon_sym_SLASH,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3481), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3489), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(211), 3,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3467), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3483), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [111204] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3459), 1,
      anon_sym_EQ,
    ACTIONS(3461), 1,
      anon_sym_TILDE,
    ACTIONS(3463), 1,
      anon_sym_PLUS,
    ACTIONS(3465), 1,
      anon_sym_DASH,
    ACTIONS(3469), 1,
      anon_sym_DASH_GT,
    ACTIONS(3471), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3473), 1,
      anon_sym_PIPE,
    ACTIONS(3475), 1,
      anon_sym_AMP,
    ACTIONS(3477), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3479), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3485), 1,
      anon_sym_STAR,
    ACTIONS(3487), 1,
      anon_sym_SLASH,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3481), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3489), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(215), 3,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3467), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3483), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [111306] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(143), 3,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [111408] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3459), 1,
      anon_sym_EQ,
    ACTIONS(3461), 1,
      anon_sym_TILDE,
    ACTIONS(3463), 1,
      anon_sym_PLUS,
    ACTIONS(3465), 1,
      anon_sym_DASH,
    ACTIONS(3469), 1,
      anon_sym_DASH_GT,
    ACTIONS(3471), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3473), 1,
      anon_sym_PIPE,
    ACTIONS(3475), 1,
      anon_sym_AMP,
    ACTIONS(3477), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3479), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3485), 1,
      anon_sym_STAR,
    ACTIONS(3487), 1,
      anon_sym_SLASH,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3481), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3489), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(219), 3,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3467), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3483), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [111510] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3503), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(625), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [111616] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3459), 1,
      anon_sym_EQ,
    ACTIONS(3461), 1,
      anon_sym_TILDE,
    ACTIONS(3463), 1,
      anon_sym_PLUS,
    ACTIONS(3465), 1,
      anon_sym_DASH,
    ACTIONS(3469), 1,
      anon_sym_DASH_GT,
    ACTIONS(3471), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3473), 1,
      anon_sym_PIPE,
    ACTIONS(3475), 1,
      anon_sym_AMP,
    ACTIONS(3477), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3479), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3485), 1,
      anon_sym_STAR,
    ACTIONS(3487), 1,
      anon_sym_SLASH,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3481), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3489), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(223), 3,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3467), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3483), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [111718] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(145), 2,
      anon_sym_EQ,
      anon_sym_DASH_GT,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(143), 8,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      sym_comma,
  [111812] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3459), 1,
      anon_sym_EQ,
    ACTIONS(3461), 1,
      anon_sym_TILDE,
    ACTIONS(3463), 1,
      anon_sym_PLUS,
    ACTIONS(3465), 1,
      anon_sym_DASH,
    ACTIONS(3469), 1,
      anon_sym_DASH_GT,
    ACTIONS(3471), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3473), 1,
      anon_sym_PIPE,
    ACTIONS(3475), 1,
      anon_sym_AMP,
    ACTIONS(3477), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3479), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3485), 1,
      anon_sym_STAR,
    ACTIONS(3487), 1,
      anon_sym_SLASH,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3481), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3489), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(227), 3,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3467), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3483), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [111914] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3459), 1,
      anon_sym_EQ,
    ACTIONS(3461), 1,
      anon_sym_TILDE,
    ACTIONS(3463), 1,
      anon_sym_PLUS,
    ACTIONS(3465), 1,
      anon_sym_DASH,
    ACTIONS(3469), 1,
      anon_sym_DASH_GT,
    ACTIONS(3471), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3473), 1,
      anon_sym_PIPE,
    ACTIONS(3475), 1,
      anon_sym_AMP,
    ACTIONS(3477), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3479), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3485), 1,
      anon_sym_STAR,
    ACTIONS(3487), 1,
      anon_sym_SLASH,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3481), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3489), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(231), 3,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3467), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3483), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [112016] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(145), 7,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(143), 15,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      sym_comma,
  [112094] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3459), 1,
      anon_sym_EQ,
    ACTIONS(3461), 1,
      anon_sym_TILDE,
    ACTIONS(3463), 1,
      anon_sym_PLUS,
    ACTIONS(3465), 1,
      anon_sym_DASH,
    ACTIONS(3469), 1,
      anon_sym_DASH_GT,
    ACTIONS(3471), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3473), 1,
      anon_sym_PIPE,
    ACTIONS(3475), 1,
      anon_sym_AMP,
    ACTIONS(3477), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3479), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3485), 1,
      anon_sym_STAR,
    ACTIONS(3487), 1,
      anon_sym_SLASH,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3481), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3489), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(235), 3,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3467), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3483), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [112196] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3459), 1,
      anon_sym_EQ,
    ACTIONS(3461), 1,
      anon_sym_TILDE,
    ACTIONS(3463), 1,
      anon_sym_PLUS,
    ACTIONS(3465), 1,
      anon_sym_DASH,
    ACTIONS(3469), 1,
      anon_sym_DASH_GT,
    ACTIONS(3471), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3473), 1,
      anon_sym_PIPE,
    ACTIONS(3475), 1,
      anon_sym_AMP,
    ACTIONS(3477), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3479), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3485), 1,
      anon_sym_STAR,
    ACTIONS(3487), 1,
      anon_sym_SLASH,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3481), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3489), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(239), 3,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3467), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3483), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [112298] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(143), 3,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [112400] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3459), 1,
      anon_sym_EQ,
    ACTIONS(3461), 1,
      anon_sym_TILDE,
    ACTIONS(3463), 1,
      anon_sym_PLUS,
    ACTIONS(3465), 1,
      anon_sym_DASH,
    ACTIONS(3469), 1,
      anon_sym_DASH_GT,
    ACTIONS(3471), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3473), 1,
      anon_sym_PIPE,
    ACTIONS(3475), 1,
      anon_sym_AMP,
    ACTIONS(3477), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3479), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3485), 1,
      anon_sym_STAR,
    ACTIONS(3487), 1,
      anon_sym_SLASH,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3481), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3489), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(243), 3,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3467), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3483), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [112502] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3459), 1,
      anon_sym_EQ,
    ACTIONS(3461), 1,
      anon_sym_TILDE,
    ACTIONS(3463), 1,
      anon_sym_PLUS,
    ACTIONS(3465), 1,
      anon_sym_DASH,
    ACTIONS(3469), 1,
      anon_sym_DASH_GT,
    ACTIONS(3471), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3473), 1,
      anon_sym_PIPE,
    ACTIONS(3475), 1,
      anon_sym_AMP,
    ACTIONS(3477), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3479), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3485), 1,
      anon_sym_STAR,
    ACTIONS(3487), 1,
      anon_sym_SLASH,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3481), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3489), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(149), 3,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3467), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3483), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [112604] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(145), 2,
      anon_sym_EQ,
      anon_sym_DASH_GT,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(143), 7,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      sym_comma,
  [112700] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(145), 3,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(143), 9,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      sym_comma,
  [112790] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(145), 4,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(143), 10,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      sym_comma,
  [112876] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3505), 1,
      anon_sym_EQ,
    ACTIONS(3507), 1,
      anon_sym_TILDE,
    ACTIONS(3509), 1,
      anon_sym_PLUS,
    ACTIONS(3511), 1,
      anon_sym_DASH,
    ACTIONS(3515), 1,
      anon_sym_DASH_GT,
    ACTIONS(3517), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3519), 1,
      anon_sym_PIPE,
    ACTIONS(3521), 1,
      anon_sym_AMP,
    ACTIONS(3523), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3525), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3531), 1,
      anon_sym_STAR,
    ACTIONS(3533), 1,
      anon_sym_SLASH,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3527), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3537), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(151), 3,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3513), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3529), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [112978] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3505), 1,
      anon_sym_EQ,
    ACTIONS(3507), 1,
      anon_sym_TILDE,
    ACTIONS(3509), 1,
      anon_sym_PLUS,
    ACTIONS(3511), 1,
      anon_sym_DASH,
    ACTIONS(3515), 1,
      anon_sym_DASH_GT,
    ACTIONS(3517), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3519), 1,
      anon_sym_PIPE,
    ACTIONS(3521), 1,
      anon_sym_AMP,
    ACTIONS(3523), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3525), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3531), 1,
      anon_sym_STAR,
    ACTIONS(3533), 1,
      anon_sym_SLASH,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3527), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3537), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(155), 3,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3513), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3529), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [113080] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3509), 1,
      anon_sym_PLUS,
    ACTIONS(3511), 1,
      anon_sym_DASH,
    ACTIONS(3519), 1,
      anon_sym_PIPE,
    ACTIONS(3521), 1,
      anon_sym_AMP,
    ACTIONS(3523), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3525), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3531), 1,
      anon_sym_STAR,
    ACTIONS(3533), 1,
      anon_sym_SLASH,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(157), 2,
      anon_sym_EQ,
      anon_sym_DASH_GT,
    ACTIONS(3527), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3537), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3529), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(155), 8,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      sym_comma,
  [113174] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3509), 1,
      anon_sym_PLUS,
    ACTIONS(3511), 1,
      anon_sym_DASH,
    ACTIONS(3531), 1,
      anon_sym_STAR,
    ACTIONS(3533), 1,
      anon_sym_SLASH,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3527), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3537), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(157), 4,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(3529), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(155), 10,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      sym_comma,
  [113260] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(157), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(155), 18,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      sym_comma,
  [113330] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3459), 1,
      anon_sym_EQ,
    ACTIONS(3461), 1,
      anon_sym_TILDE,
    ACTIONS(3463), 1,
      anon_sym_PLUS,
    ACTIONS(3465), 1,
      anon_sym_DASH,
    ACTIONS(3469), 1,
      anon_sym_DASH_GT,
    ACTIONS(3471), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3473), 1,
      anon_sym_PIPE,
    ACTIONS(3475), 1,
      anon_sym_AMP,
    ACTIONS(3477), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3479), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3485), 1,
      anon_sym_STAR,
    ACTIONS(3487), 1,
      anon_sym_SLASH,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3481), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3489), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(151), 3,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3467), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3483), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [113432] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3459), 1,
      anon_sym_EQ,
    ACTIONS(3461), 1,
      anon_sym_TILDE,
    ACTIONS(3463), 1,
      anon_sym_PLUS,
    ACTIONS(3465), 1,
      anon_sym_DASH,
    ACTIONS(3469), 1,
      anon_sym_DASH_GT,
    ACTIONS(3471), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3473), 1,
      anon_sym_PIPE,
    ACTIONS(3475), 1,
      anon_sym_AMP,
    ACTIONS(3477), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3479), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3485), 1,
      anon_sym_STAR,
    ACTIONS(3487), 1,
      anon_sym_SLASH,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3481), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3489), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(155), 3,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3467), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3483), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [113534] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3463), 1,
      anon_sym_PLUS,
    ACTIONS(3465), 1,
      anon_sym_DASH,
    ACTIONS(3473), 1,
      anon_sym_PIPE,
    ACTIONS(3475), 1,
      anon_sym_AMP,
    ACTIONS(3477), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3479), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3485), 1,
      anon_sym_STAR,
    ACTIONS(3487), 1,
      anon_sym_SLASH,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(157), 2,
      anon_sym_EQ,
      anon_sym_DASH_GT,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3481), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3489), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3483), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(155), 8,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      sym_comma,
  [113628] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3463), 1,
      anon_sym_PLUS,
    ACTIONS(3465), 1,
      anon_sym_DASH,
    ACTIONS(3485), 1,
      anon_sym_STAR,
    ACTIONS(3487), 1,
      anon_sym_SLASH,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3481), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3489), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(157), 4,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(3483), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(155), 10,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      sym_comma,
  [113714] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(145), 6,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(143), 14,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      sym_comma,
  [113796] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(157), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(155), 18,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      sym_comma,
  [113866] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3505), 1,
      anon_sym_EQ,
    ACTIONS(3507), 1,
      anon_sym_TILDE,
    ACTIONS(3509), 1,
      anon_sym_PLUS,
    ACTIONS(3511), 1,
      anon_sym_DASH,
    ACTIONS(3515), 1,
      anon_sym_DASH_GT,
    ACTIONS(3517), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3519), 1,
      anon_sym_PIPE,
    ACTIONS(3521), 1,
      anon_sym_AMP,
    ACTIONS(3523), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3525), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3531), 1,
      anon_sym_STAR,
    ACTIONS(3533), 1,
      anon_sym_SLASH,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3527), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3537), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(159), 3,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3513), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3529), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [113968] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3505), 1,
      anon_sym_EQ,
    ACTIONS(3507), 1,
      anon_sym_TILDE,
    ACTIONS(3509), 1,
      anon_sym_PLUS,
    ACTIONS(3511), 1,
      anon_sym_DASH,
    ACTIONS(3515), 1,
      anon_sym_DASH_GT,
    ACTIONS(3517), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3519), 1,
      anon_sym_PIPE,
    ACTIONS(3521), 1,
      anon_sym_AMP,
    ACTIONS(3523), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3525), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3531), 1,
      anon_sym_STAR,
    ACTIONS(3533), 1,
      anon_sym_SLASH,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3527), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3537), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(163), 3,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3513), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3529), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [114070] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3505), 1,
      anon_sym_EQ,
    ACTIONS(3507), 1,
      anon_sym_TILDE,
    ACTIONS(3509), 1,
      anon_sym_PLUS,
    ACTIONS(3511), 1,
      anon_sym_DASH,
    ACTIONS(3515), 1,
      anon_sym_DASH_GT,
    ACTIONS(3517), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3519), 1,
      anon_sym_PIPE,
    ACTIONS(3521), 1,
      anon_sym_AMP,
    ACTIONS(3523), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3525), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3531), 1,
      anon_sym_STAR,
    ACTIONS(3533), 1,
      anon_sym_SLASH,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3527), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3537), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(167), 3,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3513), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3529), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [114172] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3509), 1,
      anon_sym_PLUS,
    ACTIONS(3511), 1,
      anon_sym_DASH,
    ACTIONS(3519), 1,
      anon_sym_PIPE,
    ACTIONS(3521), 1,
      anon_sym_AMP,
    ACTIONS(3523), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3525), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3531), 1,
      anon_sym_STAR,
    ACTIONS(3533), 1,
      anon_sym_SLASH,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(169), 2,
      anon_sym_EQ,
      anon_sym_DASH_GT,
    ACTIONS(3527), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3537), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3529), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(167), 8,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      sym_comma,
  [114266] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3509), 1,
      anon_sym_PLUS,
    ACTIONS(3511), 1,
      anon_sym_DASH,
    ACTIONS(3531), 1,
      anon_sym_STAR,
    ACTIONS(3533), 1,
      anon_sym_SLASH,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3527), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3537), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(169), 4,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(3529), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(167), 10,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      sym_comma,
  [114352] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(169), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(167), 18,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      sym_comma,
  [114422] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3505), 1,
      anon_sym_EQ,
    ACTIONS(3507), 1,
      anon_sym_TILDE,
    ACTIONS(3509), 1,
      anon_sym_PLUS,
    ACTIONS(3511), 1,
      anon_sym_DASH,
    ACTIONS(3515), 1,
      anon_sym_DASH_GT,
    ACTIONS(3517), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3519), 1,
      anon_sym_PIPE,
    ACTIONS(3521), 1,
      anon_sym_AMP,
    ACTIONS(3523), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3525), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3531), 1,
      anon_sym_STAR,
    ACTIONS(3533), 1,
      anon_sym_SLASH,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3527), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3537), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3529), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(143), 6,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      sym_comma,
  [114522] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3505), 1,
      anon_sym_EQ,
    ACTIONS(3507), 1,
      anon_sym_TILDE,
    ACTIONS(3509), 1,
      anon_sym_PLUS,
    ACTIONS(3511), 1,
      anon_sym_DASH,
    ACTIONS(3515), 1,
      anon_sym_DASH_GT,
    ACTIONS(3517), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3519), 1,
      anon_sym_PIPE,
    ACTIONS(3521), 1,
      anon_sym_AMP,
    ACTIONS(3523), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3525), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3531), 1,
      anon_sym_STAR,
    ACTIONS(3533), 1,
      anon_sym_SLASH,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3527), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3537), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(143), 3,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3513), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3529), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [114624] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3509), 1,
      anon_sym_PLUS,
    ACTIONS(3511), 1,
      anon_sym_DASH,
    ACTIONS(3519), 1,
      anon_sym_PIPE,
    ACTIONS(3521), 1,
      anon_sym_AMP,
    ACTIONS(3523), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3525), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3531), 1,
      anon_sym_STAR,
    ACTIONS(3533), 1,
      anon_sym_SLASH,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(145), 2,
      anon_sym_EQ,
      anon_sym_DASH_GT,
    ACTIONS(3527), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3537), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3529), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(143), 8,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      sym_comma,
  [114718] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3531), 1,
      anon_sym_STAR,
    ACTIONS(3533), 1,
      anon_sym_SLASH,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3537), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(145), 7,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(143), 15,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      sym_comma,
  [114796] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3505), 1,
      anon_sym_EQ,
    ACTIONS(3507), 1,
      anon_sym_TILDE,
    ACTIONS(3509), 1,
      anon_sym_PLUS,
    ACTIONS(3511), 1,
      anon_sym_DASH,
    ACTIONS(3515), 1,
      anon_sym_DASH_GT,
    ACTIONS(3517), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3519), 1,
      anon_sym_PIPE,
    ACTIONS(3521), 1,
      anon_sym_AMP,
    ACTIONS(3523), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3525), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3531), 1,
      anon_sym_STAR,
    ACTIONS(3533), 1,
      anon_sym_SLASH,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3527), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3537), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(143), 3,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3513), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3529), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [114898] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3507), 1,
      anon_sym_TILDE,
    ACTIONS(3509), 1,
      anon_sym_PLUS,
    ACTIONS(3511), 1,
      anon_sym_DASH,
    ACTIONS(3519), 1,
      anon_sym_PIPE,
    ACTIONS(3521), 1,
      anon_sym_AMP,
    ACTIONS(3523), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3525), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3531), 1,
      anon_sym_STAR,
    ACTIONS(3533), 1,
      anon_sym_SLASH,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(145), 2,
      anon_sym_EQ,
      anon_sym_DASH_GT,
    ACTIONS(3527), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3537), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3529), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(143), 7,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      sym_comma,
  [114994] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3509), 1,
      anon_sym_PLUS,
    ACTIONS(3511), 1,
      anon_sym_DASH,
    ACTIONS(3521), 1,
      anon_sym_AMP,
    ACTIONS(3525), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3531), 1,
      anon_sym_STAR,
    ACTIONS(3533), 1,
      anon_sym_SLASH,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3527), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3537), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(145), 3,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
    ACTIONS(3529), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(143), 9,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      sym_comma,
  [115084] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3509), 1,
      anon_sym_PLUS,
    ACTIONS(3511), 1,
      anon_sym_DASH,
    ACTIONS(3531), 1,
      anon_sym_STAR,
    ACTIONS(3533), 1,
      anon_sym_SLASH,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3527), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3537), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(145), 4,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(3529), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(143), 10,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      sym_comma,
  [115170] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3509), 1,
      anon_sym_PLUS,
    ACTIONS(3511), 1,
      anon_sym_DASH,
    ACTIONS(3531), 1,
      anon_sym_STAR,
    ACTIONS(3533), 1,
      anon_sym_SLASH,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3537), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(145), 6,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(143), 14,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      sym_comma,
  [115252] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3537), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(145), 8,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
    ACTIONS(143), 16,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      sym_comma,
  [115326] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(145), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(143), 18,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      sym_comma,
  [115396] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(145), 8,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
    ACTIONS(143), 18,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      sym_comma,
  [115468] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(145), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(143), 18,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      sym_comma,
  [115538] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3549), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1741), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [115644] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3551), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(791), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [115750] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3553), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(809), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [115856] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3555), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(811), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [115962] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3557), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(819), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [116068] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3505), 1,
      anon_sym_EQ,
    ACTIONS(3507), 1,
      anon_sym_TILDE,
    ACTIONS(3509), 1,
      anon_sym_PLUS,
    ACTIONS(3511), 1,
      anon_sym_DASH,
    ACTIONS(3515), 1,
      anon_sym_DASH_GT,
    ACTIONS(3517), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3519), 1,
      anon_sym_PIPE,
    ACTIONS(3521), 1,
      anon_sym_AMP,
    ACTIONS(3523), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3525), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3531), 1,
      anon_sym_STAR,
    ACTIONS(3533), 1,
      anon_sym_SLASH,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3527), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3537), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(171), 3,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3513), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3529), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [116170] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3505), 1,
      anon_sym_EQ,
    ACTIONS(3507), 1,
      anon_sym_TILDE,
    ACTIONS(3509), 1,
      anon_sym_PLUS,
    ACTIONS(3511), 1,
      anon_sym_DASH,
    ACTIONS(3515), 1,
      anon_sym_DASH_GT,
    ACTIONS(3517), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3519), 1,
      anon_sym_PIPE,
    ACTIONS(3521), 1,
      anon_sym_AMP,
    ACTIONS(3523), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3525), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3531), 1,
      anon_sym_STAR,
    ACTIONS(3533), 1,
      anon_sym_SLASH,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3527), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3537), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(175), 3,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3513), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3529), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [116272] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3559), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(483), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [116378] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3505), 1,
      anon_sym_EQ,
    ACTIONS(3507), 1,
      anon_sym_TILDE,
    ACTIONS(3509), 1,
      anon_sym_PLUS,
    ACTIONS(3511), 1,
      anon_sym_DASH,
    ACTIONS(3515), 1,
      anon_sym_DASH_GT,
    ACTIONS(3517), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3519), 1,
      anon_sym_PIPE,
    ACTIONS(3521), 1,
      anon_sym_AMP,
    ACTIONS(3523), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3525), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3531), 1,
      anon_sym_STAR,
    ACTIONS(3533), 1,
      anon_sym_SLASH,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3527), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3537), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3529), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(179), 6,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      sym_comma,
  [116478] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3505), 1,
      anon_sym_EQ,
    ACTIONS(3507), 1,
      anon_sym_TILDE,
    ACTIONS(3509), 1,
      anon_sym_PLUS,
    ACTIONS(3511), 1,
      anon_sym_DASH,
    ACTIONS(3515), 1,
      anon_sym_DASH_GT,
    ACTIONS(3517), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3519), 1,
      anon_sym_PIPE,
    ACTIONS(3521), 1,
      anon_sym_AMP,
    ACTIONS(3523), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3525), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3531), 1,
      anon_sym_STAR,
    ACTIONS(3533), 1,
      anon_sym_SLASH,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3527), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3537), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(179), 3,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3513), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3529), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [116580] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3509), 1,
      anon_sym_PLUS,
    ACTIONS(3511), 1,
      anon_sym_DASH,
    ACTIONS(3519), 1,
      anon_sym_PIPE,
    ACTIONS(3521), 1,
      anon_sym_AMP,
    ACTIONS(3523), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3525), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3531), 1,
      anon_sym_STAR,
    ACTIONS(3533), 1,
      anon_sym_SLASH,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(181), 2,
      anon_sym_EQ,
      anon_sym_DASH_GT,
    ACTIONS(3527), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3537), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3529), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(179), 8,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      sym_comma,
  [116674] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(231), 3,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [116776] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3505), 1,
      anon_sym_EQ,
    ACTIONS(3507), 1,
      anon_sym_TILDE,
    ACTIONS(3509), 1,
      anon_sym_PLUS,
    ACTIONS(3511), 1,
      anon_sym_DASH,
    ACTIONS(3515), 1,
      anon_sym_DASH_GT,
    ACTIONS(3517), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3519), 1,
      anon_sym_PIPE,
    ACTIONS(3521), 1,
      anon_sym_AMP,
    ACTIONS(3523), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3525), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3531), 1,
      anon_sym_STAR,
    ACTIONS(3533), 1,
      anon_sym_SLASH,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3527), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3537), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(179), 3,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3513), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3529), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [116878] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3507), 1,
      anon_sym_TILDE,
    ACTIONS(3509), 1,
      anon_sym_PLUS,
    ACTIONS(3511), 1,
      anon_sym_DASH,
    ACTIONS(3519), 1,
      anon_sym_PIPE,
    ACTIONS(3521), 1,
      anon_sym_AMP,
    ACTIONS(3523), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3525), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3531), 1,
      anon_sym_STAR,
    ACTIONS(3533), 1,
      anon_sym_SLASH,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(181), 2,
      anon_sym_EQ,
      anon_sym_DASH_GT,
    ACTIONS(3527), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3537), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3529), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(179), 7,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      sym_comma,
  [116974] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3509), 1,
      anon_sym_PLUS,
    ACTIONS(3511), 1,
      anon_sym_DASH,
    ACTIONS(3521), 1,
      anon_sym_AMP,
    ACTIONS(3525), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3531), 1,
      anon_sym_STAR,
    ACTIONS(3533), 1,
      anon_sym_SLASH,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3527), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3537), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(181), 3,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
    ACTIONS(3529), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(179), 9,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      sym_comma,
  [117064] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3509), 1,
      anon_sym_PLUS,
    ACTIONS(3511), 1,
      anon_sym_DASH,
    ACTIONS(3531), 1,
      anon_sym_STAR,
    ACTIONS(3533), 1,
      anon_sym_SLASH,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3527), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3537), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(181), 4,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(3529), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(179), 10,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      sym_comma,
  [117150] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3509), 1,
      anon_sym_PLUS,
    ACTIONS(3511), 1,
      anon_sym_DASH,
    ACTIONS(3531), 1,
      anon_sym_STAR,
    ACTIONS(3533), 1,
      anon_sym_SLASH,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3537), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(181), 6,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(179), 14,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      sym_comma,
  [117232] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3537), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(181), 8,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
    ACTIONS(179), 16,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      sym_comma,
  [117306] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3561), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(429), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [117412] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3563), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(488), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [117518] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(181), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(179), 18,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      sym_comma,
  [117588] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3565), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(493), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [117694] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(181), 8,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
    ACTIONS(179), 18,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      sym_comma,
  [117766] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(181), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(179), 18,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      sym_comma,
  [117836] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3567), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(496), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [117942] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3569), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(505), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [118048] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(145), 8,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
    ACTIONS(143), 16,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      sym_comma,
  [118122] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(145), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(143), 18,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      sym_comma,
  [118192] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3571), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    STATE(1763), 1,
      sym__close_parenthesis,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [118298] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3573), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(550), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [118404] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3575), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(552), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [118510] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(145), 8,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
    ACTIONS(143), 18,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      sym_comma,
  [118582] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3505), 1,
      anon_sym_EQ,
    ACTIONS(3507), 1,
      anon_sym_TILDE,
    ACTIONS(3509), 1,
      anon_sym_PLUS,
    ACTIONS(3511), 1,
      anon_sym_DASH,
    ACTIONS(3515), 1,
      anon_sym_DASH_GT,
    ACTIONS(3517), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3519), 1,
      anon_sym_PIPE,
    ACTIONS(3521), 1,
      anon_sym_AMP,
    ACTIONS(3523), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3525), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3531), 1,
      anon_sym_STAR,
    ACTIONS(3533), 1,
      anon_sym_SLASH,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3527), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3537), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(183), 3,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3513), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3529), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [118684] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3577), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(554), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [118790] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3459), 1,
      anon_sym_EQ,
    ACTIONS(3461), 1,
      anon_sym_TILDE,
    ACTIONS(3463), 1,
      anon_sym_PLUS,
    ACTIONS(3465), 1,
      anon_sym_DASH,
    ACTIONS(3469), 1,
      anon_sym_DASH_GT,
    ACTIONS(3471), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3473), 1,
      anon_sym_PIPE,
    ACTIONS(3475), 1,
      anon_sym_AMP,
    ACTIONS(3477), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3479), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3485), 1,
      anon_sym_STAR,
    ACTIONS(3487), 1,
      anon_sym_SLASH,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3481), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3489), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(159), 3,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3467), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3483), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [118892] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3579), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(560), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [118998] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(145), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(143), 18,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      sym_comma,
  [119068] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3505), 1,
      anon_sym_EQ,
    ACTIONS(3507), 1,
      anon_sym_TILDE,
    ACTIONS(3509), 1,
      anon_sym_PLUS,
    ACTIONS(3511), 1,
      anon_sym_DASH,
    ACTIONS(3515), 1,
      anon_sym_DASH_GT,
    ACTIONS(3517), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3519), 1,
      anon_sym_PIPE,
    ACTIONS(3521), 1,
      anon_sym_AMP,
    ACTIONS(3523), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3525), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3531), 1,
      anon_sym_STAR,
    ACTIONS(3533), 1,
      anon_sym_SLASH,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3527), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3537), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(187), 3,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3513), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3529), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [119170] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3581), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    STATE(1774), 1,
      sym__close_parenthesis,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [119276] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3583), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(602), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [119382] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3585), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(604), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [119488] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3587), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(606), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [119594] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3589), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(612), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [119700] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3459), 1,
      anon_sym_EQ,
    ACTIONS(3461), 1,
      anon_sym_TILDE,
    ACTIONS(3463), 1,
      anon_sym_PLUS,
    ACTIONS(3465), 1,
      anon_sym_DASH,
    ACTIONS(3469), 1,
      anon_sym_DASH_GT,
    ACTIONS(3471), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3473), 1,
      anon_sym_PIPE,
    ACTIONS(3475), 1,
      anon_sym_AMP,
    ACTIONS(3477), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3479), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3485), 1,
      anon_sym_STAR,
    ACTIONS(3487), 1,
      anon_sym_SLASH,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3481), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3489), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(163), 3,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3467), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3483), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [119802] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3459), 1,
      anon_sym_EQ,
    ACTIONS(3461), 1,
      anon_sym_TILDE,
    ACTIONS(3463), 1,
      anon_sym_PLUS,
    ACTIONS(3465), 1,
      anon_sym_DASH,
    ACTIONS(3469), 1,
      anon_sym_DASH_GT,
    ACTIONS(3471), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3473), 1,
      anon_sym_PIPE,
    ACTIONS(3475), 1,
      anon_sym_AMP,
    ACTIONS(3477), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3479), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3485), 1,
      anon_sym_STAR,
    ACTIONS(3487), 1,
      anon_sym_SLASH,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3481), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3489), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(167), 3,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3467), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3483), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [119904] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3463), 1,
      anon_sym_PLUS,
    ACTIONS(3465), 1,
      anon_sym_DASH,
    ACTIONS(3473), 1,
      anon_sym_PIPE,
    ACTIONS(3475), 1,
      anon_sym_AMP,
    ACTIONS(3477), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3479), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3485), 1,
      anon_sym_STAR,
    ACTIONS(3487), 1,
      anon_sym_SLASH,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(169), 2,
      anon_sym_EQ,
      anon_sym_DASH_GT,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3481), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3489), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3483), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(167), 8,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      sym_comma,
  [119998] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3505), 1,
      anon_sym_EQ,
    ACTIONS(3507), 1,
      anon_sym_TILDE,
    ACTIONS(3509), 1,
      anon_sym_PLUS,
    ACTIONS(3511), 1,
      anon_sym_DASH,
    ACTIONS(3515), 1,
      anon_sym_DASH_GT,
    ACTIONS(3517), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3519), 1,
      anon_sym_PIPE,
    ACTIONS(3521), 1,
      anon_sym_AMP,
    ACTIONS(3523), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3525), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3531), 1,
      anon_sym_STAR,
    ACTIONS(3533), 1,
      anon_sym_SLASH,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3527), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3537), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(191), 3,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3513), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3529), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [120100] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3505), 1,
      anon_sym_EQ,
    ACTIONS(3507), 1,
      anon_sym_TILDE,
    ACTIONS(3509), 1,
      anon_sym_PLUS,
    ACTIONS(3511), 1,
      anon_sym_DASH,
    ACTIONS(3515), 1,
      anon_sym_DASH_GT,
    ACTIONS(3517), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3519), 1,
      anon_sym_PIPE,
    ACTIONS(3521), 1,
      anon_sym_AMP,
    ACTIONS(3523), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3525), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3531), 1,
      anon_sym_STAR,
    ACTIONS(3533), 1,
      anon_sym_SLASH,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3527), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3537), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(195), 3,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3513), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3529), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [120202] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3463), 1,
      anon_sym_PLUS,
    ACTIONS(3465), 1,
      anon_sym_DASH,
    ACTIONS(3485), 1,
      anon_sym_STAR,
    ACTIONS(3487), 1,
      anon_sym_SLASH,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3481), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3489), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(169), 4,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(3483), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(167), 10,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      sym_comma,
  [120288] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3505), 1,
      anon_sym_EQ,
    ACTIONS(3507), 1,
      anon_sym_TILDE,
    ACTIONS(3509), 1,
      anon_sym_PLUS,
    ACTIONS(3511), 1,
      anon_sym_DASH,
    ACTIONS(3515), 1,
      anon_sym_DASH_GT,
    ACTIONS(3517), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3519), 1,
      anon_sym_PIPE,
    ACTIONS(3521), 1,
      anon_sym_AMP,
    ACTIONS(3523), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3525), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3531), 1,
      anon_sym_STAR,
    ACTIONS(3533), 1,
      anon_sym_SLASH,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3527), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3537), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(199), 3,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3513), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3529), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [120390] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3591), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(394), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [120496] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3593), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(683), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [120602] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(169), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(167), 18,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      sym_comma,
  [120672] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3595), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(693), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [120778] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3597), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(695), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [120884] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3599), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(703), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [120990] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3505), 1,
      anon_sym_EQ,
    ACTIONS(3507), 1,
      anon_sym_TILDE,
    ACTIONS(3509), 1,
      anon_sym_PLUS,
    ACTIONS(3511), 1,
      anon_sym_DASH,
    ACTIONS(3515), 1,
      anon_sym_DASH_GT,
    ACTIONS(3517), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3519), 1,
      anon_sym_PIPE,
    ACTIONS(3521), 1,
      anon_sym_AMP,
    ACTIONS(3523), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3525), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3531), 1,
      anon_sym_STAR,
    ACTIONS(3533), 1,
      anon_sym_SLASH,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3527), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3537), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(203), 3,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3513), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3529), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [121092] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3459), 1,
      anon_sym_EQ,
    ACTIONS(3461), 1,
      anon_sym_TILDE,
    ACTIONS(3463), 1,
      anon_sym_PLUS,
    ACTIONS(3465), 1,
      anon_sym_DASH,
    ACTIONS(3469), 1,
      anon_sym_DASH_GT,
    ACTIONS(3471), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3473), 1,
      anon_sym_PIPE,
    ACTIONS(3475), 1,
      anon_sym_AMP,
    ACTIONS(3477), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3479), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3485), 1,
      anon_sym_STAR,
    ACTIONS(3487), 1,
      anon_sym_SLASH,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    ACTIONS(3601), 1,
      anon_sym_QMARK,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3481), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3489), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3497), 2,
      sym__external_close_bracket,
      sym_comma,
    ACTIONS(3467), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3483), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [121196] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3603), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1725), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [121302] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3605), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(749), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [121408] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3459), 1,
      anon_sym_EQ,
    ACTIONS(3461), 1,
      anon_sym_TILDE,
    ACTIONS(3463), 1,
      anon_sym_PLUS,
    ACTIONS(3465), 1,
      anon_sym_DASH,
    ACTIONS(3469), 1,
      anon_sym_DASH_GT,
    ACTIONS(3471), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3473), 1,
      anon_sym_PIPE,
    ACTIONS(3475), 1,
      anon_sym_AMP,
    ACTIONS(3477), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3479), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3485), 1,
      anon_sym_STAR,
    ACTIONS(3487), 1,
      anon_sym_SLASH,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3481), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3489), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3483), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(143), 6,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      sym_comma,
  [121508] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3607), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(751), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [121614] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3609), 2,
      sym__external_close_parenthesis,
      sym_comma,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [121718] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3611), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(753), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [121824] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3613), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(759), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [121930] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(171), 3,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [122032] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(175), 3,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [122134] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3505), 1,
      anon_sym_EQ,
    ACTIONS(3507), 1,
      anon_sym_TILDE,
    ACTIONS(3509), 1,
      anon_sym_PLUS,
    ACTIONS(3511), 1,
      anon_sym_DASH,
    ACTIONS(3515), 1,
      anon_sym_DASH_GT,
    ACTIONS(3517), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3519), 1,
      anon_sym_PIPE,
    ACTIONS(3521), 1,
      anon_sym_AMP,
    ACTIONS(3523), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3525), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3531), 1,
      anon_sym_STAR,
    ACTIONS(3533), 1,
      anon_sym_SLASH,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3527), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3537), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(207), 3,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3513), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3529), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [122236] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3505), 1,
      anon_sym_EQ,
    ACTIONS(3507), 1,
      anon_sym_TILDE,
    ACTIONS(3509), 1,
      anon_sym_PLUS,
    ACTIONS(3511), 1,
      anon_sym_DASH,
    ACTIONS(3515), 1,
      anon_sym_DASH_GT,
    ACTIONS(3517), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3519), 1,
      anon_sym_PIPE,
    ACTIONS(3521), 1,
      anon_sym_AMP,
    ACTIONS(3523), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3525), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3531), 1,
      anon_sym_STAR,
    ACTIONS(3533), 1,
      anon_sym_SLASH,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3527), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3537), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(211), 3,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3513), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3529), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [122338] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(179), 6,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      sym_comma,
  [122438] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(179), 3,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [122540] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(181), 2,
      anon_sym_EQ,
      anon_sym_DASH_GT,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(179), 8,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      sym_comma,
  [122634] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(181), 7,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(179), 15,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      sym_comma,
  [122712] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3505), 1,
      anon_sym_EQ,
    ACTIONS(3507), 1,
      anon_sym_TILDE,
    ACTIONS(3509), 1,
      anon_sym_PLUS,
    ACTIONS(3511), 1,
      anon_sym_DASH,
    ACTIONS(3515), 1,
      anon_sym_DASH_GT,
    ACTIONS(3517), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3519), 1,
      anon_sym_PIPE,
    ACTIONS(3521), 1,
      anon_sym_AMP,
    ACTIONS(3523), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3525), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3531), 1,
      anon_sym_STAR,
    ACTIONS(3533), 1,
      anon_sym_SLASH,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3527), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3537), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(215), 3,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3513), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3529), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [122814] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3615), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(346), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [122920] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3617), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(807), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [123026] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(179), 3,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [123128] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3619), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(817), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [123234] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3459), 1,
      anon_sym_EQ,
    ACTIONS(3461), 1,
      anon_sym_TILDE,
    ACTIONS(3463), 1,
      anon_sym_PLUS,
    ACTIONS(3465), 1,
      anon_sym_DASH,
    ACTIONS(3469), 1,
      anon_sym_DASH_GT,
    ACTIONS(3471), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3473), 1,
      anon_sym_PIPE,
    ACTIONS(3475), 1,
      anon_sym_AMP,
    ACTIONS(3477), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3479), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3485), 1,
      anon_sym_STAR,
    ACTIONS(3487), 1,
      anon_sym_SLASH,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3481), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3489), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(143), 3,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3467), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3483), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [123336] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(181), 2,
      anon_sym_EQ,
      anon_sym_DASH_GT,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(179), 7,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      sym_comma,
  [123432] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3621), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(821), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [123538] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3505), 1,
      anon_sym_EQ,
    ACTIONS(3507), 1,
      anon_sym_TILDE,
    ACTIONS(3509), 1,
      anon_sym_PLUS,
    ACTIONS(3511), 1,
      anon_sym_DASH,
    ACTIONS(3515), 1,
      anon_sym_DASH_GT,
    ACTIONS(3517), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3519), 1,
      anon_sym_PIPE,
    ACTIONS(3521), 1,
      anon_sym_AMP,
    ACTIONS(3523), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3525), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3531), 1,
      anon_sym_STAR,
    ACTIONS(3533), 1,
      anon_sym_SLASH,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3527), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3537), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(219), 3,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3513), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3529), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [123640] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3623), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(828), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [123746] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(181), 3,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(179), 9,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      sym_comma,
  [123836] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(181), 4,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(179), 10,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      sym_comma,
  [123922] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3463), 1,
      anon_sym_PLUS,
    ACTIONS(3465), 1,
      anon_sym_DASH,
    ACTIONS(3473), 1,
      anon_sym_PIPE,
    ACTIONS(3475), 1,
      anon_sym_AMP,
    ACTIONS(3477), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3479), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3485), 1,
      anon_sym_STAR,
    ACTIONS(3487), 1,
      anon_sym_SLASH,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(145), 2,
      anon_sym_EQ,
      anon_sym_DASH_GT,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3481), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3489), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3483), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(143), 8,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      sym_comma,
  [124016] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(181), 6,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(179), 14,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      sym_comma,
  [124098] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3505), 1,
      anon_sym_EQ,
    ACTIONS(3507), 1,
      anon_sym_TILDE,
    ACTIONS(3509), 1,
      anon_sym_PLUS,
    ACTIONS(3511), 1,
      anon_sym_DASH,
    ACTIONS(3515), 1,
      anon_sym_DASH_GT,
    ACTIONS(3517), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3519), 1,
      anon_sym_PIPE,
    ACTIONS(3521), 1,
      anon_sym_AMP,
    ACTIONS(3523), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3525), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3531), 1,
      anon_sym_STAR,
    ACTIONS(3533), 1,
      anon_sym_SLASH,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3527), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3537), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(223), 3,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3513), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3529), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [124200] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3625), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1673), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [124306] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3627), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(872), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [124412] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(181), 8,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
    ACTIONS(179), 16,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      sym_comma,
  [124486] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3629), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(874), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [124592] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3505), 1,
      anon_sym_EQ,
    ACTIONS(3507), 1,
      anon_sym_TILDE,
    ACTIONS(3509), 1,
      anon_sym_PLUS,
    ACTIONS(3511), 1,
      anon_sym_DASH,
    ACTIONS(3515), 1,
      anon_sym_DASH_GT,
    ACTIONS(3517), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3519), 1,
      anon_sym_PIPE,
    ACTIONS(3521), 1,
      anon_sym_AMP,
    ACTIONS(3523), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3525), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3531), 1,
      anon_sym_STAR,
    ACTIONS(3533), 1,
      anon_sym_SLASH,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3527), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3537), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(227), 3,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3513), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3529), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [124694] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(181), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(179), 18,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      sym_comma,
  [124764] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3631), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(876), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [124870] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3633), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(882), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [124976] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(181), 8,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
    ACTIONS(179), 18,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      sym_comma,
  [125048] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3505), 1,
      anon_sym_EQ,
    ACTIONS(3507), 1,
      anon_sym_TILDE,
    ACTIONS(3509), 1,
      anon_sym_PLUS,
    ACTIONS(3511), 1,
      anon_sym_DASH,
    ACTIONS(3515), 1,
      anon_sym_DASH_GT,
    ACTIONS(3517), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3519), 1,
      anon_sym_PIPE,
    ACTIONS(3521), 1,
      anon_sym_AMP,
    ACTIONS(3523), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3525), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3531), 1,
      anon_sym_STAR,
    ACTIONS(3533), 1,
      anon_sym_SLASH,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3527), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3537), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(231), 3,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3513), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3529), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [125150] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(181), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(179), 18,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      sym_comma,
  [125220] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3505), 1,
      anon_sym_EQ,
    ACTIONS(3507), 1,
      anon_sym_TILDE,
    ACTIONS(3509), 1,
      anon_sym_PLUS,
    ACTIONS(3511), 1,
      anon_sym_DASH,
    ACTIONS(3515), 1,
      anon_sym_DASH_GT,
    ACTIONS(3517), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3519), 1,
      anon_sym_PIPE,
    ACTIONS(3521), 1,
      anon_sym_AMP,
    ACTIONS(3523), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3525), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3531), 1,
      anon_sym_STAR,
    ACTIONS(3533), 1,
      anon_sym_SLASH,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3527), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3537), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(235), 3,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3513), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3529), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [125322] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3505), 1,
      anon_sym_EQ,
    ACTIONS(3507), 1,
      anon_sym_TILDE,
    ACTIONS(3509), 1,
      anon_sym_PLUS,
    ACTIONS(3511), 1,
      anon_sym_DASH,
    ACTIONS(3515), 1,
      anon_sym_DASH_GT,
    ACTIONS(3517), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3519), 1,
      anon_sym_PIPE,
    ACTIONS(3521), 1,
      anon_sym_AMP,
    ACTIONS(3523), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3525), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3531), 1,
      anon_sym_STAR,
    ACTIONS(3533), 1,
      anon_sym_SLASH,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3527), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3537), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(239), 3,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3513), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3529), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [125424] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3635), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1706), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [125530] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3637), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(923), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [125636] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3639), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(925), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [125742] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3641), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(927), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [125848] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3643), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(933), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [125954] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3485), 1,
      anon_sym_STAR,
    ACTIONS(3487), 1,
      anon_sym_SLASH,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3489), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(145), 7,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(143), 15,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      sym_comma,
  [126032] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3645), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(946), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [126138] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3505), 1,
      anon_sym_EQ,
    ACTIONS(3507), 1,
      anon_sym_TILDE,
    ACTIONS(3509), 1,
      anon_sym_PLUS,
    ACTIONS(3511), 1,
      anon_sym_DASH,
    ACTIONS(3515), 1,
      anon_sym_DASH_GT,
    ACTIONS(3517), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3519), 1,
      anon_sym_PIPE,
    ACTIONS(3521), 1,
      anon_sym_AMP,
    ACTIONS(3523), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3525), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3531), 1,
      anon_sym_STAR,
    ACTIONS(3533), 1,
      anon_sym_SLASH,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3527), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3537), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(243), 3,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3513), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3529), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [126240] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3505), 1,
      anon_sym_EQ,
    ACTIONS(3507), 1,
      anon_sym_TILDE,
    ACTIONS(3509), 1,
      anon_sym_PLUS,
    ACTIONS(3511), 1,
      anon_sym_DASH,
    ACTIONS(3515), 1,
      anon_sym_DASH_GT,
    ACTIONS(3517), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3519), 1,
      anon_sym_PIPE,
    ACTIONS(3521), 1,
      anon_sym_AMP,
    ACTIONS(3523), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3525), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3531), 1,
      anon_sym_STAR,
    ACTIONS(3533), 1,
      anon_sym_SLASH,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3527), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3537), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(149), 3,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3513), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3529), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [126342] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3647), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(949), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [126448] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3649), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(964), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [126554] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3651), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(966), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [126660] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3653), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(977), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [126766] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3655), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(979), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [126872] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(183), 3,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [126974] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3459), 1,
      anon_sym_EQ,
    ACTIONS(3461), 1,
      anon_sym_TILDE,
    ACTIONS(3463), 1,
      anon_sym_PLUS,
    ACTIONS(3465), 1,
      anon_sym_DASH,
    ACTIONS(3469), 1,
      anon_sym_DASH_GT,
    ACTIONS(3471), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3473), 1,
      anon_sym_PIPE,
    ACTIONS(3475), 1,
      anon_sym_AMP,
    ACTIONS(3477), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3479), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3485), 1,
      anon_sym_STAR,
    ACTIONS(3487), 1,
      anon_sym_SLASH,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3481), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3489), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(143), 3,
      sym__external_close_bracket,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3467), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3483), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [127076] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(187), 3,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [127178] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3657), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(990), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [127284] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3505), 1,
      anon_sym_EQ,
    ACTIONS(3507), 1,
      anon_sym_TILDE,
    ACTIONS(3509), 1,
      anon_sym_PLUS,
    ACTIONS(3511), 1,
      anon_sym_DASH,
    ACTIONS(3515), 1,
      anon_sym_DASH_GT,
    ACTIONS(3517), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3519), 1,
      anon_sym_PIPE,
    ACTIONS(3521), 1,
      anon_sym_AMP,
    ACTIONS(3523), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3525), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3531), 1,
      anon_sym_STAR,
    ACTIONS(3533), 1,
      anon_sym_SLASH,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    ACTIONS(3659), 1,
      anon_sym_QMARK,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3497), 2,
      sym__external_close_bracket2,
      sym_comma,
    ACTIONS(3527), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3537), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3513), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3529), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [127388] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3661), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(992), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [127494] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3461), 1,
      anon_sym_TILDE,
    ACTIONS(3463), 1,
      anon_sym_PLUS,
    ACTIONS(3465), 1,
      anon_sym_DASH,
    ACTIONS(3473), 1,
      anon_sym_PIPE,
    ACTIONS(3475), 1,
      anon_sym_AMP,
    ACTIONS(3477), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3479), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3485), 1,
      anon_sym_STAR,
    ACTIONS(3487), 1,
      anon_sym_SLASH,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(145), 2,
      anon_sym_EQ,
      anon_sym_DASH_GT,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3481), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3489), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3483), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(143), 7,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      sym_comma,
  [127590] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3663), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1003), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [127696] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3665), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1005), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [127802] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3463), 1,
      anon_sym_PLUS,
    ACTIONS(3465), 1,
      anon_sym_DASH,
    ACTIONS(3475), 1,
      anon_sym_AMP,
    ACTIONS(3479), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3485), 1,
      anon_sym_STAR,
    ACTIONS(3487), 1,
      anon_sym_SLASH,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3481), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3489), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(145), 3,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
    ACTIONS(3483), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(143), 9,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      sym_comma,
  [127892] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3463), 1,
      anon_sym_PLUS,
    ACTIONS(3465), 1,
      anon_sym_DASH,
    ACTIONS(3485), 1,
      anon_sym_STAR,
    ACTIONS(3487), 1,
      anon_sym_SLASH,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3481), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3489), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(145), 4,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(3483), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(143), 10,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      sym_comma,
  [127978] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3667), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1016), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [128084] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(191), 3,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [128186] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3669), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1018), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [128292] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(195), 3,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [128394] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3671), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(514), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [128500] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(199), 3,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [128602] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3673), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1029), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [128708] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3675), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1031), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [128814] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3463), 1,
      anon_sym_PLUS,
    ACTIONS(3465), 1,
      anon_sym_DASH,
    ACTIONS(3485), 1,
      anon_sym_STAR,
    ACTIONS(3487), 1,
      anon_sym_SLASH,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3489), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(145), 6,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(143), 14,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      sym_comma,
  [128896] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3489), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(145), 8,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
    ACTIONS(143), 16,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      sym_comma,
  [128970] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3677), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1039), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [129076] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(203), 3,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [129178] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3679), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1041), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [129284] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(207), 3,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [129386] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    ACTIONS(3491), 1,
      anon_sym_COLON,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(145), 8,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
    ACTIONS(143), 18,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      sym_comma,
  [129458] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(211), 3,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [129560] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3681), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1050), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [129666] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(215), 3,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [129768] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3683), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1052), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [129874] = 32,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    ACTIONS(3493), 1,
      anon_sym_QMARK,
    ACTIONS(3685), 1,
      sym__external_close_parenthesis,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(506), 1,
      sym__close_parenthesis,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [129980] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3409), 1,
      sym__external_open_parenthesis,
    ACTIONS(3411), 1,
      sym__external_open_bracket,
    ACTIONS(3413), 1,
      sym__external_open_bracket2,
    STATE(265), 1,
      sym__open_parenthesis,
    STATE(266), 1,
      sym__open_bracket,
    STATE(267), 1,
      sym__open_bracket2,
    STATE(1727), 1,
      sym_subset2_arguments,
    STATE(1801), 1,
      sym_call_arguments,
    STATE(1803), 1,
      sym_subset_arguments,
    ACTIONS(3405), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3407), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(145), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(143), 18,
      sym__external_close_bracket,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      sym_comma,
  [130050] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(219), 3,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [130152] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(223), 3,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [130254] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3415), 1,
      anon_sym_EQ,
    ACTIONS(3417), 1,
      anon_sym_TILDE,
    ACTIONS(3419), 1,
      anon_sym_PLUS,
    ACTIONS(3421), 1,
      anon_sym_DASH,
    ACTIONS(3425), 1,
      anon_sym_DASH_GT,
    ACTIONS(3427), 1,
      anon_sym_DASH_GT_GT,
    ACTIONS(3429), 1,
      anon_sym_PIPE,
    ACTIONS(3431), 1,
      anon_sym_AMP,
    ACTIONS(3433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3435), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3441), 1,
      anon_sym_STAR,
    ACTIONS(3443), 1,
      anon_sym_SLASH,
    ACTIONS(3449), 1,
      anon_sym_COLON,
    ACTIONS(3453), 1,
      sym__external_open_parenthesis,
    ACTIONS(3455), 1,
      sym__external_open_bracket,
    ACTIONS(3457), 1,
      sym__external_open_bracket2,
    STATE(258), 1,
      sym__open_parenthesis,
    STATE(259), 1,
      sym__open_bracket,
    STATE(260), 1,
      sym__open_bracket2,
    STATE(1756), 1,
      sym_call_arguments,
    STATE(1758), 1,
      sym_subset_arguments,
    STATE(1759), 1,
      sym_subset2_arguments,
    ACTIONS(3437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(3445), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3447), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3451), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(227), 3,
      sym__external_close_parenthesis,
      anon_sym_QMARK,
      sym_comma,
    ACTIONS(3423), 3,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
    ACTIONS(3439), 4,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [130356] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3531), 1,
      anon_sym_STAR,
    ACTIONS(3533), 1,
      anon_sym_SLASH,
    ACTIONS(3539), 1,
      anon_sym_COLON,
    ACTIONS(3543), 1,
      sym__external_open_parenthesis,
    ACTIONS(3545), 1,
      sym__external_open_bracket,
    ACTIONS(3547), 1,
      sym__external_open_bracket2,
    STATE(268), 1,
      sym__open_parenthesis,
    STATE(269), 1,
      sym__open_bracket,
    STATE(270), 1,
      sym__open_bracket2,
    STATE(1753), 1,
      sym_call_arguments,
    STATE(1754), 1,
      sym_subset_arguments,
    STATE(1757), 1,
      sym_subset2_arguments,
    ACTIONS(3535), 2,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
    ACTIONS(3537), 2,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
    ACTIONS(3541), 2,
      anon_sym_DOLLAR,
      anon_sym_AT,
    ACTIONS(181), 7,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(179), 15,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      sym_comma,
  [130434] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(609), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(607), 27,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [130479] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(637), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(635), 27,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [130524] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(633), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(631), 27,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [130569] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(643), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(641), 27,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [130614] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(647), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(645), 27,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [130659] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(651), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(649), 27,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [130704] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(613), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(611), 27,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [130749] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(633), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(631), 27,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [130794] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(637), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(635), 27,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [130839] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3687), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3689), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(617), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(615), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [130888] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3691), 1,
      anon_sym_L,
    ACTIONS(3693), 1,
      anon_sym_i,
    ACTIONS(625), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(623), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [130937] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(651), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(649), 27,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [130982] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(613), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(611), 27,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [131027] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(633), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(631), 27,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [131072] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(609), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(607), 27,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [131117] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(643), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(641), 27,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [131162] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(647), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(645), 27,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [131207] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(651), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(649), 27,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [131252] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3695), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3697), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(617), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(615), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [131301] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3699), 1,
      anon_sym_L,
    ACTIONS(3701), 1,
      anon_sym_i,
    ACTIONS(625), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(623), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [131350] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(609), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(607), 27,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [131395] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(609), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(607), 27,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [131440] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(609), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(607), 27,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [131485] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(637), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(635), 27,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [131530] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(613), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(611), 27,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [131575] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3703), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3705), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(617), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(615), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [131624] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3707), 1,
      anon_sym_L,
    ACTIONS(3709), 1,
      anon_sym_i,
    ACTIONS(625), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(623), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [131673] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(609), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(607), 27,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [131718] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(609), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(607), 27,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [131763] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(643), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(641), 27,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [131808] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(647), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(645), 27,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [131853] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(609), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(607), 27,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [131898] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(609), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(607), 27,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [131943] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(609), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(607), 26,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [131987] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(647), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(645), 26,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [132031] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(609), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(607), 26,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [132075] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(613), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(611), 26,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [132119] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(633), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(631), 26,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [132163] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(651), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(649), 26,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [132207] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(357), 15,
      sym__newline,
      sym__semicolon,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      sym__external_close_brace,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(355), 21,
      anon_sym_function,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
  [132251] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(613), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(611), 26,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [132295] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(633), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(631), 26,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [132339] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3711), 1,
      anon_sym_L,
    ACTIONS(3713), 1,
      anon_sym_i,
    ACTIONS(625), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(623), 25,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [132387] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(609), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(607), 26,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [132431] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(609), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(607), 26,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [132475] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(609), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(607), 26,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [132519] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3715), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3717), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(617), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(615), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [132567] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(637), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(635), 26,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [132611] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(609), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(607), 26,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [132655] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3719), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3721), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(617), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(615), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [132703] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3715), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3717), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(3723), 1,
      anon_sym_EQ,
    ACTIONS(617), 8,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(615), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [132753] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3723), 1,
      anon_sym_EQ,
    ACTIONS(3725), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3727), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(617), 8,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(615), 25,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [132803] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3719), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3721), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(3723), 1,
      anon_sym_EQ,
    ACTIONS(617), 8,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(615), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [132853] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(637), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(635), 26,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [132897] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3729), 1,
      anon_sym_L,
    ACTIONS(3731), 1,
      anon_sym_i,
    ACTIONS(625), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(623), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [132945] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(609), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(607), 26,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [132989] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3725), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3727), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(617), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(615), 25,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [133037] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(609), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(607), 26,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [133081] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(643), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(641), 26,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [133125] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(647), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(645), 26,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [133169] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(643), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(641), 26,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [133213] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(651), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(649), 26,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [133257] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(643), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(641), 26,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [133301] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(651), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(649), 26,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [133345] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(647), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(645), 26,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [133389] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3733), 1,
      anon_sym_L,
    ACTIONS(3735), 1,
      anon_sym_i,
    ACTIONS(625), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(623), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [133437] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(613), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(611), 26,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [133481] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(609), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(607), 26,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [133525] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(637), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(635), 26,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [133569] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(633), 10,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(631), 26,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      anon_sym_COLON_COLON_COLON,
      sym_comma,
  [133613] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(745), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(747), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [133656] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(761), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(763), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [133699] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(739), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(737), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [133742] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(767), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(765), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [133785] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(771), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(769), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [133828] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(775), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(773), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [133871] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(786), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(784), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [133914] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(794), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(792), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [133957] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(798), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(796), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [134000] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(812), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(814), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [134043] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(802), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(800), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [134086] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(806), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(804), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [134129] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(808), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(810), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [134172] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(790), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(788), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [134215] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(725), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(727), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [134258] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(741), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(743), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [134301] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(749), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(751), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [134344] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(753), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(755), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [134387] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(790), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(788), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [134430] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(757), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(759), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [134473] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(761), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(763), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [134516] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(818), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(816), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [134559] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(822), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(820), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [134602] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3737), 1,
      sym__newline,
    STATE(1677), 1,
      aux_sym_function_definition_repeat1,
    ACTIONS(671), 12,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(669), 21,
      anon_sym_function,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
  [134649] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(818), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(816), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [134692] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(826), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(824), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [134735] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(830), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(828), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [134778] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(812), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(814), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [134821] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(725), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(727), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [134864] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(739), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(737), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [134907] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(767), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(765), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [134950] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(771), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(769), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [134993] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(818), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(816), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [135036] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(822), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(820), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [135079] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(775), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(773), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [135122] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(786), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(784), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [135165] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(794), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(792), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [135208] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(733), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(735), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [135251] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(798), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(796), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [135294] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(830), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(828), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [135337] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(812), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(814), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [135380] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(725), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(727), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [135423] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(822), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(820), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [135466] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(802), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(800), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [135509] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(806), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(804), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [135552] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(808), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(810), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [135595] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(733), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(735), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [135638] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(733), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(735), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [135681] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(741), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(743), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [135724] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(745), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(747), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [135767] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(749), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(751), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [135810] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(753), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(755), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [135853] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(757), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(759), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [135896] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(761), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(763), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [135939] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(790), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(788), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [135982] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(826), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(824), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [136025] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(739), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(737), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [136068] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(767), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(765), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [136111] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(771), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(769), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [136154] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(775), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(773), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [136197] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(786), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(784), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [136240] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(794), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(792), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [136283] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(798), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(796), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [136326] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(802), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(800), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [136369] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(806), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(804), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [136412] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(808), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(810), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [136455] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(830), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(828), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [136498] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(741), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(743), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [136541] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(745), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(747), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [136584] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(749), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(751), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [136627] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(753), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(755), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [136670] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(757), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(759), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [136713] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(826), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(824), 26,
      sym__external_else,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [136756] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(812), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(814), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [136798] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(749), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(751), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [136840] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(806), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(804), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [136882] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(808), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(810), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [136924] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(818), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(816), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [136966] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(790), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(788), 25,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [137008] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(822), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(820), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [137050] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(733), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(735), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [137092] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(741), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(743), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [137134] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(745), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(747), 25,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [137176] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(749), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(751), 25,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [137218] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(753), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(755), 25,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [137260] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(775), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(773), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [137302] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(790), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(788), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [137344] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(757), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(759), 25,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [137386] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(739), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(737), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [137428] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(761), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(763), 25,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [137470] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(753), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(755), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [137512] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(767), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(765), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [137554] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(761), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(763), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [137596] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(771), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(769), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [137638] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3723), 1,
      anon_sym_EQ,
    ACTIONS(617), 8,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(615), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [137682] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(775), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(773), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [137724] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(786), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(784), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [137766] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(818), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(816), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [137808] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(822), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(820), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [137850] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(826), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(824), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [137892] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(830), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(828), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [137934] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(794), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(792), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [137976] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(826), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(824), 25,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [138018] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(812), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(814), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [138060] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(830), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(828), 25,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [138102] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(812), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(814), 25,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [138144] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(725), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(727), 25,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [138186] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3723), 1,
      anon_sym_EQ,
    ACTIONS(617), 8,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(615), 25,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [138230] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(798), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(796), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [138272] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(757), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(759), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [138314] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(725), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(727), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [138356] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(786), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(784), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [138398] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(733), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(735), 25,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [138440] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(794), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(792), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [138482] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(739), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(737), 25,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [138524] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(739), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(737), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [138566] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(798), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(796), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [138608] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(733), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(735), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [138650] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(767), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(765), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [138692] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(767), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(765), 25,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [138734] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(757), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(759), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [138776] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(771), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(769), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [138818] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(741), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(743), 25,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [138860] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(771), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(769), 25,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [138902] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(775), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(773), 25,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [138944] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(802), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(800), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [138986] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(786), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(784), 25,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [139028] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(794), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(792), 25,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [139070] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(798), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(796), 25,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [139112] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3742), 13,
      sym__newline,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(3740), 21,
      anon_sym_function,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
  [139154] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(806), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(804), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [139196] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(818), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(816), 25,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [139238] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(808), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(810), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [139280] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(761), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(763), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [139322] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(802), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(800), 25,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [139364] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(806), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(804), 25,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [139406] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(725), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(727), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [139448] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(808), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(810), 25,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [139490] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(822), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(820), 25,
      sym__external_open_parenthesis,
      sym__external_close_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [139532] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3746), 13,
      sym__newline,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(3744), 21,
      anon_sym_function,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
  [139574] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3723), 1,
      anon_sym_EQ,
    ACTIONS(617), 8,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(615), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [139618] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(790), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(788), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [139660] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3750), 13,
      sym__newline,
      sym__raw_string_open,
      sym__external_open_parenthesis,
      sym__external_open_brace,
      anon_sym_BSLASH,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      sym__hex_literal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(3748), 21,
      anon_sym_function,
      anon_sym_if,
      anon_sym_for,
      anon_sym_while,
      anon_sym_repeat,
      sym__number_literal,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
      sym_next,
      sym_break,
      sym_true,
      sym_false,
      sym_null,
      sym_inf,
      sym_nan,
      anon_sym_NA,
      anon_sym_NA_integer_,
      anon_sym_NA_real_,
      anon_sym_NA_complex_,
      anon_sym_NA_character_,
  [139702] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(741), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(743), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [139744] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(802), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(800), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [139786] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(745), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(747), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [139828] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(749), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(751), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [139870] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(826), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(824), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [139912] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(753), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(755), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [139954] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(830), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(828), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_close_bracket,
      sym__external_open_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [139996] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(745), 9,
      anon_sym_EQ,
      anon_sym_DASH,
      anon_sym_DASH_GT,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_COLON,
    ACTIONS(747), 25,
      sym__external_open_parenthesis,
      sym__external_open_bracket,
      sym__external_open_bracket2,
      sym__external_close_bracket2,
      anon_sym_QMARK,
      anon_sym_TILDE,
      anon_sym_PLUS,
      anon_sym_LT_DASH,
      anon_sym_LT_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_DASH_GT_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SLASH,
      anon_sym_STAR_STAR,
      anon_sym_CARET,
      aux_sym_binary_operator_token1,
      anon_sym_PIPE_GT,
      anon_sym_DOLLAR,
      anon_sym_AT,
      sym_comma,
  [140038] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3754), 1,
      sym__external_close_parenthesis,
    STATE(1783), 1,
      sym__close_parenthesis,
    STATE(1923), 1,
      sym_parameter,
    STATE(2032), 1,
      sym__parameter_name,
    STATE(2050), 1,
      sym__parameter_without_default,
    STATE(2064), 1,
      sym__parameter_with_default,
    ACTIONS(3752), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
  [140065] = 6,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2032), 1,
      sym__parameter_name,
    STATE(2050), 1,
      sym__parameter_without_default,
    STATE(2064), 1,
      sym__parameter_with_default,
    STATE(2074), 1,
      sym_parameter,
    ACTIONS(3752), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
  [140086] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3756), 1,
      sym__newline,
    ACTIONS(3758), 1,
      sym__external_open_parenthesis,
    STATE(769), 1,
      sym_parameters,
    STATE(1805), 1,
      sym__open_parenthesis,
    STATE(1821), 1,
      aux_sym_function_definition_repeat1,
  [140105] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3758), 1,
      sym__external_open_parenthesis,
    ACTIONS(3760), 1,
      sym__newline,
    STATE(515), 1,
      sym_parameters,
    STATE(1805), 1,
      sym__open_parenthesis,
    STATE(1814), 1,
      aux_sym_function_definition_repeat1,
  [140124] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3758), 1,
      sym__external_open_parenthesis,
    ACTIONS(3762), 1,
      sym__newline,
    STATE(715), 1,
      sym_parameters,
    STATE(1805), 1,
      sym__open_parenthesis,
    STATE(1820), 1,
      aux_sym_function_definition_repeat1,
  [140143] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3758), 1,
      sym__external_open_parenthesis,
    ACTIONS(3764), 1,
      sym__newline,
    STATE(857), 1,
      sym_parameters,
    STATE(1805), 1,
      sym__open_parenthesis,
    STATE(2048), 1,
      aux_sym_function_definition_repeat1,
  [140162] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3758), 1,
      sym__external_open_parenthesis,
    ACTIONS(3766), 1,
      sym__newline,
    STATE(566), 1,
      sym_parameters,
    STATE(1805), 1,
      sym__open_parenthesis,
    STATE(1823), 1,
      aux_sym_function_definition_repeat1,
  [140181] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3758), 1,
      sym__external_open_parenthesis,
    ACTIONS(3764), 1,
      sym__newline,
    STATE(1049), 1,
      sym_parameters,
    STATE(1805), 1,
      sym__open_parenthesis,
    STATE(2048), 1,
      aux_sym_function_definition_repeat1,
  [140200] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3758), 1,
      sym__external_open_parenthesis,
    ACTIONS(3768), 1,
      sym__newline,
    STATE(655), 1,
      sym_parameters,
    STATE(1805), 1,
      sym__open_parenthesis,
    STATE(1818), 1,
      aux_sym_function_definition_repeat1,
  [140219] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3758), 1,
      sym__external_open_parenthesis,
    ACTIONS(3764), 1,
      sym__newline,
    STATE(535), 1,
      sym_parameters,
    STATE(1805), 1,
      sym__open_parenthesis,
    STATE(2048), 1,
      aux_sym_function_definition_repeat1,
  [140238] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3758), 1,
      sym__external_open_parenthesis,
    ACTIONS(3770), 1,
      sym__newline,
    STATE(888), 1,
      sym_parameters,
    STATE(1805), 1,
      sym__open_parenthesis,
    STATE(1822), 1,
      aux_sym_function_definition_repeat1,
  [140257] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3758), 1,
      sym__external_open_parenthesis,
    ACTIONS(3772), 1,
      sym__newline,
    STATE(490), 1,
      sym_parameters,
    STATE(1805), 1,
      sym__open_parenthesis,
    STATE(1826), 1,
      aux_sym_function_definition_repeat1,
  [140276] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3758), 1,
      sym__external_open_parenthesis,
    ACTIONS(3774), 1,
      sym__newline,
    STATE(947), 1,
      sym_parameters,
    STATE(1805), 1,
      sym__open_parenthesis,
    STATE(1812), 1,
      aux_sym_function_definition_repeat1,
  [140295] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3758), 1,
      sym__external_open_parenthesis,
    ACTIONS(3764), 1,
      sym__newline,
    STATE(691), 1,
      sym_parameters,
    STATE(1805), 1,
      sym__open_parenthesis,
    STATE(2048), 1,
      aux_sym_function_definition_repeat1,
  [140314] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3758), 1,
      sym__external_open_parenthesis,
    ACTIONS(3776), 1,
      sym__newline,
    STATE(624), 1,
      sym_parameters,
    STATE(1805), 1,
      sym__open_parenthesis,
    STATE(1825), 1,
      aux_sym_function_definition_repeat1,
  [140333] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3758), 1,
      sym__external_open_parenthesis,
    ACTIONS(3764), 1,
      sym__newline,
    STATE(734), 1,
      sym_parameters,
    STATE(1805), 1,
      sym__open_parenthesis,
    STATE(2048), 1,
      aux_sym_function_definition_repeat1,
  [140352] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3758), 1,
      sym__external_open_parenthesis,
    ACTIONS(3764), 1,
      sym__newline,
    STATE(789), 1,
      sym_parameters,
    STATE(1805), 1,
      sym__open_parenthesis,
    STATE(2048), 1,
      aux_sym_function_definition_repeat1,
  [140371] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3758), 1,
      sym__external_open_parenthesis,
    ACTIONS(3764), 1,
      sym__newline,
    STATE(908), 1,
      sym_parameters,
    STATE(1805), 1,
      sym__open_parenthesis,
    STATE(2048), 1,
      aux_sym_function_definition_repeat1,
  [140390] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3758), 1,
      sym__external_open_parenthesis,
    ACTIONS(3764), 1,
      sym__newline,
    STATE(586), 1,
      sym_parameters,
    STATE(1805), 1,
      sym__open_parenthesis,
    STATE(2048), 1,
      aux_sym_function_definition_repeat1,
  [140409] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3758), 1,
      sym__external_open_parenthesis,
    ACTIONS(3778), 1,
      sym__newline,
    STATE(838), 1,
      sym_parameters,
    STATE(1805), 1,
      sym__open_parenthesis,
    STATE(1810), 1,
      aux_sym_function_definition_repeat1,
  [140428] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3758), 1,
      sym__external_open_parenthesis,
    ACTIONS(3764), 1,
      sym__newline,
    STATE(654), 1,
      sym_parameters,
    STATE(1805), 1,
      sym__open_parenthesis,
    STATE(2048), 1,
      aux_sym_function_definition_repeat1,
  [140447] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3758), 1,
      sym__external_open_parenthesis,
    ACTIONS(3764), 1,
      sym__newline,
    STATE(502), 1,
      sym_parameters,
    STATE(1805), 1,
      sym__open_parenthesis,
    STATE(2048), 1,
      aux_sym_function_definition_repeat1,
  [140466] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3780), 1,
      sym__newline,
    ACTIONS(3782), 1,
      sym__external_open_parenthesis,
    STATE(1122), 1,
      sym__open_parenthesis,
    STATE(1997), 1,
      aux_sym_function_definition_repeat1,
  [140482] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(415), 1,
      sym_comma,
    ACTIONS(3784), 1,
      sym__external_close_bracket,
    STATE(1784), 1,
      sym__close_bracket,
    STATE(2029), 1,
      aux_sym_call_arguments_repeat1,
  [140498] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(415), 1,
      sym_comma,
    ACTIONS(3786), 1,
      sym__external_close_bracket,
    STATE(1778), 1,
      sym__close_bracket,
    STATE(1910), 1,
      aux_sym_call_arguments_repeat1,
  [140514] = 4,
    ACTIONS(3788), 1,
      anon_sym_SQUOTE,
    ACTIONS(3792), 1,
      sym_comment,
    STATE(1834), 1,
      aux_sym__single_quoted_string_content,
    ACTIONS(3790), 2,
      aux_sym__single_quoted_string_content_token1,
      sym_escape_sequence,
  [140528] = 4,
    ACTIONS(3792), 1,
      sym_comment,
    ACTIONS(3794), 1,
      anon_sym_DQUOTE,
    STATE(1835), 1,
      aux_sym__double_quoted_string_content,
    ACTIONS(3796), 2,
      aux_sym__double_quoted_string_content_token1,
      sym_escape_sequence,
  [140542] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(415), 1,
      sym_comma,
    ACTIONS(3798), 1,
      sym__external_close_bracket,
    STATE(1780), 1,
      sym__close_bracket,
    STATE(2029), 1,
      aux_sym_call_arguments_repeat1,
  [140558] = 4,
    ACTIONS(3792), 1,
      sym_comment,
    ACTIONS(3800), 1,
      anon_sym_SQUOTE,
    STATE(1844), 1,
      aux_sym__single_quoted_string_content,
    ACTIONS(3790), 2,
      aux_sym__single_quoted_string_content_token1,
      sym_escape_sequence,
  [140572] = 4,
    ACTIONS(3792), 1,
      sym_comment,
    ACTIONS(3802), 1,
      anon_sym_SQUOTE,
    STATE(1952), 1,
      aux_sym__single_quoted_string_content,
    ACTIONS(3790), 2,
      aux_sym__single_quoted_string_content_token1,
      sym_escape_sequence,
  [140586] = 4,
    ACTIONS(3792), 1,
      sym_comment,
    ACTIONS(3804), 1,
      anon_sym_DQUOTE,
    STATE(1961), 1,
      aux_sym__double_quoted_string_content,
    ACTIONS(3796), 2,
      aux_sym__double_quoted_string_content_token1,
      sym_escape_sequence,
  [140600] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(477), 1,
      sym_comma,
    ACTIONS(3806), 1,
      sym__external_close_bracket2,
    STATE(1781), 1,
      sym__close_bracket2,
    STATE(1913), 1,
      aux_sym_call_arguments_repeat1,
  [140616] = 4,
    ACTIONS(3792), 1,
      sym_comment,
    ACTIONS(3808), 1,
      anon_sym_DQUOTE,
    STATE(1845), 1,
      aux_sym__double_quoted_string_content,
    ACTIONS(3796), 2,
      aux_sym__double_quoted_string_content_token1,
      sym_escape_sequence,
  [140630] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(477), 1,
      sym_comma,
    ACTIONS(3810), 1,
      sym__external_close_bracket2,
    STATE(1782), 1,
      sym__close_bracket2,
    STATE(2049), 1,
      aux_sym_call_arguments_repeat1,
  [140646] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3764), 1,
      sym__newline,
    ACTIONS(3812), 1,
      sym__external_open_parenthesis,
    STATE(2023), 1,
      sym__open_parenthesis,
    STATE(2048), 1,
      aux_sym_function_definition_repeat1,
  [140662] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(533), 1,
      sym_comma,
    ACTIONS(3814), 1,
      sym__external_close_parenthesis,
    STATE(1658), 1,
      sym__close_parenthesis,
    STATE(2035), 1,
      aux_sym_call_arguments_repeat1,
  [140678] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(477), 1,
      sym_comma,
    ACTIONS(3816), 1,
      sym__external_close_bracket2,
    STATE(370), 1,
      sym__close_bracket2,
    STATE(2049), 1,
      aux_sym_call_arguments_repeat1,
  [140694] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(533), 1,
      sym_comma,
    ACTIONS(3818), 1,
      sym__external_close_parenthesis,
    STATE(434), 1,
      sym__close_parenthesis,
    STATE(2035), 1,
      aux_sym_call_arguments_repeat1,
  [140710] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(533), 1,
      sym_comma,
    ACTIONS(3820), 1,
      sym__external_close_parenthesis,
    STATE(1664), 1,
      sym__close_parenthesis,
    STATE(2035), 1,
      aux_sym_call_arguments_repeat1,
  [140726] = 4,
    ACTIONS(3792), 1,
      sym_comment,
    ACTIONS(3822), 1,
      anon_sym_SQUOTE,
    STATE(1952), 1,
      aux_sym__single_quoted_string_content,
    ACTIONS(3790), 2,
      aux_sym__single_quoted_string_content_token1,
      sym_escape_sequence,
  [140740] = 4,
    ACTIONS(3792), 1,
      sym_comment,
    ACTIONS(3824), 1,
      anon_sym_DQUOTE,
    STATE(1961), 1,
      aux_sym__double_quoted_string_content,
    ACTIONS(3796), 2,
      aux_sym__double_quoted_string_content_token1,
      sym_escape_sequence,
  [140754] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(533), 1,
      sym_comma,
    ACTIONS(3826), 1,
      sym__external_close_parenthesis,
    STATE(1788), 1,
      sym__close_parenthesis,
    STATE(2035), 1,
      aux_sym_call_arguments_repeat1,
  [140770] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(477), 1,
      sym_comma,
    ACTIONS(3828), 1,
      sym__external_close_bracket2,
    STATE(1786), 1,
      sym__close_bracket2,
    STATE(2049), 1,
      aux_sym_call_arguments_repeat1,
  [140786] = 4,
    ACTIONS(3792), 1,
      sym_comment,
    ACTIONS(3830), 1,
      anon_sym_SQUOTE,
    STATE(1857), 1,
      aux_sym__single_quoted_string_content,
    ACTIONS(3790), 2,
      aux_sym__single_quoted_string_content_token1,
      sym_escape_sequence,
  [140800] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(533), 1,
      sym_comma,
    ACTIONS(3832), 1,
      sym__external_close_parenthesis,
    STATE(1772), 1,
      sym__close_parenthesis,
    STATE(1855), 1,
      aux_sym_call_arguments_repeat1,
  [140816] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(533), 1,
      sym_comma,
    ACTIONS(3834), 1,
      sym__external_close_parenthesis,
    STATE(1775), 1,
      sym__close_parenthesis,
    STATE(2035), 1,
      aux_sym_call_arguments_repeat1,
  [140832] = 4,
    ACTIONS(3792), 1,
      sym_comment,
    ACTIONS(3836), 1,
      anon_sym_SQUOTE,
    STATE(1853), 1,
      aux_sym__single_quoted_string_content,
    ACTIONS(3790), 2,
      aux_sym__single_quoted_string_content_token1,
      sym_escape_sequence,
  [140846] = 4,
    ACTIONS(3792), 1,
      sym_comment,
    ACTIONS(3838), 1,
      anon_sym_DQUOTE,
    STATE(1854), 1,
      aux_sym__double_quoted_string_content,
    ACTIONS(3796), 2,
      aux_sym__double_quoted_string_content_token1,
      sym_escape_sequence,
  [140860] = 4,
    ACTIONS(3792), 1,
      sym_comment,
    ACTIONS(3840), 1,
      anon_sym_SQUOTE,
    STATE(1952), 1,
      aux_sym__single_quoted_string_content,
    ACTIONS(3790), 2,
      aux_sym__single_quoted_string_content_token1,
      sym_escape_sequence,
  [140874] = 4,
    ACTIONS(3792), 1,
      sym_comment,
    ACTIONS(3842), 1,
      anon_sym_DQUOTE,
    STATE(1961), 1,
      aux_sym__double_quoted_string_content,
    ACTIONS(3796), 2,
      aux_sym__double_quoted_string_content_token1,
      sym_escape_sequence,
  [140888] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(533), 1,
      sym_comma,
    ACTIONS(3844), 1,
      sym__external_close_parenthesis,
    STATE(1798), 1,
      sym__close_parenthesis,
    STATE(2035), 1,
      aux_sym_call_arguments_repeat1,
  [140904] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(477), 1,
      sym_comma,
    ACTIONS(3846), 1,
      sym__external_close_bracket2,
    STATE(1666), 1,
      sym__close_bracket2,
    STATE(2049), 1,
      aux_sym_call_arguments_repeat1,
  [140920] = 4,
    ACTIONS(3792), 1,
      sym_comment,
    ACTIONS(3848), 1,
      anon_sym_SQUOTE,
    STATE(1952), 1,
      aux_sym__single_quoted_string_content,
    ACTIONS(3790), 2,
      aux_sym__single_quoted_string_content_token1,
      sym_escape_sequence,
  [140934] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(533), 1,
      sym_comma,
    ACTIONS(3850), 1,
      sym__external_close_parenthesis,
    STATE(360), 1,
      sym__close_parenthesis,
    STATE(1862), 1,
      aux_sym_call_arguments_repeat1,
  [140950] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(533), 1,
      sym_comma,
    ACTIONS(3852), 1,
      sym__external_close_parenthesis,
    STATE(361), 1,
      sym__close_parenthesis,
    STATE(2035), 1,
      aux_sym_call_arguments_repeat1,
  [140966] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(415), 1,
      sym_comma,
    ACTIONS(3854), 1,
      sym__external_close_bracket,
    STATE(1688), 1,
      sym__close_bracket,
    STATE(1931), 1,
      aux_sym_call_arguments_repeat1,
  [140982] = 4,
    ACTIONS(3792), 1,
      sym_comment,
    ACTIONS(3856), 1,
      anon_sym_DQUOTE,
    STATE(1961), 1,
      aux_sym__double_quoted_string_content,
    ACTIONS(3796), 2,
      aux_sym__double_quoted_string_content_token1,
      sym_escape_sequence,
  [140996] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(533), 1,
      sym_comma,
    ACTIONS(3858), 1,
      sym__external_close_parenthesis,
    STATE(367), 1,
      sym__close_parenthesis,
    STATE(2035), 1,
      aux_sym_call_arguments_repeat1,
  [141012] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(415), 1,
      sym_comma,
    ACTIONS(3860), 1,
      sym__external_close_bracket,
    STATE(1689), 1,
      sym__close_bracket,
    STATE(2029), 1,
      aux_sym_call_arguments_repeat1,
  [141028] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(477), 1,
      sym_comma,
    ACTIONS(3862), 1,
      sym__external_close_bracket2,
    STATE(1690), 1,
      sym__close_bracket2,
    STATE(1956), 1,
      aux_sym_call_arguments_repeat1,
  [141044] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(415), 1,
      sym_comma,
    ACTIONS(3864), 1,
      sym__external_close_bracket,
    STATE(366), 1,
      sym__close_bracket,
    STATE(2029), 1,
      aux_sym_call_arguments_repeat1,
  [141060] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(415), 1,
      sym_comma,
    ACTIONS(3866), 1,
      sym__external_close_bracket,
    STATE(1713), 1,
      sym__close_bracket,
    STATE(1911), 1,
      aux_sym_call_arguments_repeat1,
  [141076] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(415), 1,
      sym_comma,
    ACTIONS(3868), 1,
      sym__external_close_bracket,
    STATE(1714), 1,
      sym__close_bracket,
    STATE(2029), 1,
      aux_sym_call_arguments_repeat1,
  [141092] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(477), 1,
      sym_comma,
    ACTIONS(3870), 1,
      sym__external_close_bracket2,
    STATE(1715), 1,
      sym__close_bracket2,
    STATE(1917), 1,
      aux_sym_call_arguments_repeat1,
  [141108] = 4,
    ACTIONS(3792), 1,
      sym_comment,
    ACTIONS(3872), 1,
      anon_sym_SQUOTE,
    STATE(1873), 1,
      aux_sym__single_quoted_string_content,
    ACTIONS(3790), 2,
      aux_sym__single_quoted_string_content_token1,
      sym_escape_sequence,
  [141122] = 4,
    ACTIONS(3792), 1,
      sym_comment,
    ACTIONS(3874), 1,
      anon_sym_DQUOTE,
    STATE(1874), 1,
      aux_sym__double_quoted_string_content,
    ACTIONS(3796), 2,
      aux_sym__double_quoted_string_content_token1,
      sym_escape_sequence,
  [141136] = 4,
    ACTIONS(3792), 1,
      sym_comment,
    ACTIONS(3876), 1,
      anon_sym_SQUOTE,
    STATE(1888), 1,
      aux_sym__single_quoted_string_content,
    ACTIONS(3790), 2,
      aux_sym__single_quoted_string_content_token1,
      sym_escape_sequence,
  [141150] = 4,
    ACTIONS(3792), 1,
      sym_comment,
    ACTIONS(3878), 1,
      anon_sym_SQUOTE,
    STATE(1885), 1,
      aux_sym__single_quoted_string_content,
    ACTIONS(3790), 2,
      aux_sym__single_quoted_string_content_token1,
      sym_escape_sequence,
  [141164] = 4,
    ACTIONS(3792), 1,
      sym_comment,
    ACTIONS(3880), 1,
      anon_sym_SQUOTE,
    STATE(1952), 1,
      aux_sym__single_quoted_string_content,
    ACTIONS(3790), 2,
      aux_sym__single_quoted_string_content_token1,
      sym_escape_sequence,
  [141178] = 4,
    ACTIONS(3792), 1,
      sym_comment,
    ACTIONS(3882), 1,
      anon_sym_DQUOTE,
    STATE(1961), 1,
      aux_sym__double_quoted_string_content,
    ACTIONS(3796), 2,
      aux_sym__double_quoted_string_content_token1,
      sym_escape_sequence,
  [141192] = 4,
    ACTIONS(3792), 1,
      sym_comment,
    ACTIONS(3884), 1,
      anon_sym_DQUOTE,
    STATE(1886), 1,
      aux_sym__double_quoted_string_content,
    ACTIONS(3796), 2,
      aux_sym__double_quoted_string_content_token1,
      sym_escape_sequence,
  [141206] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(477), 1,
      sym_comma,
    ACTIONS(3886), 1,
      sym__external_close_bracket2,
    STATE(1716), 1,
      sym__close_bracket2,
    STATE(2049), 1,
      aux_sym_call_arguments_repeat1,
  [141222] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(533), 1,
      sym_comma,
    ACTIONS(3888), 1,
      sym__external_close_parenthesis,
    STATE(448), 1,
      sym__close_parenthesis,
    STATE(1842), 1,
      aux_sym_call_arguments_repeat1,
  [141238] = 4,
    ACTIONS(3792), 1,
      sym_comment,
    ACTIONS(3890), 1,
      anon_sym_DQUOTE,
    STATE(1891), 1,
      aux_sym__double_quoted_string_content,
    ACTIONS(3796), 2,
      aux_sym__double_quoted_string_content_token1,
      sym_escape_sequence,
  [141252] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(533), 1,
      sym_comma,
    ACTIONS(3892), 1,
      sym__external_close_parenthesis,
    STATE(1684), 1,
      sym__close_parenthesis,
    STATE(1883), 1,
      aux_sym_call_arguments_repeat1,
  [141268] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(533), 1,
      sym_comma,
    ACTIONS(3894), 1,
      sym__external_close_parenthesis,
    STATE(1685), 1,
      sym__close_parenthesis,
    STATE(2035), 1,
      aux_sym_call_arguments_repeat1,
  [141284] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3896), 1,
      sym__newline,
    ACTIONS(3898), 1,
      sym__external_open_parenthesis,
    STATE(1061), 1,
      sym__open_parenthesis,
    STATE(1928), 1,
      aux_sym_function_definition_repeat1,
  [141300] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3900), 1,
      sym_comma,
    ACTIONS(3902), 1,
      sym__external_close_parenthesis,
    STATE(1796), 1,
      sym__close_parenthesis,
    STATE(2041), 1,
      aux_sym_parameters_repeat1,
  [141316] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(533), 1,
      sym_comma,
    ACTIONS(3904), 1,
      sym__external_close_parenthesis,
    STATE(1697), 1,
      sym__close_parenthesis,
    STATE(2035), 1,
      aux_sym_call_arguments_repeat1,
  [141332] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(415), 1,
      sym_comma,
    ACTIONS(3906), 1,
      sym__external_close_bracket,
    STATE(1729), 1,
      sym__close_bracket,
    STATE(2029), 1,
      aux_sym_call_arguments_repeat1,
  [141348] = 4,
    ACTIONS(3792), 1,
      sym_comment,
    ACTIONS(3908), 1,
      anon_sym_SQUOTE,
    STATE(1952), 1,
      aux_sym__single_quoted_string_content,
    ACTIONS(3790), 2,
      aux_sym__single_quoted_string_content_token1,
      sym_escape_sequence,
  [141362] = 4,
    ACTIONS(3792), 1,
      sym_comment,
    ACTIONS(3910), 1,
      anon_sym_DQUOTE,
    STATE(1961), 1,
      aux_sym__double_quoted_string_content,
    ACTIONS(3796), 2,
      aux_sym__double_quoted_string_content_token1,
      sym_escape_sequence,
  [141376] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(415), 1,
      sym_comma,
    ACTIONS(3912), 1,
      sym__external_close_bracket,
    STATE(1749), 1,
      sym__close_bracket,
    STATE(1828), 1,
      aux_sym_call_arguments_repeat1,
  [141392] = 4,
    ACTIONS(3792), 1,
      sym_comment,
    ACTIONS(3914), 1,
      anon_sym_SQUOTE,
    STATE(1952), 1,
      aux_sym__single_quoted_string_content,
    ACTIONS(3790), 2,
      aux_sym__single_quoted_string_content_token1,
      sym_escape_sequence,
  [141406] = 4,
    ACTIONS(3792), 1,
      sym_comment,
    ACTIONS(3916), 1,
      anon_sym_SQUOTE,
    STATE(1892), 1,
      aux_sym__single_quoted_string_content,
    ACTIONS(3790), 2,
      aux_sym__single_quoted_string_content_token1,
      sym_escape_sequence,
  [141420] = 4,
    ACTIONS(3792), 1,
      sym_comment,
    ACTIONS(3918), 1,
      anon_sym_DQUOTE,
    STATE(1893), 1,
      aux_sym__double_quoted_string_content,
    ACTIONS(3796), 2,
      aux_sym__double_quoted_string_content_token1,
      sym_escape_sequence,
  [141434] = 4,
    ACTIONS(3792), 1,
      sym_comment,
    ACTIONS(3920), 1,
      anon_sym_DQUOTE,
    STATE(1961), 1,
      aux_sym__double_quoted_string_content,
    ACTIONS(3796), 2,
      aux_sym__double_quoted_string_content_token1,
      sym_escape_sequence,
  [141448] = 4,
    ACTIONS(3792), 1,
      sym_comment,
    ACTIONS(3922), 1,
      anon_sym_SQUOTE,
    STATE(1952), 1,
      aux_sym__single_quoted_string_content,
    ACTIONS(3790), 2,
      aux_sym__single_quoted_string_content_token1,
      sym_escape_sequence,
  [141462] = 4,
    ACTIONS(3792), 1,
      sym_comment,
    ACTIONS(3924), 1,
      anon_sym_DQUOTE,
    STATE(1961), 1,
      aux_sym__double_quoted_string_content,
    ACTIONS(3796), 2,
      aux_sym__double_quoted_string_content_token1,
      sym_escape_sequence,
  [141476] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(477), 1,
      sym_comma,
    ACTIONS(3926), 1,
      sym__external_close_bracket2,
    STATE(1692), 1,
      sym__close_bracket2,
    STATE(2049), 1,
      aux_sym_call_arguments_repeat1,
  [141492] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(477), 1,
      sym_comma,
    ACTIONS(3928), 1,
      sym__external_close_bracket2,
    STATE(1730), 1,
      sym__close_bracket2,
    STATE(2049), 1,
      aux_sym_call_arguments_repeat1,
  [141508] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(533), 1,
      sym_comma,
    ACTIONS(3930), 1,
      sym__external_close_parenthesis,
    STATE(1745), 1,
      sym__close_parenthesis,
    STATE(1903), 1,
      aux_sym_call_arguments_repeat1,
  [141524] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(533), 1,
      sym_comma,
    ACTIONS(3932), 1,
      sym__external_close_parenthesis,
    STATE(1711), 1,
      sym__close_parenthesis,
    STATE(1900), 1,
      aux_sym_call_arguments_repeat1,
  [141540] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(533), 1,
      sym_comma,
    ACTIONS(3934), 1,
      sym__external_close_parenthesis,
    STATE(1712), 1,
      sym__close_parenthesis,
    STATE(2035), 1,
      aux_sym_call_arguments_repeat1,
  [141556] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(533), 1,
      sym_comma,
    ACTIONS(3936), 1,
      sym__external_close_parenthesis,
    STATE(1747), 1,
      sym__close_parenthesis,
    STATE(2035), 1,
      aux_sym_call_arguments_repeat1,
  [141572] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(533), 1,
      sym_comma,
    ACTIONS(3938), 1,
      sym__external_close_parenthesis,
    STATE(1717), 1,
      sym__close_parenthesis,
    STATE(2035), 1,
      aux_sym_call_arguments_repeat1,
  [141588] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(415), 1,
      sym_comma,
    ACTIONS(3940), 1,
      sym__external_close_bracket,
    STATE(1665), 1,
      sym__close_bracket,
    STATE(2029), 1,
      aux_sym_call_arguments_repeat1,
  [141604] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(415), 1,
      sym_comma,
    ACTIONS(3942), 1,
      sym__external_close_bracket,
    STATE(407), 1,
      sym__close_bracket,
    STATE(2029), 1,
      aux_sym_call_arguments_repeat1,
  [141620] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(533), 1,
      sym_comma,
    ACTIONS(3944), 1,
      sym__external_close_parenthesis,
    STATE(1779), 1,
      sym__close_parenthesis,
    STATE(2035), 1,
      aux_sym_call_arguments_repeat1,
  [141636] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3946), 1,
      sym__newline,
    ACTIONS(3948), 1,
      sym__external_open_parenthesis,
    STATE(1062), 1,
      sym__open_parenthesis,
    STATE(1916), 1,
      aux_sym_function_definition_repeat1,
  [141652] = 4,
    ACTIONS(3792), 1,
      sym_comment,
    ACTIONS(3950), 1,
      anon_sym_DQUOTE,
    STATE(1961), 1,
      aux_sym__double_quoted_string_content,
    ACTIONS(3796), 2,
      aux_sym__double_quoted_string_content_token1,
      sym_escape_sequence,
  [141666] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(533), 1,
      sym_comma,
    ACTIONS(3952), 1,
      sym__external_close_parenthesis,
    STATE(440), 1,
      sym__close_parenthesis,
    STATE(1922), 1,
      aux_sym_call_arguments_repeat1,
  [141682] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(415), 1,
      sym_comma,
    ACTIONS(3954), 1,
      sym__external_close_bracket,
    STATE(362), 1,
      sym__close_bracket,
    STATE(1937), 1,
      aux_sym_call_arguments_repeat1,
  [141698] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(415), 1,
      sym_comma,
    ACTIONS(3956), 1,
      sym__external_close_bracket,
    STATE(363), 1,
      sym__close_bracket,
    STATE(2029), 1,
      aux_sym_call_arguments_repeat1,
  [141714] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(477), 1,
      sym_comma,
    ACTIONS(3958), 1,
      sym__external_close_bracket2,
    STATE(364), 1,
      sym__close_bracket2,
    STATE(1942), 1,
      aux_sym_call_arguments_repeat1,
  [141730] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(415), 1,
      sym_comma,
    ACTIONS(3960), 1,
      sym__external_close_bracket,
    STATE(1789), 1,
      sym__close_bracket,
    STATE(2029), 1,
      aux_sym_call_arguments_repeat1,
  [141746] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(415), 1,
      sym_comma,
    ACTIONS(3962), 1,
      sym__external_close_bracket,
    STATE(1718), 1,
      sym__close_bracket,
    STATE(2029), 1,
      aux_sym_call_arguments_repeat1,
  [141762] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(477), 1,
      sym_comma,
    ACTIONS(3964), 1,
      sym__external_close_bracket2,
    STATE(365), 1,
      sym__close_bracket2,
    STATE(2049), 1,
      aux_sym_call_arguments_repeat1,
  [141778] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(477), 1,
      sym_comma,
    ACTIONS(3966), 1,
      sym__external_close_bracket2,
    STATE(1791), 1,
      sym__close_bracket2,
    STATE(2049), 1,
      aux_sym_call_arguments_repeat1,
  [141794] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(533), 1,
      sym_comma,
    ACTIONS(3968), 1,
      sym__external_close_parenthesis,
    STATE(442), 1,
      sym__close_parenthesis,
    STATE(2035), 1,
      aux_sym_call_arguments_repeat1,
  [141810] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(477), 1,
      sym_comma,
    ACTIONS(3970), 1,
      sym__external_close_bracket2,
    STATE(421), 1,
      sym__close_bracket2,
    STATE(1947), 1,
      aux_sym_call_arguments_repeat1,
  [141826] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3764), 1,
      sym__newline,
    ACTIONS(3972), 1,
      sym__external_open_parenthesis,
    STATE(1064), 1,
      sym__open_parenthesis,
    STATE(2048), 1,
      aux_sym_function_definition_repeat1,
  [141842] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(477), 1,
      sym_comma,
    ACTIONS(3974), 1,
      sym__external_close_bracket2,
    STATE(1719), 1,
      sym__close_bracket2,
    STATE(2049), 1,
      aux_sym_call_arguments_repeat1,
  [141858] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(415), 1,
      sym_comma,
    ACTIONS(3976), 1,
      sym__external_close_bracket,
    STATE(1750), 1,
      sym__close_bracket,
    STATE(2029), 1,
      aux_sym_call_arguments_repeat1,
  [141874] = 4,
    ACTIONS(3792), 1,
      sym_comment,
    ACTIONS(3978), 1,
      anon_sym_SQUOTE,
    STATE(1925), 1,
      aux_sym__single_quoted_string_content,
    ACTIONS(3790), 2,
      aux_sym__single_quoted_string_content_token1,
      sym_escape_sequence,
  [141888] = 4,
    ACTIONS(3792), 1,
      sym_comment,
    ACTIONS(3980), 1,
      anon_sym_DQUOTE,
    STATE(1926), 1,
      aux_sym__double_quoted_string_content,
    ACTIONS(3796), 2,
      aux_sym__double_quoted_string_content_token1,
      sym_escape_sequence,
  [141902] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(415), 1,
      sym_comma,
    ACTIONS(3982), 1,
      sym__external_close_bracket,
    STATE(436), 1,
      sym__close_bracket,
    STATE(2029), 1,
      aux_sym_call_arguments_repeat1,
  [141918] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(533), 1,
      sym_comma,
    ACTIONS(3984), 1,
      sym__external_close_parenthesis,
    STATE(435), 1,
      sym__close_parenthesis,
    STATE(2035), 1,
      aux_sym_call_arguments_repeat1,
  [141934] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3900), 1,
      sym_comma,
    ACTIONS(3986), 1,
      sym__external_close_parenthesis,
    STATE(1793), 1,
      sym__close_parenthesis,
    STATE(1882), 1,
      aux_sym_parameters_repeat1,
  [141950] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(533), 1,
      sym_comma,
    ACTIONS(3988), 1,
      sym__external_close_parenthesis,
    STATE(438), 1,
      sym__close_parenthesis,
    STATE(2035), 1,
      aux_sym_call_arguments_repeat1,
  [141966] = 4,
    ACTIONS(3792), 1,
      sym_comment,
    ACTIONS(3990), 1,
      anon_sym_SQUOTE,
    STATE(1952), 1,
      aux_sym__single_quoted_string_content,
    ACTIONS(3790), 2,
      aux_sym__single_quoted_string_content_token1,
      sym_escape_sequence,
  [141980] = 4,
    ACTIONS(3792), 1,
      sym_comment,
    ACTIONS(3992), 1,
      anon_sym_DQUOTE,
    STATE(1961), 1,
      aux_sym__double_quoted_string_content,
    ACTIONS(3796), 2,
      aux_sym__double_quoted_string_content_token1,
      sym_escape_sequence,
  [141994] = 4,
    ACTIONS(3792), 1,
      sym_comment,
    ACTIONS(3994), 1,
      anon_sym_SQUOTE,
    STATE(1952), 1,
      aux_sym__single_quoted_string_content,
    ACTIONS(3790), 2,
      aux_sym__single_quoted_string_content_token1,
      sym_escape_sequence,
  [142008] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3764), 1,
      sym__newline,
    ACTIONS(3996), 1,
      sym__external_open_parenthesis,
    STATE(1059), 1,
      sym__open_parenthesis,
    STATE(2048), 1,
      aux_sym_function_definition_repeat1,
  [142024] = 4,
    ACTIONS(3792), 1,
      sym_comment,
    ACTIONS(3998), 1,
      anon_sym_DQUOTE,
    STATE(1861), 1,
      aux_sym__double_quoted_string_content,
    ACTIONS(3796), 2,
      aux_sym__double_quoted_string_content_token1,
      sym_escape_sequence,
  [142038] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(415), 1,
      sym_comma,
    ACTIONS(4000), 1,
      sym__external_close_bracket,
    STATE(444), 1,
      sym__close_bracket,
    STATE(1921), 1,
      aux_sym_call_arguments_repeat1,
  [142054] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(415), 1,
      sym_comma,
    ACTIONS(4002), 1,
      sym__external_close_bracket,
    STATE(1698), 1,
      sym__close_bracket,
    STATE(2029), 1,
      aux_sym_call_arguments_repeat1,
  [142070] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(477), 1,
      sym_comma,
    ACTIONS(4004), 1,
      sym__external_close_bracket2,
    STATE(454), 1,
      sym__close_bracket2,
    STATE(2049), 1,
      aux_sym_call_arguments_repeat1,
  [142086] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(415), 1,
      sym_comma,
    ACTIONS(4006), 1,
      sym__external_close_bracket,
    STATE(451), 1,
      sym__close_bracket,
    STATE(1902), 1,
      aux_sym_call_arguments_repeat1,
  [142102] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(533), 1,
      sym_comma,
    ACTIONS(4008), 1,
      sym__external_close_parenthesis,
    STATE(348), 1,
      sym__close_parenthesis,
    STATE(1946), 1,
      aux_sym_call_arguments_repeat1,
  [142118] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(415), 1,
      sym_comma,
    ACTIONS(4010), 1,
      sym__external_close_bracket,
    STATE(1659), 1,
      sym__close_bracket,
    STATE(1901), 1,
      aux_sym_call_arguments_repeat1,
  [142134] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(533), 1,
      sym_comma,
    ACTIONS(4012), 1,
      sym__external_close_parenthesis,
    STATE(349), 1,
      sym__close_parenthesis,
    STATE(2035), 1,
      aux_sym_call_arguments_repeat1,
  [142150] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(415), 1,
      sym_comma,
    ACTIONS(4014), 1,
      sym__external_close_bracket,
    STATE(368), 1,
      sym__close_bracket,
    STATE(2029), 1,
      aux_sym_call_arguments_repeat1,
  [142166] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(415), 1,
      sym_comma,
    ACTIONS(4016), 1,
      sym__external_close_bracket,
    STATE(1660), 1,
      sym__close_bracket,
    STATE(2029), 1,
      aux_sym_call_arguments_repeat1,
  [142182] = 4,
    ACTIONS(3792), 1,
      sym_comment,
    ACTIONS(4018), 1,
      anon_sym_SQUOTE,
    STATE(1927), 1,
      aux_sym__single_quoted_string_content,
    ACTIONS(3790), 2,
      aux_sym__single_quoted_string_content_token1,
      sym_escape_sequence,
  [142196] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(477), 1,
      sym_comma,
    ACTIONS(4020), 1,
      sym__external_close_bracket2,
    STATE(1661), 1,
      sym__close_bracket2,
    STATE(1856), 1,
      aux_sym_call_arguments_repeat1,
  [142212] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(533), 1,
      sym_comma,
    ACTIONS(4022), 1,
      sym__external_close_parenthesis,
    STATE(1773), 1,
      sym__close_parenthesis,
    STATE(1846), 1,
      aux_sym_call_arguments_repeat1,
  [142228] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(477), 1,
      sym_comma,
    ACTIONS(4024), 1,
      sym__external_close_bracket2,
    STATE(369), 1,
      sym__close_bracket2,
    STATE(2049), 1,
      aux_sym_call_arguments_repeat1,
  [142244] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(477), 1,
      sym_comma,
    ACTIONS(4026), 1,
      sym__external_close_bracket2,
    STATE(427), 1,
      sym__close_bracket2,
    STATE(2049), 1,
      aux_sym_call_arguments_repeat1,
  [142260] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(477), 1,
      sym_comma,
    ACTIONS(4028), 1,
      sym__external_close_bracket2,
    STATE(1662), 1,
      sym__close_bracket2,
    STATE(2049), 1,
      aux_sym_call_arguments_repeat1,
  [142276] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(477), 1,
      sym_comma,
    ACTIONS(4030), 1,
      sym__external_close_bracket2,
    STATE(1755), 1,
      sym__close_bracket2,
    STATE(1847), 1,
      aux_sym_call_arguments_repeat1,
  [142292] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(533), 1,
      sym_comma,
    ACTIONS(4032), 1,
      sym__external_close_parenthesis,
    STATE(358), 1,
      sym__close_parenthesis,
    STATE(2035), 1,
      aux_sym_call_arguments_repeat1,
  [142308] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(477), 1,
      sym_comma,
    ACTIONS(4034), 1,
      sym__external_close_bracket2,
    STATE(430), 1,
      sym__close_bracket2,
    STATE(2049), 1,
      aux_sym_call_arguments_repeat1,
  [142324] = 4,
    ACTIONS(3792), 1,
      sym_comment,
    ACTIONS(4036), 1,
      anon_sym_DQUOTE,
    STATE(1905), 1,
      aux_sym__double_quoted_string_content,
    ACTIONS(3796), 2,
      aux_sym__double_quoted_string_content_token1,
      sym_escape_sequence,
  [142338] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(415), 1,
      sym_comma,
    ACTIONS(4038), 1,
      sym__external_close_bracket,
    STATE(446), 1,
      sym__close_bracket,
    STATE(2029), 1,
      aux_sym_call_arguments_repeat1,
  [142354] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(477), 1,
      sym_comma,
    ACTIONS(4040), 1,
      sym__external_close_bracket2,
    STATE(453), 1,
      sym__close_bracket2,
    STATE(1932), 1,
      aux_sym_call_arguments_repeat1,
  [142370] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(415), 1,
      sym_comma,
    ACTIONS(4042), 1,
      sym__external_close_bracket,
    STATE(350), 1,
      sym__close_bracket,
    STATE(1865), 1,
      aux_sym_call_arguments_repeat1,
  [142386] = 4,
    ACTIONS(3792), 1,
      sym_comment,
    ACTIONS(4044), 1,
      anon_sym_SQUOTE,
    STATE(1952), 1,
      aux_sym__single_quoted_string_content,
    ACTIONS(4046), 2,
      aux_sym__single_quoted_string_content_token1,
      sym_escape_sequence,
  [142400] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4049), 1,
      sym__newline,
    ACTIONS(4051), 1,
      sym__external_open_parenthesis,
    STATE(1125), 1,
      sym__open_parenthesis,
    STATE(1954), 1,
      aux_sym_function_definition_repeat1,
  [142416] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3764), 1,
      sym__newline,
    ACTIONS(4053), 1,
      sym__external_open_parenthesis,
    STATE(1067), 1,
      sym__open_parenthesis,
    STATE(2048), 1,
      aux_sym_function_definition_repeat1,
  [142432] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(415), 1,
      sym_comma,
    ACTIONS(4055), 1,
      sym__external_close_bracket,
    STATE(354), 1,
      sym__close_bracket,
    STATE(2029), 1,
      aux_sym_call_arguments_repeat1,
  [142448] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(477), 1,
      sym_comma,
    ACTIONS(4057), 1,
      sym__external_close_bracket2,
    STATE(1699), 1,
      sym__close_bracket2,
    STATE(2049), 1,
      aux_sym_call_arguments_repeat1,
  [142464] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4059), 1,
      sym__newline,
    ACTIONS(4061), 1,
      sym__external_open_parenthesis,
    STATE(1071), 1,
      sym__open_parenthesis,
    STATE(1959), 1,
      aux_sym_function_definition_repeat1,
  [142480] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(477), 1,
      sym_comma,
    ACTIONS(4063), 1,
      sym__external_close_bracket2,
    STATE(356), 1,
      sym__close_bracket2,
    STATE(1841), 1,
      aux_sym_call_arguments_repeat1,
  [142496] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3764), 1,
      sym__newline,
    ACTIONS(4065), 1,
      sym__external_open_parenthesis,
    STATE(1072), 1,
      sym__open_parenthesis,
    STATE(2048), 1,
      aux_sym_function_definition_repeat1,
  [142512] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4067), 1,
      sym__newline,
    ACTIONS(4069), 1,
      sym__external_open_parenthesis,
    STATE(1076), 1,
      sym__open_parenthesis,
    STATE(1962), 1,
      aux_sym_function_definition_repeat1,
  [142528] = 4,
    ACTIONS(3792), 1,
      sym_comment,
    ACTIONS(4071), 1,
      anon_sym_DQUOTE,
    STATE(1961), 1,
      aux_sym__double_quoted_string_content,
    ACTIONS(4073), 2,
      aux_sym__double_quoted_string_content_token1,
      sym_escape_sequence,
  [142542] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3764), 1,
      sym__newline,
    ACTIONS(4076), 1,
      sym__external_open_parenthesis,
    STATE(1077), 1,
      sym__open_parenthesis,
    STATE(2048), 1,
      aux_sym_function_definition_repeat1,
  [142558] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(477), 1,
      sym_comma,
    ACTIONS(4078), 1,
      sym__external_close_bracket2,
    STATE(452), 1,
      sym__close_bracket2,
    STATE(2049), 1,
      aux_sym_call_arguments_repeat1,
  [142574] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4080), 1,
      sym__newline,
    ACTIONS(4082), 1,
      sym__external_open_parenthesis,
    STATE(1081), 1,
      sym__open_parenthesis,
    STATE(1965), 1,
      aux_sym_function_definition_repeat1,
  [142590] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3764), 1,
      sym__newline,
    ACTIONS(4084), 1,
      sym__external_open_parenthesis,
    STATE(1082), 1,
      sym__open_parenthesis,
    STATE(2048), 1,
      aux_sym_function_definition_repeat1,
  [142606] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4086), 1,
      sym__newline,
    ACTIONS(4088), 1,
      sym__external_open_parenthesis,
    STATE(1086), 1,
      sym__open_parenthesis,
    STATE(1968), 1,
      aux_sym_function_definition_repeat1,
  [142622] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(415), 1,
      sym_comma,
    ACTIONS(4090), 1,
      sym__external_close_bracket,
    STATE(416), 1,
      sym__close_bracket,
    STATE(2029), 1,
      aux_sym_call_arguments_repeat1,
  [142638] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3764), 1,
      sym__newline,
    ACTIONS(4092), 1,
      sym__external_open_parenthesis,
    STATE(1087), 1,
      sym__open_parenthesis,
    STATE(2048), 1,
      aux_sym_function_definition_repeat1,
  [142654] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(477), 1,
      sym_comma,
    ACTIONS(4094), 1,
      sym__external_close_bracket2,
    STATE(1762), 1,
      sym__close_bracket2,
    STATE(2049), 1,
      aux_sym_call_arguments_repeat1,
  [142670] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4096), 1,
      sym__newline,
    ACTIONS(4098), 1,
      sym__external_open_parenthesis,
    STATE(1091), 1,
      sym__open_parenthesis,
    STATE(1972), 1,
      aux_sym_function_definition_repeat1,
  [142686] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(415), 1,
      sym_comma,
    ACTIONS(4100), 1,
      sym__external_close_bracket,
    STATE(1739), 1,
      sym__close_bracket,
    STATE(1884), 1,
      aux_sym_call_arguments_repeat1,
  [142702] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3764), 1,
      sym__newline,
    ACTIONS(4102), 1,
      sym__external_open_parenthesis,
    STATE(1092), 1,
      sym__open_parenthesis,
    STATE(2048), 1,
      aux_sym_function_definition_repeat1,
  [142718] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4104), 1,
      sym__newline,
    ACTIONS(4106), 1,
      sym__external_open_parenthesis,
    STATE(1096), 1,
      sym__open_parenthesis,
    STATE(1974), 1,
      aux_sym_function_definition_repeat1,
  [142734] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3764), 1,
      sym__newline,
    ACTIONS(4108), 1,
      sym__external_open_parenthesis,
    STATE(1097), 1,
      sym__open_parenthesis,
    STATE(2048), 1,
      aux_sym_function_definition_repeat1,
  [142750] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(415), 1,
      sym_comma,
    ACTIONS(4110), 1,
      sym__external_close_bracket,
    STATE(1765), 1,
      sym__close_bracket,
    STATE(2029), 1,
      aux_sym_call_arguments_repeat1,
  [142766] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4112), 1,
      sym__newline,
    ACTIONS(4114), 1,
      sym__external_open_parenthesis,
    STATE(1101), 1,
      sym__open_parenthesis,
    STATE(1978), 1,
      aux_sym_function_definition_repeat1,
  [142782] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(477), 1,
      sym_comma,
    ACTIONS(4116), 1,
      sym__external_close_bracket2,
    STATE(357), 1,
      sym__close_bracket2,
    STATE(2049), 1,
      aux_sym_call_arguments_repeat1,
  [142798] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3764), 1,
      sym__newline,
    ACTIONS(4118), 1,
      sym__external_open_parenthesis,
    STATE(1102), 1,
      sym__open_parenthesis,
    STATE(2048), 1,
      aux_sym_function_definition_repeat1,
  [142814] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(477), 1,
      sym_comma,
    ACTIONS(4120), 1,
      sym__external_close_bracket2,
    STATE(1767), 1,
      sym__close_bracket2,
    STATE(1895), 1,
      aux_sym_call_arguments_repeat1,
  [142830] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4122), 1,
      sym__newline,
    ACTIONS(4124), 1,
      sym__external_open_parenthesis,
    STATE(1106), 1,
      sym__open_parenthesis,
    STATE(1981), 1,
      aux_sym_function_definition_repeat1,
  [142846] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3764), 1,
      sym__newline,
    ACTIONS(4126), 1,
      sym__external_open_parenthesis,
    STATE(1107), 1,
      sym__open_parenthesis,
    STATE(2048), 1,
      aux_sym_function_definition_repeat1,
  [142862] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4128), 1,
      sym__newline,
    ACTIONS(4130), 1,
      sym__external_open_parenthesis,
    STATE(1110), 1,
      sym__open_parenthesis,
    STATE(1984), 1,
      aux_sym_function_definition_repeat1,
  [142878] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4132), 1,
      sym__newline,
    ACTIONS(4134), 1,
      sym__external_open_parenthesis,
    STATE(1839), 1,
      aux_sym_function_definition_repeat1,
    STATE(2022), 1,
      sym__open_parenthesis,
  [142894] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3764), 1,
      sym__newline,
    ACTIONS(4136), 1,
      sym__external_open_parenthesis,
    STATE(1055), 1,
      sym__open_parenthesis,
    STATE(2048), 1,
      aux_sym_function_definition_repeat1,
  [142910] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(477), 1,
      sym_comma,
    ACTIONS(4138), 1,
      sym__external_close_bracket2,
    STATE(1770), 1,
      sym__close_bracket2,
    STATE(2049), 1,
      aux_sym_call_arguments_repeat1,
  [142926] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4140), 1,
      sym__newline,
    ACTIONS(4142), 1,
      sym__external_open_parenthesis,
    STATE(1112), 1,
      sym__open_parenthesis,
    STATE(1987), 1,
      aux_sym_function_definition_repeat1,
  [142942] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3764), 1,
      sym__newline,
    ACTIONS(4144), 1,
      sym__external_open_parenthesis,
    STATE(1113), 1,
      sym__open_parenthesis,
    STATE(2048), 1,
      aux_sym_function_definition_repeat1,
  [142958] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4146), 1,
      sym__newline,
    ACTIONS(4148), 1,
      sym__external_open_parenthesis,
    STATE(1114), 1,
      sym__open_parenthesis,
    STATE(1989), 1,
      aux_sym_function_definition_repeat1,
  [142974] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3764), 1,
      sym__newline,
    ACTIONS(4150), 1,
      sym__external_open_parenthesis,
    STATE(1115), 1,
      sym__open_parenthesis,
    STATE(2048), 1,
      aux_sym_function_definition_repeat1,
  [142990] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4152), 1,
      sym__newline,
    ACTIONS(4154), 1,
      sym__external_open_parenthesis,
    STATE(1116), 1,
      sym__open_parenthesis,
    STATE(1991), 1,
      aux_sym_function_definition_repeat1,
  [143006] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3764), 1,
      sym__newline,
    ACTIONS(4156), 1,
      sym__external_open_parenthesis,
    STATE(1117), 1,
      sym__open_parenthesis,
    STATE(2048), 1,
      aux_sym_function_definition_repeat1,
  [143022] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4158), 1,
      sym__newline,
    ACTIONS(4160), 1,
      sym__external_open_parenthesis,
    STATE(1118), 1,
      sym__open_parenthesis,
    STATE(1993), 1,
      aux_sym_function_definition_repeat1,
  [143038] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3764), 1,
      sym__newline,
    ACTIONS(4162), 1,
      sym__external_open_parenthesis,
    STATE(1119), 1,
      sym__open_parenthesis,
    STATE(2048), 1,
      aux_sym_function_definition_repeat1,
  [143054] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4164), 1,
      sym__newline,
    ACTIONS(4166), 1,
      sym__external_open_parenthesis,
    STATE(1120), 1,
      sym__open_parenthesis,
    STATE(1995), 1,
      aux_sym_function_definition_repeat1,
  [143070] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3764), 1,
      sym__newline,
    ACTIONS(4168), 1,
      sym__external_open_parenthesis,
    STATE(1121), 1,
      sym__open_parenthesis,
    STATE(2048), 1,
      aux_sym_function_definition_repeat1,
  [143086] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(533), 1,
      sym_comma,
    ACTIONS(4170), 1,
      sym__external_close_parenthesis,
    STATE(1777), 1,
      sym__close_parenthesis,
    STATE(2035), 1,
      aux_sym_call_arguments_repeat1,
  [143102] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3764), 1,
      sym__newline,
    ACTIONS(4172), 1,
      sym__external_open_parenthesis,
    STATE(1123), 1,
      sym__open_parenthesis,
    STATE(2048), 1,
      aux_sym_function_definition_repeat1,
  [143118] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4174), 1,
      sym__newline,
    ACTIONS(4176), 1,
      sym__external_open_parenthesis,
    STATE(1124), 1,
      sym__open_parenthesis,
    STATE(1999), 1,
      aux_sym_function_definition_repeat1,
  [143134] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3764), 1,
      sym__newline,
    ACTIONS(4178), 1,
      sym__external_open_parenthesis,
    STATE(1056), 1,
      sym__open_parenthesis,
    STATE(2048), 1,
      aux_sym_function_definition_repeat1,
  [143150] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4180), 1,
      sym__newline,
    ACTIONS(4182), 1,
      sym__external_open_parenthesis,
    STATE(1066), 1,
      sym__open_parenthesis,
    STATE(2002), 1,
      aux_sym_function_definition_repeat1,
  [143166] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4184), 1,
      sym__newline,
    ACTIONS(4186), 1,
      sym__external_open_parenthesis,
    STATE(2003), 1,
      aux_sym_function_definition_repeat1,
    STATE(2024), 1,
      sym__open_parenthesis,
  [143182] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3764), 1,
      sym__newline,
    ACTIONS(4188), 1,
      sym__external_open_parenthesis,
    STATE(1111), 1,
      sym__open_parenthesis,
    STATE(2048), 1,
      aux_sym_function_definition_repeat1,
  [143198] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3764), 1,
      sym__newline,
    ACTIONS(4190), 1,
      sym__external_open_parenthesis,
    STATE(2026), 1,
      sym__open_parenthesis,
    STATE(2048), 1,
      aux_sym_function_definition_repeat1,
  [143214] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4192), 1,
      sym__newline,
    ACTIONS(4194), 1,
      sym__external_open_parenthesis,
    STATE(2005), 1,
      aux_sym_function_definition_repeat1,
    STATE(2027), 1,
      sym__open_parenthesis,
  [143230] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3764), 1,
      sym__newline,
    ACTIONS(4196), 1,
      sym__external_open_parenthesis,
    STATE(2028), 1,
      sym__open_parenthesis,
    STATE(2048), 1,
      aux_sym_function_definition_repeat1,
  [143246] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4198), 1,
      sym__newline,
    ACTIONS(4200), 1,
      sym__external_open_parenthesis,
    STATE(2007), 1,
      aux_sym_function_definition_repeat1,
    STATE(2030), 1,
      sym__open_parenthesis,
  [143262] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3764), 1,
      sym__newline,
    ACTIONS(4202), 1,
      sym__external_open_parenthesis,
    STATE(2031), 1,
      sym__open_parenthesis,
    STATE(2048), 1,
      aux_sym_function_definition_repeat1,
  [143278] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4204), 1,
      sym__newline,
    ACTIONS(4206), 1,
      sym__external_open_parenthesis,
    STATE(2009), 1,
      aux_sym_function_definition_repeat1,
    STATE(2033), 1,
      sym__open_parenthesis,
  [143294] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3764), 1,
      sym__newline,
    ACTIONS(4208), 1,
      sym__external_open_parenthesis,
    STATE(2034), 1,
      sym__open_parenthesis,
    STATE(2048), 1,
      aux_sym_function_definition_repeat1,
  [143310] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4210), 1,
      sym__newline,
    ACTIONS(4212), 1,
      sym__external_open_parenthesis,
    STATE(2011), 1,
      aux_sym_function_definition_repeat1,
    STATE(2036), 1,
      sym__open_parenthesis,
  [143326] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3764), 1,
      sym__newline,
    ACTIONS(4214), 1,
      sym__external_open_parenthesis,
    STATE(2037), 1,
      sym__open_parenthesis,
    STATE(2048), 1,
      aux_sym_function_definition_repeat1,
  [143342] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4216), 1,
      sym__newline,
    ACTIONS(4218), 1,
      sym__external_open_parenthesis,
    STATE(2013), 1,
      aux_sym_function_definition_repeat1,
    STATE(2039), 1,
      sym__open_parenthesis,
  [143358] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3764), 1,
      sym__newline,
    ACTIONS(4220), 1,
      sym__external_open_parenthesis,
    STATE(2040), 1,
      sym__open_parenthesis,
    STATE(2048), 1,
      aux_sym_function_definition_repeat1,
  [143374] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4222), 1,
      sym__newline,
    ACTIONS(4224), 1,
      sym__external_open_parenthesis,
    STATE(2015), 1,
      aux_sym_function_definition_repeat1,
    STATE(2042), 1,
      sym__open_parenthesis,
  [143390] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3764), 1,
      sym__newline,
    ACTIONS(4226), 1,
      sym__external_open_parenthesis,
    STATE(2043), 1,
      sym__open_parenthesis,
    STATE(2048), 1,
      aux_sym_function_definition_repeat1,
  [143406] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4228), 1,
      sym__newline,
    ACTIONS(4230), 1,
      sym__external_open_parenthesis,
    STATE(2017), 1,
      aux_sym_function_definition_repeat1,
    STATE(2044), 1,
      sym__open_parenthesis,
  [143422] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3764), 1,
      sym__newline,
    ACTIONS(4232), 1,
      sym__external_open_parenthesis,
    STATE(2045), 1,
      sym__open_parenthesis,
    STATE(2048), 1,
      aux_sym_function_definition_repeat1,
  [143438] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4234), 1,
      sym__newline,
    ACTIONS(4236), 1,
      sym__external_open_parenthesis,
    STATE(2019), 1,
      aux_sym_function_definition_repeat1,
    STATE(2046), 1,
      sym__open_parenthesis,
  [143454] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3764), 1,
      sym__newline,
    ACTIONS(4238), 1,
      sym__external_open_parenthesis,
    STATE(2047), 1,
      sym__open_parenthesis,
    STATE(2048), 1,
      aux_sym_function_definition_repeat1,
  [143470] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(533), 1,
      sym_comma,
    ACTIONS(4240), 1,
      sym__external_close_parenthesis,
    STATE(1657), 1,
      sym__close_parenthesis,
    STATE(1843), 1,
      aux_sym_call_arguments_repeat1,
  [143486] = 3,
    ACTIONS(3792), 1,
      sym_comment,
    ACTIONS(4242), 1,
      anon_sym_SQUOTE,
    ACTIONS(4244), 2,
      aux_sym__single_quoted_string_content_token1,
      sym_escape_sequence,
  [143497] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4246), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
  [143506] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4248), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
  [143515] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4250), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
  [143524] = 3,
    ACTIONS(3792), 1,
      sym_comment,
    ACTIONS(4252), 1,
      anon_sym_DQUOTE,
    ACTIONS(4254), 2,
      aux_sym__double_quoted_string_content_token1,
      sym_escape_sequence,
  [143535] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4256), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
  [143544] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4258), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
  [143553] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4260), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
  [143562] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4262), 1,
      sym_comma,
    ACTIONS(4265), 1,
      sym__external_close_bracket,
    STATE(2029), 1,
      aux_sym_call_arguments_repeat1,
  [143575] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4267), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
  [143584] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4269), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
  [143593] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4271), 1,
      anon_sym_EQ,
    ACTIONS(4273), 2,
      sym__external_close_parenthesis,
      sym_comma,
  [143604] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4275), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
  [143613] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4277), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
  [143622] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4265), 1,
      sym__external_close_parenthesis,
    ACTIONS(4279), 1,
      sym_comma,
    STATE(2035), 1,
      aux_sym_call_arguments_repeat1,
  [143635] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4282), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
  [143644] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4284), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
  [143653] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4286), 3,
      sym__external_close_parenthesis,
      anon_sym_EQ,
      sym_comma,
  [143662] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4288), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
  [143671] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4290), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
  [143680] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4292), 1,
      sym_comma,
    ACTIONS(4295), 1,
      sym__external_close_parenthesis,
    STATE(2041), 1,
      aux_sym_parameters_repeat1,
  [143693] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4297), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
  [143702] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4299), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
  [143711] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4301), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
  [143720] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4303), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
  [143729] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4305), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
  [143738] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4307), 3,
      sym_dots,
      sym_dot_dot_i,
      sym_identifier,
  [143747] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(671), 1,
      sym__external_open_parenthesis,
    ACTIONS(4309), 1,
      sym__newline,
    STATE(2048), 1,
      aux_sym_function_definition_repeat1,
  [143760] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4265), 1,
      sym__external_close_bracket2,
    ACTIONS(4312), 1,
      sym_comma,
    STATE(2049), 1,
      aux_sym_call_arguments_repeat1,
  [143773] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4315), 2,
      sym__external_close_parenthesis,
      sym_comma,
  [143781] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4317), 1,
      sym__raw_string_content,
    ACTIONS(4319), 1,
      sym__raw_string_close,
  [143791] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4321), 1,
      sym__raw_string_content,
    ACTIONS(4323), 1,
      sym__raw_string_close,
  [143801] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4325), 1,
      sym__raw_string_content,
    ACTIONS(4327), 1,
      sym__raw_string_close,
  [143811] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4329), 2,
      sym__external_close_bracket2,
      sym_comma,
  [143819] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4331), 1,
      sym__raw_string_content,
    ACTIONS(4333), 1,
      sym__raw_string_close,
  [143829] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4335), 2,
      sym__external_close_parenthesis,
      sym_comma,
  [143837] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4337), 2,
      sym__external_close_parenthesis,
      sym_comma,
  [143845] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4339), 1,
      sym__raw_string_content,
    ACTIONS(4341), 1,
      sym__raw_string_close,
  [143855] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4337), 2,
      sym__external_close_bracket,
      sym_comma,
  [143863] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4335), 2,
      sym__external_close_bracket2,
      sym_comma,
  [143871] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4329), 2,
      sym__external_close_parenthesis,
      sym_comma,
  [143879] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4343), 2,
      sym__external_close_bracket,
      sym_comma,
  [143887] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4345), 1,
      sym__raw_string_content,
    ACTIONS(4347), 1,
      sym__raw_string_close,
  [143897] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4349), 2,
      sym__external_close_parenthesis,
      sym_comma,
  [143905] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4335), 2,
      sym__external_close_bracket,
      sym_comma,
  [143913] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4351), 2,
      sym__external_close_parenthesis,
      sym_comma,
  [143921] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4353), 1,
      sym__raw_string_content,
    ACTIONS(4355), 1,
      sym__raw_string_close,
  [143931] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4351), 2,
      sym__external_close_bracket,
      sym_comma,
  [143939] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4357), 1,
      sym__raw_string_content,
    ACTIONS(4359), 1,
      sym__raw_string_close,
  [143949] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4343), 2,
      sym__external_close_parenthesis,
      sym_comma,
  [143957] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4329), 2,
      sym__external_close_bracket,
      sym_comma,
  [143965] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4361), 1,
      sym__raw_string_content,
    ACTIONS(4363), 1,
      sym__raw_string_close,
  [143975] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4365), 1,
      sym__raw_string_content,
    ACTIONS(4367), 1,
      sym__raw_string_close,
  [143985] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4369), 2,
      sym__external_close_parenthesis,
      sym_comma,
  [143993] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4351), 2,
      sym__external_close_bracket2,
      sym_comma,
  [144001] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4337), 2,
      sym__external_close_bracket2,
      sym_comma,
  [144009] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4343), 2,
      sym__external_close_bracket2,
      sym_comma,
  [144017] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4371), 1,
      anon_sym_in,
  [144024] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4373), 1,
      anon_sym_in,
  [144031] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4375), 1,
      sym__raw_string_close,
  [144038] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4377), 1,
      sym__raw_string_close,
  [144045] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4379), 1,
      anon_sym_EQ,
  [144052] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4381), 1,
      anon_sym_in,
  [144059] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4383), 1,
      anon_sym_in,
  [144066] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4385), 1,
      anon_sym_EQ,
  [144073] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4387), 1,
      anon_sym_in,
  [144080] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4389), 1,
      anon_sym_in,
  [144087] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4391), 1,
      anon_sym_in,
  [144094] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4393), 1,
      sym__raw_string_close,
  [144101] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4395), 1,
      anon_sym_in,
  [144108] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4397), 1,
      anon_sym_in,
  [144115] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4399), 1,
      anon_sym_in,
  [144122] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4401), 1,
      sym__raw_string_close,
  [144129] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4403), 1,
      sym__raw_string_close,
  [144136] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4405), 1,
      anon_sym_in,
  [144143] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4407), 1,
      sym__raw_string_close,
  [144150] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4409), 1,
      anon_sym_in,
  [144157] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4411), 1,
      ts_builtin_sym_end,
  [144164] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4413), 1,
      anon_sym_in,
  [144171] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4415), 1,
      sym__raw_string_close,
  [144178] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4417), 1,
      sym__raw_string_close,
  [144185] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4419), 1,
      sym__raw_string_close,
  [144192] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4421), 1,
      anon_sym_in,
  [144199] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4423), 1,
      anon_sym_in,
  [144206] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4425), 1,
      anon_sym_in,
  [144213] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4427), 1,
      anon_sym_EQ,
  [144220] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4429), 1,
      anon_sym_in,
  [144227] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4431), 1,
      sym__raw_string_close,
  [144234] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4433), 1,
      anon_sym_in,
  [144241] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4435), 1,
      anon_sym_in,
  [144248] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4437), 1,
      anon_sym_in,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(405)] = 0,
  [SMALL_STATE(406)] = 71,
  [SMALL_STATE(407)] = 142,
  [SMALL_STATE(408)] = 213,
  [SMALL_STATE(409)] = 284,
  [SMALL_STATE(410)] = 413,
  [SMALL_STATE(411)] = 484,
  [SMALL_STATE(412)] = 555,
  [SMALL_STATE(413)] = 626,
  [SMALL_STATE(414)] = 697,
  [SMALL_STATE(415)] = 768,
  [SMALL_STATE(416)] = 897,
  [SMALL_STATE(417)] = 968,
  [SMALL_STATE(418)] = 1039,
  [SMALL_STATE(419)] = 1110,
  [SMALL_STATE(420)] = 1181,
  [SMALL_STATE(421)] = 1252,
  [SMALL_STATE(422)] = 1323,
  [SMALL_STATE(423)] = 1394,
  [SMALL_STATE(424)] = 1465,
  [SMALL_STATE(425)] = 1536,
  [SMALL_STATE(426)] = 1665,
  [SMALL_STATE(427)] = 1736,
  [SMALL_STATE(428)] = 1807,
  [SMALL_STATE(429)] = 1878,
  [SMALL_STATE(430)] = 1949,
  [SMALL_STATE(431)] = 2020,
  [SMALL_STATE(432)] = 2091,
  [SMALL_STATE(433)] = 2162,
  [SMALL_STATE(434)] = 2233,
  [SMALL_STATE(435)] = 2304,
  [SMALL_STATE(436)] = 2375,
  [SMALL_STATE(437)] = 2446,
  [SMALL_STATE(438)] = 2517,
  [SMALL_STATE(439)] = 2588,
  [SMALL_STATE(440)] = 2659,
  [SMALL_STATE(441)] = 2730,
  [SMALL_STATE(442)] = 2801,
  [SMALL_STATE(443)] = 2872,
  [SMALL_STATE(444)] = 3001,
  [SMALL_STATE(445)] = 3072,
  [SMALL_STATE(446)] = 3143,
  [SMALL_STATE(447)] = 3214,
  [SMALL_STATE(448)] = 3285,
  [SMALL_STATE(449)] = 3356,
  [SMALL_STATE(450)] = 3427,
  [SMALL_STATE(451)] = 3498,
  [SMALL_STATE(452)] = 3569,
  [SMALL_STATE(453)] = 3640,
  [SMALL_STATE(454)] = 3711,
  [SMALL_STATE(455)] = 3782,
  [SMALL_STATE(456)] = 3853,
  [SMALL_STATE(457)] = 3924,
  [SMALL_STATE(458)] = 4050,
  [SMALL_STATE(459)] = 4176,
  [SMALL_STATE(460)] = 4302,
  [SMALL_STATE(461)] = 4427,
  [SMALL_STATE(462)] = 4552,
  [SMALL_STATE(463)] = 4677,
  [SMALL_STATE(464)] = 4802,
  [SMALL_STATE(465)] = 4927,
  [SMALL_STATE(466)] = 5052,
  [SMALL_STATE(467)] = 5177,
  [SMALL_STATE(468)] = 5302,
  [SMALL_STATE(469)] = 5427,
  [SMALL_STATE(470)] = 5552,
  [SMALL_STATE(471)] = 5677,
  [SMALL_STATE(472)] = 5802,
  [SMALL_STATE(473)] = 5927,
  [SMALL_STATE(474)] = 6052,
  [SMALL_STATE(475)] = 6177,
  [SMALL_STATE(476)] = 6302,
  [SMALL_STATE(477)] = 6427,
  [SMALL_STATE(478)] = 6552,
  [SMALL_STATE(479)] = 6677,
  [SMALL_STATE(480)] = 6802,
  [SMALL_STATE(481)] = 6927,
  [SMALL_STATE(482)] = 7052,
  [SMALL_STATE(483)] = 7177,
  [SMALL_STATE(484)] = 7302,
  [SMALL_STATE(485)] = 7427,
  [SMALL_STATE(486)] = 7552,
  [SMALL_STATE(487)] = 7677,
  [SMALL_STATE(488)] = 7802,
  [SMALL_STATE(489)] = 7927,
  [SMALL_STATE(490)] = 8052,
  [SMALL_STATE(491)] = 8177,
  [SMALL_STATE(492)] = 8302,
  [SMALL_STATE(493)] = 8427,
  [SMALL_STATE(494)] = 8552,
  [SMALL_STATE(495)] = 8677,
  [SMALL_STATE(496)] = 8802,
  [SMALL_STATE(497)] = 8927,
  [SMALL_STATE(498)] = 9052,
  [SMALL_STATE(499)] = 9177,
  [SMALL_STATE(500)] = 9302,
  [SMALL_STATE(501)] = 9427,
  [SMALL_STATE(502)] = 9552,
  [SMALL_STATE(503)] = 9677,
  [SMALL_STATE(504)] = 9802,
  [SMALL_STATE(505)] = 9927,
  [SMALL_STATE(506)] = 10052,
  [SMALL_STATE(507)] = 10177,
  [SMALL_STATE(508)] = 10302,
  [SMALL_STATE(509)] = 10427,
  [SMALL_STATE(510)] = 10552,
  [SMALL_STATE(511)] = 10677,
  [SMALL_STATE(512)] = 10802,
  [SMALL_STATE(513)] = 10927,
  [SMALL_STATE(514)] = 11052,
  [SMALL_STATE(515)] = 11177,
  [SMALL_STATE(516)] = 11302,
  [SMALL_STATE(517)] = 11427,
  [SMALL_STATE(518)] = 11552,
  [SMALL_STATE(519)] = 11677,
  [SMALL_STATE(520)] = 11802,
  [SMALL_STATE(521)] = 11927,
  [SMALL_STATE(522)] = 12052,
  [SMALL_STATE(523)] = 12177,
  [SMALL_STATE(524)] = 12302,
  [SMALL_STATE(525)] = 12427,
  [SMALL_STATE(526)] = 12552,
  [SMALL_STATE(527)] = 12677,
  [SMALL_STATE(528)] = 12802,
  [SMALL_STATE(529)] = 12927,
  [SMALL_STATE(530)] = 13052,
  [SMALL_STATE(531)] = 13177,
  [SMALL_STATE(532)] = 13302,
  [SMALL_STATE(533)] = 13427,
  [SMALL_STATE(534)] = 13552,
  [SMALL_STATE(535)] = 13677,
  [SMALL_STATE(536)] = 13802,
  [SMALL_STATE(537)] = 13927,
  [SMALL_STATE(538)] = 14052,
  [SMALL_STATE(539)] = 14177,
  [SMALL_STATE(540)] = 14302,
  [SMALL_STATE(541)] = 14427,
  [SMALL_STATE(542)] = 14552,
  [SMALL_STATE(543)] = 14677,
  [SMALL_STATE(544)] = 14802,
  [SMALL_STATE(545)] = 14927,
  [SMALL_STATE(546)] = 15052,
  [SMALL_STATE(547)] = 15177,
  [SMALL_STATE(548)] = 15302,
  [SMALL_STATE(549)] = 15427,
  [SMALL_STATE(550)] = 15552,
  [SMALL_STATE(551)] = 15677,
  [SMALL_STATE(552)] = 15802,
  [SMALL_STATE(553)] = 15927,
  [SMALL_STATE(554)] = 16052,
  [SMALL_STATE(555)] = 16177,
  [SMALL_STATE(556)] = 16302,
  [SMALL_STATE(557)] = 16427,
  [SMALL_STATE(558)] = 16552,
  [SMALL_STATE(559)] = 16677,
  [SMALL_STATE(560)] = 16802,
  [SMALL_STATE(561)] = 16927,
  [SMALL_STATE(562)] = 17052,
  [SMALL_STATE(563)] = 17177,
  [SMALL_STATE(564)] = 17302,
  [SMALL_STATE(565)] = 17427,
  [SMALL_STATE(566)] = 17552,
  [SMALL_STATE(567)] = 17677,
  [SMALL_STATE(568)] = 17802,
  [SMALL_STATE(569)] = 17927,
  [SMALL_STATE(570)] = 18052,
  [SMALL_STATE(571)] = 18177,
  [SMALL_STATE(572)] = 18302,
  [SMALL_STATE(573)] = 18427,
  [SMALL_STATE(574)] = 18552,
  [SMALL_STATE(575)] = 18677,
  [SMALL_STATE(576)] = 18802,
  [SMALL_STATE(577)] = 18927,
  [SMALL_STATE(578)] = 19052,
  [SMALL_STATE(579)] = 19177,
  [SMALL_STATE(580)] = 19302,
  [SMALL_STATE(581)] = 19427,
  [SMALL_STATE(582)] = 19552,
  [SMALL_STATE(583)] = 19677,
  [SMALL_STATE(584)] = 19802,
  [SMALL_STATE(585)] = 19927,
  [SMALL_STATE(586)] = 20052,
  [SMALL_STATE(587)] = 20177,
  [SMALL_STATE(588)] = 20302,
  [SMALL_STATE(589)] = 20427,
  [SMALL_STATE(590)] = 20552,
  [SMALL_STATE(591)] = 20677,
  [SMALL_STATE(592)] = 20802,
  [SMALL_STATE(593)] = 20927,
  [SMALL_STATE(594)] = 21052,
  [SMALL_STATE(595)] = 21177,
  [SMALL_STATE(596)] = 21302,
  [SMALL_STATE(597)] = 21427,
  [SMALL_STATE(598)] = 21552,
  [SMALL_STATE(599)] = 21677,
  [SMALL_STATE(600)] = 21802,
  [SMALL_STATE(601)] = 21927,
  [SMALL_STATE(602)] = 22052,
  [SMALL_STATE(603)] = 22177,
  [SMALL_STATE(604)] = 22302,
  [SMALL_STATE(605)] = 22427,
  [SMALL_STATE(606)] = 22552,
  [SMALL_STATE(607)] = 22677,
  [SMALL_STATE(608)] = 22802,
  [SMALL_STATE(609)] = 22927,
  [SMALL_STATE(610)] = 23052,
  [SMALL_STATE(611)] = 23177,
  [SMALL_STATE(612)] = 23302,
  [SMALL_STATE(613)] = 23427,
  [SMALL_STATE(614)] = 23552,
  [SMALL_STATE(615)] = 23677,
  [SMALL_STATE(616)] = 23802,
  [SMALL_STATE(617)] = 23927,
  [SMALL_STATE(618)] = 24052,
  [SMALL_STATE(619)] = 24177,
  [SMALL_STATE(620)] = 24302,
  [SMALL_STATE(621)] = 24427,
  [SMALL_STATE(622)] = 24552,
  [SMALL_STATE(623)] = 24677,
  [SMALL_STATE(624)] = 24802,
  [SMALL_STATE(625)] = 24927,
  [SMALL_STATE(626)] = 25052,
  [SMALL_STATE(627)] = 25177,
  [SMALL_STATE(628)] = 25302,
  [SMALL_STATE(629)] = 25427,
  [SMALL_STATE(630)] = 25552,
  [SMALL_STATE(631)] = 25677,
  [SMALL_STATE(632)] = 25802,
  [SMALL_STATE(633)] = 25927,
  [SMALL_STATE(634)] = 26052,
  [SMALL_STATE(635)] = 26177,
  [SMALL_STATE(636)] = 26302,
  [SMALL_STATE(637)] = 26427,
  [SMALL_STATE(638)] = 26552,
  [SMALL_STATE(639)] = 26677,
  [SMALL_STATE(640)] = 26802,
  [SMALL_STATE(641)] = 26927,
  [SMALL_STATE(642)] = 27052,
  [SMALL_STATE(643)] = 27177,
  [SMALL_STATE(644)] = 27302,
  [SMALL_STATE(645)] = 27427,
  [SMALL_STATE(646)] = 27552,
  [SMALL_STATE(647)] = 27677,
  [SMALL_STATE(648)] = 27802,
  [SMALL_STATE(649)] = 27927,
  [SMALL_STATE(650)] = 28052,
  [SMALL_STATE(651)] = 28177,
  [SMALL_STATE(652)] = 28302,
  [SMALL_STATE(653)] = 28427,
  [SMALL_STATE(654)] = 28552,
  [SMALL_STATE(655)] = 28677,
  [SMALL_STATE(656)] = 28802,
  [SMALL_STATE(657)] = 28927,
  [SMALL_STATE(658)] = 29052,
  [SMALL_STATE(659)] = 29177,
  [SMALL_STATE(660)] = 29302,
  [SMALL_STATE(661)] = 29427,
  [SMALL_STATE(662)] = 29552,
  [SMALL_STATE(663)] = 29677,
  [SMALL_STATE(664)] = 29802,
  [SMALL_STATE(665)] = 29927,
  [SMALL_STATE(666)] = 30052,
  [SMALL_STATE(667)] = 30177,
  [SMALL_STATE(668)] = 30302,
  [SMALL_STATE(669)] = 30427,
  [SMALL_STATE(670)] = 30552,
  [SMALL_STATE(671)] = 30677,
  [SMALL_STATE(672)] = 30802,
  [SMALL_STATE(673)] = 30927,
  [SMALL_STATE(674)] = 31052,
  [SMALL_STATE(675)] = 31177,
  [SMALL_STATE(676)] = 31302,
  [SMALL_STATE(677)] = 31427,
  [SMALL_STATE(678)] = 31552,
  [SMALL_STATE(679)] = 31677,
  [SMALL_STATE(680)] = 31802,
  [SMALL_STATE(681)] = 31927,
  [SMALL_STATE(682)] = 32052,
  [SMALL_STATE(683)] = 32177,
  [SMALL_STATE(684)] = 32302,
  [SMALL_STATE(685)] = 32427,
  [SMALL_STATE(686)] = 32552,
  [SMALL_STATE(687)] = 32677,
  [SMALL_STATE(688)] = 32802,
  [SMALL_STATE(689)] = 32927,
  [SMALL_STATE(690)] = 33052,
  [SMALL_STATE(691)] = 33177,
  [SMALL_STATE(692)] = 33302,
  [SMALL_STATE(693)] = 33427,
  [SMALL_STATE(694)] = 33552,
  [SMALL_STATE(695)] = 33677,
  [SMALL_STATE(696)] = 33802,
  [SMALL_STATE(697)] = 33927,
  [SMALL_STATE(698)] = 34052,
  [SMALL_STATE(699)] = 34177,
  [SMALL_STATE(700)] = 34302,
  [SMALL_STATE(701)] = 34427,
  [SMALL_STATE(702)] = 34552,
  [SMALL_STATE(703)] = 34677,
  [SMALL_STATE(704)] = 34802,
  [SMALL_STATE(705)] = 34927,
  [SMALL_STATE(706)] = 35052,
  [SMALL_STATE(707)] = 35177,
  [SMALL_STATE(708)] = 35302,
  [SMALL_STATE(709)] = 35427,
  [SMALL_STATE(710)] = 35552,
  [SMALL_STATE(711)] = 35677,
  [SMALL_STATE(712)] = 35802,
  [SMALL_STATE(713)] = 35927,
  [SMALL_STATE(714)] = 36052,
  [SMALL_STATE(715)] = 36177,
  [SMALL_STATE(716)] = 36302,
  [SMALL_STATE(717)] = 36427,
  [SMALL_STATE(718)] = 36552,
  [SMALL_STATE(719)] = 36677,
  [SMALL_STATE(720)] = 36802,
  [SMALL_STATE(721)] = 36927,
  [SMALL_STATE(722)] = 37052,
  [SMALL_STATE(723)] = 37177,
  [SMALL_STATE(724)] = 37302,
  [SMALL_STATE(725)] = 37427,
  [SMALL_STATE(726)] = 37552,
  [SMALL_STATE(727)] = 37677,
  [SMALL_STATE(728)] = 37802,
  [SMALL_STATE(729)] = 37927,
  [SMALL_STATE(730)] = 38052,
  [SMALL_STATE(731)] = 38177,
  [SMALL_STATE(732)] = 38302,
  [SMALL_STATE(733)] = 38427,
  [SMALL_STATE(734)] = 38552,
  [SMALL_STATE(735)] = 38677,
  [SMALL_STATE(736)] = 38802,
  [SMALL_STATE(737)] = 38927,
  [SMALL_STATE(738)] = 39052,
  [SMALL_STATE(739)] = 39177,
  [SMALL_STATE(740)] = 39302,
  [SMALL_STATE(741)] = 39427,
  [SMALL_STATE(742)] = 39552,
  [SMALL_STATE(743)] = 39677,
  [SMALL_STATE(744)] = 39802,
  [SMALL_STATE(745)] = 39927,
  [SMALL_STATE(746)] = 40052,
  [SMALL_STATE(747)] = 40177,
  [SMALL_STATE(748)] = 40302,
  [SMALL_STATE(749)] = 40427,
  [SMALL_STATE(750)] = 40552,
  [SMALL_STATE(751)] = 40677,
  [SMALL_STATE(752)] = 40802,
  [SMALL_STATE(753)] = 40927,
  [SMALL_STATE(754)] = 41052,
  [SMALL_STATE(755)] = 41177,
  [SMALL_STATE(756)] = 41302,
  [SMALL_STATE(757)] = 41427,
  [SMALL_STATE(758)] = 41552,
  [SMALL_STATE(759)] = 41677,
  [SMALL_STATE(760)] = 41802,
  [SMALL_STATE(761)] = 41927,
  [SMALL_STATE(762)] = 42052,
  [SMALL_STATE(763)] = 42177,
  [SMALL_STATE(764)] = 42302,
  [SMALL_STATE(765)] = 42427,
  [SMALL_STATE(766)] = 42552,
  [SMALL_STATE(767)] = 42677,
  [SMALL_STATE(768)] = 42802,
  [SMALL_STATE(769)] = 42927,
  [SMALL_STATE(770)] = 43052,
  [SMALL_STATE(771)] = 43177,
  [SMALL_STATE(772)] = 43302,
  [SMALL_STATE(773)] = 43427,
  [SMALL_STATE(774)] = 43552,
  [SMALL_STATE(775)] = 43677,
  [SMALL_STATE(776)] = 43802,
  [SMALL_STATE(777)] = 43927,
  [SMALL_STATE(778)] = 44052,
  [SMALL_STATE(779)] = 44177,
  [SMALL_STATE(780)] = 44302,
  [SMALL_STATE(781)] = 44427,
  [SMALL_STATE(782)] = 44552,
  [SMALL_STATE(783)] = 44677,
  [SMALL_STATE(784)] = 44802,
  [SMALL_STATE(785)] = 44927,
  [SMALL_STATE(786)] = 45052,
  [SMALL_STATE(787)] = 45177,
  [SMALL_STATE(788)] = 45302,
  [SMALL_STATE(789)] = 45427,
  [SMALL_STATE(790)] = 45552,
  [SMALL_STATE(791)] = 45677,
  [SMALL_STATE(792)] = 45802,
  [SMALL_STATE(793)] = 45927,
  [SMALL_STATE(794)] = 46052,
  [SMALL_STATE(795)] = 46177,
  [SMALL_STATE(796)] = 46302,
  [SMALL_STATE(797)] = 46427,
  [SMALL_STATE(798)] = 46552,
  [SMALL_STATE(799)] = 46677,
  [SMALL_STATE(800)] = 46802,
  [SMALL_STATE(801)] = 46927,
  [SMALL_STATE(802)] = 47052,
  [SMALL_STATE(803)] = 47177,
  [SMALL_STATE(804)] = 47302,
  [SMALL_STATE(805)] = 47427,
  [SMALL_STATE(806)] = 47552,
  [SMALL_STATE(807)] = 47677,
  [SMALL_STATE(808)] = 47802,
  [SMALL_STATE(809)] = 47927,
  [SMALL_STATE(810)] = 48052,
  [SMALL_STATE(811)] = 48177,
  [SMALL_STATE(812)] = 48302,
  [SMALL_STATE(813)] = 48427,
  [SMALL_STATE(814)] = 48552,
  [SMALL_STATE(815)] = 48677,
  [SMALL_STATE(816)] = 48802,
  [SMALL_STATE(817)] = 48927,
  [SMALL_STATE(818)] = 49052,
  [SMALL_STATE(819)] = 49177,
  [SMALL_STATE(820)] = 49302,
  [SMALL_STATE(821)] = 49427,
  [SMALL_STATE(822)] = 49552,
  [SMALL_STATE(823)] = 49677,
  [SMALL_STATE(824)] = 49802,
  [SMALL_STATE(825)] = 49927,
  [SMALL_STATE(826)] = 50052,
  [SMALL_STATE(827)] = 50177,
  [SMALL_STATE(828)] = 50302,
  [SMALL_STATE(829)] = 50427,
  [SMALL_STATE(830)] = 50552,
  [SMALL_STATE(831)] = 50677,
  [SMALL_STATE(832)] = 50802,
  [SMALL_STATE(833)] = 50927,
  [SMALL_STATE(834)] = 51052,
  [SMALL_STATE(835)] = 51177,
  [SMALL_STATE(836)] = 51302,
  [SMALL_STATE(837)] = 51427,
  [SMALL_STATE(838)] = 51552,
  [SMALL_STATE(839)] = 51677,
  [SMALL_STATE(840)] = 51802,
  [SMALL_STATE(841)] = 51927,
  [SMALL_STATE(842)] = 52052,
  [SMALL_STATE(843)] = 52177,
  [SMALL_STATE(844)] = 52302,
  [SMALL_STATE(845)] = 52427,
  [SMALL_STATE(846)] = 52552,
  [SMALL_STATE(847)] = 52677,
  [SMALL_STATE(848)] = 52802,
  [SMALL_STATE(849)] = 52927,
  [SMALL_STATE(850)] = 53052,
  [SMALL_STATE(851)] = 53177,
  [SMALL_STATE(852)] = 53302,
  [SMALL_STATE(853)] = 53427,
  [SMALL_STATE(854)] = 53552,
  [SMALL_STATE(855)] = 53677,
  [SMALL_STATE(856)] = 53802,
  [SMALL_STATE(857)] = 53927,
  [SMALL_STATE(858)] = 54052,
  [SMALL_STATE(859)] = 54177,
  [SMALL_STATE(860)] = 54302,
  [SMALL_STATE(861)] = 54427,
  [SMALL_STATE(862)] = 54552,
  [SMALL_STATE(863)] = 54677,
  [SMALL_STATE(864)] = 54802,
  [SMALL_STATE(865)] = 54927,
  [SMALL_STATE(866)] = 55052,
  [SMALL_STATE(867)] = 55177,
  [SMALL_STATE(868)] = 55302,
  [SMALL_STATE(869)] = 55427,
  [SMALL_STATE(870)] = 55552,
  [SMALL_STATE(871)] = 55677,
  [SMALL_STATE(872)] = 55802,
  [SMALL_STATE(873)] = 55927,
  [SMALL_STATE(874)] = 56052,
  [SMALL_STATE(875)] = 56177,
  [SMALL_STATE(876)] = 56302,
  [SMALL_STATE(877)] = 56427,
  [SMALL_STATE(878)] = 56552,
  [SMALL_STATE(879)] = 56677,
  [SMALL_STATE(880)] = 56802,
  [SMALL_STATE(881)] = 56927,
  [SMALL_STATE(882)] = 57052,
  [SMALL_STATE(883)] = 57177,
  [SMALL_STATE(884)] = 57302,
  [SMALL_STATE(885)] = 57427,
  [SMALL_STATE(886)] = 57552,
  [SMALL_STATE(887)] = 57677,
  [SMALL_STATE(888)] = 57802,
  [SMALL_STATE(889)] = 57927,
  [SMALL_STATE(890)] = 58052,
  [SMALL_STATE(891)] = 58177,
  [SMALL_STATE(892)] = 58302,
  [SMALL_STATE(893)] = 58427,
  [SMALL_STATE(894)] = 58552,
  [SMALL_STATE(895)] = 58677,
  [SMALL_STATE(896)] = 58802,
  [SMALL_STATE(897)] = 58927,
  [SMALL_STATE(898)] = 59052,
  [SMALL_STATE(899)] = 59177,
  [SMALL_STATE(900)] = 59302,
  [SMALL_STATE(901)] = 59427,
  [SMALL_STATE(902)] = 59552,
  [SMALL_STATE(903)] = 59677,
  [SMALL_STATE(904)] = 59802,
  [SMALL_STATE(905)] = 59927,
  [SMALL_STATE(906)] = 60052,
  [SMALL_STATE(907)] = 60177,
  [SMALL_STATE(908)] = 60302,
  [SMALL_STATE(909)] = 60427,
  [SMALL_STATE(910)] = 60552,
  [SMALL_STATE(911)] = 60677,
  [SMALL_STATE(912)] = 60802,
  [SMALL_STATE(913)] = 60927,
  [SMALL_STATE(914)] = 61052,
  [SMALL_STATE(915)] = 61177,
  [SMALL_STATE(916)] = 61302,
  [SMALL_STATE(917)] = 61427,
  [SMALL_STATE(918)] = 61552,
  [SMALL_STATE(919)] = 61677,
  [SMALL_STATE(920)] = 61802,
  [SMALL_STATE(921)] = 61927,
  [SMALL_STATE(922)] = 62052,
  [SMALL_STATE(923)] = 62177,
  [SMALL_STATE(924)] = 62302,
  [SMALL_STATE(925)] = 62427,
  [SMALL_STATE(926)] = 62552,
  [SMALL_STATE(927)] = 62677,
  [SMALL_STATE(928)] = 62802,
  [SMALL_STATE(929)] = 62927,
  [SMALL_STATE(930)] = 63052,
  [SMALL_STATE(931)] = 63177,
  [SMALL_STATE(932)] = 63302,
  [SMALL_STATE(933)] = 63427,
  [SMALL_STATE(934)] = 63552,
  [SMALL_STATE(935)] = 63677,
  [SMALL_STATE(936)] = 63802,
  [SMALL_STATE(937)] = 63927,
  [SMALL_STATE(938)] = 64052,
  [SMALL_STATE(939)] = 64177,
  [SMALL_STATE(940)] = 64302,
  [SMALL_STATE(941)] = 64427,
  [SMALL_STATE(942)] = 64552,
  [SMALL_STATE(943)] = 64677,
  [SMALL_STATE(944)] = 64802,
  [SMALL_STATE(945)] = 64927,
  [SMALL_STATE(946)] = 65052,
  [SMALL_STATE(947)] = 65177,
  [SMALL_STATE(948)] = 65302,
  [SMALL_STATE(949)] = 65427,
  [SMALL_STATE(950)] = 65552,
  [SMALL_STATE(951)] = 65677,
  [SMALL_STATE(952)] = 65802,
  [SMALL_STATE(953)] = 65927,
  [SMALL_STATE(954)] = 66052,
  [SMALL_STATE(955)] = 66177,
  [SMALL_STATE(956)] = 66302,
  [SMALL_STATE(957)] = 66427,
  [SMALL_STATE(958)] = 66552,
  [SMALL_STATE(959)] = 66677,
  [SMALL_STATE(960)] = 66802,
  [SMALL_STATE(961)] = 66927,
  [SMALL_STATE(962)] = 67052,
  [SMALL_STATE(963)] = 67177,
  [SMALL_STATE(964)] = 67302,
  [SMALL_STATE(965)] = 67427,
  [SMALL_STATE(966)] = 67552,
  [SMALL_STATE(967)] = 67677,
  [SMALL_STATE(968)] = 67802,
  [SMALL_STATE(969)] = 67927,
  [SMALL_STATE(970)] = 68052,
  [SMALL_STATE(971)] = 68177,
  [SMALL_STATE(972)] = 68302,
  [SMALL_STATE(973)] = 68427,
  [SMALL_STATE(974)] = 68552,
  [SMALL_STATE(975)] = 68677,
  [SMALL_STATE(976)] = 68802,
  [SMALL_STATE(977)] = 68927,
  [SMALL_STATE(978)] = 69052,
  [SMALL_STATE(979)] = 69177,
  [SMALL_STATE(980)] = 69302,
  [SMALL_STATE(981)] = 69427,
  [SMALL_STATE(982)] = 69552,
  [SMALL_STATE(983)] = 69677,
  [SMALL_STATE(984)] = 69802,
  [SMALL_STATE(985)] = 69927,
  [SMALL_STATE(986)] = 70052,
  [SMALL_STATE(987)] = 70177,
  [SMALL_STATE(988)] = 70302,
  [SMALL_STATE(989)] = 70427,
  [SMALL_STATE(990)] = 70552,
  [SMALL_STATE(991)] = 70677,
  [SMALL_STATE(992)] = 70802,
  [SMALL_STATE(993)] = 70927,
  [SMALL_STATE(994)] = 71052,
  [SMALL_STATE(995)] = 71177,
  [SMALL_STATE(996)] = 71302,
  [SMALL_STATE(997)] = 71427,
  [SMALL_STATE(998)] = 71552,
  [SMALL_STATE(999)] = 71677,
  [SMALL_STATE(1000)] = 71802,
  [SMALL_STATE(1001)] = 71927,
  [SMALL_STATE(1002)] = 72052,
  [SMALL_STATE(1003)] = 72177,
  [SMALL_STATE(1004)] = 72302,
  [SMALL_STATE(1005)] = 72427,
  [SMALL_STATE(1006)] = 72552,
  [SMALL_STATE(1007)] = 72677,
  [SMALL_STATE(1008)] = 72802,
  [SMALL_STATE(1009)] = 72927,
  [SMALL_STATE(1010)] = 73052,
  [SMALL_STATE(1011)] = 73177,
  [SMALL_STATE(1012)] = 73302,
  [SMALL_STATE(1013)] = 73427,
  [SMALL_STATE(1014)] = 73552,
  [SMALL_STATE(1015)] = 73677,
  [SMALL_STATE(1016)] = 73802,
  [SMALL_STATE(1017)] = 73927,
  [SMALL_STATE(1018)] = 74052,
  [SMALL_STATE(1019)] = 74177,
  [SMALL_STATE(1020)] = 74302,
  [SMALL_STATE(1021)] = 74427,
  [SMALL_STATE(1022)] = 74552,
  [SMALL_STATE(1023)] = 74677,
  [SMALL_STATE(1024)] = 74802,
  [SMALL_STATE(1025)] = 74927,
  [SMALL_STATE(1026)] = 75052,
  [SMALL_STATE(1027)] = 75177,
  [SMALL_STATE(1028)] = 75302,
  [SMALL_STATE(1029)] = 75427,
  [SMALL_STATE(1030)] = 75552,
  [SMALL_STATE(1031)] = 75677,
  [SMALL_STATE(1032)] = 75802,
  [SMALL_STATE(1033)] = 75927,
  [SMALL_STATE(1034)] = 76052,
  [SMALL_STATE(1035)] = 76177,
  [SMALL_STATE(1036)] = 76302,
  [SMALL_STATE(1037)] = 76427,
  [SMALL_STATE(1038)] = 76552,
  [SMALL_STATE(1039)] = 76677,
  [SMALL_STATE(1040)] = 76802,
  [SMALL_STATE(1041)] = 76927,
  [SMALL_STATE(1042)] = 77052,
  [SMALL_STATE(1043)] = 77177,
  [SMALL_STATE(1044)] = 77302,
  [SMALL_STATE(1045)] = 77427,
  [SMALL_STATE(1046)] = 77552,
  [SMALL_STATE(1047)] = 77677,
  [SMALL_STATE(1048)] = 77802,
  [SMALL_STATE(1049)] = 77927,
  [SMALL_STATE(1050)] = 78052,
  [SMALL_STATE(1051)] = 78177,
  [SMALL_STATE(1052)] = 78302,
  [SMALL_STATE(1053)] = 78427,
  [SMALL_STATE(1054)] = 78552,
  [SMALL_STATE(1055)] = 78677,
  [SMALL_STATE(1056)] = 78796,
  [SMALL_STATE(1057)] = 78915,
  [SMALL_STATE(1058)] = 79034,
  [SMALL_STATE(1059)] = 79153,
  [SMALL_STATE(1060)] = 79272,
  [SMALL_STATE(1061)] = 79391,
  [SMALL_STATE(1062)] = 79510,
  [SMALL_STATE(1063)] = 79629,
  [SMALL_STATE(1064)] = 79748,
  [SMALL_STATE(1065)] = 79867,
  [SMALL_STATE(1066)] = 79986,
  [SMALL_STATE(1067)] = 80105,
  [SMALL_STATE(1068)] = 80224,
  [SMALL_STATE(1069)] = 80343,
  [SMALL_STATE(1070)] = 80462,
  [SMALL_STATE(1071)] = 80581,
  [SMALL_STATE(1072)] = 80700,
  [SMALL_STATE(1073)] = 80819,
  [SMALL_STATE(1074)] = 80938,
  [SMALL_STATE(1075)] = 81057,
  [SMALL_STATE(1076)] = 81176,
  [SMALL_STATE(1077)] = 81295,
  [SMALL_STATE(1078)] = 81414,
  [SMALL_STATE(1079)] = 81533,
  [SMALL_STATE(1080)] = 81652,
  [SMALL_STATE(1081)] = 81771,
  [SMALL_STATE(1082)] = 81890,
  [SMALL_STATE(1083)] = 82009,
  [SMALL_STATE(1084)] = 82128,
  [SMALL_STATE(1085)] = 82247,
  [SMALL_STATE(1086)] = 82366,
  [SMALL_STATE(1087)] = 82485,
  [SMALL_STATE(1088)] = 82604,
  [SMALL_STATE(1089)] = 82723,
  [SMALL_STATE(1090)] = 82842,
  [SMALL_STATE(1091)] = 82961,
  [SMALL_STATE(1092)] = 83080,
  [SMALL_STATE(1093)] = 83199,
  [SMALL_STATE(1094)] = 83318,
  [SMALL_STATE(1095)] = 83437,
  [SMALL_STATE(1096)] = 83556,
  [SMALL_STATE(1097)] = 83675,
  [SMALL_STATE(1098)] = 83794,
  [SMALL_STATE(1099)] = 83913,
  [SMALL_STATE(1100)] = 84032,
  [SMALL_STATE(1101)] = 84151,
  [SMALL_STATE(1102)] = 84270,
  [SMALL_STATE(1103)] = 84389,
  [SMALL_STATE(1104)] = 84508,
  [SMALL_STATE(1105)] = 84627,
  [SMALL_STATE(1106)] = 84746,
  [SMALL_STATE(1107)] = 84865,
  [SMALL_STATE(1108)] = 84984,
  [SMALL_STATE(1109)] = 85103,
  [SMALL_STATE(1110)] = 85222,
  [SMALL_STATE(1111)] = 85341,
  [SMALL_STATE(1112)] = 85460,
  [SMALL_STATE(1113)] = 85579,
  [SMALL_STATE(1114)] = 85698,
  [SMALL_STATE(1115)] = 85817,
  [SMALL_STATE(1116)] = 85936,
  [SMALL_STATE(1117)] = 86055,
  [SMALL_STATE(1118)] = 86174,
  [SMALL_STATE(1119)] = 86293,
  [SMALL_STATE(1120)] = 86412,
  [SMALL_STATE(1121)] = 86531,
  [SMALL_STATE(1122)] = 86650,
  [SMALL_STATE(1123)] = 86769,
  [SMALL_STATE(1124)] = 86888,
  [SMALL_STATE(1125)] = 87007,
  [SMALL_STATE(1126)] = 87126,
  [SMALL_STATE(1127)] = 87201,
  [SMALL_STATE(1128)] = 87276,
  [SMALL_STATE(1129)] = 87351,
  [SMALL_STATE(1130)] = 87426,
  [SMALL_STATE(1131)] = 87501,
  [SMALL_STATE(1132)] = 87576,
  [SMALL_STATE(1133)] = 87650,
  [SMALL_STATE(1134)] = 87724,
  [SMALL_STATE(1135)] = 87798,
  [SMALL_STATE(1136)] = 87872,
  [SMALL_STATE(1137)] = 87946,
  [SMALL_STATE(1138)] = 88020,
  [SMALL_STATE(1139)] = 88089,
  [SMALL_STATE(1140)] = 88158,
  [SMALL_STATE(1141)] = 88227,
  [SMALL_STATE(1142)] = 88295,
  [SMALL_STATE(1143)] = 88363,
  [SMALL_STATE(1144)] = 88431,
  [SMALL_STATE(1145)] = 88486,
  [SMALL_STATE(1146)] = 88541,
  [SMALL_STATE(1147)] = 88596,
  [SMALL_STATE(1148)] = 88650,
  [SMALL_STATE(1149)] = 88758,
  [SMALL_STATE(1150)] = 88812,
  [SMALL_STATE(1151)] = 88920,
  [SMALL_STATE(1152)] = 89028,
  [SMALL_STATE(1153)] = 89136,
  [SMALL_STATE(1154)] = 89244,
  [SMALL_STATE(1155)] = 89352,
  [SMALL_STATE(1156)] = 89460,
  [SMALL_STATE(1157)] = 89568,
  [SMALL_STATE(1158)] = 89676,
  [SMALL_STATE(1159)] = 89784,
  [SMALL_STATE(1160)] = 89892,
  [SMALL_STATE(1161)] = 90000,
  [SMALL_STATE(1162)] = 90108,
  [SMALL_STATE(1163)] = 90216,
  [SMALL_STATE(1164)] = 90324,
  [SMALL_STATE(1165)] = 90432,
  [SMALL_STATE(1166)] = 90540,
  [SMALL_STATE(1167)] = 90594,
  [SMALL_STATE(1168)] = 90702,
  [SMALL_STATE(1169)] = 90810,
  [SMALL_STATE(1170)] = 90918,
  [SMALL_STATE(1171)] = 91026,
  [SMALL_STATE(1172)] = 91134,
  [SMALL_STATE(1173)] = 91242,
  [SMALL_STATE(1174)] = 91350,
  [SMALL_STATE(1175)] = 91453,
  [SMALL_STATE(1176)] = 91536,
  [SMALL_STATE(1177)] = 91639,
  [SMALL_STATE(1178)] = 91714,
  [SMALL_STATE(1179)] = 91811,
  [SMALL_STATE(1180)] = 91882,
  [SMALL_STATE(1181)] = 91985,
  [SMALL_STATE(1182)] = 92088,
  [SMALL_STATE(1183)] = 92161,
  [SMALL_STATE(1184)] = 92264,
  [SMALL_STATE(1185)] = 92367,
  [SMALL_STATE(1186)] = 92462,
  [SMALL_STATE(1187)] = 92549,
  [SMALL_STATE(1188)] = 92620,
  [SMALL_STATE(1189)] = 92721,
  [SMALL_STATE(1190)] = 92816,
  [SMALL_STATE(1191)] = 92919,
  [SMALL_STATE(1192)] = 93006,
  [SMALL_STATE(1193)] = 93101,
  [SMALL_STATE(1194)] = 93192,
  [SMALL_STATE(1195)] = 93271,
  [SMALL_STATE(1196)] = 93342,
  [SMALL_STATE(1197)] = 93445,
  [SMALL_STATE(1198)] = 93546,
  [SMALL_STATE(1199)] = 93643,
  [SMALL_STATE(1200)] = 93714,
  [SMALL_STATE(1201)] = 93805,
  [SMALL_STATE(1202)] = 93908,
  [SMALL_STATE(1203)] = 93995,
  [SMALL_STATE(1204)] = 94098,
  [SMALL_STATE(1205)] = 94181,
  [SMALL_STATE(1206)] = 94276,
  [SMALL_STATE(1207)] = 94351,
  [SMALL_STATE(1208)] = 94422,
  [SMALL_STATE(1209)] = 94493,
  [SMALL_STATE(1210)] = 94572,
  [SMALL_STATE(1211)] = 94645,
  [SMALL_STATE(1212)] = 94748,
  [SMALL_STATE(1213)] = 94819,
  [SMALL_STATE(1214)] = 94922,
  [SMALL_STATE(1215)] = 95025,
  [SMALL_STATE(1216)] = 95128,
  [SMALL_STATE(1217)] = 95231,
  [SMALL_STATE(1218)] = 95304,
  [SMALL_STATE(1219)] = 95401,
  [SMALL_STATE(1220)] = 95502,
  [SMALL_STATE(1221)] = 95605,
  [SMALL_STATE(1222)] = 95700,
  [SMALL_STATE(1223)] = 95779,
  [SMALL_STATE(1224)] = 95858,
  [SMALL_STATE(1225)] = 95955,
  [SMALL_STATE(1226)] = 96046,
  [SMALL_STATE(1227)] = 96133,
  [SMALL_STATE(1228)] = 96216,
  [SMALL_STATE(1229)] = 96291,
  [SMALL_STATE(1230)] = 96362,
  [SMALL_STATE(1231)] = 96435,
  [SMALL_STATE(1232)] = 96506,
  [SMALL_STATE(1233)] = 96609,
  [SMALL_STATE(1234)] = 96712,
  [SMALL_STATE(1235)] = 96815,
  [SMALL_STATE(1236)] = 96906,
  [SMALL_STATE(1237)] = 97007,
  [SMALL_STATE(1238)] = 97094,
  [SMALL_STATE(1239)] = 97197,
  [SMALL_STATE(1240)] = 97300,
  [SMALL_STATE(1241)] = 97403,
  [SMALL_STATE(1242)] = 97506,
  [SMALL_STATE(1243)] = 97589,
  [SMALL_STATE(1244)] = 97692,
  [SMALL_STATE(1245)] = 97767,
  [SMALL_STATE(1246)] = 97870,
  [SMALL_STATE(1247)] = 97973,
  [SMALL_STATE(1248)] = 98044,
  [SMALL_STATE(1249)] = 98147,
  [SMALL_STATE(1250)] = 98250,
  [SMALL_STATE(1251)] = 98353,
  [SMALL_STATE(1252)] = 98448,
  [SMALL_STATE(1253)] = 98551,
  [SMALL_STATE(1254)] = 98624,
  [SMALL_STATE(1255)] = 98719,
  [SMALL_STATE(1256)] = 98822,
  [SMALL_STATE(1257)] = 98925,
  [SMALL_STATE(1258)] = 98996,
  [SMALL_STATE(1259)] = 99099,
  [SMALL_STATE(1260)] = 99202,
  [SMALL_STATE(1261)] = 99305,
  [SMALL_STATE(1262)] = 99384,
  [SMALL_STATE(1263)] = 99487,
  [SMALL_STATE(1264)] = 99590,
  [SMALL_STATE(1265)] = 99693,
  [SMALL_STATE(1266)] = 99796,
  [SMALL_STATE(1267)] = 99899,
  [SMALL_STATE(1268)] = 100002,
  [SMALL_STATE(1269)] = 100105,
  [SMALL_STATE(1270)] = 100200,
  [SMALL_STATE(1271)] = 100287,
  [SMALL_STATE(1272)] = 100374,
  [SMALL_STATE(1273)] = 100471,
  [SMALL_STATE(1274)] = 100542,
  [SMALL_STATE(1275)] = 100643,
  [SMALL_STATE(1276)] = 100734,
  [SMALL_STATE(1277)] = 100821,
  [SMALL_STATE(1278)] = 100904,
  [SMALL_STATE(1279)] = 100979,
  [SMALL_STATE(1280)] = 101050,
  [SMALL_STATE(1281)] = 101153,
  [SMALL_STATE(1282)] = 101226,
  [SMALL_STATE(1283)] = 101297,
  [SMALL_STATE(1284)] = 101392,
  [SMALL_STATE(1285)] = 101495,
  [SMALL_STATE(1286)] = 101598,
  [SMALL_STATE(1287)] = 101701,
  [SMALL_STATE(1288)] = 101804,
  [SMALL_STATE(1289)] = 101907,
  [SMALL_STATE(1290)] = 102010,
  [SMALL_STATE(1291)] = 102113,
  [SMALL_STATE(1292)] = 102216,
  [SMALL_STATE(1293)] = 102319,
  [SMALL_STATE(1294)] = 102422,
  [SMALL_STATE(1295)] = 102517,
  [SMALL_STATE(1296)] = 102620,
  [SMALL_STATE(1297)] = 102723,
  [SMALL_STATE(1298)] = 102826,
  [SMALL_STATE(1299)] = 102929,
  [SMALL_STATE(1300)] = 103016,
  [SMALL_STATE(1301)] = 103119,
  [SMALL_STATE(1302)] = 103222,
  [SMALL_STATE(1303)] = 103325,
  [SMALL_STATE(1304)] = 103420,
  [SMALL_STATE(1305)] = 103523,
  [SMALL_STATE(1306)] = 103594,
  [SMALL_STATE(1307)] = 103681,
  [SMALL_STATE(1308)] = 103784,
  [SMALL_STATE(1309)] = 103887,
  [SMALL_STATE(1310)] = 103990,
  [SMALL_STATE(1311)] = 104093,
  [SMALL_STATE(1312)] = 104196,
  [SMALL_STATE(1313)] = 104299,
  [SMALL_STATE(1314)] = 104370,
  [SMALL_STATE(1315)] = 104473,
  [SMALL_STATE(1316)] = 104576,
  [SMALL_STATE(1317)] = 104677,
  [SMALL_STATE(1318)] = 104748,
  [SMALL_STATE(1319)] = 104851,
  [SMALL_STATE(1320)] = 104954,
  [SMALL_STATE(1321)] = 105057,
  [SMALL_STATE(1322)] = 105160,
  [SMALL_STATE(1323)] = 105263,
  [SMALL_STATE(1324)] = 105366,
  [SMALL_STATE(1325)] = 105461,
  [SMALL_STATE(1326)] = 105564,
  [SMALL_STATE(1327)] = 105667,
  [SMALL_STATE(1328)] = 105770,
  [SMALL_STATE(1329)] = 105873,
  [SMALL_STATE(1330)] = 105952,
  [SMALL_STATE(1331)] = 106023,
  [SMALL_STATE(1332)] = 106126,
  [SMALL_STATE(1333)] = 106213,
  [SMALL_STATE(1334)] = 106310,
  [SMALL_STATE(1335)] = 106393,
  [SMALL_STATE(1336)] = 106484,
  [SMALL_STATE(1337)] = 106559,
  [SMALL_STATE(1338)] = 106662,
  [SMALL_STATE(1339)] = 106765,
  [SMALL_STATE(1340)] = 106852,
  [SMALL_STATE(1341)] = 106955,
  [SMALL_STATE(1342)] = 107058,
  [SMALL_STATE(1343)] = 107128,
  [SMALL_STATE(1344)] = 107230,
  [SMALL_STATE(1345)] = 107332,
  [SMALL_STATE(1346)] = 107434,
  [SMALL_STATE(1347)] = 107536,
  [SMALL_STATE(1348)] = 107638,
  [SMALL_STATE(1349)] = 107740,
  [SMALL_STATE(1350)] = 107840,
  [SMALL_STATE(1351)] = 107942,
  [SMALL_STATE(1352)] = 108036,
  [SMALL_STATE(1353)] = 108114,
  [SMALL_STATE(1354)] = 108216,
  [SMALL_STATE(1355)] = 108318,
  [SMALL_STATE(1356)] = 108414,
  [SMALL_STATE(1357)] = 108504,
  [SMALL_STATE(1358)] = 108606,
  [SMALL_STATE(1359)] = 108692,
  [SMALL_STATE(1360)] = 108774,
  [SMALL_STATE(1361)] = 108848,
  [SMALL_STATE(1362)] = 108942,
  [SMALL_STATE(1363)] = 109012,
  [SMALL_STATE(1364)] = 109084,
  [SMALL_STATE(1365)] = 109154,
  [SMALL_STATE(1366)] = 109240,
  [SMALL_STATE(1367)] = 109310,
  [SMALL_STATE(1368)] = 109412,
  [SMALL_STATE(1369)] = 109514,
  [SMALL_STATE(1370)] = 109620,
  [SMALL_STATE(1371)] = 109722,
  [SMALL_STATE(1372)] = 109824,
  [SMALL_STATE(1373)] = 109928,
  [SMALL_STATE(1374)] = 110030,
  [SMALL_STATE(1375)] = 110136,
  [SMALL_STATE(1376)] = 110242,
  [SMALL_STATE(1377)] = 110344,
  [SMALL_STATE(1378)] = 110446,
  [SMALL_STATE(1379)] = 110548,
  [SMALL_STATE(1380)] = 110650,
  [SMALL_STATE(1381)] = 110744,
  [SMALL_STATE(1382)] = 110830,
  [SMALL_STATE(1383)] = 110900,
  [SMALL_STATE(1384)] = 111000,
  [SMALL_STATE(1385)] = 111102,
  [SMALL_STATE(1386)] = 111204,
  [SMALL_STATE(1387)] = 111306,
  [SMALL_STATE(1388)] = 111408,
  [SMALL_STATE(1389)] = 111510,
  [SMALL_STATE(1390)] = 111616,
  [SMALL_STATE(1391)] = 111718,
  [SMALL_STATE(1392)] = 111812,
  [SMALL_STATE(1393)] = 111914,
  [SMALL_STATE(1394)] = 112016,
  [SMALL_STATE(1395)] = 112094,
  [SMALL_STATE(1396)] = 112196,
  [SMALL_STATE(1397)] = 112298,
  [SMALL_STATE(1398)] = 112400,
  [SMALL_STATE(1399)] = 112502,
  [SMALL_STATE(1400)] = 112604,
  [SMALL_STATE(1401)] = 112700,
  [SMALL_STATE(1402)] = 112790,
  [SMALL_STATE(1403)] = 112876,
  [SMALL_STATE(1404)] = 112978,
  [SMALL_STATE(1405)] = 113080,
  [SMALL_STATE(1406)] = 113174,
  [SMALL_STATE(1407)] = 113260,
  [SMALL_STATE(1408)] = 113330,
  [SMALL_STATE(1409)] = 113432,
  [SMALL_STATE(1410)] = 113534,
  [SMALL_STATE(1411)] = 113628,
  [SMALL_STATE(1412)] = 113714,
  [SMALL_STATE(1413)] = 113796,
  [SMALL_STATE(1414)] = 113866,
  [SMALL_STATE(1415)] = 113968,
  [SMALL_STATE(1416)] = 114070,
  [SMALL_STATE(1417)] = 114172,
  [SMALL_STATE(1418)] = 114266,
  [SMALL_STATE(1419)] = 114352,
  [SMALL_STATE(1420)] = 114422,
  [SMALL_STATE(1421)] = 114522,
  [SMALL_STATE(1422)] = 114624,
  [SMALL_STATE(1423)] = 114718,
  [SMALL_STATE(1424)] = 114796,
  [SMALL_STATE(1425)] = 114898,
  [SMALL_STATE(1426)] = 114994,
  [SMALL_STATE(1427)] = 115084,
  [SMALL_STATE(1428)] = 115170,
  [SMALL_STATE(1429)] = 115252,
  [SMALL_STATE(1430)] = 115326,
  [SMALL_STATE(1431)] = 115396,
  [SMALL_STATE(1432)] = 115468,
  [SMALL_STATE(1433)] = 115538,
  [SMALL_STATE(1434)] = 115644,
  [SMALL_STATE(1435)] = 115750,
  [SMALL_STATE(1436)] = 115856,
  [SMALL_STATE(1437)] = 115962,
  [SMALL_STATE(1438)] = 116068,
  [SMALL_STATE(1439)] = 116170,
  [SMALL_STATE(1440)] = 116272,
  [SMALL_STATE(1441)] = 116378,
  [SMALL_STATE(1442)] = 116478,
  [SMALL_STATE(1443)] = 116580,
  [SMALL_STATE(1444)] = 116674,
  [SMALL_STATE(1445)] = 116776,
  [SMALL_STATE(1446)] = 116878,
  [SMALL_STATE(1447)] = 116974,
  [SMALL_STATE(1448)] = 117064,
  [SMALL_STATE(1449)] = 117150,
  [SMALL_STATE(1450)] = 117232,
  [SMALL_STATE(1451)] = 117306,
  [SMALL_STATE(1452)] = 117412,
  [SMALL_STATE(1453)] = 117518,
  [SMALL_STATE(1454)] = 117588,
  [SMALL_STATE(1455)] = 117694,
  [SMALL_STATE(1456)] = 117766,
  [SMALL_STATE(1457)] = 117836,
  [SMALL_STATE(1458)] = 117942,
  [SMALL_STATE(1459)] = 118048,
  [SMALL_STATE(1460)] = 118122,
  [SMALL_STATE(1461)] = 118192,
  [SMALL_STATE(1462)] = 118298,
  [SMALL_STATE(1463)] = 118404,
  [SMALL_STATE(1464)] = 118510,
  [SMALL_STATE(1465)] = 118582,
  [SMALL_STATE(1466)] = 118684,
  [SMALL_STATE(1467)] = 118790,
  [SMALL_STATE(1468)] = 118892,
  [SMALL_STATE(1469)] = 118998,
  [SMALL_STATE(1470)] = 119068,
  [SMALL_STATE(1471)] = 119170,
  [SMALL_STATE(1472)] = 119276,
  [SMALL_STATE(1473)] = 119382,
  [SMALL_STATE(1474)] = 119488,
  [SMALL_STATE(1475)] = 119594,
  [SMALL_STATE(1476)] = 119700,
  [SMALL_STATE(1477)] = 119802,
  [SMALL_STATE(1478)] = 119904,
  [SMALL_STATE(1479)] = 119998,
  [SMALL_STATE(1480)] = 120100,
  [SMALL_STATE(1481)] = 120202,
  [SMALL_STATE(1482)] = 120288,
  [SMALL_STATE(1483)] = 120390,
  [SMALL_STATE(1484)] = 120496,
  [SMALL_STATE(1485)] = 120602,
  [SMALL_STATE(1486)] = 120672,
  [SMALL_STATE(1487)] = 120778,
  [SMALL_STATE(1488)] = 120884,
  [SMALL_STATE(1489)] = 120990,
  [SMALL_STATE(1490)] = 121092,
  [SMALL_STATE(1491)] = 121196,
  [SMALL_STATE(1492)] = 121302,
  [SMALL_STATE(1493)] = 121408,
  [SMALL_STATE(1494)] = 121508,
  [SMALL_STATE(1495)] = 121614,
  [SMALL_STATE(1496)] = 121718,
  [SMALL_STATE(1497)] = 121824,
  [SMALL_STATE(1498)] = 121930,
  [SMALL_STATE(1499)] = 122032,
  [SMALL_STATE(1500)] = 122134,
  [SMALL_STATE(1501)] = 122236,
  [SMALL_STATE(1502)] = 122338,
  [SMALL_STATE(1503)] = 122438,
  [SMALL_STATE(1504)] = 122540,
  [SMALL_STATE(1505)] = 122634,
  [SMALL_STATE(1506)] = 122712,
  [SMALL_STATE(1507)] = 122814,
  [SMALL_STATE(1508)] = 122920,
  [SMALL_STATE(1509)] = 123026,
  [SMALL_STATE(1510)] = 123128,
  [SMALL_STATE(1511)] = 123234,
  [SMALL_STATE(1512)] = 123336,
  [SMALL_STATE(1513)] = 123432,
  [SMALL_STATE(1514)] = 123538,
  [SMALL_STATE(1515)] = 123640,
  [SMALL_STATE(1516)] = 123746,
  [SMALL_STATE(1517)] = 123836,
  [SMALL_STATE(1518)] = 123922,
  [SMALL_STATE(1519)] = 124016,
  [SMALL_STATE(1520)] = 124098,
  [SMALL_STATE(1521)] = 124200,
  [SMALL_STATE(1522)] = 124306,
  [SMALL_STATE(1523)] = 124412,
  [SMALL_STATE(1524)] = 124486,
  [SMALL_STATE(1525)] = 124592,
  [SMALL_STATE(1526)] = 124694,
  [SMALL_STATE(1527)] = 124764,
  [SMALL_STATE(1528)] = 124870,
  [SMALL_STATE(1529)] = 124976,
  [SMALL_STATE(1530)] = 125048,
  [SMALL_STATE(1531)] = 125150,
  [SMALL_STATE(1532)] = 125220,
  [SMALL_STATE(1533)] = 125322,
  [SMALL_STATE(1534)] = 125424,
  [SMALL_STATE(1535)] = 125530,
  [SMALL_STATE(1536)] = 125636,
  [SMALL_STATE(1537)] = 125742,
  [SMALL_STATE(1538)] = 125848,
  [SMALL_STATE(1539)] = 125954,
  [SMALL_STATE(1540)] = 126032,
  [SMALL_STATE(1541)] = 126138,
  [SMALL_STATE(1542)] = 126240,
  [SMALL_STATE(1543)] = 126342,
  [SMALL_STATE(1544)] = 126448,
  [SMALL_STATE(1545)] = 126554,
  [SMALL_STATE(1546)] = 126660,
  [SMALL_STATE(1547)] = 126766,
  [SMALL_STATE(1548)] = 126872,
  [SMALL_STATE(1549)] = 126974,
  [SMALL_STATE(1550)] = 127076,
  [SMALL_STATE(1551)] = 127178,
  [SMALL_STATE(1552)] = 127284,
  [SMALL_STATE(1553)] = 127388,
  [SMALL_STATE(1554)] = 127494,
  [SMALL_STATE(1555)] = 127590,
  [SMALL_STATE(1556)] = 127696,
  [SMALL_STATE(1557)] = 127802,
  [SMALL_STATE(1558)] = 127892,
  [SMALL_STATE(1559)] = 127978,
  [SMALL_STATE(1560)] = 128084,
  [SMALL_STATE(1561)] = 128186,
  [SMALL_STATE(1562)] = 128292,
  [SMALL_STATE(1563)] = 128394,
  [SMALL_STATE(1564)] = 128500,
  [SMALL_STATE(1565)] = 128602,
  [SMALL_STATE(1566)] = 128708,
  [SMALL_STATE(1567)] = 128814,
  [SMALL_STATE(1568)] = 128896,
  [SMALL_STATE(1569)] = 128970,
  [SMALL_STATE(1570)] = 129076,
  [SMALL_STATE(1571)] = 129178,
  [SMALL_STATE(1572)] = 129284,
  [SMALL_STATE(1573)] = 129386,
  [SMALL_STATE(1574)] = 129458,
  [SMALL_STATE(1575)] = 129560,
  [SMALL_STATE(1576)] = 129666,
  [SMALL_STATE(1577)] = 129768,
  [SMALL_STATE(1578)] = 129874,
  [SMALL_STATE(1579)] = 129980,
  [SMALL_STATE(1580)] = 130050,
  [SMALL_STATE(1581)] = 130152,
  [SMALL_STATE(1582)] = 130254,
  [SMALL_STATE(1583)] = 130356,
  [SMALL_STATE(1584)] = 130434,
  [SMALL_STATE(1585)] = 130479,
  [SMALL_STATE(1586)] = 130524,
  [SMALL_STATE(1587)] = 130569,
  [SMALL_STATE(1588)] = 130614,
  [SMALL_STATE(1589)] = 130659,
  [SMALL_STATE(1590)] = 130704,
  [SMALL_STATE(1591)] = 130749,
  [SMALL_STATE(1592)] = 130794,
  [SMALL_STATE(1593)] = 130839,
  [SMALL_STATE(1594)] = 130888,
  [SMALL_STATE(1595)] = 130937,
  [SMALL_STATE(1596)] = 130982,
  [SMALL_STATE(1597)] = 131027,
  [SMALL_STATE(1598)] = 131072,
  [SMALL_STATE(1599)] = 131117,
  [SMALL_STATE(1600)] = 131162,
  [SMALL_STATE(1601)] = 131207,
  [SMALL_STATE(1602)] = 131252,
  [SMALL_STATE(1603)] = 131301,
  [SMALL_STATE(1604)] = 131350,
  [SMALL_STATE(1605)] = 131395,
  [SMALL_STATE(1606)] = 131440,
  [SMALL_STATE(1607)] = 131485,
  [SMALL_STATE(1608)] = 131530,
  [SMALL_STATE(1609)] = 131575,
  [SMALL_STATE(1610)] = 131624,
  [SMALL_STATE(1611)] = 131673,
  [SMALL_STATE(1612)] = 131718,
  [SMALL_STATE(1613)] = 131763,
  [SMALL_STATE(1614)] = 131808,
  [SMALL_STATE(1615)] = 131853,
  [SMALL_STATE(1616)] = 131898,
  [SMALL_STATE(1617)] = 131943,
  [SMALL_STATE(1618)] = 131987,
  [SMALL_STATE(1619)] = 132031,
  [SMALL_STATE(1620)] = 132075,
  [SMALL_STATE(1621)] = 132119,
  [SMALL_STATE(1622)] = 132163,
  [SMALL_STATE(1623)] = 132207,
  [SMALL_STATE(1624)] = 132251,
  [SMALL_STATE(1625)] = 132295,
  [SMALL_STATE(1626)] = 132339,
  [SMALL_STATE(1627)] = 132387,
  [SMALL_STATE(1628)] = 132431,
  [SMALL_STATE(1629)] = 132475,
  [SMALL_STATE(1630)] = 132519,
  [SMALL_STATE(1631)] = 132567,
  [SMALL_STATE(1632)] = 132611,
  [SMALL_STATE(1633)] = 132655,
  [SMALL_STATE(1634)] = 132703,
  [SMALL_STATE(1635)] = 132753,
  [SMALL_STATE(1636)] = 132803,
  [SMALL_STATE(1637)] = 132853,
  [SMALL_STATE(1638)] = 132897,
  [SMALL_STATE(1639)] = 132945,
  [SMALL_STATE(1640)] = 132989,
  [SMALL_STATE(1641)] = 133037,
  [SMALL_STATE(1642)] = 133081,
  [SMALL_STATE(1643)] = 133125,
  [SMALL_STATE(1644)] = 133169,
  [SMALL_STATE(1645)] = 133213,
  [SMALL_STATE(1646)] = 133257,
  [SMALL_STATE(1647)] = 133301,
  [SMALL_STATE(1648)] = 133345,
  [SMALL_STATE(1649)] = 133389,
  [SMALL_STATE(1650)] = 133437,
  [SMALL_STATE(1651)] = 133481,
  [SMALL_STATE(1652)] = 133525,
  [SMALL_STATE(1653)] = 133569,
  [SMALL_STATE(1654)] = 133613,
  [SMALL_STATE(1655)] = 133656,
  [SMALL_STATE(1656)] = 133699,
  [SMALL_STATE(1657)] = 133742,
  [SMALL_STATE(1658)] = 133785,
  [SMALL_STATE(1659)] = 133828,
  [SMALL_STATE(1660)] = 133871,
  [SMALL_STATE(1661)] = 133914,
  [SMALL_STATE(1662)] = 133957,
  [SMALL_STATE(1663)] = 134000,
  [SMALL_STATE(1664)] = 134043,
  [SMALL_STATE(1665)] = 134086,
  [SMALL_STATE(1666)] = 134129,
  [SMALL_STATE(1667)] = 134172,
  [SMALL_STATE(1668)] = 134215,
  [SMALL_STATE(1669)] = 134258,
  [SMALL_STATE(1670)] = 134301,
  [SMALL_STATE(1671)] = 134344,
  [SMALL_STATE(1672)] = 134387,
  [SMALL_STATE(1673)] = 134430,
  [SMALL_STATE(1674)] = 134473,
  [SMALL_STATE(1675)] = 134516,
  [SMALL_STATE(1676)] = 134559,
  [SMALL_STATE(1677)] = 134602,
  [SMALL_STATE(1678)] = 134649,
  [SMALL_STATE(1679)] = 134692,
  [SMALL_STATE(1680)] = 134735,
  [SMALL_STATE(1681)] = 134778,
  [SMALL_STATE(1682)] = 134821,
  [SMALL_STATE(1683)] = 134864,
  [SMALL_STATE(1684)] = 134907,
  [SMALL_STATE(1685)] = 134950,
  [SMALL_STATE(1686)] = 134993,
  [SMALL_STATE(1687)] = 135036,
  [SMALL_STATE(1688)] = 135079,
  [SMALL_STATE(1689)] = 135122,
  [SMALL_STATE(1690)] = 135165,
  [SMALL_STATE(1691)] = 135208,
  [SMALL_STATE(1692)] = 135251,
  [SMALL_STATE(1693)] = 135294,
  [SMALL_STATE(1694)] = 135337,
  [SMALL_STATE(1695)] = 135380,
  [SMALL_STATE(1696)] = 135423,
  [SMALL_STATE(1697)] = 135466,
  [SMALL_STATE(1698)] = 135509,
  [SMALL_STATE(1699)] = 135552,
  [SMALL_STATE(1700)] = 135595,
  [SMALL_STATE(1701)] = 135638,
  [SMALL_STATE(1702)] = 135681,
  [SMALL_STATE(1703)] = 135724,
  [SMALL_STATE(1704)] = 135767,
  [SMALL_STATE(1705)] = 135810,
  [SMALL_STATE(1706)] = 135853,
  [SMALL_STATE(1707)] = 135896,
  [SMALL_STATE(1708)] = 135939,
  [SMALL_STATE(1709)] = 135982,
  [SMALL_STATE(1710)] = 136025,
  [SMALL_STATE(1711)] = 136068,
  [SMALL_STATE(1712)] = 136111,
  [SMALL_STATE(1713)] = 136154,
  [SMALL_STATE(1714)] = 136197,
  [SMALL_STATE(1715)] = 136240,
  [SMALL_STATE(1716)] = 136283,
  [SMALL_STATE(1717)] = 136326,
  [SMALL_STATE(1718)] = 136369,
  [SMALL_STATE(1719)] = 136412,
  [SMALL_STATE(1720)] = 136455,
  [SMALL_STATE(1721)] = 136498,
  [SMALL_STATE(1722)] = 136541,
  [SMALL_STATE(1723)] = 136584,
  [SMALL_STATE(1724)] = 136627,
  [SMALL_STATE(1725)] = 136670,
  [SMALL_STATE(1726)] = 136713,
  [SMALL_STATE(1727)] = 136756,
  [SMALL_STATE(1728)] = 136798,
  [SMALL_STATE(1729)] = 136840,
  [SMALL_STATE(1730)] = 136882,
  [SMALL_STATE(1731)] = 136924,
  [SMALL_STATE(1732)] = 136966,
  [SMALL_STATE(1733)] = 137008,
  [SMALL_STATE(1734)] = 137050,
  [SMALL_STATE(1735)] = 137092,
  [SMALL_STATE(1736)] = 137134,
  [SMALL_STATE(1737)] = 137176,
  [SMALL_STATE(1738)] = 137218,
  [SMALL_STATE(1739)] = 137260,
  [SMALL_STATE(1740)] = 137302,
  [SMALL_STATE(1741)] = 137344,
  [SMALL_STATE(1742)] = 137386,
  [SMALL_STATE(1743)] = 137428,
  [SMALL_STATE(1744)] = 137470,
  [SMALL_STATE(1745)] = 137512,
  [SMALL_STATE(1746)] = 137554,
  [SMALL_STATE(1747)] = 137596,
  [SMALL_STATE(1748)] = 137638,
  [SMALL_STATE(1749)] = 137682,
  [SMALL_STATE(1750)] = 137724,
  [SMALL_STATE(1751)] = 137766,
  [SMALL_STATE(1752)] = 137808,
  [SMALL_STATE(1753)] = 137850,
  [SMALL_STATE(1754)] = 137892,
  [SMALL_STATE(1755)] = 137934,
  [SMALL_STATE(1756)] = 137976,
  [SMALL_STATE(1757)] = 138018,
  [SMALL_STATE(1758)] = 138060,
  [SMALL_STATE(1759)] = 138102,
  [SMALL_STATE(1760)] = 138144,
  [SMALL_STATE(1761)] = 138186,
  [SMALL_STATE(1762)] = 138230,
  [SMALL_STATE(1763)] = 138272,
  [SMALL_STATE(1764)] = 138314,
  [SMALL_STATE(1765)] = 138356,
  [SMALL_STATE(1766)] = 138398,
  [SMALL_STATE(1767)] = 138440,
  [SMALL_STATE(1768)] = 138482,
  [SMALL_STATE(1769)] = 138524,
  [SMALL_STATE(1770)] = 138566,
  [SMALL_STATE(1771)] = 138608,
  [SMALL_STATE(1772)] = 138650,
  [SMALL_STATE(1773)] = 138692,
  [SMALL_STATE(1774)] = 138734,
  [SMALL_STATE(1775)] = 138776,
  [SMALL_STATE(1776)] = 138818,
  [SMALL_STATE(1777)] = 138860,
  [SMALL_STATE(1778)] = 138902,
  [SMALL_STATE(1779)] = 138944,
  [SMALL_STATE(1780)] = 138986,
  [SMALL_STATE(1781)] = 139028,
  [SMALL_STATE(1782)] = 139070,
  [SMALL_STATE(1783)] = 139112,
  [SMALL_STATE(1784)] = 139154,
  [SMALL_STATE(1785)] = 139196,
  [SMALL_STATE(1786)] = 139238,
  [SMALL_STATE(1787)] = 139280,
  [SMALL_STATE(1788)] = 139322,
  [SMALL_STATE(1789)] = 139364,
  [SMALL_STATE(1790)] = 139406,
  [SMALL_STATE(1791)] = 139448,
  [SMALL_STATE(1792)] = 139490,
  [SMALL_STATE(1793)] = 139532,
  [SMALL_STATE(1794)] = 139574,
  [SMALL_STATE(1795)] = 139618,
  [SMALL_STATE(1796)] = 139660,
  [SMALL_STATE(1797)] = 139702,
  [SMALL_STATE(1798)] = 139744,
  [SMALL_STATE(1799)] = 139786,
  [SMALL_STATE(1800)] = 139828,
  [SMALL_STATE(1801)] = 139870,
  [SMALL_STATE(1802)] = 139912,
  [SMALL_STATE(1803)] = 139954,
  [SMALL_STATE(1804)] = 139996,
  [SMALL_STATE(1805)] = 140038,
  [SMALL_STATE(1806)] = 140065,
  [SMALL_STATE(1807)] = 140086,
  [SMALL_STATE(1808)] = 140105,
  [SMALL_STATE(1809)] = 140124,
  [SMALL_STATE(1810)] = 140143,
  [SMALL_STATE(1811)] = 140162,
  [SMALL_STATE(1812)] = 140181,
  [SMALL_STATE(1813)] = 140200,
  [SMALL_STATE(1814)] = 140219,
  [SMALL_STATE(1815)] = 140238,
  [SMALL_STATE(1816)] = 140257,
  [SMALL_STATE(1817)] = 140276,
  [SMALL_STATE(1818)] = 140295,
  [SMALL_STATE(1819)] = 140314,
  [SMALL_STATE(1820)] = 140333,
  [SMALL_STATE(1821)] = 140352,
  [SMALL_STATE(1822)] = 140371,
  [SMALL_STATE(1823)] = 140390,
  [SMALL_STATE(1824)] = 140409,
  [SMALL_STATE(1825)] = 140428,
  [SMALL_STATE(1826)] = 140447,
  [SMALL_STATE(1827)] = 140466,
  [SMALL_STATE(1828)] = 140482,
  [SMALL_STATE(1829)] = 140498,
  [SMALL_STATE(1830)] = 140514,
  [SMALL_STATE(1831)] = 140528,
  [SMALL_STATE(1832)] = 140542,
  [SMALL_STATE(1833)] = 140558,
  [SMALL_STATE(1834)] = 140572,
  [SMALL_STATE(1835)] = 140586,
  [SMALL_STATE(1836)] = 140600,
  [SMALL_STATE(1837)] = 140616,
  [SMALL_STATE(1838)] = 140630,
  [SMALL_STATE(1839)] = 140646,
  [SMALL_STATE(1840)] = 140662,
  [SMALL_STATE(1841)] = 140678,
  [SMALL_STATE(1842)] = 140694,
  [SMALL_STATE(1843)] = 140710,
  [SMALL_STATE(1844)] = 140726,
  [SMALL_STATE(1845)] = 140740,
  [SMALL_STATE(1846)] = 140754,
  [SMALL_STATE(1847)] = 140770,
  [SMALL_STATE(1848)] = 140786,
  [SMALL_STATE(1849)] = 140800,
  [SMALL_STATE(1850)] = 140816,
  [SMALL_STATE(1851)] = 140832,
  [SMALL_STATE(1852)] = 140846,
  [SMALL_STATE(1853)] = 140860,
  [SMALL_STATE(1854)] = 140874,
  [SMALL_STATE(1855)] = 140888,
  [SMALL_STATE(1856)] = 140904,
  [SMALL_STATE(1857)] = 140920,
  [SMALL_STATE(1858)] = 140934,
  [SMALL_STATE(1859)] = 140950,
  [SMALL_STATE(1860)] = 140966,
  [SMALL_STATE(1861)] = 140982,
  [SMALL_STATE(1862)] = 140996,
  [SMALL_STATE(1863)] = 141012,
  [SMALL_STATE(1864)] = 141028,
  [SMALL_STATE(1865)] = 141044,
  [SMALL_STATE(1866)] = 141060,
  [SMALL_STATE(1867)] = 141076,
  [SMALL_STATE(1868)] = 141092,
  [SMALL_STATE(1869)] = 141108,
  [SMALL_STATE(1870)] = 141122,
  [SMALL_STATE(1871)] = 141136,
  [SMALL_STATE(1872)] = 141150,
  [SMALL_STATE(1873)] = 141164,
  [SMALL_STATE(1874)] = 141178,
  [SMALL_STATE(1875)] = 141192,
  [SMALL_STATE(1876)] = 141206,
  [SMALL_STATE(1877)] = 141222,
  [SMALL_STATE(1878)] = 141238,
  [SMALL_STATE(1879)] = 141252,
  [SMALL_STATE(1880)] = 141268,
  [SMALL_STATE(1881)] = 141284,
  [SMALL_STATE(1882)] = 141300,
  [SMALL_STATE(1883)] = 141316,
  [SMALL_STATE(1884)] = 141332,
  [SMALL_STATE(1885)] = 141348,
  [SMALL_STATE(1886)] = 141362,
  [SMALL_STATE(1887)] = 141376,
  [SMALL_STATE(1888)] = 141392,
  [SMALL_STATE(1889)] = 141406,
  [SMALL_STATE(1890)] = 141420,
  [SMALL_STATE(1891)] = 141434,
  [SMALL_STATE(1892)] = 141448,
  [SMALL_STATE(1893)] = 141462,
  [SMALL_STATE(1894)] = 141476,
  [SMALL_STATE(1895)] = 141492,
  [SMALL_STATE(1896)] = 141508,
  [SMALL_STATE(1897)] = 141524,
  [SMALL_STATE(1898)] = 141540,
  [SMALL_STATE(1899)] = 141556,
  [SMALL_STATE(1900)] = 141572,
  [SMALL_STATE(1901)] = 141588,
  [SMALL_STATE(1902)] = 141604,
  [SMALL_STATE(1903)] = 141620,
  [SMALL_STATE(1904)] = 141636,
  [SMALL_STATE(1905)] = 141652,
  [SMALL_STATE(1906)] = 141666,
  [SMALL_STATE(1907)] = 141682,
  [SMALL_STATE(1908)] = 141698,
  [SMALL_STATE(1909)] = 141714,
  [SMALL_STATE(1910)] = 141730,
  [SMALL_STATE(1911)] = 141746,
  [SMALL_STATE(1912)] = 141762,
  [SMALL_STATE(1913)] = 141778,
  [SMALL_STATE(1914)] = 141794,
  [SMALL_STATE(1915)] = 141810,
  [SMALL_STATE(1916)] = 141826,
  [SMALL_STATE(1917)] = 141842,
  [SMALL_STATE(1918)] = 141858,
  [SMALL_STATE(1919)] = 141874,
  [SMALL_STATE(1920)] = 141888,
  [SMALL_STATE(1921)] = 141902,
  [SMALL_STATE(1922)] = 141918,
  [SMALL_STATE(1923)] = 141934,
  [SMALL_STATE(1924)] = 141950,
  [SMALL_STATE(1925)] = 141966,
  [SMALL_STATE(1926)] = 141980,
  [SMALL_STATE(1927)] = 141994,
  [SMALL_STATE(1928)] = 142008,
  [SMALL_STATE(1929)] = 142024,
  [SMALL_STATE(1930)] = 142038,
  [SMALL_STATE(1931)] = 142054,
  [SMALL_STATE(1932)] = 142070,
  [SMALL_STATE(1933)] = 142086,
  [SMALL_STATE(1934)] = 142102,
  [SMALL_STATE(1935)] = 142118,
  [SMALL_STATE(1936)] = 142134,
  [SMALL_STATE(1937)] = 142150,
  [SMALL_STATE(1938)] = 142166,
  [SMALL_STATE(1939)] = 142182,
  [SMALL_STATE(1940)] = 142196,
  [SMALL_STATE(1941)] = 142212,
  [SMALL_STATE(1942)] = 142228,
  [SMALL_STATE(1943)] = 142244,
  [SMALL_STATE(1944)] = 142260,
  [SMALL_STATE(1945)] = 142276,
  [SMALL_STATE(1946)] = 142292,
  [SMALL_STATE(1947)] = 142308,
  [SMALL_STATE(1948)] = 142324,
  [SMALL_STATE(1949)] = 142338,
  [SMALL_STATE(1950)] = 142354,
  [SMALL_STATE(1951)] = 142370,
  [SMALL_STATE(1952)] = 142386,
  [SMALL_STATE(1953)] = 142400,
  [SMALL_STATE(1954)] = 142416,
  [SMALL_STATE(1955)] = 142432,
  [SMALL_STATE(1956)] = 142448,
  [SMALL_STATE(1957)] = 142464,
  [SMALL_STATE(1958)] = 142480,
  [SMALL_STATE(1959)] = 142496,
  [SMALL_STATE(1960)] = 142512,
  [SMALL_STATE(1961)] = 142528,
  [SMALL_STATE(1962)] = 142542,
  [SMALL_STATE(1963)] = 142558,
  [SMALL_STATE(1964)] = 142574,
  [SMALL_STATE(1965)] = 142590,
  [SMALL_STATE(1966)] = 142606,
  [SMALL_STATE(1967)] = 142622,
  [SMALL_STATE(1968)] = 142638,
  [SMALL_STATE(1969)] = 142654,
  [SMALL_STATE(1970)] = 142670,
  [SMALL_STATE(1971)] = 142686,
  [SMALL_STATE(1972)] = 142702,
  [SMALL_STATE(1973)] = 142718,
  [SMALL_STATE(1974)] = 142734,
  [SMALL_STATE(1975)] = 142750,
  [SMALL_STATE(1976)] = 142766,
  [SMALL_STATE(1977)] = 142782,
  [SMALL_STATE(1978)] = 142798,
  [SMALL_STATE(1979)] = 142814,
  [SMALL_STATE(1980)] = 142830,
  [SMALL_STATE(1981)] = 142846,
  [SMALL_STATE(1982)] = 142862,
  [SMALL_STATE(1983)] = 142878,
  [SMALL_STATE(1984)] = 142894,
  [SMALL_STATE(1985)] = 142910,
  [SMALL_STATE(1986)] = 142926,
  [SMALL_STATE(1987)] = 142942,
  [SMALL_STATE(1988)] = 142958,
  [SMALL_STATE(1989)] = 142974,
  [SMALL_STATE(1990)] = 142990,
  [SMALL_STATE(1991)] = 143006,
  [SMALL_STATE(1992)] = 143022,
  [SMALL_STATE(1993)] = 143038,
  [SMALL_STATE(1994)] = 143054,
  [SMALL_STATE(1995)] = 143070,
  [SMALL_STATE(1996)] = 143086,
  [SMALL_STATE(1997)] = 143102,
  [SMALL_STATE(1998)] = 143118,
  [SMALL_STATE(1999)] = 143134,
  [SMALL_STATE(2000)] = 143150,
  [SMALL_STATE(2001)] = 143166,
  [SMALL_STATE(2002)] = 143182,
  [SMALL_STATE(2003)] = 143198,
  [SMALL_STATE(2004)] = 143214,
  [SMALL_STATE(2005)] = 143230,
  [SMALL_STATE(2006)] = 143246,
  [SMALL_STATE(2007)] = 143262,
  [SMALL_STATE(2008)] = 143278,
  [SMALL_STATE(2009)] = 143294,
  [SMALL_STATE(2010)] = 143310,
  [SMALL_STATE(2011)] = 143326,
  [SMALL_STATE(2012)] = 143342,
  [SMALL_STATE(2013)] = 143358,
  [SMALL_STATE(2014)] = 143374,
  [SMALL_STATE(2015)] = 143390,
  [SMALL_STATE(2016)] = 143406,
  [SMALL_STATE(2017)] = 143422,
  [SMALL_STATE(2018)] = 143438,
  [SMALL_STATE(2019)] = 143454,
  [SMALL_STATE(2020)] = 143470,
  [SMALL_STATE(2021)] = 143486,
  [SMALL_STATE(2022)] = 143497,
  [SMALL_STATE(2023)] = 143506,
  [SMALL_STATE(2024)] = 143515,
  [SMALL_STATE(2025)] = 143524,
  [SMALL_STATE(2026)] = 143535,
  [SMALL_STATE(2027)] = 143544,
  [SMALL_STATE(2028)] = 143553,
  [SMALL_STATE(2029)] = 143562,
  [SMALL_STATE(2030)] = 143575,
  [SMALL_STATE(2031)] = 143584,
  [SMALL_STATE(2032)] = 143593,
  [SMALL_STATE(2033)] = 143604,
  [SMALL_STATE(2034)] = 143613,
  [SMALL_STATE(2035)] = 143622,
  [SMALL_STATE(2036)] = 143635,
  [SMALL_STATE(2037)] = 143644,
  [SMALL_STATE(2038)] = 143653,
  [SMALL_STATE(2039)] = 143662,
  [SMALL_STATE(2040)] = 143671,
  [SMALL_STATE(2041)] = 143680,
  [SMALL_STATE(2042)] = 143693,
  [SMALL_STATE(2043)] = 143702,
  [SMALL_STATE(2044)] = 143711,
  [SMALL_STATE(2045)] = 143720,
  [SMALL_STATE(2046)] = 143729,
  [SMALL_STATE(2047)] = 143738,
  [SMALL_STATE(2048)] = 143747,
  [SMALL_STATE(2049)] = 143760,
  [SMALL_STATE(2050)] = 143773,
  [SMALL_STATE(2051)] = 143781,
  [SMALL_STATE(2052)] = 143791,
  [SMALL_STATE(2053)] = 143801,
  [SMALL_STATE(2054)] = 143811,
  [SMALL_STATE(2055)] = 143819,
  [SMALL_STATE(2056)] = 143829,
  [SMALL_STATE(2057)] = 143837,
  [SMALL_STATE(2058)] = 143845,
  [SMALL_STATE(2059)] = 143855,
  [SMALL_STATE(2060)] = 143863,
  [SMALL_STATE(2061)] = 143871,
  [SMALL_STATE(2062)] = 143879,
  [SMALL_STATE(2063)] = 143887,
  [SMALL_STATE(2064)] = 143897,
  [SMALL_STATE(2065)] = 143905,
  [SMALL_STATE(2066)] = 143913,
  [SMALL_STATE(2067)] = 143921,
  [SMALL_STATE(2068)] = 143931,
  [SMALL_STATE(2069)] = 143939,
  [SMALL_STATE(2070)] = 143949,
  [SMALL_STATE(2071)] = 143957,
  [SMALL_STATE(2072)] = 143965,
  [SMALL_STATE(2073)] = 143975,
  [SMALL_STATE(2074)] = 143985,
  [SMALL_STATE(2075)] = 143993,
  [SMALL_STATE(2076)] = 144001,
  [SMALL_STATE(2077)] = 144009,
  [SMALL_STATE(2078)] = 144017,
  [SMALL_STATE(2079)] = 144024,
  [SMALL_STATE(2080)] = 144031,
  [SMALL_STATE(2081)] = 144038,
  [SMALL_STATE(2082)] = 144045,
  [SMALL_STATE(2083)] = 144052,
  [SMALL_STATE(2084)] = 144059,
  [SMALL_STATE(2085)] = 144066,
  [SMALL_STATE(2086)] = 144073,
  [SMALL_STATE(2087)] = 144080,
  [SMALL_STATE(2088)] = 144087,
  [SMALL_STATE(2089)] = 144094,
  [SMALL_STATE(2090)] = 144101,
  [SMALL_STATE(2091)] = 144108,
  [SMALL_STATE(2092)] = 144115,
  [SMALL_STATE(2093)] = 144122,
  [SMALL_STATE(2094)] = 144129,
  [SMALL_STATE(2095)] = 144136,
  [SMALL_STATE(2096)] = 144143,
  [SMALL_STATE(2097)] = 144150,
  [SMALL_STATE(2098)] = 144157,
  [SMALL_STATE(2099)] = 144164,
  [SMALL_STATE(2100)] = 144171,
  [SMALL_STATE(2101)] = 144178,
  [SMALL_STATE(2102)] = 144185,
  [SMALL_STATE(2103)] = 144192,
  [SMALL_STATE(2104)] = 144199,
  [SMALL_STATE(2105)] = 144206,
  [SMALL_STATE(2106)] = 144213,
  [SMALL_STATE(2107)] = 144220,
  [SMALL_STATE(2108)] = 144227,
  [SMALL_STATE(2109)] = 144234,
  [SMALL_STATE(2110)] = 144241,
  [SMALL_STATE(2111)] = 144248,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [5] = {.entry = {.count = 1, .reusable = true}}, SHIFT(443),
  [7] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 5, 0, 37),
  [9] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 5, 0, 37),
  [11] = {.entry = {.count = 1, .reusable = false}}, SHIFT(636),
  [13] = {.entry = {.count = 1, .reusable = true}}, SHIFT(637),
  [15] = {.entry = {.count = 1, .reusable = true}}, SHIFT(638),
  [17] = {.entry = {.count = 1, .reusable = false}}, SHIFT(638),
  [19] = {.entry = {.count = 1, .reusable = true}}, SHIFT(639),
  [21] = {.entry = {.count = 1, .reusable = false}}, SHIFT(640),
  [23] = {.entry = {.count = 1, .reusable = true}}, SHIFT(640),
  [25] = {.entry = {.count = 1, .reusable = false}}, SHIFT(641),
  [27] = {.entry = {.count = 1, .reusable = false}}, SHIFT(642),
  [29] = {.entry = {.count = 1, .reusable = true}}, SHIFT(641),
  [31] = {.entry = {.count = 1, .reusable = true}}, SHIFT(642),
  [33] = {.entry = {.count = 1, .reusable = false}}, SHIFT(643),
  [35] = {.entry = {.count = 1, .reusable = true}}, SHIFT(643),
  [37] = {.entry = {.count = 1, .reusable = false}}, SHIFT(644),
  [39] = {.entry = {.count = 1, .reusable = true}}, SHIFT(644),
  [41] = {.entry = {.count = 1, .reusable = true}}, SHIFT(645),
  [43] = {.entry = {.count = 1, .reusable = true}}, SHIFT(646),
  [45] = {.entry = {.count = 1, .reusable = false}}, SHIFT(647),
  [47] = {.entry = {.count = 1, .reusable = true}}, SHIFT(133),
  [49] = {.entry = {.count = 1, .reusable = true}}, SHIFT(510),
  [51] = {.entry = {.count = 1, .reusable = true}}, SHIFT(271),
  [53] = {.entry = {.count = 1, .reusable = true}}, SHIFT(272),
  [55] = {.entry = {.count = 1, .reusable = true}}, SHIFT(273),
  [57] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 7, 0, 46),
  [59] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 7, 0, 46),
  [61] = {.entry = {.count = 1, .reusable = false}}, SHIFT(776),
  [63] = {.entry = {.count = 1, .reusable = true}}, SHIFT(777),
  [65] = {.entry = {.count = 1, .reusable = true}}, SHIFT(778),
  [67] = {.entry = {.count = 1, .reusable = false}}, SHIFT(778),
  [69] = {.entry = {.count = 1, .reusable = true}}, SHIFT(779),
  [71] = {.entry = {.count = 1, .reusable = false}}, SHIFT(780),
  [73] = {.entry = {.count = 1, .reusable = true}}, SHIFT(780),
  [75] = {.entry = {.count = 1, .reusable = false}}, SHIFT(781),
  [77] = {.entry = {.count = 1, .reusable = false}}, SHIFT(782),
  [79] = {.entry = {.count = 1, .reusable = true}}, SHIFT(781),
  [81] = {.entry = {.count = 1, .reusable = true}}, SHIFT(782),
  [83] = {.entry = {.count = 1, .reusable = false}}, SHIFT(783),
  [85] = {.entry = {.count = 1, .reusable = true}}, SHIFT(783),
  [87] = {.entry = {.count = 1, .reusable = false}}, SHIFT(784),
  [89] = {.entry = {.count = 1, .reusable = true}}, SHIFT(784),
  [91] = {.entry = {.count = 1, .reusable = true}}, SHIFT(785),
  [93] = {.entry = {.count = 1, .reusable = true}}, SHIFT(786),
  [95] = {.entry = {.count = 1, .reusable = false}}, SHIFT(787),
  [97] = {.entry = {.count = 1, .reusable = true}}, SHIFT(247),
  [99] = {.entry = {.count = 1, .reusable = true}}, SHIFT(833),
  [101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(276),
  [103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(277),
  [105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(278),
  [107] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 6, 0, 42),
  [109] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 6, 0, 42),
  [111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(620),
  [113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(634),
  [115] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 6, 0, 41),
  [117] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 6, 0, 41),
  [119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(619),
  [121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(494),
  [123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(500),
  [125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(501),
  [127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(509),
  [129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(694),
  [131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(700),
  [133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(701),
  [135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(708),
  [137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(820),
  [139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(825),
  [141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(826),
  [143] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binary_operator, 3, 0, 17),
  [145] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binary_operator, 3, 0, 17),
  [147] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 10, 0, 58),
  [149] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 10, 0, 58),
  [151] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_repeat_statement, 2, 0, 3),
  [153] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_repeat_statement, 2, 0, 3),
  [155] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unary_operator, 2, 0, 4),
  [157] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unary_operator, 2, 0, 4),
  [159] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 3, 0, 10),
  [161] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 3, 0, 10),
  [163] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_repeat_statement, 3, 0, 14),
  [165] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_repeat_statement, 3, 0, 14),
  [167] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unary_operator, 3, 0, 15),
  [169] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unary_operator, 3, 0, 15),
  [171] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 4, 0, 24),
  [173] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 4, 0, 24),
  [175] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 4, 0, 26),
  [177] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 4, 0, 26),
  [179] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binary_operator, 4, 0, 27),
  [181] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binary_operator, 4, 0, 27),
  [183] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 5, 0, 36),
  [185] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 5, 0, 36),
  [187] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while_statement, 5, 0, 38),
  [189] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_statement, 5, 0, 38),
  [191] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while_statement, 6, 0, 43),
  [193] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_statement, 6, 0, 43),
  [195] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while_statement, 6, 0, 44),
  [197] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_statement, 6, 0, 44),
  [199] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 7, 0, 45),
  [201] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 7, 0, 45),
  [203] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 7, 0, 47),
  [205] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 7, 0, 47),
  [207] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while_statement, 7, 0, 48),
  [209] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_statement, 7, 0, 48),
  [211] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 8, 0, 49),
  [213] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 8, 0, 49),
  [215] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 8, 0, 50),
  [217] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 8, 0, 50),
  [219] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 8, 0, 51),
  [221] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 8, 0, 51),
  [223] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 8, 0, 52),
  [225] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 8, 0, 52),
  [227] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 8, 0, 53),
  [229] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 8, 0, 53),
  [231] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 9, 0, 54),
  [233] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 9, 0, 54),
  [235] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 9, 0, 55),
  [237] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 9, 0, 55),
  [239] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 9, 0, 56),
  [241] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 9, 0, 56),
  [243] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 9, 0, 57),
  [245] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 9, 0, 57),
  [247] = {.entry = {.count = 1, .reusable = false}}, SHIFT(986),
  [249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(988),
  [251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(989),
  [253] = {.entry = {.count = 1, .reusable = false}}, SHIFT(989),
  [255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(999),
  [257] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1000),
  [259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1000),
  [261] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1001),
  [263] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1002),
  [265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1001),
  [267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1002),
  [269] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1012),
  [271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1012),
  [273] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1013),
  [275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1013),
  [277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1014),
  [279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1015),
  [281] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1025),
  [283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(256),
  [285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(283),
  [287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(263),
  [289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(264),
  [291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1038),
  [293] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1038),
  [295] = {.entry = {.count = 1, .reusable = false}}, SHIFT(463),
  [297] = {.entry = {.count = 1, .reusable = false}}, SHIFT(466),
  [299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(463),
  [301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(466),
  [303] = {.entry = {.count = 1, .reusable = false}}, SHIFT(468),
  [305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(468),
  [307] = {.entry = {.count = 1, .reusable = false}}, SHIFT(470),
  [309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(470),
  [311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(472),
  [313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(478),
  [315] = {.entry = {.count = 1, .reusable = false}}, SHIFT(484),
  [317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(253),
  [319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(254),
  [321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(261),
  [323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(251),
  [325] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_extract_operator, 2, 0, 6),
  [327] = {.entry = {.count = 1, .reusable = false}}, SHIFT(387),
  [329] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_extract_operator, 2, 0, 6),
  [331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1919),
  [333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1920),
  [335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(152),
  [337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2073),
  [339] = {.entry = {.count = 1, .reusable = false}}, SHIFT(976),
  [341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1028),
  [343] = {.entry = {.count = 1, .reusable = false}}, SHIFT(461),
  [345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(461),
  [347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(796),
  [349] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_extract_operator, 3, 0, 6),
  [351] = {.entry = {.count = 1, .reusable = false}}, SHIFT(341),
  [353] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_extract_operator, 3, 0, 6),
  [355] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_braced_expression_repeat1, 1, 0, 8),
  [357] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_braced_expression_repeat1, 1, 0, 8),
  [359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(987),
  [361] = {.entry = {.count = 1, .reusable = false}}, SHIFT(359),
  [363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1851),
  [365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1852),
  [367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2053),
  [369] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 1, 0, 0),
  [371] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 1, 0, 0),
  [373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1027),
  [375] = {.entry = {.count = 1, .reusable = false}}, SHIFT(342),
  [377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(210),
  [379] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1636),
  [381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1808),
  [383] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1808),
  [385] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1988),
  [387] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2006),
  [389] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1960),
  [391] = {.entry = {.count = 1, .reusable = false}}, SHIFT(968),
  [393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(969),
  [395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(970),
  [397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(971),
  [399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(972),
  [401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1649),
  [403] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1649),
  [405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1833),
  [407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1837),
  [409] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1490),
  [411] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1794),
  [413] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1740),
  [415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(310),
  [417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2051),
  [419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1075),
  [421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(386),
  [423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1723),
  [425] = {.entry = {.count = 1, .reusable = false}}, SHIFT(439),
  [427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1939),
  [429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1948),
  [431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2052),
  [433] = {.entry = {.count = 1, .reusable = false}}, SHIFT(456),
  [435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1871),
  [437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1878),
  [439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2067),
  [441] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1634),
  [443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1811),
  [445] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1811),
  [447] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1990),
  [449] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2008),
  [451] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1964),
  [453] = {.entry = {.count = 1, .reusable = false}}, SHIFT(981),
  [455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(982),
  [457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(983),
  [459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(984),
  [461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(985),
  [463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1638),
  [465] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1638),
  [467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1872),
  [469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1875),
  [471] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1552),
  [473] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1748),
  [475] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1795),
  [477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(298),
  [479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2069),
  [481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1080),
  [483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(389),
  [485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(405),
  [487] = {.entry = {.count = 1, .reusable = false}}, SHIFT(339),
  [489] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_namespace_operator, 2, 0, 6),
  [491] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_namespace_operator, 2, 0, 6),
  [493] = {.entry = {.count = 1, .reusable = false}}, SHIFT(433),
  [495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(249),
  [497] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1635),
  [499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1813),
  [501] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1813),
  [503] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1982),
  [505] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2001),
  [507] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1953),
  [509] = {.entry = {.count = 1, .reusable = false}}, SHIFT(939),
  [511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(940),
  [513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(941),
  [515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(942),
  [517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(943),
  [519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1626),
  [521] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1626),
  [523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1848),
  [525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1929),
  [527] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1372),
  [529] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1761),
  [531] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1732),
  [533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(294),
  [535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2072),
  [537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1065),
  [539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(420),
  [541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(381),
  [543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1705),
  [545] = {.entry = {.count = 1, .reusable = false}}, SHIFT(455),
  [547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(250),
  [549] = {.entry = {.count = 1, .reusable = false}}, SHIFT(340),
  [551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1736),
  [553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1737),
  [555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1738),
  [557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(450),
  [559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1704),
  [561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(424),
  [563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(426),
  [565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1799),
  [567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1800),
  [569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1802),
  [571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1804),
  [573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1728),
  [575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1744),
  [577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(390),
  [579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(391),
  [581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(392),
  [583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1722),
  [585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1724),
  [587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(343),
  [589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(344),
  [591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(345),
  [593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1654),
  [595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1670),
  [597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1671),
  [599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1703),
  [601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(412),
  [603] = {.entry = {.count = 1, .reusable = false}}, SHIFT(417),
  [605] = {.entry = {.count = 1, .reusable = false}}, SHIFT(411),
  [607] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 1, 0, 1),
  [609] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 1, 0, 1),
  [611] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__single_quoted_string, 3, 0, 16),
  [613] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__single_quoted_string, 3, 0, 16),
  [615] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expression, 1, 0, 0),
  [617] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__expression, 1, 0, 0),
  [619] = {.entry = {.count = 1, .reusable = false}}, SHIFT(257),
  [621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(257),
  [623] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_float, 1, 0, 0),
  [625] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_float, 1, 0, 0),
  [627] = {.entry = {.count = 1, .reusable = false}}, SHIFT(372),
  [629] = {.entry = {.count = 1, .reusable = false}}, SHIFT(373),
  [631] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__double_quoted_string, 3, 0, 16),
  [633] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__double_quoted_string, 3, 0, 16),
  [635] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__raw_string, 2, 0, 2),
  [637] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__raw_string, 2, 0, 2),
  [639] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_call_arguments_repeat1, 1, 0, 0),
  [641] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__single_quoted_string, 2, 0, 5),
  [643] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__single_quoted_string, 2, 0, 5),
  [645] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__double_quoted_string, 2, 0, 5),
  [647] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__double_quoted_string, 2, 0, 5),
  [649] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__raw_string, 3, 0, 9),
  [651] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__raw_string, 3, 0, 9),
  [653] = {.entry = {.count = 1, .reusable = false}}, SHIFT(252),
  [655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(252),
  [657] = {.entry = {.count = 1, .reusable = false}}, SHIFT(399),
  [659] = {.entry = {.count = 1, .reusable = false}}, SHIFT(400),
  [661] = {.entry = {.count = 1, .reusable = false}}, SHIFT(285),
  [663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(285),
  [665] = {.entry = {.count = 1, .reusable = false}}, SHIFT(406),
  [667] = {.entry = {.count = 1, .reusable = false}}, SHIFT(422),
  [669] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_function_definition_repeat1, 2, 0, 0),
  [671] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_function_definition_repeat1, 2, 0, 0),
  [673] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_function_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(317),
  [676] = {.entry = {.count = 1, .reusable = false}}, SHIFT(284),
  [678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(284),
  [680] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_function_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(323),
  [683] = {.entry = {.count = 1, .reusable = false}}, SHIFT(437),
  [685] = {.entry = {.count = 1, .reusable = false}}, SHIFT(445),
  [687] = {.entry = {.count = 1, .reusable = false}}, SHIFT(311),
  [689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1817),
  [691] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1817),
  [693] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1986),
  [695] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2004),
  [697] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1957),
  [699] = {.entry = {.count = 1, .reusable = false}}, SHIFT(956),
  [701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(957),
  [703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(958),
  [705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(959),
  [707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(960),
  [709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(330),
  [711] = {.entry = {.count = 1, .reusable = false}}, SHIFT(330),
  [713] = {.entry = {.count = 1, .reusable = false}}, SHIFT(189),
  [715] = {.entry = {.count = 1, .reusable = false}}, SHIFT(408),
  [717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1623),
  [719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1070),
  [721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(384),
  [723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(423),
  [725] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_braced_expression, 2, 0, 2),
  [727] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_braced_expression, 2, 0, 2),
  [729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(347),
  [731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1743),
  [733] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_namespace_operator, 3, 0, 17),
  [735] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_namespace_operator, 3, 0, 17),
  [737] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_extract_operator, 4, 0, 27),
  [739] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_extract_operator, 4, 0, 27),
  [741] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_extract_operator, 3, 0, 17),
  [743] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_extract_operator, 3, 0, 17),
  [745] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_arguments, 2, 0, 2),
  [747] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_arguments, 2, 0, 2),
  [749] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subset_arguments, 2, 0, 2),
  [751] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subset_arguments, 2, 0, 2),
  [753] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subset2_arguments, 2, 0, 2),
  [755] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subset2_arguments, 2, 0, 2),
  [757] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_expression, 3, 0, 21),
  [759] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_expression, 3, 0, 21),
  [761] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_braced_expression, 3, 0, 22),
  [763] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_braced_expression, 3, 0, 22),
  [765] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_arguments, 3, 0, 29),
  [767] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_arguments, 3, 0, 29),
  [769] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_arguments, 3, 0, 30),
  [771] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_arguments, 3, 0, 30),
  [773] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subset_arguments, 3, 0, 29),
  [775] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subset_arguments, 3, 0, 29),
  [777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1746),
  [779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1787),
  [781] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_function_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(353),
  [784] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subset_arguments, 3, 0, 30),
  [786] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subset_arguments, 3, 0, 30),
  [788] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_na, 1, 0, 0),
  [790] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_na, 1, 0, 0),
  [792] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subset2_arguments, 3, 0, 29),
  [794] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subset2_arguments, 3, 0, 29),
  [796] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subset2_arguments, 3, 0, 30),
  [798] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subset2_arguments, 3, 0, 30),
  [800] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_arguments, 4, 0, 39),
  [802] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_arguments, 4, 0, 39),
  [804] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subset_arguments, 4, 0, 39),
  [806] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subset_arguments, 4, 0, 39),
  [808] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subset2_arguments, 4, 0, 39),
  [810] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subset2_arguments, 4, 0, 39),
  [812] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subset2, 2, 0, 7),
  [814] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subset2, 2, 0, 7),
  [816] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_integer, 2, 0, 0),
  [818] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_integer, 2, 0, 0),
  [820] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_complex, 2, 0, 0),
  [822] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_complex, 2, 0, 0),
  [824] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call, 2, 0, 7),
  [826] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call, 2, 0, 7),
  [828] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subset, 2, 0, 7),
  [830] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subset, 2, 0, 7),
  [832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(397),
  [834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1674),
  [836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1707),
  [838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1760),
  [840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(414),
  [842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(413),
  [844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(419),
  [846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1655),
  [848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1790),
  [850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1764),
  [852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(377),
  [854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1695),
  [856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(336),
  [858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1668),
  [860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1682),
  [862] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_function_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(404),
  [865] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_program, 2, 0, 0),
  [867] = {.entry = {.count = 1, .reusable = false}}, SHIFT(318),
  [869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1816),
  [871] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1816),
  [873] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1881),
  [875] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1983),
  [877] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1904),
  [879] = {.entry = {.count = 1, .reusable = false}}, SHIFT(974),
  [881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(485),
  [883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(486),
  [885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(489),
  [887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(621),
  [889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(316),
  [891] = {.entry = {.count = 1, .reusable = false}}, SHIFT(316),
  [893] = {.entry = {.count = 1, .reusable = false}}, SHIFT(225),
  [895] = {.entry = {.count = 1, .reusable = false}}, SHIFT(431),
  [897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(425),
  [899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1058),
  [901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(335),
  [903] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_braced_expression_repeat1, 2, 0, 23), SHIFT_REPEAT(311),
  [906] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_braced_expression_repeat1, 2, 0, 23), SHIFT_REPEAT(1817),
  [909] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_braced_expression_repeat1, 2, 0, 23), SHIFT_REPEAT(1817),
  [912] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_braced_expression_repeat1, 2, 0, 23), SHIFT_REPEAT(1986),
  [915] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_braced_expression_repeat1, 2, 0, 23), SHIFT_REPEAT(2004),
  [918] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_braced_expression_repeat1, 2, 0, 23), SHIFT_REPEAT(1957),
  [921] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_braced_expression_repeat1, 2, 0, 23), SHIFT_REPEAT(956),
  [924] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_braced_expression_repeat1, 2, 0, 23), SHIFT_REPEAT(957),
  [927] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_braced_expression_repeat1, 2, 0, 23), SHIFT_REPEAT(958),
  [930] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_braced_expression_repeat1, 2, 0, 23), SHIFT_REPEAT(959),
  [933] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_braced_expression_repeat1, 2, 0, 23), SHIFT_REPEAT(960),
  [936] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_braced_expression_repeat1, 2, 0, 23), SHIFT_REPEAT(330),
  [939] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_braced_expression_repeat1, 2, 0, 23), SHIFT_REPEAT(330),
  [942] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_braced_expression_repeat1, 2, 0, 23), SHIFT_REPEAT(1871),
  [945] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_braced_expression_repeat1, 2, 0, 23), SHIFT_REPEAT(1878),
  [948] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_braced_expression_repeat1, 2, 0, 23), SHIFT_REPEAT(189),
  [951] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_braced_expression_repeat1, 2, 0, 23), SHIFT_REPEAT(408),
  [954] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_braced_expression_repeat1, 2, 0, 23), SHIFT_REPEAT(1623),
  [957] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_braced_expression_repeat1, 2, 0, 23), SHIFT_REPEAT(2067),
  [960] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_braced_expression_repeat1, 2, 0, 23), SHIFT_REPEAT(1070),
  [963] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_braced_expression_repeat1, 2, 0, 23), SHIFT_REPEAT(384),
  [966] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_braced_expression_repeat1, 2, 0, 23),
  [968] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0),
  [970] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(318),
  [973] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(1816),
  [976] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(1816),
  [979] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(1881),
  [982] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(1983),
  [985] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(1904),
  [988] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(974),
  [991] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(485),
  [994] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(486),
  [997] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(489),
  [1000] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(621),
  [1003] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(316),
  [1006] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(316),
  [1009] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(1939),
  [1012] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(1948),
  [1015] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(225),
  [1018] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(431),
  [1021] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(425),
  [1024] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(2052),
  [1027] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(1058),
  [1030] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2, 0, 0), SHIFT_REPEAT(335),
  [1033] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_program, 1, 0, 0),
  [1035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(409),
  [1037] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1630),
  [1039] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__argument_named, 2, 0, 11),
  [1041] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1633),
  [1043] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1640),
  [1045] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1380),
  [1047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1677),
  [1049] = {.entry = {.count = 1, .reusable = false}}, SHIFT(140),
  [1051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(944),
  [1053] = {.entry = {.count = 1, .reusable = false}}, SHIFT(209),
  [1055] = {.entry = {.count = 1, .reusable = false}}, SHIFT(141),
  [1057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(945),
  [1059] = {.entry = {.count = 1, .reusable = false}}, SHIFT(211),
  [1061] = {.entry = {.count = 1, .reusable = false}}, SHIFT(212),
  [1063] = {.entry = {.count = 1, .reusable = false}}, SHIFT(143),
  [1065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(950),
  [1067] = {.entry = {.count = 1, .reusable = false}}, SHIFT(213),
  [1069] = {.entry = {.count = 1, .reusable = false}}, SHIFT(144),
  [1071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(954),
  [1073] = {.entry = {.count = 1, .reusable = false}}, SHIFT(214),
  [1075] = {.entry = {.count = 1, .reusable = false}}, SHIFT(145),
  [1077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(962),
  [1079] = {.entry = {.count = 1, .reusable = false}}, SHIFT(215),
  [1081] = {.entry = {.count = 1, .reusable = false}}, SHIFT(146),
  [1083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(973),
  [1085] = {.entry = {.count = 1, .reusable = false}}, SHIFT(216),
  [1087] = {.entry = {.count = 1, .reusable = false}}, SHIFT(217),
  [1089] = {.entry = {.count = 1, .reusable = false}}, SHIFT(218),
  [1091] = {.entry = {.count = 1, .reusable = false}}, SHIFT(219),
  [1093] = {.entry = {.count = 1, .reusable = false}}, SHIFT(220),
  [1095] = {.entry = {.count = 1, .reusable = false}}, SHIFT(147),
  [1097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(975),
  [1099] = {.entry = {.count = 1, .reusable = false}}, SHIFT(221),
  [1101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(165),
  [1103] = {.entry = {.count = 1, .reusable = false}}, SHIFT(222),
  [1105] = {.entry = {.count = 1, .reusable = false}}, SHIFT(288),
  [1107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1819),
  [1109] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1819),
  [1111] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2000),
  [1113] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2010),
  [1115] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1966),
  [1117] = {.entry = {.count = 1, .reusable = false}}, SHIFT(994),
  [1119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(995),
  [1121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(996),
  [1123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(997),
  [1125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(998),
  [1127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(289),
  [1129] = {.entry = {.count = 1, .reusable = false}}, SHIFT(289),
  [1131] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2),
  [1133] = {.entry = {.count = 1, .reusable = false}}, SHIFT(355),
  [1135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(495),
  [1137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1085),
  [1139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(393),
  [1141] = {.entry = {.count = 1, .reusable = false}}, SHIFT(166),
  [1143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(503),
  [1145] = {.entry = {.count = 1, .reusable = false}}, SHIFT(148),
  [1147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1026),
  [1149] = {.entry = {.count = 1, .reusable = false}}, SHIFT(244),
  [1151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(628),
  [1153] = {.entry = {.count = 1, .reusable = false}}, SHIFT(245),
  [1155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(635),
  [1157] = {.entry = {.count = 1, .reusable = false}}, SHIFT(223),
  [1159] = {.entry = {.count = 1, .reusable = false}}, SHIFT(224),
  [1161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(492),
  [1163] = {.entry = {.count = 1, .reusable = false}}, SHIFT(246),
  [1165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(649),
  [1167] = {.entry = {.count = 1, .reusable = false}}, SHIFT(241),
  [1169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(491),
  [1171] = {.entry = {.count = 1, .reusable = false}}, SHIFT(149),
  [1173] = {.entry = {.count = 1, .reusable = false}}, SHIFT(226),
  [1175] = {.entry = {.count = 1, .reusable = false}}, SHIFT(227),
  [1177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(498),
  [1179] = {.entry = {.count = 1, .reusable = false}}, SHIFT(228),
  [1181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(499),
  [1183] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6),
  [1185] = {.entry = {.count = 1, .reusable = false}}, SHIFT(229),
  [1187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(504),
  [1189] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4),
  [1191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(512),
  [1193] = {.entry = {.count = 1, .reusable = false}}, SHIFT(230),
  [1195] = {.entry = {.count = 1, .reusable = false}}, SHIFT(231),
  [1197] = {.entry = {.count = 1, .reusable = false}}, SHIFT(232),
  [1199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(507),
  [1201] = {.entry = {.count = 1, .reusable = false}}, SHIFT(233),
  [1203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(508),
  [1205] = {.entry = {.count = 1, .reusable = false}}, SHIFT(150),
  [1207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(480),
  [1209] = {.entry = {.count = 1, .reusable = false}}, SHIFT(167),
  [1211] = {.entry = {.count = 1, .reusable = false}}, SHIFT(234),
  [1213] = {.entry = {.count = 1, .reusable = false}}, SHIFT(235),
  [1215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(511),
  [1217] = {.entry = {.count = 1, .reusable = false}}, SHIFT(168),
  [1219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(587),
  [1221] = {.entry = {.count = 1, .reusable = false}}, SHIFT(236),
  [1223] = {.entry = {.count = 1, .reusable = false}}, SHIFT(237),
  [1225] = {.entry = {.count = 1, .reusable = false}}, SHIFT(238),
  [1227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(513),
  [1229] = {.entry = {.count = 1, .reusable = false}}, SHIFT(169),
  [1231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(618),
  [1233] = {.entry = {.count = 1, .reusable = false}}, SHIFT(239),
  [1235] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5),
  [1237] = {.entry = {.count = 1, .reusable = false}}, SHIFT(240),
  [1239] = {.entry = {.count = 1, .reusable = false}}, SHIFT(170),
  [1241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(623),
  [1243] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1467),
  [1245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(534),
  [1247] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1476),
  [1249] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1477),
  [1251] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1478),
  [1253] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1481),
  [1255] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1485),
  [1257] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1493),
  [1259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(536),
  [1261] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1511),
  [1263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(537),
  [1265] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1518),
  [1267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(538),
  [1269] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1539),
  [1271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(539),
  [1273] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1549),
  [1275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(540),
  [1277] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1554),
  [1279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(541),
  [1281] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1557),
  [1283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(542),
  [1285] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1558),
  [1287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(543),
  [1289] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1567),
  [1291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(544),
  [1293] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1568),
  [1295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(545),
  [1297] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1342),
  [1299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(546),
  [1301] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1573),
  [1303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(547),
  [1305] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1579),
  [1307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(548),
  [1309] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1345),
  [1311] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1348),
  [1313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(549),
  [1315] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1349),
  [1317] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1350),
  [1319] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1351),
  [1321] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1352),
  [1323] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1353),
  [1325] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1355),
  [1327] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1356),
  [1329] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1358),
  [1331] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1359),
  [1333] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1360),
  [1335] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1362),
  [1337] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1363),
  [1339] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1364),
  [1341] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1367),
  [1343] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1368),
  [1345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(551),
  [1347] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1370),
  [1349] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1371),
  [1351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(555),
  [1353] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1373),
  [1355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(556),
  [1357] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1377),
  [1359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(559),
  [1361] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1384),
  [1363] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1385),
  [1365] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1386),
  [1367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(561),
  [1369] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1388),
  [1371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(562),
  [1373] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1390),
  [1375] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1392),
  [1377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(564),
  [1379] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1393),
  [1381] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1395),
  [1383] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1396),
  [1385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(565),
  [1387] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1398),
  [1389] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1399),
  [1391] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1414),
  [1393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(585),
  [1395] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1415),
  [1397] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1416),
  [1399] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1417),
  [1401] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1418),
  [1403] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1419),
  [1405] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1420),
  [1407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(588),
  [1409] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1421),
  [1411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(589),
  [1413] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1422),
  [1415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(590),
  [1417] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1423),
  [1419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(591),
  [1421] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1424),
  [1423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(592),
  [1425] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1425),
  [1427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(593),
  [1429] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1426),
  [1431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(594),
  [1433] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1427),
  [1435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(595),
  [1437] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1428),
  [1439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(596),
  [1441] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1429),
  [1443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(597),
  [1445] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1430),
  [1447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(598),
  [1449] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1431),
  [1451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(599),
  [1453] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1432),
  [1455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(600),
  [1457] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1438),
  [1459] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1439),
  [1461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(601),
  [1463] = {.entry = {.count = 1, .reusable = false}}, SHIFT(171),
  [1465] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1441),
  [1467] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1442),
  [1469] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1443),
  [1471] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1583),
  [1473] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1445),
  [1475] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1446),
  [1477] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1447),
  [1479] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1448),
  [1481] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1449),
  [1483] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1450),
  [1485] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1453),
  [1487] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1455),
  [1489] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1456),
  [1491] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1465),
  [1493] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1470),
  [1495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(603),
  [1497] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1479),
  [1499] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1480),
  [1501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(607),
  [1503] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1482),
  [1505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(608),
  [1507] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1489),
  [1509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(611),
  [1511] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1500),
  [1513] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1501),
  [1515] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1506),
  [1517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(613),
  [1519] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1514),
  [1521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(614),
  [1523] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1520),
  [1525] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1525),
  [1527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(616),
  [1529] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1530),
  [1531] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1532),
  [1533] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1533),
  [1535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(617),
  [1537] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1541),
  [1539] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1542),
  [1541] = {.entry = {.count = 1, .reusable = false}}, SHIFT(172),
  [1543] = {.entry = {.count = 1, .reusable = false}}, SHIFT(173),
  [1545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(631),
  [1547] = {.entry = {.count = 1, .reusable = false}}, SHIFT(174),
  [1549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(633),
  [1551] = {.entry = {.count = 1, .reusable = false}}, SHIFT(142),
  [1553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(662),
  [1555] = {.entry = {.count = 1, .reusable = false}}, SHIFT(242),
  [1557] = {.entry = {.count = 1, .reusable = false}}, SHIFT(175),
  [1559] = {.entry = {.count = 1, .reusable = false}}, SHIFT(25),
  [1561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(653),
  [1563] = {.entry = {.count = 1, .reusable = false}}, SHIFT(176),
  [1565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(648),
  [1567] = {.entry = {.count = 1, .reusable = false}}, SHIFT(26),
  [1569] = {.entry = {.count = 1, .reusable = false}}, SHIFT(27),
  [1571] = {.entry = {.count = 1, .reusable = false}}, SHIFT(190),
  [1573] = {.entry = {.count = 1, .reusable = false}}, SHIFT(28),
  [1575] = {.entry = {.count = 1, .reusable = false}}, SHIFT(29),
  [1577] = {.entry = {.count = 1, .reusable = false}}, SHIFT(177),
  [1579] = {.entry = {.count = 1, .reusable = false}}, SHIFT(30),
  [1581] = {.entry = {.count = 1, .reusable = false}}, SHIFT(178),
  [1583] = {.entry = {.count = 1, .reusable = false}}, SHIFT(179),
  [1585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(651),
  [1587] = {.entry = {.count = 1, .reusable = false}}, SHIFT(131),
  [1589] = {.entry = {.count = 1, .reusable = false}}, SHIFT(31),
  [1591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(657),
  [1593] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18),
  [1595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(660),
  [1597] = {.entry = {.count = 1, .reusable = false}}, SHIFT(129),
  [1599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(661),
  [1601] = {.entry = {.count = 1, .reusable = false}}, SHIFT(33),
  [1603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(663),
  [1605] = {.entry = {.count = 1, .reusable = false}}, SHIFT(34),
  [1607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(664),
  [1609] = {.entry = {.count = 1, .reusable = false}}, SHIFT(35),
  [1611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(666),
  [1613] = {.entry = {.count = 1, .reusable = false}}, SHIFT(36),
  [1615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(667),
  [1617] = {.entry = {.count = 1, .reusable = false}}, SHIFT(37),
  [1619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(669),
  [1621] = {.entry = {.count = 1, .reusable = false}}, SHIFT(38),
  [1623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(670),
  [1625] = {.entry = {.count = 1, .reusable = false}}, SHIFT(39),
  [1627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(671),
  [1629] = {.entry = {.count = 1, .reusable = false}}, SHIFT(40),
  [1631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(672),
  [1633] = {.entry = {.count = 1, .reusable = false}}, SHIFT(41),
  [1635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(673),
  [1637] = {.entry = {.count = 1, .reusable = false}}, SHIFT(180),
  [1639] = {.entry = {.count = 1, .reusable = false}}, SHIFT(132),
  [1641] = {.entry = {.count = 1, .reusable = false}}, SHIFT(151),
  [1643] = {.entry = {.count = 1, .reusable = false}}, SHIFT(181),
  [1645] = {.entry = {.count = 1, .reusable = false}}, SHIFT(153),
  [1647] = {.entry = {.count = 1, .reusable = false}}, SHIFT(42),
  [1649] = {.entry = {.count = 1, .reusable = false}}, SHIFT(43),
  [1651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(682),
  [1653] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1376),
  [1655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(690),
  [1657] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1378),
  [1659] = {.entry = {.count = 1, .reusable = false}}, SHIFT(44),
  [1661] = {.entry = {.count = 1, .reusable = false}}, SHIFT(45),
  [1663] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1379),
  [1665] = {.entry = {.count = 1, .reusable = false}}, SHIFT(46),
  [1667] = {.entry = {.count = 1, .reusable = false}}, SHIFT(47),
  [1669] = {.entry = {.count = 1, .reusable = false}}, SHIFT(134),
  [1671] = {.entry = {.count = 1, .reusable = false}}, SHIFT(48),
  [1673] = {.entry = {.count = 1, .reusable = false}}, SHIFT(49),
  [1675] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1381),
  [1677] = {.entry = {.count = 1, .reusable = false}}, SHIFT(50),
  [1679] = {.entry = {.count = 1, .reusable = false}}, SHIFT(51),
  [1681] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1382),
  [1683] = {.entry = {.count = 1, .reusable = false}}, SHIFT(52),
  [1685] = {.entry = {.count = 1, .reusable = false}}, SHIFT(53),
  [1687] = {.entry = {.count = 1, .reusable = false}}, SHIFT(54),
  [1689] = {.entry = {.count = 1, .reusable = false}}, SHIFT(55),
  [1691] = {.entry = {.count = 1, .reusable = false}}, SHIFT(56),
  [1693] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1383),
  [1695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(696),
  [1697] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1387),
  [1699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(698),
  [1701] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1391),
  [1703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(704),
  [1705] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1394),
  [1707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(705),
  [1709] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1397),
  [1711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(709),
  [1713] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1400),
  [1715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(711),
  [1717] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1401),
  [1719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(712),
  [1721] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1402),
  [1723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(714),
  [1725] = {.entry = {.count = 1, .reusable = false}}, SHIFT(57),
  [1727] = {.entry = {.count = 1, .reusable = false}}, SHIFT(58),
  [1729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(692),
  [1731] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1412),
  [1733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(765),
  [1735] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1459),
  [1737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(766),
  [1739] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1460),
  [1741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(767),
  [1743] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1464),
  [1745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(768),
  [1747] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1469),
  [1749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(771),
  [1751] = {.entry = {.count = 1, .reusable = false}}, SHIFT(154),
  [1753] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1498),
  [1755] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1499),
  [1757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(790),
  [1759] = {.entry = {.count = 1, .reusable = false}}, SHIFT(59),
  [1761] = {.entry = {.count = 1, .reusable = false}}, SHIFT(60),
  [1763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(697),
  [1765] = {.entry = {.count = 1, .reusable = false}}, SHIFT(61),
  [1767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(699),
  [1769] = {.entry = {.count = 1, .reusable = false}}, SHIFT(62),
  [1771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(702),
  [1773] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1502),
  [1775] = {.entry = {.count = 1, .reusable = false}}, SHIFT(63),
  [1777] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1503),
  [1779] = {.entry = {.count = 1, .reusable = false}}, SHIFT(64),
  [1781] = {.entry = {.count = 1, .reusable = false}}, SHIFT(65),
  [1783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(706),
  [1785] = {.entry = {.count = 1, .reusable = false}}, SHIFT(66),
  [1787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(707),
  [1789] = {.entry = {.count = 1, .reusable = false}}, SHIFT(67),
  [1791] = {.entry = {.count = 1, .reusable = false}}, SHIFT(68),
  [1793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(710),
  [1795] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1504),
  [1797] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1505),
  [1799] = {.entry = {.count = 1, .reusable = false}}, SHIFT(69),
  [1801] = {.entry = {.count = 1, .reusable = false}}, SHIFT(70),
  [1803] = {.entry = {.count = 1, .reusable = false}}, SHIFT(71),
  [1805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(713),
  [1807] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1509),
  [1809] = {.entry = {.count = 1, .reusable = false}}, SHIFT(72),
  [1811] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1512),
  [1813] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1516),
  [1815] = {.entry = {.count = 1, .reusable = false}}, SHIFT(73),
  [1817] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1517),
  [1819] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1609),
  [1821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1809),
  [1823] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1809),
  [1825] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1992),
  [1827] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2012),
  [1829] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1970),
  [1831] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1007),
  [1833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1008),
  [1835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1009),
  [1837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1010),
  [1839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1011),
  [1841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1610),
  [1843] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1610),
  [1845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1830),
  [1847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1831),
  [1849] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1328),
  [1851] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1672),
  [1853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(733),
  [1855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2063),
  [1857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1090),
  [1859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(395),
  [1861] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1338),
  [1863] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1181),
  [1865] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1189),
  [1867] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1191),
  [1869] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1195),
  [1871] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1197),
  [1873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(735),
  [1875] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1205),
  [1877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(737),
  [1879] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1209),
  [1881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(738),
  [1883] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1213),
  [1885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(739),
  [1887] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1218),
  [1889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(740),
  [1891] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1235),
  [1893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(741),
  [1895] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1237),
  [1897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(742),
  [1899] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1242),
  [1901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(743),
  [1903] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1244),
  [1905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(744),
  [1907] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1247),
  [1909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(745),
  [1911] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1253),
  [1913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(746),
  [1915] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1257),
  [1917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(747),
  [1919] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1266),
  [1921] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1268),
  [1923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(748),
  [1925] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1274),
  [1927] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1280),
  [1929] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1283),
  [1931] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1223),
  [1933] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1262),
  [1935] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1178),
  [1937] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1193),
  [1939] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1332),
  [1941] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1334),
  [1943] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1336),
  [1945] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1207),
  [1947] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1217),
  [1949] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1317),
  [1951] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1320),
  [1953] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1327),
  [1955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(750),
  [1957] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1340),
  [1959] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1176),
  [1961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(754),
  [1963] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1180),
  [1965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(755),
  [1967] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1234),
  [1969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(758),
  [1971] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1288),
  [1973] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1289),
  [1975] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1292),
  [1977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(760),
  [1979] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1296),
  [1981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(761),
  [1983] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1309),
  [1985] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1318),
  [1987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(763),
  [1989] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1321),
  [1991] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1322),
  [1993] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1323),
  [1995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(764),
  [1997] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1325),
  [1999] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1326),
  [2001] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1519),
  [2003] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1523),
  [2005] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1526),
  [2007] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1529),
  [2009] = {.entry = {.count = 1, .reusable = false}}, SHIFT(299),
  [2011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1807),
  [2013] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1807),
  [2015] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1994),
  [2017] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2014),
  [2019] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1973),
  [2021] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1020),
  [2023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1021),
  [2025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1022),
  [2027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1023),
  [2029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1024),
  [2031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(300),
  [2033] = {.entry = {.count = 1, .reusable = false}}, SHIFT(300),
  [2035] = {.entry = {.count = 1, .reusable = false}}, SHIFT(79),
  [2037] = {.entry = {.count = 1, .reusable = false}}, SHIFT(388),
  [2039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(788),
  [2041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1095),
  [2043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(396),
  [2045] = {.entry = {.count = 1, .reusable = false}}, SHIFT(80),
  [2047] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1531),
  [2049] = {.entry = {.count = 1, .reusable = false}}, SHIFT(81),
  [2051] = {.entry = {.count = 1, .reusable = false}}, SHIFT(82),
  [2053] = {.entry = {.count = 1, .reusable = false}}, SHIFT(83),
  [2055] = {.entry = {.count = 1, .reusable = false}}, SHIFT(84),
  [2057] = {.entry = {.count = 1, .reusable = false}}, SHIFT(85),
  [2059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(792),
  [2061] = {.entry = {.count = 1, .reusable = false}}, SHIFT(87),
  [2063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(794),
  [2065] = {.entry = {.count = 1, .reusable = false}}, SHIFT(88),
  [2067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(795),
  [2069] = {.entry = {.count = 1, .reusable = false}}, SHIFT(89),
  [2071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1054),
  [2073] = {.entry = {.count = 1, .reusable = false}}, SHIFT(90),
  [2075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(797),
  [2077] = {.entry = {.count = 1, .reusable = false}}, SHIFT(91),
  [2079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(798),
  [2081] = {.entry = {.count = 1, .reusable = false}}, SHIFT(92),
  [2083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(799),
  [2085] = {.entry = {.count = 1, .reusable = false}}, SHIFT(93),
  [2087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(800),
  [2089] = {.entry = {.count = 1, .reusable = false}}, SHIFT(94),
  [2091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(801),
  [2093] = {.entry = {.count = 1, .reusable = false}}, SHIFT(95),
  [2095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(802),
  [2097] = {.entry = {.count = 1, .reusable = false}}, SHIFT(96),
  [2099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(803),
  [2101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(97),
  [2103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(804),
  [2105] = {.entry = {.count = 1, .reusable = false}}, SHIFT(98),
  [2107] = {.entry = {.count = 1, .reusable = false}}, SHIFT(99),
  [2109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(806),
  [2111] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1548),
  [2113] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1550),
  [2115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(808),
  [2117] = {.entry = {.count = 1, .reusable = false}}, SHIFT(100),
  [2119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(101),
  [2121] = {.entry = {.count = 1, .reusable = false}}, SHIFT(102),
  [2123] = {.entry = {.count = 1, .reusable = false}}, SHIFT(103),
  [2125] = {.entry = {.count = 1, .reusable = false}}, SHIFT(139),
  [2127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(906),
  [2129] = {.entry = {.count = 1, .reusable = false}}, SHIFT(105),
  [2131] = {.entry = {.count = 1, .reusable = false}}, SHIFT(106),
  [2133] = {.entry = {.count = 1, .reusable = false}}, SHIFT(107),
  [2135] = {.entry = {.count = 1, .reusable = false}}, SHIFT(108),
  [2137] = {.entry = {.count = 1, .reusable = false}}, SHIFT(109),
  [2139] = {.entry = {.count = 1, .reusable = false}}, SHIFT(110),
  [2141] = {.entry = {.count = 1, .reusable = false}}, SHIFT(111),
  [2143] = {.entry = {.count = 1, .reusable = false}}, SHIFT(112),
  [2145] = {.entry = {.count = 1, .reusable = false}}, SHIFT(155),
  [2147] = {.entry = {.count = 1, .reusable = false}}, SHIFT(113),
  [2149] = {.entry = {.count = 1, .reusable = false}}, SHIFT(114),
  [2151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(816),
  [2153] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1560),
  [2155] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1562),
  [2157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(812),
  [2159] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1564),
  [2161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(813),
  [2163] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1570),
  [2165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(818),
  [2167] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1572),
  [2169] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1574),
  [2171] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1576),
  [2173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(823),
  [2175] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1580),
  [2177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(829),
  [2179] = {.entry = {.count = 1, .reusable = false}}, SHIFT(115),
  [2181] = {.entry = {.count = 1, .reusable = false}}, SHIFT(116),
  [2183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(822),
  [2185] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1581),
  [2187] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1582),
  [2189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(834),
  [2191] = {.entry = {.count = 1, .reusable = false}}, SHIFT(117),
  [2193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(824),
  [2195] = {.entry = {.count = 1, .reusable = false}}, SHIFT(118),
  [2197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(827),
  [2199] = {.entry = {.count = 1, .reusable = false}}, SHIFT(119),
  [2201] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1444),
  [2203] = {.entry = {.count = 1, .reusable = false}}, SHIFT(120),
  [2205] = {.entry = {.count = 1, .reusable = false}}, SHIFT(121),
  [2207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(831),
  [2209] = {.entry = {.count = 1, .reusable = false}}, SHIFT(122),
  [2211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(832),
  [2213] = {.entry = {.count = 1, .reusable = false}}, SHIFT(123),
  [2215] = {.entry = {.count = 1, .reusable = false}}, SHIFT(124),
  [2217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(835),
  [2219] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1343),
  [2221] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1344),
  [2223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(836),
  [2225] = {.entry = {.count = 1, .reusable = false}}, SHIFT(125),
  [2227] = {.entry = {.count = 1, .reusable = false}}, SHIFT(126),
  [2229] = {.entry = {.count = 1, .reusable = false}}, SHIFT(127),
  [2231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(837),
  [2233] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1346),
  [2235] = {.entry = {.count = 1, .reusable = false}}, SHIFT(128),
  [2237] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1347),
  [2239] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19),
  [2241] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1593),
  [2243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1824),
  [2245] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1824),
  [2247] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1827),
  [2249] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2016),
  [2251] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1976),
  [2253] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1033),
  [2255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1034),
  [2257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1035),
  [2259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1036),
  [2261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1037),
  [2263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1594),
  [2265] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1594),
  [2267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1869),
  [2269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1870),
  [2271] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1337),
  [2273] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1708),
  [2275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(856),
  [2277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2055),
  [2279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1100),
  [2281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(398),
  [2283] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1183),
  [2285] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1184),
  [2287] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1185),
  [2289] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1186),
  [2291] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1187),
  [2293] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1188),
  [2295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(858),
  [2297] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1192),
  [2299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(860),
  [2301] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1194),
  [2303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(861),
  [2305] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1196),
  [2307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(862),
  [2309] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1198),
  [2311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(863),
  [2313] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1200),
  [2315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(864),
  [2317] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1202),
  [2319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(865),
  [2321] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1204),
  [2323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(866),
  [2325] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1206),
  [2327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(867),
  [2329] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1208),
  [2331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(868),
  [2333] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1210),
  [2335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(869),
  [2337] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1212),
  [2339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(870),
  [2341] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1215),
  [2343] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1216),
  [2345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(871),
  [2347] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1219),
  [2349] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1220),
  [2351] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1221),
  [2353] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1222),
  [2355] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1174),
  [2357] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1224),
  [2359] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1225),
  [2361] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1226),
  [2363] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1227),
  [2365] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1228),
  [2367] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1229),
  [2369] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1230),
  [2371] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1231),
  [2373] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1232),
  [2375] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1233),
  [2377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(873),
  [2379] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1238),
  [2381] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1239),
  [2383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(877),
  [2385] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1241),
  [2387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(878),
  [2389] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1245),
  [2391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(881),
  [2393] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1248),
  [2395] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1249),
  [2397] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1250),
  [2399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(883),
  [2401] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1252),
  [2403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(884),
  [2405] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1255),
  [2407] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1256),
  [2409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(886),
  [2411] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1258),
  [2413] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1259),
  [2415] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1260),
  [2417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(887),
  [2419] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1341),
  [2421] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1263),
  [2423] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1602),
  [2425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1815),
  [2427] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1815),
  [2429] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1998),
  [2431] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2018),
  [2433] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1980),
  [2435] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1043),
  [2437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1044),
  [2439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1045),
  [2441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1046),
  [2443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1047),
  [2445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1603),
  [2447] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1603),
  [2449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1889),
  [2451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1890),
  [2453] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1203),
  [2455] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1667),
  [2457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(907),
  [2459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2058),
  [2461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1105),
  [2463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(401),
  [2465] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1286),
  [2467] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1287),
  [2469] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1294),
  [2471] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1299),
  [2473] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1305),
  [2475] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1316),
  [2477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(909),
  [2479] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1324),
  [2481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(911),
  [2483] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1329),
  [2485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(912),
  [2487] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1331),
  [2489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(913),
  [2491] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1333),
  [2493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(914),
  [2495] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1335),
  [2497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(915),
  [2499] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1339),
  [2501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(916),
  [2503] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1175),
  [2505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(917),
  [2507] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1177),
  [2509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(918),
  [2511] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1179),
  [2513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(919),
  [2515] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1182),
  [2517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(920),
  [2519] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1199),
  [2521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(921),
  [2523] = {.entry = {.count = 1, .reusable = false}}, SHIFT(156),
  [2525] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1211),
  [2527] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1214),
  [2529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(922),
  [2531] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1236),
  [2533] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1243),
  [2535] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1251),
  [2537] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1261),
  [2539] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1264),
  [2541] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1272),
  [2543] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1275),
  [2545] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1276),
  [2547] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1277),
  [2549] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1278),
  [2551] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1279),
  [2553] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1281),
  [2555] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1282),
  [2557] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1284),
  [2559] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1285),
  [2561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(924),
  [2563] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1290),
  [2565] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1291),
  [2567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(928),
  [2569] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1293),
  [2571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(929),
  [2573] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1297),
  [2575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(932),
  [2577] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1300),
  [2579] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1301),
  [2581] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1302),
  [2583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(934),
  [2585] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1304),
  [2587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(935),
  [2589] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1307),
  [2591] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1308),
  [2593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(937),
  [2595] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1310),
  [2597] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1311),
  [2599] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1312),
  [2601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(938),
  [2603] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1314),
  [2605] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1315),
  [2607] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1354),
  [2609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(656),
  [2611] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1357),
  [2613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(659),
  [2615] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1361),
  [2617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(460),
  [2619] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1365),
  [2621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(665),
  [2623] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1366),
  [2625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(668),
  [2627] = {.entry = {.count = 1, .reusable = false}}, SHIFT(157),
  [2629] = {.entry = {.count = 1, .reusable = false}}, SHIFT(158),
  [2631] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1163),
  [2633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(948),
  [2635] = {.entry = {.count = 1, .reusable = false}}, SHIFT(187),
  [2637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1048),
  [2639] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1150),
  [2641] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1167),
  [2643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(952),
  [2645] = {.entry = {.count = 1, .reusable = false}}, SHIFT(159),
  [2647] = {.entry = {.count = 1, .reusable = false}}, SHIFT(188),
  [2649] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1165),
  [2651] = {.entry = {.count = 1, .reusable = false}}, SHIFT(130),
  [2653] = {.entry = {.count = 1, .reusable = false}}, SHIFT(160),
  [2655] = {.entry = {.count = 1, .reusable = false}}, SHIFT(191),
  [2657] = {.entry = {.count = 1, .reusable = false}}, SHIFT(182),
  [2659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(951),
  [2661] = {.entry = {.count = 1, .reusable = false}}, SHIFT(183),
  [2663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(953),
  [2665] = {.entry = {.count = 1, .reusable = false}}, SHIFT(184),
  [2667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(955),
  [2669] = {.entry = {.count = 1, .reusable = false}}, SHIFT(185),
  [2671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(961),
  [2673] = {.entry = {.count = 1, .reusable = false}}, SHIFT(186),
  [2675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(963),
  [2677] = {.entry = {.count = 1, .reusable = false}}, SHIFT(192),
  [2679] = {.entry = {.count = 1, .reusable = false}}, SHIFT(161),
  [2681] = {.entry = {.count = 1, .reusable = false}}, SHIFT(193),
  [2683] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7),
  [2685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(965),
  [2687] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8),
  [2689] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9),
  [2691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(967),
  [2693] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10),
  [2695] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1408),
  [2697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(516),
  [2699] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1409),
  [2701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(517),
  [2703] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1410),
  [2705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(518),
  [2707] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1411),
  [2709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(519),
  [2711] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1413),
  [2713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(520),
  [2715] = {.entry = {.count = 1, .reusable = false}}, SHIFT(162),
  [2717] = {.entry = {.count = 1, .reusable = false}}, SHIFT(243),
  [2719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(622),
  [2721] = {.entry = {.count = 1, .reusable = false}}, SHIFT(163),
  [2723] = {.entry = {.count = 1, .reusable = false}}, SHIFT(135),
  [2725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(650),
  [2727] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1172),
  [2729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(978),
  [2731] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1170),
  [2733] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1173),
  [2735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(980),
  [2737] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1162),
  [2739] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1403),
  [2741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(567),
  [2743] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1404),
  [2745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(568),
  [2747] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1405),
  [2749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(569),
  [2751] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1406),
  [2753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(570),
  [2755] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1407),
  [2757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(571),
  [2759] = {.entry = {.count = 1, .reusable = false}}, SHIFT(194),
  [2761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(462),
  [2763] = {.entry = {.count = 1, .reusable = false}}, SHIFT(195),
  [2765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(464),
  [2767] = {.entry = {.count = 1, .reusable = false}}, SHIFT(196),
  [2769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(465),
  [2771] = {.entry = {.count = 1, .reusable = false}}, SHIFT(197),
  [2773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(467),
  [2775] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1155),
  [2777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(991),
  [2779] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1154),
  [2781] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1158),
  [2783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(993),
  [2785] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1171),
  [2787] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20),
  [2789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(626),
  [2791] = {.entry = {.count = 1, .reusable = false}}, SHIFT(21),
  [2793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(627),
  [2795] = {.entry = {.count = 1, .reusable = false}}, SHIFT(22),
  [2797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(629),
  [2799] = {.entry = {.count = 1, .reusable = false}}, SHIFT(23),
  [2801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(630),
  [2803] = {.entry = {.count = 1, .reusable = false}}, SHIFT(24),
  [2805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(632),
  [2807] = {.entry = {.count = 1, .reusable = false}}, SHIFT(198),
  [2809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(469),
  [2811] = {.entry = {.count = 1, .reusable = false}}, SHIFT(199),
  [2813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(471),
  [2815] = {.entry = {.count = 1, .reusable = false}}, SHIFT(200),
  [2817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(473),
  [2819] = {.entry = {.count = 1, .reusable = false}}, SHIFT(201),
  [2821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(474),
  [2823] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1164),
  [2825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1004),
  [2827] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1168),
  [2829] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1169),
  [2831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1006),
  [2833] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1148),
  [2835] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1240),
  [2837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(716),
  [2839] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1246),
  [2841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(717),
  [2843] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1254),
  [2845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(718),
  [2847] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1270),
  [2849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(719),
  [2851] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1330),
  [2853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(720),
  [2855] = {.entry = {.count = 1, .reusable = false}}, SHIFT(202),
  [2857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(475),
  [2859] = {.entry = {.count = 1, .reusable = false}}, SHIFT(203),
  [2861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(476),
  [2863] = {.entry = {.count = 1, .reusable = false}}, SHIFT(204),
  [2865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(477),
  [2867] = {.entry = {.count = 1, .reusable = false}}, SHIFT(205),
  [2869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(479),
  [2871] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15),
  [2873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1017),
  [2875] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16),
  [2877] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17),
  [2879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1019),
  [2881] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3),
  [2883] = {.entry = {.count = 1, .reusable = false}}, SHIFT(74),
  [2885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(770),
  [2887] = {.entry = {.count = 1, .reusable = false}}, SHIFT(75),
  [2889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(772),
  [2891] = {.entry = {.count = 1, .reusable = false}}, SHIFT(76),
  [2893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(773),
  [2895] = {.entry = {.count = 1, .reusable = false}}, SHIFT(77),
  [2897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(774),
  [2899] = {.entry = {.count = 1, .reusable = false}}, SHIFT(78),
  [2901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(775),
  [2903] = {.entry = {.count = 1, .reusable = false}}, SHIFT(206),
  [2905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(481),
  [2907] = {.entry = {.count = 1, .reusable = false}}, SHIFT(164),
  [2909] = {.entry = {.count = 1, .reusable = false}}, SHIFT(136),
  [2911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(652),
  [2913] = {.entry = {.count = 1, .reusable = false}}, SHIFT(137),
  [2915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(689),
  [2917] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1151),
  [2919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1030),
  [2921] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1152),
  [2923] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1153),
  [2925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1032),
  [2927] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1156),
  [2929] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1295),
  [2931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(839),
  [2933] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1298),
  [2935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(840),
  [2937] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1303),
  [2939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(841),
  [2941] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1306),
  [2943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(842),
  [2945] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1313),
  [2947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(843),
  [2949] = {.entry = {.count = 1, .reusable = false}}, SHIFT(138),
  [2951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(805),
  [2953] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1157),
  [2955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1040),
  [2957] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1159),
  [2959] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1160),
  [2961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1042),
  [2963] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1161),
  [2965] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1265),
  [2967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(889),
  [2969] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1267),
  [2971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(890),
  [2973] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1269),
  [2975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(891),
  [2977] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1271),
  [2979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(892),
  [2981] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1273),
  [2983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(893),
  [2985] = {.entry = {.count = 1, .reusable = false}}, SHIFT(207),
  [2987] = {.entry = {.count = 1, .reusable = false}}, SHIFT(208),
  [2989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(487),
  [2991] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11),
  [2993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1051),
  [2995] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12),
  [2997] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13),
  [2999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1053),
  [3001] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14),
  [3003] = {.entry = {.count = 1, .reusable = false}}, SHIFT(104),
  [3005] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1543),
  [3007] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1571),
  [3009] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1563),
  [3011] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1375),
  [3013] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1374),
  [3015] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1389),
  [3017] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1369),
  [3019] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1440),
  [3021] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1495),
  [3023] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1578),
  [3025] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1433),
  [3027] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1575),
  [3029] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1435),
  [3031] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1436),
  [3033] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1437),
  [3035] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1451),
  [3037] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1452),
  [3039] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1454),
  [3041] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1457),
  [3043] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1458),
  [3045] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1461),
  [3047] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1462),
  [3049] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1463),
  [3051] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1466),
  [3053] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1468),
  [3055] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1471),
  [3057] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1472),
  [3059] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1473),
  [3061] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1474),
  [3063] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1475),
  [3065] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1483),
  [3067] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1484),
  [3069] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1486),
  [3071] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1487),
  [3073] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1488),
  [3075] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1491),
  [3077] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1492),
  [3079] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1494),
  [3081] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1496),
  [3083] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1497),
  [3085] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1507),
  [3087] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1508),
  [3089] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1510),
  [3091] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1513),
  [3093] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1515),
  [3095] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1521),
  [3097] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1522),
  [3099] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1524),
  [3101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1527),
  [3103] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1528),
  [3105] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1534),
  [3107] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1535),
  [3109] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1536),
  [3111] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1537),
  [3113] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1538),
  [3115] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1540),
  [3117] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1577),
  [3119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1544),
  [3121] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1545),
  [3123] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1546),
  [3125] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1547),
  [3127] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1551),
  [3129] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1553),
  [3131] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1555),
  [3133] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1556),
  [3135] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1559),
  [3137] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1561),
  [3139] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1565),
  [3141] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1566),
  [3143] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1569),
  [3145] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1434),
  [3147] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1669),
  [3149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1127),
  [3151] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1683),
  [3153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1145),
  [3155] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1710),
  [3157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1146),
  [3159] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1656),
  [3161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1144),
  [3163] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1702),
  [3165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1128),
  [3167] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1721),
  [3169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1129),
  [3171] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1797),
  [3173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1137),
  [3175] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1776),
  [3177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1134),
  [3179] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1768),
  [3181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1147),
  [3183] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1742),
  [3185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1149),
  [3187] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1735),
  [3189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1135),
  [3191] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1769),
  [3193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1166),
  [3195] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1701),
  [3197] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1691),
  [3199] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1700),
  [3201] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1766),
  [3203] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1771),
  [3205] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1734),
  [3207] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_function_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(1144),
  [3210] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_function_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(1145),
  [3213] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_function_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(1146),
  [3216] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_function_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(1147),
  [3219] = {.entry = {.count = 1, .reusable = false}}, SHIFT(721),
  [3221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(722),
  [3223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(723),
  [3225] = {.entry = {.count = 1, .reusable = false}}, SHIFT(723),
  [3227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(724),
  [3229] = {.entry = {.count = 1, .reusable = false}}, SHIFT(725),
  [3231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(725),
  [3233] = {.entry = {.count = 1, .reusable = false}}, SHIFT(726),
  [3235] = {.entry = {.count = 1, .reusable = false}}, SHIFT(727),
  [3237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(726),
  [3239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(727),
  [3241] = {.entry = {.count = 1, .reusable = false}}, SHIFT(728),
  [3243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(728),
  [3245] = {.entry = {.count = 1, .reusable = false}}, SHIFT(729),
  [3247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(729),
  [3249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(730),
  [3251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(731),
  [3253] = {.entry = {.count = 1, .reusable = false}}, SHIFT(732),
  [3255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1131),
  [3257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(762),
  [3259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(274),
  [3261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(248),
  [3263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(275),
  [3265] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_function_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(1149),
  [3268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(814),
  [3270] = {.entry = {.count = 1, .reusable = false}}, SHIFT(844),
  [3272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(845),
  [3274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(846),
  [3276] = {.entry = {.count = 1, .reusable = false}}, SHIFT(846),
  [3278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(847),
  [3280] = {.entry = {.count = 1, .reusable = false}}, SHIFT(848),
  [3282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(848),
  [3284] = {.entry = {.count = 1, .reusable = false}}, SHIFT(849),
  [3286] = {.entry = {.count = 1, .reusable = false}}, SHIFT(850),
  [3288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(849),
  [3290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(850),
  [3292] = {.entry = {.count = 1, .reusable = false}}, SHIFT(851),
  [3294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(851),
  [3296] = {.entry = {.count = 1, .reusable = false}}, SHIFT(852),
  [3298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(852),
  [3300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(853),
  [3302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(854),
  [3304] = {.entry = {.count = 1, .reusable = false}}, SHIFT(855),
  [3306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1126),
  [3308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(875),
  [3310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(279),
  [3312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(280),
  [3314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(281),
  [3316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(879),
  [3318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(880),
  [3320] = {.entry = {.count = 1, .reusable = false}}, SHIFT(894),
  [3322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(895),
  [3324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(896),
  [3326] = {.entry = {.count = 1, .reusable = false}}, SHIFT(896),
  [3328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(897),
  [3330] = {.entry = {.count = 1, .reusable = false}}, SHIFT(898),
  [3332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(898),
  [3334] = {.entry = {.count = 1, .reusable = false}}, SHIFT(899),
  [3336] = {.entry = {.count = 1, .reusable = false}}, SHIFT(900),
  [3338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(899),
  [3340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(900),
  [3342] = {.entry = {.count = 1, .reusable = false}}, SHIFT(901),
  [3344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(901),
  [3346] = {.entry = {.count = 1, .reusable = false}}, SHIFT(902),
  [3348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(902),
  [3350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(903),
  [3352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(904),
  [3354] = {.entry = {.count = 1, .reusable = false}}, SHIFT(905),
  [3356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1130),
  [3358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(609),
  [3360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(282),
  [3362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(262),
  [3364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(255),
  [3366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(605),
  [3368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(885),
  [3370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(926),
  [3372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(610),
  [3374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(930),
  [3376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(931),
  [3378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(936),
  [3380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(563),
  [3382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(810),
  [3384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(752),
  [3386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(830),
  [3388] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_function_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(1166),
  [3391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(815),
  [3393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(756),
  [3395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(757),
  [3397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(557),
  [3399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(615),
  [3401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(553),
  [3403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(558),
  [3405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(531),
  [3407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1132),
  [3409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(265),
  [3411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(266),
  [3413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(267),
  [3415] = {.entry = {.count = 1, .reusable = false}}, SHIFT(674),
  [3417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(676),
  [3419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(677),
  [3421] = {.entry = {.count = 1, .reusable = false}}, SHIFT(677),
  [3423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(678),
  [3425] = {.entry = {.count = 1, .reusable = false}}, SHIFT(679),
  [3427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(679),
  [3429] = {.entry = {.count = 1, .reusable = false}}, SHIFT(680),
  [3431] = {.entry = {.count = 1, .reusable = false}}, SHIFT(681),
  [3433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(680),
  [3435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(681),
  [3437] = {.entry = {.count = 1, .reusable = false}}, SHIFT(684),
  [3439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(684),
  [3441] = {.entry = {.count = 1, .reusable = false}}, SHIFT(685),
  [3443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(685),
  [3445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(686),
  [3447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(687),
  [3449] = {.entry = {.count = 1, .reusable = false}}, SHIFT(688),
  [3451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1133),
  [3453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(258),
  [3455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(259),
  [3457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(260),
  [3459] = {.entry = {.count = 1, .reusable = false}}, SHIFT(521),
  [3461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(523),
  [3463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(524),
  [3465] = {.entry = {.count = 1, .reusable = false}}, SHIFT(524),
  [3467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(525),
  [3469] = {.entry = {.count = 1, .reusable = false}}, SHIFT(526),
  [3471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(526),
  [3473] = {.entry = {.count = 1, .reusable = false}}, SHIFT(527),
  [3475] = {.entry = {.count = 1, .reusable = false}}, SHIFT(528),
  [3477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(527),
  [3479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(528),
  [3481] = {.entry = {.count = 1, .reusable = false}}, SHIFT(529),
  [3483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(529),
  [3485] = {.entry = {.count = 1, .reusable = false}}, SHIFT(530),
  [3487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(530),
  [3489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(532),
  [3491] = {.entry = {.count = 1, .reusable = false}}, SHIFT(533),
  [3493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(675),
  [3495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(482),
  [3497] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__argument_value, 1, 0, 20),
  [3499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(497),
  [3501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(410),
  [3503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(625),
  [3505] = {.entry = {.count = 1, .reusable = false}}, SHIFT(572),
  [3507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(574),
  [3509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(575),
  [3511] = {.entry = {.count = 1, .reusable = false}}, SHIFT(575),
  [3513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(576),
  [3515] = {.entry = {.count = 1, .reusable = false}}, SHIFT(577),
  [3517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(577),
  [3519] = {.entry = {.count = 1, .reusable = false}}, SHIFT(578),
  [3521] = {.entry = {.count = 1, .reusable = false}}, SHIFT(579),
  [3523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(578),
  [3525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(579),
  [3527] = {.entry = {.count = 1, .reusable = false}}, SHIFT(580),
  [3529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(580),
  [3531] = {.entry = {.count = 1, .reusable = false}}, SHIFT(581),
  [3533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(581),
  [3535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(582),
  [3537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(583),
  [3539] = {.entry = {.count = 1, .reusable = false}}, SHIFT(584),
  [3541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1136),
  [3543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(268),
  [3545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(269),
  [3547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(270),
  [3549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1741),
  [3551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(791),
  [3553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(809),
  [3555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(811),
  [3557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(819),
  [3559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(483),
  [3561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(429),
  [3563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(488),
  [3565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(493),
  [3567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(496),
  [3569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(505),
  [3571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1763),
  [3573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(550),
  [3575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(552),
  [3577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(554),
  [3579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(560),
  [3581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1774),
  [3583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(602),
  [3585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(604),
  [3587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(606),
  [3589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(612),
  [3591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(394),
  [3593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(683),
  [3595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(693),
  [3597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(695),
  [3599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(703),
  [3601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(522),
  [3603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1725),
  [3605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(749),
  [3607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(751),
  [3609] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__parameter_with_default, 3, 0, 35),
  [3611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(753),
  [3613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(759),
  [3615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(346),
  [3617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(807),
  [3619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(817),
  [3621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(821),
  [3623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(828),
  [3625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1673),
  [3627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(872),
  [3629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(874),
  [3631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(876),
  [3633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(882),
  [3635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1706),
  [3637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(923),
  [3639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(925),
  [3641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(927),
  [3643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(933),
  [3645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(946),
  [3647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(949),
  [3649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(964),
  [3651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(966),
  [3653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(977),
  [3655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(979),
  [3657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(990),
  [3659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(573),
  [3661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(992),
  [3663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1003),
  [3665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1005),
  [3667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1016),
  [3669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1018),
  [3671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(514),
  [3673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1029),
  [3675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1031),
  [3677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1039),
  [3679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1041),
  [3681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1050),
  [3683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1052),
  [3685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(506),
  [3687] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1140),
  [3689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1140),
  [3691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1678),
  [3693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1696),
  [3695] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1139),
  [3697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1139),
  [3699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1675),
  [3701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1676),
  [3703] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1138),
  [3705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1138),
  [3707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1686),
  [3709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1687),
  [3711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1785),
  [3713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1792),
  [3715] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1142),
  [3717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1142),
  [3719] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1143),
  [3721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1143),
  [3723] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__argument_name_string_or_identifier_or_null, 1, 0, 0),
  [3725] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1141),
  [3727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1141),
  [3729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1731),
  [3731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1733),
  [3733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1751),
  [3735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1752),
  [3737] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_function_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(1677),
  [3740] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameters, 2, 0, 2),
  [3742] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameters, 2, 0, 2),
  [3744] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameters, 3, 0, 25),
  [3746] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameters, 3, 0, 25),
  [3748] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameters, 4, 0, 33),
  [3750] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameters, 4, 0, 33),
  [3752] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2038),
  [3754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1783),
  [3756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1821),
  [3758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1805),
  [3760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1814),
  [3762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1820),
  [3764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2048),
  [3766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1823),
  [3768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1818),
  [3770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1822),
  [3772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1826),
  [3774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1812),
  [3776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1825),
  [3778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1810),
  [3780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1997),
  [3782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1122),
  [3784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1784),
  [3786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1778),
  [3788] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1587),
  [3790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2021),
  [3792] = {.entry = {.count = 1, .reusable = false}}, SHIFT_EXTRA(),
  [3794] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1588),
  [3796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2025),
  [3798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1780),
  [3800] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1642),
  [3802] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1596),
  [3804] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1597),
  [3806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1781),
  [3808] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1643),
  [3810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1782),
  [3812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2023),
  [3814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1658),
  [3816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(370),
  [3818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(434),
  [3820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1664),
  [3822] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1624),
  [3824] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1625),
  [3826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1788),
  [3828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1786),
  [3830] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1644),
  [3832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1772),
  [3834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1775),
  [3836] = {.entry = {.count = 1, .reusable = false}}, SHIFT(305),
  [3838] = {.entry = {.count = 1, .reusable = false}}, SHIFT(306),
  [3840] = {.entry = {.count = 1, .reusable = false}}, SHIFT(308),
  [3842] = {.entry = {.count = 1, .reusable = false}}, SHIFT(309),
  [3844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1798),
  [3846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1666),
  [3848] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1650),
  [3850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(360),
  [3852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(361),
  [3854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1688),
  [3856] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1653),
  [3858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(367),
  [3860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1689),
  [3862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1690),
  [3864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(366),
  [3866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1713),
  [3868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1714),
  [3870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1715),
  [3872] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1599),
  [3874] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1600),
  [3876] = {.entry = {.count = 1, .reusable = false}}, SHIFT(313),
  [3878] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1646),
  [3880] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1608),
  [3882] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1586),
  [3884] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1648),
  [3886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1716),
  [3888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(448),
  [3890] = {.entry = {.count = 1, .reusable = false}}, SHIFT(314),
  [3892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1684),
  [3894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1685),
  [3896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1928),
  [3898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1061),
  [3900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1806),
  [3902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1796),
  [3904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1697),
  [3906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1729),
  [3908] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1620),
  [3910] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1621),
  [3912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1749),
  [3914] = {.entry = {.count = 1, .reusable = false}}, SHIFT(321),
  [3916] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1613),
  [3918] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1614),
  [3920] = {.entry = {.count = 1, .reusable = false}}, SHIFT(312),
  [3922] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1590),
  [3924] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1591),
  [3926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1692),
  [3928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1730),
  [3930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1745),
  [3932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1711),
  [3934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1712),
  [3936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1747),
  [3938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1717),
  [3940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1665),
  [3942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(407),
  [3944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1779),
  [3946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1916),
  [3948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1062),
  [3950] = {.entry = {.count = 1, .reusable = false}}, SHIFT(320),
  [3952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(440),
  [3954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(362),
  [3956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(363),
  [3958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(364),
  [3960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1789),
  [3962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1718),
  [3964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(365),
  [3966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1791),
  [3968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(442),
  [3970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(421),
  [3972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1064),
  [3974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1719),
  [3976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1750),
  [3978] = {.entry = {.count = 1, .reusable = false}}, SHIFT(295),
  [3980] = {.entry = {.count = 1, .reusable = false}}, SHIFT(296),
  [3982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(436),
  [3984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(435),
  [3986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1793),
  [3988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(438),
  [3990] = {.entry = {.count = 1, .reusable = false}}, SHIFT(287),
  [3992] = {.entry = {.count = 1, .reusable = false}}, SHIFT(292),
  [3994] = {.entry = {.count = 1, .reusable = false}}, SHIFT(315),
  [3996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1059),
  [3998] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1618),
  [4000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(444),
  [4002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1698),
  [4004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(454),
  [4006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(451),
  [4008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(348),
  [4010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1659),
  [4012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(349),
  [4014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(368),
  [4016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1660),
  [4018] = {.entry = {.count = 1, .reusable = false}}, SHIFT(327),
  [4020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1661),
  [4022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1773),
  [4024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(369),
  [4026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(427),
  [4028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1662),
  [4030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1755),
  [4032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(358),
  [4034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(430),
  [4036] = {.entry = {.count = 1, .reusable = false}}, SHIFT(328),
  [4038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(446),
  [4040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(453),
  [4042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(350),
  [4044] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__single_quoted_string_content, 2, 0, 0),
  [4046] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__single_quoted_string_content, 2, 0, 0), SHIFT_REPEAT(2021),
  [4049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1954),
  [4051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1125),
  [4053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1067),
  [4055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(354),
  [4057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1699),
  [4059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1959),
  [4061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1071),
  [4063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(356),
  [4065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1072),
  [4067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1962),
  [4069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1076),
  [4071] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__double_quoted_string_content, 2, 0, 0),
  [4073] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__double_quoted_string_content, 2, 0, 0), SHIFT_REPEAT(2025),
  [4076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1077),
  [4078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(452),
  [4080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1965),
  [4082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1081),
  [4084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1082),
  [4086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1968),
  [4088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1086),
  [4090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(416),
  [4092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1087),
  [4094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1762),
  [4096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1972),
  [4098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1091),
  [4100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1739),
  [4102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1092),
  [4104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1974),
  [4106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1096),
  [4108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1097),
  [4110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1765),
  [4112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1978),
  [4114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1101),
  [4116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(357),
  [4118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1102),
  [4120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1767),
  [4122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1981),
  [4124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1106),
  [4126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1107),
  [4128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1984),
  [4130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1110),
  [4132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1839),
  [4134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2022),
  [4136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1055),
  [4138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1770),
  [4140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1987),
  [4142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1112),
  [4144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1113),
  [4146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1989),
  [4148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1114),
  [4150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1115),
  [4152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1991),
  [4154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1116),
  [4156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1117),
  [4158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1993),
  [4160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1118),
  [4162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1119),
  [4164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1995),
  [4166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1120),
  [4168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1121),
  [4170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1777),
  [4172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1123),
  [4174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1999),
  [4176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1124),
  [4178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1056),
  [4180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2002),
  [4182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1066),
  [4184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2003),
  [4186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2024),
  [4188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1111),
  [4190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2026),
  [4192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2005),
  [4194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2027),
  [4196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2028),
  [4198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2007),
  [4200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2030),
  [4202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2031),
  [4204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2009),
  [4206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2033),
  [4208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2034),
  [4210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2011),
  [4212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2036),
  [4214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2037),
  [4216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2013),
  [4218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2039),
  [4220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2040),
  [4222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2015),
  [4224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2042),
  [4226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2043),
  [4228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2017),
  [4230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2044),
  [4232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2045),
  [4234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2019),
  [4236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2046),
  [4238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2047),
  [4240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1657),
  [4242] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__single_quoted_string_content, 1, 0, 0),
  [4244] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__single_quoted_string_content, 1, 0, 0),
  [4246] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2109),
  [4248] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2079),
  [4250] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2097),
  [4252] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__double_quoted_string_content, 1, 0, 0),
  [4254] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__double_quoted_string_content, 1, 0, 0),
  [4256] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2099),
  [4258] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2078),
  [4260] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2105),
  [4262] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_call_arguments_repeat1, 2, 0, 31), SHIFT_REPEAT(310),
  [4265] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_call_arguments_repeat1, 2, 0, 31),
  [4267] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2110),
  [4269] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2104),
  [4271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1063),
  [4273] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__parameter_without_default, 1, 0, 13),
  [4275] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2088),
  [4277] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2092),
  [4279] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_call_arguments_repeat1, 2, 0, 31), SHIFT_REPEAT(294),
  [4282] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2086),
  [4284] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2087),
  [4286] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__parameter_name, 1, 0, 11),
  [4288] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2103),
  [4290] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2107),
  [4292] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_parameters_repeat1, 2, 0, 34), SHIFT_REPEAT(1806),
  [4295] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_parameters_repeat1, 2, 0, 34),
  [4297] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2083),
  [4299] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2084),
  [4301] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2090),
  [4303] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2091),
  [4305] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2111),
  [4307] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2095),
  [4309] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_function_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(2048),
  [4312] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_call_arguments_repeat1, 2, 0, 31), SHIFT_REPEAT(298),
  [4315] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 1, 0, 13),
  [4317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2100),
  [4319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1631),
  [4321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2102),
  [4323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(326),
  [4325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2093),
  [4327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(304),
  [4329] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__argument_unnamed, 1, 0, 19),
  [4331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2094),
  [4333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1592),
  [4335] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument, 1, 0, 19),
  [4337] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__argument_named, 3, 0, 40),
  [4339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2108),
  [4341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1607),
  [4343] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument, 1, 0, 18),
  [4345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2080),
  [4347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1585),
  [4349] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 1, 0, 12),
  [4351] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_call_arguments_repeat1, 2, 0, 28),
  [4353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2096),
  [4355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(334),
  [4357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2089),
  [4359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1652),
  [4361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2101),
  [4363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1637),
  [4365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2081),
  [4367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(293),
  [4369] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_parameters_repeat1, 2, 0, 32),
  [4371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1073),
  [4373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1060),
  [4375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1595),
  [4377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(297),
  [4379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(458),
  [4381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1098),
  [4383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1099),
  [4385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(457),
  [4387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1088),
  [4389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1089),
  [4391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1083),
  [4393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1647),
  [4395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1103),
  [4397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1104),
  [4399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1084),
  [4401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(307),
  [4403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1601),
  [4405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1109),
  [4407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(322),
  [4409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1068),
  [4411] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [4413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1069),
  [4415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1645),
  [4417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1622),
  [4419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(329),
  [4421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1093),
  [4423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1079),
  [4425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1074),
  [4427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(459),
  [4429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1094),
  [4431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1589),
  [4433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1057),
  [4435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1078),
  [4437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1108),
};

enum ts_external_scanner_symbol_identifiers {
  ts_external_token__start = 0,
  ts_external_token__newline = 1,
  ts_external_token__semicolon = 2,
  ts_external_token__raw_string_open = 3,
  ts_external_token__raw_string_content = 4,
  ts_external_token__raw_string_close = 5,
  ts_external_token__external_else = 6,
  ts_external_token__external_open_parenthesis = 7,
  ts_external_token__external_close_parenthesis = 8,
  ts_external_token__external_open_brace = 9,
  ts_external_token__external_close_brace = 10,
  ts_external_token__external_open_bracket = 11,
  ts_external_token__external_close_bracket = 12,
  ts_external_token__external_open_bracket2 = 13,
  ts_external_token__external_close_bracket2 = 14,
  ts_external_token__error_sentinel = 15,
};

static const TSSymbol ts_external_scanner_symbol_map[EXTERNAL_TOKEN_COUNT] = {
  [ts_external_token__start] = sym__start,
  [ts_external_token__newline] = sym__newline,
  [ts_external_token__semicolon] = sym__semicolon,
  [ts_external_token__raw_string_open] = sym__raw_string_open,
  [ts_external_token__raw_string_content] = sym__raw_string_content,
  [ts_external_token__raw_string_close] = sym__raw_string_close,
  [ts_external_token__external_else] = sym__external_else,
  [ts_external_token__external_open_parenthesis] = sym__external_open_parenthesis,
  [ts_external_token__external_close_parenthesis] = sym__external_close_parenthesis,
  [ts_external_token__external_open_brace] = sym__external_open_brace,
  [ts_external_token__external_close_brace] = sym__external_close_brace,
  [ts_external_token__external_open_bracket] = sym__external_open_bracket,
  [ts_external_token__external_close_bracket] = sym__external_close_bracket,
  [ts_external_token__external_open_bracket2] = sym__external_open_bracket2,
  [ts_external_token__external_close_bracket2] = sym__external_close_bracket2,
  [ts_external_token__error_sentinel] = sym__error_sentinel,
};

static const bool ts_external_scanner_states[38][EXTERNAL_TOKEN_COUNT] = {
  [1] = {
    [ts_external_token__start] = true,
    [ts_external_token__newline] = true,
    [ts_external_token__semicolon] = true,
    [ts_external_token__raw_string_open] = true,
    [ts_external_token__raw_string_content] = true,
    [ts_external_token__raw_string_close] = true,
    [ts_external_token__external_else] = true,
    [ts_external_token__external_open_parenthesis] = true,
    [ts_external_token__external_close_parenthesis] = true,
    [ts_external_token__external_open_brace] = true,
    [ts_external_token__external_close_brace] = true,
    [ts_external_token__external_open_bracket] = true,
    [ts_external_token__external_close_bracket] = true,
    [ts_external_token__external_open_bracket2] = true,
    [ts_external_token__external_close_bracket2] = true,
    [ts_external_token__error_sentinel] = true,
  },
  [2] = {
    [ts_external_token__start] = true,
  },
  [3] = {
    [ts_external_token__newline] = true,
    [ts_external_token__semicolon] = true,
    [ts_external_token__raw_string_open] = true,
    [ts_external_token__external_else] = true,
    [ts_external_token__external_open_parenthesis] = true,
    [ts_external_token__external_open_brace] = true,
    [ts_external_token__external_open_bracket] = true,
    [ts_external_token__external_open_bracket2] = true,
  },
  [4] = {
    [ts_external_token__newline] = true,
    [ts_external_token__semicolon] = true,
    [ts_external_token__raw_string_open] = true,
    [ts_external_token__external_else] = true,
    [ts_external_token__external_open_parenthesis] = true,
    [ts_external_token__external_open_brace] = true,
    [ts_external_token__external_close_brace] = true,
    [ts_external_token__external_open_bracket] = true,
    [ts_external_token__external_open_bracket2] = true,
  },
  [5] = {
    [ts_external_token__newline] = true,
    [ts_external_token__semicolon] = true,
    [ts_external_token__raw_string_open] = true,
    [ts_external_token__external_open_parenthesis] = true,
    [ts_external_token__external_open_brace] = true,
    [ts_external_token__external_close_brace] = true,
    [ts_external_token__external_open_bracket] = true,
    [ts_external_token__external_open_bracket2] = true,
  },
  [6] = {
    [ts_external_token__newline] = true,
    [ts_external_token__semicolon] = true,
    [ts_external_token__raw_string_open] = true,
    [ts_external_token__external_open_parenthesis] = true,
    [ts_external_token__external_open_brace] = true,
    [ts_external_token__external_open_bracket] = true,
    [ts_external_token__external_open_bracket2] = true,
  },
  [7] = {
    [ts_external_token__raw_string_open] = true,
    [ts_external_token__external_open_parenthesis] = true,
    [ts_external_token__external_open_brace] = true,
    [ts_external_token__external_close_bracket] = true,
  },
  [8] = {
    [ts_external_token__raw_string_open] = true,
    [ts_external_token__external_open_parenthesis] = true,
    [ts_external_token__external_open_brace] = true,
    [ts_external_token__external_close_bracket2] = true,
  },
  [9] = {
    [ts_external_token__raw_string_open] = true,
    [ts_external_token__external_open_parenthesis] = true,
    [ts_external_token__external_close_parenthesis] = true,
    [ts_external_token__external_open_brace] = true,
  },
  [10] = {
    [ts_external_token__newline] = true,
    [ts_external_token__semicolon] = true,
    [ts_external_token__raw_string_open] = true,
    [ts_external_token__external_open_parenthesis] = true,
    [ts_external_token__external_open_brace] = true,
    [ts_external_token__external_close_brace] = true,
  },
  [11] = {
    [ts_external_token__newline] = true,
    [ts_external_token__semicolon] = true,
    [ts_external_token__raw_string_open] = true,
    [ts_external_token__external_open_parenthesis] = true,
    [ts_external_token__external_open_brace] = true,
  },
  [12] = {
    [ts_external_token__newline] = true,
    [ts_external_token__raw_string_open] = true,
    [ts_external_token__external_open_parenthesis] = true,
    [ts_external_token__external_open_brace] = true,
  },
  [13] = {
    [ts_external_token__raw_string_open] = true,
    [ts_external_token__external_open_parenthesis] = true,
    [ts_external_token__external_open_brace] = true,
  },
  [14] = {
    [ts_external_token__newline] = true,
    [ts_external_token__raw_string_open] = true,
    [ts_external_token__external_else] = true,
    [ts_external_token__external_open_parenthesis] = true,
    [ts_external_token__external_open_bracket] = true,
    [ts_external_token__external_close_bracket] = true,
    [ts_external_token__external_open_bracket2] = true,
  },
  [15] = {
    [ts_external_token__newline] = true,
    [ts_external_token__raw_string_open] = true,
    [ts_external_token__external_else] = true,
    [ts_external_token__external_open_parenthesis] = true,
    [ts_external_token__external_open_bracket] = true,
    [ts_external_token__external_open_bracket2] = true,
    [ts_external_token__external_close_bracket2] = true,
  },
  [16] = {
    [ts_external_token__newline] = true,
    [ts_external_token__raw_string_open] = true,
    [ts_external_token__external_else] = true,
    [ts_external_token__external_open_parenthesis] = true,
    [ts_external_token__external_close_parenthesis] = true,
    [ts_external_token__external_open_bracket] = true,
    [ts_external_token__external_open_bracket2] = true,
  },
  [17] = {
    [ts_external_token__newline] = true,
    [ts_external_token__raw_string_open] = true,
    [ts_external_token__external_open_parenthesis] = true,
    [ts_external_token__external_open_bracket] = true,
    [ts_external_token__external_close_bracket] = true,
    [ts_external_token__external_open_bracket2] = true,
  },
  [18] = {
    [ts_external_token__newline] = true,
    [ts_external_token__raw_string_open] = true,
    [ts_external_token__external_open_parenthesis] = true,
    [ts_external_token__external_close_parenthesis] = true,
    [ts_external_token__external_open_bracket] = true,
    [ts_external_token__external_open_bracket2] = true,
  },
  [19] = {
    [ts_external_token__newline] = true,
    [ts_external_token__raw_string_open] = true,
    [ts_external_token__external_open_parenthesis] = true,
    [ts_external_token__external_open_bracket] = true,
    [ts_external_token__external_open_bracket2] = true,
    [ts_external_token__external_close_bracket2] = true,
  },
  [20] = {
    [ts_external_token__raw_string_open] = true,
    [ts_external_token__external_else] = true,
    [ts_external_token__external_open_parenthesis] = true,
    [ts_external_token__external_close_parenthesis] = true,
    [ts_external_token__external_open_bracket] = true,
    [ts_external_token__external_open_bracket2] = true,
  },
  [21] = {
    [ts_external_token__raw_string_open] = true,
    [ts_external_token__external_else] = true,
    [ts_external_token__external_open_parenthesis] = true,
    [ts_external_token__external_open_bracket] = true,
    [ts_external_token__external_open_bracket2] = true,
    [ts_external_token__external_close_bracket2] = true,
  },
  [22] = {
    [ts_external_token__raw_string_open] = true,
    [ts_external_token__external_else] = true,
    [ts_external_token__external_open_parenthesis] = true,
    [ts_external_token__external_open_bracket] = true,
    [ts_external_token__external_close_bracket] = true,
    [ts_external_token__external_open_bracket2] = true,
  },
  [23] = {
    [ts_external_token__raw_string_open] = true,
    [ts_external_token__external_open_parenthesis] = true,
    [ts_external_token__external_close_parenthesis] = true,
    [ts_external_token__external_open_bracket] = true,
    [ts_external_token__external_open_bracket2] = true,
  },
  [24] = {
    [ts_external_token__raw_string_open] = true,
    [ts_external_token__external_open_parenthesis] = true,
    [ts_external_token__external_open_bracket] = true,
    [ts_external_token__external_open_bracket2] = true,
    [ts_external_token__external_close_bracket2] = true,
  },
  [25] = {
    [ts_external_token__raw_string_open] = true,
    [ts_external_token__external_open_parenthesis] = true,
    [ts_external_token__external_open_bracket] = true,
    [ts_external_token__external_close_bracket] = true,
    [ts_external_token__external_open_bracket2] = true,
  },
  [26] = {
    [ts_external_token__external_else] = true,
    [ts_external_token__external_open_parenthesis] = true,
    [ts_external_token__external_close_parenthesis] = true,
    [ts_external_token__external_open_bracket] = true,
    [ts_external_token__external_open_bracket2] = true,
  },
  [27] = {
    [ts_external_token__external_else] = true,
    [ts_external_token__external_open_parenthesis] = true,
    [ts_external_token__external_open_bracket] = true,
    [ts_external_token__external_close_bracket] = true,
    [ts_external_token__external_open_bracket2] = true,
  },
  [28] = {
    [ts_external_token__external_else] = true,
    [ts_external_token__external_open_parenthesis] = true,
    [ts_external_token__external_open_bracket] = true,
    [ts_external_token__external_open_bracket2] = true,
    [ts_external_token__external_close_bracket2] = true,
  },
  [29] = {
    [ts_external_token__external_open_parenthesis] = true,
    [ts_external_token__external_open_bracket] = true,
    [ts_external_token__external_close_bracket] = true,
    [ts_external_token__external_open_bracket2] = true,
  },
  [30] = {
    [ts_external_token__external_open_parenthesis] = true,
    [ts_external_token__external_close_parenthesis] = true,
    [ts_external_token__external_open_bracket] = true,
    [ts_external_token__external_open_bracket2] = true,
  },
  [31] = {
    [ts_external_token__external_open_parenthesis] = true,
    [ts_external_token__external_open_bracket] = true,
    [ts_external_token__external_open_bracket2] = true,
    [ts_external_token__external_close_bracket2] = true,
  },
  [32] = {
    [ts_external_token__external_close_parenthesis] = true,
  },
  [33] = {
    [ts_external_token__newline] = true,
    [ts_external_token__external_open_parenthesis] = true,
  },
  [34] = {
    [ts_external_token__external_close_bracket] = true,
  },
  [35] = {
    [ts_external_token__external_close_bracket2] = true,
  },
  [36] = {
    [ts_external_token__raw_string_content] = true,
    [ts_external_token__raw_string_close] = true,
  },
  [37] = {
    [ts_external_token__raw_string_close] = true,
  },
};

#ifdef __cplusplus
extern "C" {
#endif
void *tree_sitter_r_external_scanner_create(void);
void tree_sitter_r_external_scanner_destroy(void *);
bool tree_sitter_r_external_scanner_scan(void *, TSLexer *, const bool *);
unsigned tree_sitter_r_external_scanner_serialize(void *, char *);
void tree_sitter_r_external_scanner_deserialize(void *, const char *, unsigned);

#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_r(void) {
  static const TSLanguage language = {
    .version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = ts_lex_modes,
    .lex_fn = ts_lex,
    .keyword_lex_fn = ts_lex_keywords,
    .keyword_capture_token = sym_identifier,
    .external_scanner = {
      &ts_external_scanner_states[0][0],
      ts_external_scanner_symbol_map,
      tree_sitter_r_external_scanner_create,
      tree_sitter_r_external_scanner_destroy,
      tree_sitter_r_external_scanner_scan,
      tree_sitter_r_external_scanner_serialize,
      tree_sitter_r_external_scanner_deserialize,
    },
    .primary_state_ids = ts_primary_state_ids,
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
