#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#define LANGUAGE_VERSION 14
#define STATE_COUNT 2831
#define LARGE_STATE_COUNT 189
#define SYMBOL_COUNT 270
#define ALIAS_COUNT 4
#define TOKEN_COUNT 108
#define EXTERNAL_TOKEN_COUNT 12
#define FIELD_COUNT 32
#define MAX_ALIAS_SEQUENCE_LENGTH 10
#define PRODUCTION_ID_COUNT 140

enum ts_symbol_identifiers {
  sym_identifier = 1,
  anon_sym_SEMI = 2,
  anon_sym_import = 3,
  anon_sym_DOT = 4,
  anon_sym_from = 5,
  anon_sym___future__ = 6,
  anon_sym_LPAREN = 7,
  anon_sym_RPAREN = 8,
  anon_sym_COMMA = 9,
  anon_sym_as = 10,
  anon_sym_STAR = 11,
  anon_sym_print = 12,
  anon_sym_GT_GT = 13,
  anon_sym_assert = 14,
  anon_sym_COLON_EQ = 15,
  anon_sym_return = 16,
  anon_sym_del = 17,
  anon_sym_raise = 18,
  anon_sym_pass = 19,
  anon_sym_break = 20,
  anon_sym_continue = 21,
  anon_sym_if = 22,
  anon_sym_COLON = 23,
  anon_sym_elif = 24,
  anon_sym_else = 25,
  anon_sym_match = 26,
  anon_sym_case = 27,
  anon_sym_async = 28,
  anon_sym_for = 29,
  anon_sym_in = 30,
  anon_sym_while = 31,
  anon_sym_try = 32,
  anon_sym_except = 33,
  anon_sym_except_STAR = 34,
  anon_sym_finally = 35,
  anon_sym_with = 36,
  anon_sym_def = 37,
  anon_sym_DASH_GT = 38,
  anon_sym_STAR_STAR = 39,
  anon_sym_global = 40,
  anon_sym_nonlocal = 41,
  anon_sym_exec = 42,
  anon_sym_type = 43,
  anon_sym_EQ = 44,
  anon_sym_class = 45,
  anon_sym_LBRACK = 46,
  anon_sym_RBRACK = 47,
  anon_sym_AT = 48,
  anon_sym_DASH = 49,
  anon_sym__ = 50,
  anon_sym_PIPE = 51,
  anon_sym_LBRACE = 52,
  anon_sym_RBRACE = 53,
  anon_sym_PLUS = 54,
  anon_sym_not = 55,
  anon_sym_and = 56,
  anon_sym_or = 57,
  anon_sym_SLASH = 58,
  anon_sym_PERCENT = 59,
  anon_sym_SLASH_SLASH = 60,
  anon_sym_AMP = 61,
  anon_sym_CARET = 62,
  anon_sym_LT_LT = 63,
  anon_sym_TILDE = 64,
  anon_sym_LT = 65,
  anon_sym_LT_EQ = 66,
  anon_sym_EQ_EQ = 67,
  anon_sym_BANG_EQ = 68,
  anon_sym_GT_EQ = 69,
  anon_sym_GT = 70,
  anon_sym_LT_GT = 71,
  anon_sym_is = 72,
  anon_sym_lambda = 73,
  anon_sym_PLUS_EQ = 74,
  anon_sym_DASH_EQ = 75,
  anon_sym_STAR_EQ = 76,
  anon_sym_SLASH_EQ = 77,
  anon_sym_AT_EQ = 78,
  anon_sym_SLASH_SLASH_EQ = 79,
  anon_sym_PERCENT_EQ = 80,
  anon_sym_STAR_STAR_EQ = 81,
  anon_sym_GT_GT_EQ = 82,
  anon_sym_LT_LT_EQ = 83,
  anon_sym_AMP_EQ = 84,
  anon_sym_CARET_EQ = 85,
  anon_sym_PIPE_EQ = 86,
  anon_sym_yield = 87,
  sym_ellipsis = 88,
  sym_escape_sequence = 89,
  sym__not_escape_sequence = 90,
  aux_sym_format_specifier_token1 = 91,
  sym_type_conversion = 92,
  sym_integer = 93,
  sym_float = 94,
  anon_sym_await = 95,
  sym_true = 96,
  sym_false = 97,
  sym_none = 98,
  sym_comment = 99,
  sym_line_continuation = 100,
  sym__newline = 101,
  sym__indent = 102,
  sym__dedent = 103,
  sym_string_start = 104,
  sym__string_content = 105,
  sym_escape_interpolation = 106,
  sym_string_end = 107,
  sym_module = 108,
  sym__statement = 109,
  sym__simple_statements = 110,
  sym_import_statement = 111,
  sym_import_prefix = 112,
  sym_relative_import = 113,
  sym_future_import_statement = 114,
  sym_import_from_statement = 115,
  sym__import_list = 116,
  sym_aliased_import = 117,
  sym_wildcard_import = 118,
  sym_print_statement = 119,
  sym_chevron = 120,
  sym_assert_statement = 121,
  sym_expression_statement = 122,
  sym_named_expression = 123,
  sym__named_expression_lhs = 124,
  sym_return_statement = 125,
  sym_delete_statement = 126,
  sym_raise_statement = 127,
  sym_pass_statement = 128,
  sym_break_statement = 129,
  sym_continue_statement = 130,
  sym_if_statement = 131,
  sym_elif_clause = 132,
  sym_else_clause = 133,
  sym_match_statement = 134,
  sym__match_block = 135,
  sym_case_clause = 136,
  sym_for_statement = 137,
  sym_while_statement = 138,
  sym_try_statement = 139,
  sym_except_clause = 140,
  sym_except_group_clause = 141,
  sym_finally_clause = 142,
  sym_with_statement = 143,
  sym_with_clause = 144,
  sym_with_item = 145,
  sym_function_definition = 146,
  sym_parameters = 147,
  sym_lambda_parameters = 148,
  sym_list_splat = 149,
  sym_dictionary_splat = 150,
  sym_global_statement = 151,
  sym_nonlocal_statement = 152,
  sym_exec_statement = 153,
  sym_type_alias_statement = 154,
  sym_class_definition = 155,
  sym_type_parameter = 156,
  sym_parenthesized_list_splat = 157,
  sym_argument_list = 158,
  sym_decorated_definition = 159,
  sym_decorator = 160,
  sym_block = 161,
  sym_expression_list = 162,
  sym_dotted_name = 163,
  sym_case_pattern = 164,
  sym__simple_pattern = 165,
  sym__as_pattern = 166,
  sym_union_pattern = 167,
  sym__list_pattern = 168,
  sym__tuple_pattern = 169,
  sym_dict_pattern = 170,
  sym__key_value_pattern = 171,
  sym_keyword_pattern = 172,
  sym_splat_pattern = 173,
  sym_class_pattern = 174,
  sym_complex_pattern = 175,
  sym__parameters = 176,
  sym__patterns = 177,
  sym_parameter = 178,
  sym_pattern = 179,
  sym_tuple_pattern = 180,
  sym_list_pattern = 181,
  sym_default_parameter = 182,
  sym_typed_default_parameter = 183,
  sym_list_splat_pattern = 184,
  sym_dictionary_splat_pattern = 185,
  sym_as_pattern = 186,
  sym__expression_within_for_in_clause = 187,
  sym_expression = 188,
  sym_primary_expression = 189,
  sym_not_operator = 190,
  sym_boolean_operator = 191,
  sym_binary_operator = 192,
  sym_unary_operator = 193,
  sym_comparison_operator = 194,
  sym_lambda = 195,
  sym_lambda_within_for_in_clause = 196,
  sym_assignment = 197,
  sym_augmented_assignment = 198,
  sym_pattern_list = 199,
  sym__right_hand_side = 200,
  sym_yield = 201,
  sym_attribute = 202,
  sym_subscript = 203,
  sym_slice = 204,
  sym_call = 205,
  sym_typed_parameter = 206,
  sym_type = 207,
  sym_splat_type = 208,
  sym_generic_type = 209,
  sym_union_type = 210,
  sym_constrained_type = 211,
  sym_member_type = 212,
  sym_keyword_argument = 213,
  sym_list = 214,
  sym_set = 215,
  sym_tuple = 216,
  sym_dictionary = 217,
  sym_pair = 218,
  sym_list_comprehension = 219,
  sym_dictionary_comprehension = 220,
  sym_set_comprehension = 221,
  sym_generator_expression = 222,
  sym__comprehension_clauses = 223,
  sym_parenthesized_expression = 224,
  sym__collection_elements = 225,
  sym_for_in_clause = 226,
  sym_if_clause = 227,
  sym_conditional_expression = 228,
  sym_concatenated_string = 229,
  sym_string = 230,
  sym_string_content = 231,
  sym_interpolation = 232,
  sym__f_expression = 233,
  sym_format_specifier = 234,
  sym_await = 235,
  sym_positional_separator = 236,
  sym_keyword_separator = 237,
  aux_sym_module_repeat1 = 238,
  aux_sym__simple_statements_repeat1 = 239,
  aux_sym_import_prefix_repeat1 = 240,
  aux_sym__import_list_repeat1 = 241,
  aux_sym_print_statement_repeat1 = 242,
  aux_sym_assert_statement_repeat1 = 243,
  aux_sym_if_statement_repeat1 = 244,
  aux_sym_match_statement_repeat1 = 245,
  aux_sym__match_block_repeat1 = 246,
  aux_sym_case_clause_repeat1 = 247,
  aux_sym_try_statement_repeat1 = 248,
  aux_sym_try_statement_repeat2 = 249,
  aux_sym_with_clause_repeat1 = 250,
  aux_sym_global_statement_repeat1 = 251,
  aux_sym_type_parameter_repeat1 = 252,
  aux_sym_argument_list_repeat1 = 253,
  aux_sym_decorated_definition_repeat1 = 254,
  aux_sym_dotted_name_repeat1 = 255,
  aux_sym_union_pattern_repeat1 = 256,
  aux_sym_dict_pattern_repeat1 = 257,
  aux_sym__parameters_repeat1 = 258,
  aux_sym__patterns_repeat1 = 259,
  aux_sym_comparison_operator_repeat1 = 260,
  aux_sym_subscript_repeat1 = 261,
  aux_sym_dictionary_repeat1 = 262,
  aux_sym__comprehension_clauses_repeat1 = 263,
  aux_sym__collection_elements_repeat1 = 264,
  aux_sym_for_in_clause_repeat1 = 265,
  aux_sym_concatenated_string_repeat1 = 266,
  aux_sym_string_repeat1 = 267,
  aux_sym_string_content_repeat1 = 268,
  aux_sym_format_specifier_repeat1 = 269,
  alias_sym_as_pattern_target = 270,
  alias_sym_format_expression = 271,
  anon_alias_sym_isnot = 272,
  anon_alias_sym_notin = 273,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [sym_identifier] = "identifier",
  [anon_sym_SEMI] = ";",
  [anon_sym_import] = "import",
  [anon_sym_DOT] = ".",
  [anon_sym_from] = "from",
  [anon_sym___future__] = "__future__",
  [anon_sym_LPAREN] = "(",
  [anon_sym_RPAREN] = ")",
  [anon_sym_COMMA] = ",",
  [anon_sym_as] = "as",
  [anon_sym_STAR] = "*",
  [anon_sym_print] = "print",
  [anon_sym_GT_GT] = ">>",
  [anon_sym_assert] = "assert",
  [anon_sym_COLON_EQ] = ":=",
  [anon_sym_return] = "return",
  [anon_sym_del] = "del",
  [anon_sym_raise] = "raise",
  [anon_sym_pass] = "pass",
  [anon_sym_break] = "break",
  [anon_sym_continue] = "continue",
  [anon_sym_if] = "if",
  [anon_sym_COLON] = ":",
  [anon_sym_elif] = "elif",
  [anon_sym_else] = "else",
  [anon_sym_match] = "match",
  [anon_sym_case] = "case",
  [anon_sym_async] = "async",
  [anon_sym_for] = "for",
  [anon_sym_in] = "in",
  [anon_sym_while] = "while",
  [anon_sym_try] = "try",
  [anon_sym_except] = "except",
  [anon_sym_except_STAR] = "except*",
  [anon_sym_finally] = "finally",
  [anon_sym_with] = "with",
  [anon_sym_def] = "def",
  [anon_sym_DASH_GT] = "->",
  [anon_sym_STAR_STAR] = "**",
  [anon_sym_global] = "global",
  [anon_sym_nonlocal] = "nonlocal",
  [anon_sym_exec] = "exec",
  [anon_sym_type] = "type",
  [anon_sym_EQ] = "=",
  [anon_sym_class] = "class",
  [anon_sym_LBRACK] = "[",
  [anon_sym_RBRACK] = "]",
  [anon_sym_AT] = "@",
  [anon_sym_DASH] = "-",
  [anon_sym__] = "_",
  [anon_sym_PIPE] = "|",
  [anon_sym_LBRACE] = "{",
  [anon_sym_RBRACE] = "}",
  [anon_sym_PLUS] = "+",
  [anon_sym_not] = "not",
  [anon_sym_and] = "and",
  [anon_sym_or] = "or",
  [anon_sym_SLASH] = "/",
  [anon_sym_PERCENT] = "%",
  [anon_sym_SLASH_SLASH] = "//",
  [anon_sym_AMP] = "&",
  [anon_sym_CARET] = "^",
  [anon_sym_LT_LT] = "<<",
  [anon_sym_TILDE] = "~",
  [anon_sym_LT] = "<",
  [anon_sym_LT_EQ] = "<=",
  [anon_sym_EQ_EQ] = "==",
  [anon_sym_BANG_EQ] = "!=",
  [anon_sym_GT_EQ] = ">=",
  [anon_sym_GT] = ">",
  [anon_sym_LT_GT] = "<>",
  [anon_sym_is] = "is",
  [anon_sym_lambda] = "lambda",
  [anon_sym_PLUS_EQ] = "+=",
  [anon_sym_DASH_EQ] = "-=",
  [anon_sym_STAR_EQ] = "*=",
  [anon_sym_SLASH_EQ] = "/=",
  [anon_sym_AT_EQ] = "@=",
  [anon_sym_SLASH_SLASH_EQ] = "//=",
  [anon_sym_PERCENT_EQ] = "%=",
  [anon_sym_STAR_STAR_EQ] = "**=",
  [anon_sym_GT_GT_EQ] = ">>=",
  [anon_sym_LT_LT_EQ] = "<<=",
  [anon_sym_AMP_EQ] = "&=",
  [anon_sym_CARET_EQ] = "^=",
  [anon_sym_PIPE_EQ] = "|=",
  [anon_sym_yield] = "yield",
  [sym_ellipsis] = "ellipsis",
  [sym_escape_sequence] = "escape_sequence",
  [sym__not_escape_sequence] = "_not_escape_sequence",
  [aux_sym_format_specifier_token1] = "format_specifier_token1",
  [sym_type_conversion] = "type_conversion",
  [sym_integer] = "integer",
  [sym_float] = "float",
  [anon_sym_await] = "await",
  [sym_true] = "true",
  [sym_false] = "false",
  [sym_none] = "none",
  [sym_comment] = "comment",
  [sym_line_continuation] = "line_continuation",
  [sym__newline] = "_newline",
  [sym__indent] = "_indent",
  [sym__dedent] = "_dedent",
  [sym_string_start] = "string_start",
  [sym__string_content] = "_string_content",
  [sym_escape_interpolation] = "escape_interpolation",
  [sym_string_end] = "string_end",
  [sym_module] = "module",
  [sym__statement] = "_statement",
  [sym__simple_statements] = "_simple_statements",
  [sym_import_statement] = "import_statement",
  [sym_import_prefix] = "import_prefix",
  [sym_relative_import] = "relative_import",
  [sym_future_import_statement] = "future_import_statement",
  [sym_import_from_statement] = "import_from_statement",
  [sym__import_list] = "_import_list",
  [sym_aliased_import] = "aliased_import",
  [sym_wildcard_import] = "wildcard_import",
  [sym_print_statement] = "print_statement",
  [sym_chevron] = "chevron",
  [sym_assert_statement] = "assert_statement",
  [sym_expression_statement] = "expression_statement",
  [sym_named_expression] = "named_expression",
  [sym__named_expression_lhs] = "_named_expression_lhs",
  [sym_return_statement] = "return_statement",
  [sym_delete_statement] = "delete_statement",
  [sym_raise_statement] = "raise_statement",
  [sym_pass_statement] = "pass_statement",
  [sym_break_statement] = "break_statement",
  [sym_continue_statement] = "continue_statement",
  [sym_if_statement] = "if_statement",
  [sym_elif_clause] = "elif_clause",
  [sym_else_clause] = "else_clause",
  [sym_match_statement] = "match_statement",
  [sym__match_block] = "block",
  [sym_case_clause] = "case_clause",
  [sym_for_statement] = "for_statement",
  [sym_while_statement] = "while_statement",
  [sym_try_statement] = "try_statement",
  [sym_except_clause] = "except_clause",
  [sym_except_group_clause] = "except_group_clause",
  [sym_finally_clause] = "finally_clause",
  [sym_with_statement] = "with_statement",
  [sym_with_clause] = "with_clause",
  [sym_with_item] = "with_item",
  [sym_function_definition] = "function_definition",
  [sym_parameters] = "parameters",
  [sym_lambda_parameters] = "lambda_parameters",
  [sym_list_splat] = "list_splat",
  [sym_dictionary_splat] = "dictionary_splat",
  [sym_global_statement] = "global_statement",
  [sym_nonlocal_statement] = "nonlocal_statement",
  [sym_exec_statement] = "exec_statement",
  [sym_type_alias_statement] = "type_alias_statement",
  [sym_class_definition] = "class_definition",
  [sym_type_parameter] = "type_parameter",
  [sym_parenthesized_list_splat] = "parenthesized_list_splat",
  [sym_argument_list] = "argument_list",
  [sym_decorated_definition] = "decorated_definition",
  [sym_decorator] = "decorator",
  [sym_block] = "block",
  [sym_expression_list] = "expression_list",
  [sym_dotted_name] = "dotted_name",
  [sym_case_pattern] = "case_pattern",
  [sym__simple_pattern] = "_simple_pattern",
  [sym__as_pattern] = "as_pattern",
  [sym_union_pattern] = "union_pattern",
  [sym__list_pattern] = "list_pattern",
  [sym__tuple_pattern] = "tuple_pattern",
  [sym_dict_pattern] = "dict_pattern",
  [sym__key_value_pattern] = "_key_value_pattern",
  [sym_keyword_pattern] = "keyword_pattern",
  [sym_splat_pattern] = "splat_pattern",
  [sym_class_pattern] = "class_pattern",
  [sym_complex_pattern] = "complex_pattern",
  [sym__parameters] = "_parameters",
  [sym__patterns] = "_patterns",
  [sym_parameter] = "parameter",
  [sym_pattern] = "pattern",
  [sym_tuple_pattern] = "tuple_pattern",
  [sym_list_pattern] = "list_pattern",
  [sym_default_parameter] = "default_parameter",
  [sym_typed_default_parameter] = "typed_default_parameter",
  [sym_list_splat_pattern] = "list_splat_pattern",
  [sym_dictionary_splat_pattern] = "dictionary_splat_pattern",
  [sym_as_pattern] = "as_pattern",
  [sym__expression_within_for_in_clause] = "_expression_within_for_in_clause",
  [sym_expression] = "expression",
  [sym_primary_expression] = "primary_expression",
  [sym_not_operator] = "not_operator",
  [sym_boolean_operator] = "boolean_operator",
  [sym_binary_operator] = "binary_operator",
  [sym_unary_operator] = "unary_operator",
  [sym_comparison_operator] = "comparison_operator",
  [sym_lambda] = "lambda",
  [sym_lambda_within_for_in_clause] = "lambda",
  [sym_assignment] = "assignment",
  [sym_augmented_assignment] = "augmented_assignment",
  [sym_pattern_list] = "pattern_list",
  [sym__right_hand_side] = "_right_hand_side",
  [sym_yield] = "yield",
  [sym_attribute] = "attribute",
  [sym_subscript] = "subscript",
  [sym_slice] = "slice",
  [sym_call] = "call",
  [sym_typed_parameter] = "typed_parameter",
  [sym_type] = "type",
  [sym_splat_type] = "splat_type",
  [sym_generic_type] = "generic_type",
  [sym_union_type] = "union_type",
  [sym_constrained_type] = "constrained_type",
  [sym_member_type] = "member_type",
  [sym_keyword_argument] = "keyword_argument",
  [sym_list] = "list",
  [sym_set] = "set",
  [sym_tuple] = "tuple",
  [sym_dictionary] = "dictionary",
  [sym_pair] = "pair",
  [sym_list_comprehension] = "list_comprehension",
  [sym_dictionary_comprehension] = "dictionary_comprehension",
  [sym_set_comprehension] = "set_comprehension",
  [sym_generator_expression] = "generator_expression",
  [sym__comprehension_clauses] = "_comprehension_clauses",
  [sym_parenthesized_expression] = "parenthesized_expression",
  [sym__collection_elements] = "_collection_elements",
  [sym_for_in_clause] = "for_in_clause",
  [sym_if_clause] = "if_clause",
  [sym_conditional_expression] = "conditional_expression",
  [sym_concatenated_string] = "concatenated_string",
  [sym_string] = "string",
  [sym_string_content] = "string_content",
  [sym_interpolation] = "interpolation",
  [sym__f_expression] = "_f_expression",
  [sym_format_specifier] = "format_specifier",
  [sym_await] = "await",
  [sym_positional_separator] = "positional_separator",
  [sym_keyword_separator] = "keyword_separator",
  [aux_sym_module_repeat1] = "module_repeat1",
  [aux_sym__simple_statements_repeat1] = "_simple_statements_repeat1",
  [aux_sym_import_prefix_repeat1] = "import_prefix_repeat1",
  [aux_sym__import_list_repeat1] = "_import_list_repeat1",
  [aux_sym_print_statement_repeat1] = "print_statement_repeat1",
  [aux_sym_assert_statement_repeat1] = "assert_statement_repeat1",
  [aux_sym_if_statement_repeat1] = "if_statement_repeat1",
  [aux_sym_match_statement_repeat1] = "match_statement_repeat1",
  [aux_sym__match_block_repeat1] = "_match_block_repeat1",
  [aux_sym_case_clause_repeat1] = "case_clause_repeat1",
  [aux_sym_try_statement_repeat1] = "try_statement_repeat1",
  [aux_sym_try_statement_repeat2] = "try_statement_repeat2",
  [aux_sym_with_clause_repeat1] = "with_clause_repeat1",
  [aux_sym_global_statement_repeat1] = "global_statement_repeat1",
  [aux_sym_type_parameter_repeat1] = "type_parameter_repeat1",
  [aux_sym_argument_list_repeat1] = "argument_list_repeat1",
  [aux_sym_decorated_definition_repeat1] = "decorated_definition_repeat1",
  [aux_sym_dotted_name_repeat1] = "dotted_name_repeat1",
  [aux_sym_union_pattern_repeat1] = "union_pattern_repeat1",
  [aux_sym_dict_pattern_repeat1] = "dict_pattern_repeat1",
  [aux_sym__parameters_repeat1] = "_parameters_repeat1",
  [aux_sym__patterns_repeat1] = "_patterns_repeat1",
  [aux_sym_comparison_operator_repeat1] = "comparison_operator_repeat1",
  [aux_sym_subscript_repeat1] = "subscript_repeat1",
  [aux_sym_dictionary_repeat1] = "dictionary_repeat1",
  [aux_sym__comprehension_clauses_repeat1] = "_comprehension_clauses_repeat1",
  [aux_sym__collection_elements_repeat1] = "_collection_elements_repeat1",
  [aux_sym_for_in_clause_repeat1] = "for_in_clause_repeat1",
  [aux_sym_concatenated_string_repeat1] = "concatenated_string_repeat1",
  [aux_sym_string_repeat1] = "string_repeat1",
  [aux_sym_string_content_repeat1] = "string_content_repeat1",
  [aux_sym_format_specifier_repeat1] = "format_specifier_repeat1",
  [alias_sym_as_pattern_target] = "as_pattern_target",
  [alias_sym_format_expression] = "format_expression",
  [anon_alias_sym_isnot] = "is not",
  [anon_alias_sym_notin] = "not in",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [sym_identifier] = sym_identifier,
  [anon_sym_SEMI] = anon_sym_SEMI,
  [anon_sym_import] = anon_sym_import,
  [anon_sym_DOT] = anon_sym_DOT,
  [anon_sym_from] = anon_sym_from,
  [anon_sym___future__] = anon_sym___future__,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_as] = anon_sym_as,
  [anon_sym_STAR] = anon_sym_STAR,
  [anon_sym_print] = anon_sym_print,
  [anon_sym_GT_GT] = anon_sym_GT_GT,
  [anon_sym_assert] = anon_sym_assert,
  [anon_sym_COLON_EQ] = anon_sym_COLON_EQ,
  [anon_sym_return] = anon_sym_return,
  [anon_sym_del] = anon_sym_del,
  [anon_sym_raise] = anon_sym_raise,
  [anon_sym_pass] = anon_sym_pass,
  [anon_sym_break] = anon_sym_break,
  [anon_sym_continue] = anon_sym_continue,
  [anon_sym_if] = anon_sym_if,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym_elif] = anon_sym_elif,
  [anon_sym_else] = anon_sym_else,
  [anon_sym_match] = anon_sym_match,
  [anon_sym_case] = anon_sym_case,
  [anon_sym_async] = anon_sym_async,
  [anon_sym_for] = anon_sym_for,
  [anon_sym_in] = anon_sym_in,
  [anon_sym_while] = anon_sym_while,
  [anon_sym_try] = anon_sym_try,
  [anon_sym_except] = anon_sym_except,
  [anon_sym_except_STAR] = anon_sym_except_STAR,
  [anon_sym_finally] = anon_sym_finally,
  [anon_sym_with] = anon_sym_with,
  [anon_sym_def] = anon_sym_def,
  [anon_sym_DASH_GT] = anon_sym_DASH_GT,
  [anon_sym_STAR_STAR] = anon_sym_STAR_STAR,
  [anon_sym_global] = anon_sym_global,
  [anon_sym_nonlocal] = anon_sym_nonlocal,
  [anon_sym_exec] = anon_sym_exec,
  [anon_sym_type] = anon_sym_type,
  [anon_sym_EQ] = anon_sym_EQ,
  [anon_sym_class] = anon_sym_class,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_AT] = anon_sym_AT,
  [anon_sym_DASH] = anon_sym_DASH,
  [anon_sym__] = anon_sym__,
  [anon_sym_PIPE] = anon_sym_PIPE,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [anon_sym_PLUS] = anon_sym_PLUS,
  [anon_sym_not] = anon_sym_not,
  [anon_sym_and] = anon_sym_and,
  [anon_sym_or] = anon_sym_or,
  [anon_sym_SLASH] = anon_sym_SLASH,
  [anon_sym_PERCENT] = anon_sym_PERCENT,
  [anon_sym_SLASH_SLASH] = anon_sym_SLASH_SLASH,
  [anon_sym_AMP] = anon_sym_AMP,
  [anon_sym_CARET] = anon_sym_CARET,
  [anon_sym_LT_LT] = anon_sym_LT_LT,
  [anon_sym_TILDE] = anon_sym_TILDE,
  [anon_sym_LT] = anon_sym_LT,
  [anon_sym_LT_EQ] = anon_sym_LT_EQ,
  [anon_sym_EQ_EQ] = anon_sym_EQ_EQ,
  [anon_sym_BANG_EQ] = anon_sym_BANG_EQ,
  [anon_sym_GT_EQ] = anon_sym_GT_EQ,
  [anon_sym_GT] = anon_sym_GT,
  [anon_sym_LT_GT] = anon_sym_LT_GT,
  [anon_sym_is] = anon_sym_is,
  [anon_sym_lambda] = anon_sym_lambda,
  [anon_sym_PLUS_EQ] = anon_sym_PLUS_EQ,
  [anon_sym_DASH_EQ] = anon_sym_DASH_EQ,
  [anon_sym_STAR_EQ] = anon_sym_STAR_EQ,
  [anon_sym_SLASH_EQ] = anon_sym_SLASH_EQ,
  [anon_sym_AT_EQ] = anon_sym_AT_EQ,
  [anon_sym_SLASH_SLASH_EQ] = anon_sym_SLASH_SLASH_EQ,
  [anon_sym_PERCENT_EQ] = anon_sym_PERCENT_EQ,
  [anon_sym_STAR_STAR_EQ] = anon_sym_STAR_STAR_EQ,
  [anon_sym_GT_GT_EQ] = anon_sym_GT_GT_EQ,
  [anon_sym_LT_LT_EQ] = anon_sym_LT_LT_EQ,
  [anon_sym_AMP_EQ] = anon_sym_AMP_EQ,
  [anon_sym_CARET_EQ] = anon_sym_CARET_EQ,
  [anon_sym_PIPE_EQ] = anon_sym_PIPE_EQ,
  [anon_sym_yield] = anon_sym_yield,
  [sym_ellipsis] = sym_ellipsis,
  [sym_escape_sequence] = sym_escape_sequence,
  [sym__not_escape_sequence] = sym__not_escape_sequence,
  [aux_sym_format_specifier_token1] = aux_sym_format_specifier_token1,
  [sym_type_conversion] = sym_type_conversion,
  [sym_integer] = sym_integer,
  [sym_float] = sym_float,
  [anon_sym_await] = anon_sym_await,
  [sym_true] = sym_true,
  [sym_false] = sym_false,
  [sym_none] = sym_none,
  [sym_comment] = sym_comment,
  [sym_line_continuation] = sym_line_continuation,
  [sym__newline] = sym__newline,
  [sym__indent] = sym__indent,
  [sym__dedent] = sym__dedent,
  [sym_string_start] = sym_string_start,
  [sym__string_content] = sym__string_content,
  [sym_escape_interpolation] = sym_escape_interpolation,
  [sym_string_end] = sym_string_end,
  [sym_module] = sym_module,
  [sym__statement] = sym__statement,
  [sym__simple_statements] = sym__simple_statements,
  [sym_import_statement] = sym_import_statement,
  [sym_import_prefix] = sym_import_prefix,
  [sym_relative_import] = sym_relative_import,
  [sym_future_import_statement] = sym_future_import_statement,
  [sym_import_from_statement] = sym_import_from_statement,
  [sym__import_list] = sym__import_list,
  [sym_aliased_import] = sym_aliased_import,
  [sym_wildcard_import] = sym_wildcard_import,
  [sym_print_statement] = sym_print_statement,
  [sym_chevron] = sym_chevron,
  [sym_assert_statement] = sym_assert_statement,
  [sym_expression_statement] = sym_expression_statement,
  [sym_named_expression] = sym_named_expression,
  [sym__named_expression_lhs] = sym__named_expression_lhs,
  [sym_return_statement] = sym_return_statement,
  [sym_delete_statement] = sym_delete_statement,
  [sym_raise_statement] = sym_raise_statement,
  [sym_pass_statement] = sym_pass_statement,
  [sym_break_statement] = sym_break_statement,
  [sym_continue_statement] = sym_continue_statement,
  [sym_if_statement] = sym_if_statement,
  [sym_elif_clause] = sym_elif_clause,
  [sym_else_clause] = sym_else_clause,
  [sym_match_statement] = sym_match_statement,
  [sym__match_block] = sym_block,
  [sym_case_clause] = sym_case_clause,
  [sym_for_statement] = sym_for_statement,
  [sym_while_statement] = sym_while_statement,
  [sym_try_statement] = sym_try_statement,
  [sym_except_clause] = sym_except_clause,
  [sym_except_group_clause] = sym_except_group_clause,
  [sym_finally_clause] = sym_finally_clause,
  [sym_with_statement] = sym_with_statement,
  [sym_with_clause] = sym_with_clause,
  [sym_with_item] = sym_with_item,
  [sym_function_definition] = sym_function_definition,
  [sym_parameters] = sym_parameters,
  [sym_lambda_parameters] = sym_lambda_parameters,
  [sym_list_splat] = sym_list_splat,
  [sym_dictionary_splat] = sym_dictionary_splat,
  [sym_global_statement] = sym_global_statement,
  [sym_nonlocal_statement] = sym_nonlocal_statement,
  [sym_exec_statement] = sym_exec_statement,
  [sym_type_alias_statement] = sym_type_alias_statement,
  [sym_class_definition] = sym_class_definition,
  [sym_type_parameter] = sym_type_parameter,
  [sym_parenthesized_list_splat] = sym_parenthesized_list_splat,
  [sym_argument_list] = sym_argument_list,
  [sym_decorated_definition] = sym_decorated_definition,
  [sym_decorator] = sym_decorator,
  [sym_block] = sym_block,
  [sym_expression_list] = sym_expression_list,
  [sym_dotted_name] = sym_dotted_name,
  [sym_case_pattern] = sym_case_pattern,
  [sym__simple_pattern] = sym__simple_pattern,
  [sym__as_pattern] = sym_as_pattern,
  [sym_union_pattern] = sym_union_pattern,
  [sym__list_pattern] = sym_list_pattern,
  [sym__tuple_pattern] = sym_tuple_pattern,
  [sym_dict_pattern] = sym_dict_pattern,
  [sym__key_value_pattern] = sym__key_value_pattern,
  [sym_keyword_pattern] = sym_keyword_pattern,
  [sym_splat_pattern] = sym_splat_pattern,
  [sym_class_pattern] = sym_class_pattern,
  [sym_complex_pattern] = sym_complex_pattern,
  [sym__parameters] = sym__parameters,
  [sym__patterns] = sym__patterns,
  [sym_parameter] = sym_parameter,
  [sym_pattern] = sym_pattern,
  [sym_tuple_pattern] = sym_tuple_pattern,
  [sym_list_pattern] = sym_list_pattern,
  [sym_default_parameter] = sym_default_parameter,
  [sym_typed_default_parameter] = sym_typed_default_parameter,
  [sym_list_splat_pattern] = sym_list_splat_pattern,
  [sym_dictionary_splat_pattern] = sym_dictionary_splat_pattern,
  [sym_as_pattern] = sym_as_pattern,
  [sym__expression_within_for_in_clause] = sym__expression_within_for_in_clause,
  [sym_expression] = sym_expression,
  [sym_primary_expression] = sym_primary_expression,
  [sym_not_operator] = sym_not_operator,
  [sym_boolean_operator] = sym_boolean_operator,
  [sym_binary_operator] = sym_binary_operator,
  [sym_unary_operator] = sym_unary_operator,
  [sym_comparison_operator] = sym_comparison_operator,
  [sym_lambda] = sym_lambda,
  [sym_lambda_within_for_in_clause] = sym_lambda,
  [sym_assignment] = sym_assignment,
  [sym_augmented_assignment] = sym_augmented_assignment,
  [sym_pattern_list] = sym_pattern_list,
  [sym__right_hand_side] = sym__right_hand_side,
  [sym_yield] = sym_yield,
  [sym_attribute] = sym_attribute,
  [sym_subscript] = sym_subscript,
  [sym_slice] = sym_slice,
  [sym_call] = sym_call,
  [sym_typed_parameter] = sym_typed_parameter,
  [sym_type] = sym_type,
  [sym_splat_type] = sym_splat_type,
  [sym_generic_type] = sym_generic_type,
  [sym_union_type] = sym_union_type,
  [sym_constrained_type] = sym_constrained_type,
  [sym_member_type] = sym_member_type,
  [sym_keyword_argument] = sym_keyword_argument,
  [sym_list] = sym_list,
  [sym_set] = sym_set,
  [sym_tuple] = sym_tuple,
  [sym_dictionary] = sym_dictionary,
  [sym_pair] = sym_pair,
  [sym_list_comprehension] = sym_list_comprehension,
  [sym_dictionary_comprehension] = sym_dictionary_comprehension,
  [sym_set_comprehension] = sym_set_comprehension,
  [sym_generator_expression] = sym_generator_expression,
  [sym__comprehension_clauses] = sym__comprehension_clauses,
  [sym_parenthesized_expression] = sym_parenthesized_expression,
  [sym__collection_elements] = sym__collection_elements,
  [sym_for_in_clause] = sym_for_in_clause,
  [sym_if_clause] = sym_if_clause,
  [sym_conditional_expression] = sym_conditional_expression,
  [sym_concatenated_string] = sym_concatenated_string,
  [sym_string] = sym_string,
  [sym_string_content] = sym_string_content,
  [sym_interpolation] = sym_interpolation,
  [sym__f_expression] = sym__f_expression,
  [sym_format_specifier] = sym_format_specifier,
  [sym_await] = sym_await,
  [sym_positional_separator] = sym_positional_separator,
  [sym_keyword_separator] = sym_keyword_separator,
  [aux_sym_module_repeat1] = aux_sym_module_repeat1,
  [aux_sym__simple_statements_repeat1] = aux_sym__simple_statements_repeat1,
  [aux_sym_import_prefix_repeat1] = aux_sym_import_prefix_repeat1,
  [aux_sym__import_list_repeat1] = aux_sym__import_list_repeat1,
  [aux_sym_print_statement_repeat1] = aux_sym_print_statement_repeat1,
  [aux_sym_assert_statement_repeat1] = aux_sym_assert_statement_repeat1,
  [aux_sym_if_statement_repeat1] = aux_sym_if_statement_repeat1,
  [aux_sym_match_statement_repeat1] = aux_sym_match_statement_repeat1,
  [aux_sym__match_block_repeat1] = aux_sym__match_block_repeat1,
  [aux_sym_case_clause_repeat1] = aux_sym_case_clause_repeat1,
  [aux_sym_try_statement_repeat1] = aux_sym_try_statement_repeat1,
  [aux_sym_try_statement_repeat2] = aux_sym_try_statement_repeat2,
  [aux_sym_with_clause_repeat1] = aux_sym_with_clause_repeat1,
  [aux_sym_global_statement_repeat1] = aux_sym_global_statement_repeat1,
  [aux_sym_type_parameter_repeat1] = aux_sym_type_parameter_repeat1,
  [aux_sym_argument_list_repeat1] = aux_sym_argument_list_repeat1,
  [aux_sym_decorated_definition_repeat1] = aux_sym_decorated_definition_repeat1,
  [aux_sym_dotted_name_repeat1] = aux_sym_dotted_name_repeat1,
  [aux_sym_union_pattern_repeat1] = aux_sym_union_pattern_repeat1,
  [aux_sym_dict_pattern_repeat1] = aux_sym_dict_pattern_repeat1,
  [aux_sym__parameters_repeat1] = aux_sym__parameters_repeat1,
  [aux_sym__patterns_repeat1] = aux_sym__patterns_repeat1,
  [aux_sym_comparison_operator_repeat1] = aux_sym_comparison_operator_repeat1,
  [aux_sym_subscript_repeat1] = aux_sym_subscript_repeat1,
  [aux_sym_dictionary_repeat1] = aux_sym_dictionary_repeat1,
  [aux_sym__comprehension_clauses_repeat1] = aux_sym__comprehension_clauses_repeat1,
  [aux_sym__collection_elements_repeat1] = aux_sym__collection_elements_repeat1,
  [aux_sym_for_in_clause_repeat1] = aux_sym_for_in_clause_repeat1,
  [aux_sym_concatenated_string_repeat1] = aux_sym_concatenated_string_repeat1,
  [aux_sym_string_repeat1] = aux_sym_string_repeat1,
  [aux_sym_string_content_repeat1] = aux_sym_string_content_repeat1,
  [aux_sym_format_specifier_repeat1] = aux_sym_format_specifier_repeat1,
  [alias_sym_as_pattern_target] = alias_sym_as_pattern_target,
  [alias_sym_format_expression] = alias_sym_format_expression,
  [anon_alias_sym_isnot] = anon_alias_sym_isnot,
  [anon_alias_sym_notin] = anon_alias_sym_notin,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [sym_identifier] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_SEMI] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_import] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_from] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___future__] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_as] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_print] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_assert] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_return] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_del] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_raise] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_pass] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_break] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_continue] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_if] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_elif] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_else] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_match] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_case] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_async] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_for] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_in] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_while] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_try] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_except] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_except_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_finally] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_with] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_def] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_global] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_nonlocal] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_exec] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_type] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_class] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym__] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_not] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_and] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_or] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_is] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_lambda] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH_SLASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR_STAR_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_yield] = {
    .visible = true,
    .named = false,
  },
  [sym_ellipsis] = {
    .visible = true,
    .named = true,
  },
  [sym_escape_sequence] = {
    .visible = true,
    .named = true,
  },
  [sym__not_escape_sequence] = {
    .visible = false,
    .named = true,
  },
  [aux_sym_format_specifier_token1] = {
    .visible = false,
    .named = false,
  },
  [sym_type_conversion] = {
    .visible = true,
    .named = true,
  },
  [sym_integer] = {
    .visible = true,
    .named = true,
  },
  [sym_float] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_await] = {
    .visible = true,
    .named = false,
  },
  [sym_true] = {
    .visible = true,
    .named = true,
  },
  [sym_false] = {
    .visible = true,
    .named = true,
  },
  [sym_none] = {
    .visible = true,
    .named = true,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_line_continuation] = {
    .visible = true,
    .named = true,
  },
  [sym__newline] = {
    .visible = false,
    .named = true,
  },
  [sym__indent] = {
    .visible = false,
    .named = true,
  },
  [sym__dedent] = {
    .visible = false,
    .named = true,
  },
  [sym_string_start] = {
    .visible = true,
    .named = true,
  },
  [sym__string_content] = {
    .visible = false,
    .named = true,
  },
  [sym_escape_interpolation] = {
    .visible = true,
    .named = true,
  },
  [sym_string_end] = {
    .visible = true,
    .named = true,
  },
  [sym_module] = {
    .visible = true,
    .named = true,
  },
  [sym__statement] = {
    .visible = false,
    .named = true,
  },
  [sym__simple_statements] = {
    .visible = false,
    .named = true,
  },
  [sym_import_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_import_prefix] = {
    .visible = true,
    .named = true,
  },
  [sym_relative_import] = {
    .visible = true,
    .named = true,
  },
  [sym_future_import_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_import_from_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__import_list] = {
    .visible = false,
    .named = true,
  },
  [sym_aliased_import] = {
    .visible = true,
    .named = true,
  },
  [sym_wildcard_import] = {
    .visible = true,
    .named = true,
  },
  [sym_print_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_chevron] = {
    .visible = true,
    .named = true,
  },
  [sym_assert_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_expression_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_named_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__named_expression_lhs] = {
    .visible = false,
    .named = true,
  },
  [sym_return_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_delete_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_raise_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_pass_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_break_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_continue_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_if_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_elif_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_else_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_match_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__match_block] = {
    .visible = true,
    .named = true,
  },
  [sym_case_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_for_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_while_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_try_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_except_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_except_group_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_finally_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_with_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_with_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_with_item] = {
    .visible = true,
    .named = true,
  },
  [sym_function_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_parameters] = {
    .visible = true,
    .named = true,
  },
  [sym_lambda_parameters] = {
    .visible = true,
    .named = true,
  },
  [sym_list_splat] = {
    .visible = true,
    .named = true,
  },
  [sym_dictionary_splat] = {
    .visible = true,
    .named = true,
  },
  [sym_global_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_nonlocal_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_exec_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_type_alias_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_class_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_type_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym_parenthesized_list_splat] = {
    .visible = true,
    .named = true,
  },
  [sym_argument_list] = {
    .visible = true,
    .named = true,
  },
  [sym_decorated_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_decorator] = {
    .visible = true,
    .named = true,
  },
  [sym_block] = {
    .visible = true,
    .named = true,
  },
  [sym_expression_list] = {
    .visible = true,
    .named = true,
  },
  [sym_dotted_name] = {
    .visible = true,
    .named = true,
  },
  [sym_case_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym__simple_pattern] = {
    .visible = false,
    .named = true,
  },
  [sym__as_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_union_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym__list_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym__tuple_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_dict_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym__key_value_pattern] = {
    .visible = false,
    .named = true,
  },
  [sym_keyword_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_splat_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_class_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_complex_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym__parameters] = {
    .visible = false,
    .named = true,
  },
  [sym__patterns] = {
    .visible = false,
    .named = true,
  },
  [sym_parameter] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_pattern] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_tuple_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_list_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_default_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym_typed_default_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym_list_splat_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_dictionary_splat_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_as_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym__expression_within_for_in_clause] = {
    .visible = false,
    .named = true,
  },
  [sym_expression] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_primary_expression] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_not_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_boolean_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_binary_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_unary_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_comparison_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_lambda] = {
    .visible = true,
    .named = true,
  },
  [sym_lambda_within_for_in_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_assignment] = {
    .visible = true,
    .named = true,
  },
  [sym_augmented_assignment] = {
    .visible = true,
    .named = true,
  },
  [sym_pattern_list] = {
    .visible = true,
    .named = true,
  },
  [sym__right_hand_side] = {
    .visible = false,
    .named = true,
  },
  [sym_yield] = {
    .visible = true,
    .named = true,
  },
  [sym_attribute] = {
    .visible = true,
    .named = true,
  },
  [sym_subscript] = {
    .visible = true,
    .named = true,
  },
  [sym_slice] = {
    .visible = true,
    .named = true,
  },
  [sym_call] = {
    .visible = true,
    .named = true,
  },
  [sym_typed_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym_type] = {
    .visible = true,
    .named = true,
  },
  [sym_splat_type] = {
    .visible = true,
    .named = true,
  },
  [sym_generic_type] = {
    .visible = true,
    .named = true,
  },
  [sym_union_type] = {
    .visible = true,
    .named = true,
  },
  [sym_constrained_type] = {
    .visible = true,
    .named = true,
  },
  [sym_member_type] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_argument] = {
    .visible = true,
    .named = true,
  },
  [sym_list] = {
    .visible = true,
    .named = true,
  },
  [sym_set] = {
    .visible = true,
    .named = true,
  },
  [sym_tuple] = {
    .visible = true,
    .named = true,
  },
  [sym_dictionary] = {
    .visible = true,
    .named = true,
  },
  [sym_pair] = {
    .visible = true,
    .named = true,
  },
  [sym_list_comprehension] = {
    .visible = true,
    .named = true,
  },
  [sym_dictionary_comprehension] = {
    .visible = true,
    .named = true,
  },
  [sym_set_comprehension] = {
    .visible = true,
    .named = true,
  },
  [sym_generator_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__comprehension_clauses] = {
    .visible = false,
    .named = true,
  },
  [sym_parenthesized_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__collection_elements] = {
    .visible = false,
    .named = true,
  },
  [sym_for_in_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_if_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_conditional_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_concatenated_string] = {
    .visible = true,
    .named = true,
  },
  [sym_string] = {
    .visible = true,
    .named = true,
  },
  [sym_string_content] = {
    .visible = true,
    .named = true,
  },
  [sym_interpolation] = {
    .visible = true,
    .named = true,
  },
  [sym__f_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_format_specifier] = {
    .visible = true,
    .named = true,
  },
  [sym_await] = {
    .visible = true,
    .named = true,
  },
  [sym_positional_separator] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_separator] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_module_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__simple_statements_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_import_prefix_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__import_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_print_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_assert_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_if_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_match_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__match_block_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_case_clause_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_try_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_try_statement_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_with_clause_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_global_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_type_parameter_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_argument_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_decorated_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_dotted_name_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_union_pattern_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_dict_pattern_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__parameters_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__patterns_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_comparison_operator_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_subscript_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_dictionary_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__comprehension_clauses_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__collection_elements_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_for_in_clause_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_concatenated_string_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_content_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_format_specifier_repeat1] = {
    .visible = false,
    .named = false,
  },
  [alias_sym_as_pattern_target] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_format_expression] = {
    .visible = true,
    .named = true,
  },
  [anon_alias_sym_isnot] = {
    .visible = true,
    .named = false,
  },
  [anon_alias_sym_notin] = {
    .visible = true,
    .named = false,
  },
};

enum ts_field_identifiers {
  field_alias = 1,
  field_alternative = 2,
  field_argument = 3,
  field_arguments = 4,
  field_attribute = 5,
  field_body = 6,
  field_cause = 7,
  field_code = 8,
  field_condition = 9,
  field_consequence = 10,
  field_definition = 11,
  field_expression = 12,
  field_format_specifier = 13,
  field_function = 14,
  field_guard = 15,
  field_key = 16,
  field_left = 17,
  field_module_name = 18,
  field_name = 19,
  field_object = 20,
  field_operator = 21,
  field_operators = 22,
  field_parameters = 23,
  field_return_type = 24,
  field_right = 25,
  field_subject = 26,
  field_subscript = 27,
  field_superclasses = 28,
  field_type = 29,
  field_type_conversion = 30,
  field_type_parameters = 31,
  field_value = 32,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_alias] = "alias",
  [field_alternative] = "alternative",
  [field_argument] = "argument",
  [field_arguments] = "arguments",
  [field_attribute] = "attribute",
  [field_body] = "body",
  [field_cause] = "cause",
  [field_code] = "code",
  [field_condition] = "condition",
  [field_consequence] = "consequence",
  [field_definition] = "definition",
  [field_expression] = "expression",
  [field_format_specifier] = "format_specifier",
  [field_function] = "function",
  [field_guard] = "guard",
  [field_key] = "key",
  [field_left] = "left",
  [field_module_name] = "module_name",
  [field_name] = "name",
  [field_object] = "object",
  [field_operator] = "operator",
  [field_operators] = "operators",
  [field_parameters] = "parameters",
  [field_return_type] = "return_type",
  [field_right] = "right",
  [field_subject] = "subject",
  [field_subscript] = "subscript",
  [field_superclasses] = "superclasses",
  [field_type] = "type",
  [field_type_conversion] = "type_conversion",
  [field_type_parameters] = "type_parameters",
  [field_value] = "value",
};

static const TSFieldMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [3] = {.index = 0, .length = 1},
  [4] = {.index = 1, .length = 1},
  [6] = {.index = 2, .length = 1},
  [7] = {.index = 3, .length = 1},
  [8] = {.index = 4, .length = 1},
  [9] = {.index = 5, .length = 2},
  [10] = {.index = 7, .length = 2},
  [11] = {.index = 9, .length = 1},
  [12] = {.index = 10, .length = 1},
  [13] = {.index = 11, .length = 2},
  [14] = {.index = 13, .length = 1},
  [15] = {.index = 14, .length = 2},
  [16] = {.index = 16, .length = 1},
  [17] = {.index = 17, .length = 1},
  [18] = {.index = 18, .length = 2},
  [19] = {.index = 20, .length = 2},
  [20] = {.index = 22, .length = 2},
  [21] = {.index = 24, .length = 3},
  [22] = {.index = 27, .length = 1},
  [23] = {.index = 28, .length = 2},
  [24] = {.index = 30, .length = 1},
  [25] = {.index = 31, .length = 2},
  [26] = {.index = 33, .length = 1},
  [27] = {.index = 34, .length = 1},
  [28] = {.index = 35, .length = 2},
  [29] = {.index = 37, .length = 2},
  [30] = {.index = 39, .length = 1},
  [31] = {.index = 40, .length = 2},
  [32] = {.index = 42, .length = 1},
  [34] = {.index = 43, .length = 1},
  [35] = {.index = 44, .length = 2},
  [36] = {.index = 46, .length = 1},
  [37] = {.index = 47, .length = 2},
  [38] = {.index = 49, .length = 1},
  [39] = {.index = 50, .length = 3},
  [40] = {.index = 53, .length = 2},
  [41] = {.index = 55, .length = 2},
  [42] = {.index = 17, .length = 1},
  [43] = {.index = 57, .length = 1},
  [44] = {.index = 58, .length = 2},
  [45] = {.index = 60, .length = 2},
  [46] = {.index = 62, .length = 1},
  [47] = {.index = 63, .length = 2},
  [48] = {.index = 65, .length = 2},
  [49] = {.index = 67, .length = 2},
  [50] = {.index = 67, .length = 2},
  [52] = {.index = 69, .length = 2},
  [53] = {.index = 71, .length = 2},
  [54] = {.index = 73, .length = 1},
  [55] = {.index = 74, .length = 3},
  [56] = {.index = 77, .length = 3},
  [57] = {.index = 80, .length = 3},
  [58] = {.index = 83, .length = 3},
  [59] = {.index = 86, .length = 4},
  [60] = {.index = 90, .length = 1},
  [61] = {.index = 91, .length = 3},
  [62] = {.index = 94, .length = 3},
  [63] = {.index = 97, .length = 2},
  [64] = {.index = 99, .length = 2},
  [65] = {.index = 101, .length = 3},
  [66] = {.index = 104, .length = 3},
  [67] = {.index = 107, .length = 3},
  [68] = {.index = 110, .length = 3},
  [69] = {.index = 113, .length = 3},
  [70] = {.index = 18, .length = 2},
  [71] = {.index = 116, .length = 1},
  [72] = {.index = 117, .length = 3},
  [73] = {.index = 120, .length = 2},
  [74] = {.index = 122, .length = 2},
  [75] = {.index = 124, .length = 2},
  [76] = {.index = 126, .length = 3},
  [77] = {.index = 129, .length = 1},
  [78] = {.index = 130, .length = 2},
  [79] = {.index = 132, .length = 2},
  [80] = {.index = 134, .length = 4},
  [81] = {.index = 138, .length = 2},
  [82] = {.index = 140, .length = 4},
  [83] = {.index = 144, .length = 4},
  [84] = {.index = 148, .length = 1},
  [85] = {.index = 149, .length = 4},
  [86] = {.index = 153, .length = 2},
  [87] = {.index = 155, .length = 3},
  [88] = {.index = 158, .length = 3},
  [89] = {.index = 161, .length = 4},
  [91] = {.index = 165, .length = 4},
  [92] = {.index = 169, .length = 4},
  [93] = {.index = 173, .length = 4},
  [94] = {.index = 177, .length = 4},
  [95] = {.index = 181, .length = 4},
  [96] = {.index = 185, .length = 3},
  [97] = {.index = 188, .length = 3},
  [98] = {.index = 191, .length = 2},
  [99] = {.index = 193, .length = 3},
  [100] = {.index = 196, .length = 5},
  [101] = {.index = 201, .length = 3},
  [102] = {.index = 204, .length = 4},
  [103] = {.index = 208, .length = 4},
  [104] = {.index = 212, .length = 4},
  [105] = {.index = 216, .length = 4},
  [107] = {.index = 220, .length = 4},
  [108] = {.index = 224, .length = 5},
  [109] = {.index = 229, .length = 5},
  [110] = {.index = 234, .length = 3},
  [111] = {.index = 237, .length = 2},
  [112] = {.index = 239, .length = 1},
  [113] = {.index = 240, .length = 4},
  [114] = {.index = 244, .length = 4},
  [115] = {.index = 248, .length = 4},
  [116] = {.index = 252, .length = 5},
  [117] = {.index = 257, .length = 5},
  [118] = {.index = 262, .length = 5},
  [119] = {.index = 267, .length = 5},
  [120] = {.index = 272, .length = 4},
  [121] = {.index = 276, .length = 4},
  [122] = {.index = 280, .length = 2},
  [123] = {.index = 282, .length = 1},
  [124] = {.index = 283, .length = 2},
  [125] = {.index = 285, .length = 2},
  [126] = {.index = 287, .length = 5},
  [127] = {.index = 292, .length = 5},
  [128] = {.index = 297, .length = 5},
  [130] = {.index = 302, .length = 6},
  [131] = {.index = 308, .length = 2},
  [132] = {.index = 310, .length = 2},
  [133] = {.index = 312, .length = 3},
  [134] = {.index = 315, .length = 1},
  [135] = {.index = 316, .length = 6},
  [136] = {.index = 322, .length = 3},
  [137] = {.index = 325, .length = 2},
  [138] = {.index = 327, .length = 2},
  [139] = {.index = 329, .length = 3},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_name, 1, .inherited = true},
  [1] =
    {field_name, 0},
  [2] =
    {field_argument, 1},
  [3] =
    {field_value, 0},
  [4] =
    {field_code, 1},
  [5] =
    {field_argument, 1},
    {field_operator, 0},
  [7] =
    {field_arguments, 1},
    {field_function, 0},
  [9] =
    {field_operators, 1, .inherited = true},
  [10] =
    {field_definition, 1},
  [11] =
    {field_name, 0},
    {field_name, 1, .inherited = true},
  [13] =
    {field_argument, 2, .inherited = true},
  [14] =
    {field_argument, 1},
    {field_argument, 2, .inherited = true},
  [16] =
    {field_cause, 2},
  [17] =
    {field_body, 2},
  [18] =
    {field_name, 0},
    {field_value, 2},
  [20] =
    {field_left, 0},
    {field_type, 2},
  [22] =
    {field_left, 0},
    {field_right, 2},
  [24] =
    {field_left, 0},
    {field_operator, 1},
    {field_right, 2},
  [27] =
    {field_alias, 2},
  [28] =
    {field_attribute, 2},
    {field_object, 0},
  [30] =
    {field_operators, 0},
  [31] =
    {field_operators, 0, .inherited = true},
    {field_operators, 1, .inherited = true},
  [33] =
    {field_expression, 1},
  [34] =
    {field_name, 1},
  [35] =
    {field_name, 0, .inherited = true},
    {field_name, 1, .inherited = true},
  [37] =
    {field_alias, 2},
    {field_name, 0},
  [39] =
    {field_name, 3, .inherited = true},
  [40] =
    {field_module_name, 1},
    {field_name, 3, .inherited = true},
  [42] =
    {field_module_name, 1},
  [43] =
    {field_body, 1},
  [44] =
    {field_argument, 0, .inherited = true},
    {field_argument, 1, .inherited = true},
  [46] =
    {field_cause, 3},
  [47] =
    {field_condition, 1},
    {field_consequence, 3},
  [49] =
    {field_subject, 1},
  [50] =
    {field_alternative, 3, .inherited = true},
    {field_body, 3},
    {field_subject, 1},
  [53] =
    {field_subject, 0, .inherited = true},
    {field_subject, 1, .inherited = true},
  [55] =
    {field_body, 3},
    {field_condition, 1},
  [57] =
    {field_body, 3},
  [58] =
    {field_body, 3},
    {field_name, 1},
  [60] =
    {field_key, 0},
    {field_value, 2},
  [62] =
    {field_type, 2},
  [63] =
    {field_body, 3},
    {field_parameters, 1},
  [65] =
    {field_subscript, 2},
    {field_value, 0},
  [67] =
    {field_operators, 0},
    {field_operators, 1},
  [69] =
    {field_expression, 1},
    {field_type_conversion, 2},
  [71] =
    {field_expression, 1},
    {field_format_specifier, 2},
  [73] =
    {field_alternative, 0},
  [74] =
    {field_alternative, 4},
    {field_condition, 1},
    {field_consequence, 3},
  [77] =
    {field_alternative, 4, .inherited = true},
    {field_condition, 1},
    {field_consequence, 3},
  [80] =
    {field_condition, 1},
    {field_consequence, 3},
    {field_consequence, 4},
  [83] =
    {field_alternative, 4, .inherited = true},
    {field_body, 4},
    {field_subject, 1},
  [86] =
    {field_alternative, 4, .inherited = true},
    {field_body, 4},
    {field_subject, 1},
    {field_subject, 2, .inherited = true},
  [90] =
    {field_body, 4},
  [91] =
    {field_alternative, 4},
    {field_body, 3},
    {field_condition, 1},
  [94] =
    {field_body, 3},
    {field_body, 4},
    {field_condition, 1},
  [97] =
    {field_body, 2},
    {field_body, 3},
  [99] =
    {field_body, 3},
    {field_body, 4},
  [101] =
    {field_body, 4},
    {field_name, 1},
    {field_parameters, 2},
  [104] =
    {field_body, 3},
    {field_body, 4},
    {field_name, 1},
  [107] =
    {field_body, 4},
    {field_name, 1},
    {field_type_parameters, 2},
  [110] =
    {field_body, 4},
    {field_name, 1},
    {field_superclasses, 2},
  [113] =
    {field_left, 0},
    {field_right, 4},
    {field_type, 2},
  [116] =
    {field_subscript, 1},
  [117] =
    {field_subscript, 2},
    {field_subscript, 3, .inherited = true},
    {field_value, 0},
  [120] =
    {field_subscript, 0, .inherited = true},
    {field_subscript, 1, .inherited = true},
  [122] =
    {field_expression, 1},
    {field_type_conversion, 3},
  [124] =
    {field_expression, 1},
    {field_format_specifier, 3},
  [126] =
    {field_expression, 1},
    {field_format_specifier, 3},
    {field_type_conversion, 2},
  [129] =
    {field_name, 4, .inherited = true},
  [130] =
    {field_module_name, 1},
    {field_name, 4, .inherited = true},
  [132] =
    {field_left, 1},
    {field_right, 3},
  [134] =
    {field_alternative, 4, .inherited = true},
    {field_alternative, 5},
    {field_condition, 1},
    {field_consequence, 3},
  [138] =
    {field_alternative, 0, .inherited = true},
    {field_alternative, 1, .inherited = true},
  [140] =
    {field_alternative, 5},
    {field_condition, 1},
    {field_consequence, 3},
    {field_consequence, 4},
  [144] =
    {field_alternative, 5, .inherited = true},
    {field_condition, 1},
    {field_consequence, 3},
    {field_consequence, 4},
  [148] =
    {field_alternative, 1, .inherited = true},
  [149] =
    {field_alternative, 5, .inherited = true},
    {field_body, 5},
    {field_subject, 1},
    {field_subject, 2, .inherited = true},
  [153] =
    {field_body, 4},
    {field_body, 5},
  [155] =
    {field_body, 5},
    {field_name, 2},
    {field_parameters, 3},
  [158] =
    {field_body, 5},
    {field_left, 1},
    {field_right, 3},
  [161] =
    {field_alternative, 5},
    {field_body, 3},
    {field_body, 4},
    {field_condition, 1},
  [165] =
    {field_body, 4},
    {field_body, 5},
    {field_name, 1},
    {field_parameters, 2},
  [169] =
    {field_body, 5},
    {field_name, 1},
    {field_parameters, 3},
    {field_type_parameters, 2},
  [173] =
    {field_body, 4},
    {field_body, 5},
    {field_name, 1},
    {field_type_parameters, 2},
  [177] =
    {field_body, 5},
    {field_name, 1},
    {field_superclasses, 3},
    {field_type_parameters, 2},
  [181] =
    {field_body, 4},
    {field_body, 5},
    {field_name, 1},
    {field_superclasses, 2},
  [185] =
    {field_name, 0},
    {field_type, 2},
    {field_value, 4},
  [188] =
    {field_expression, 1},
    {field_format_specifier, 4},
    {field_type_conversion, 3},
  [191] =
    {field_left, 2},
    {field_right, 4},
  [193] =
    {field_left, 1},
    {field_right, 3},
    {field_right, 4},
  [196] =
    {field_alternative, 5, .inherited = true},
    {field_alternative, 6},
    {field_condition, 1},
    {field_consequence, 3},
    {field_consequence, 4},
  [201] =
    {field_body, 6},
    {field_left, 2},
    {field_right, 4},
  [204] =
    {field_body, 5},
    {field_body, 6},
    {field_name, 2},
    {field_parameters, 3},
  [208] =
    {field_body, 6},
    {field_name, 2},
    {field_parameters, 4},
    {field_type_parameters, 3},
  [212] =
    {field_alternative, 6},
    {field_body, 5},
    {field_left, 1},
    {field_right, 3},
  [216] =
    {field_body, 5},
    {field_body, 6},
    {field_left, 1},
    {field_right, 3},
  [220] =
    {field_body, 6},
    {field_name, 1},
    {field_parameters, 2},
    {field_return_type, 4},
  [224] =
    {field_body, 5},
    {field_body, 6},
    {field_name, 1},
    {field_parameters, 3},
    {field_type_parameters, 2},
  [229] =
    {field_body, 5},
    {field_body, 6},
    {field_name, 1},
    {field_superclasses, 3},
    {field_type_parameters, 2},
  [234] =
    {field_left, 2},
    {field_right, 4},
    {field_right, 5},
  [237] =
    {field_key, 1, .inherited = true},
    {field_value, 1, .inherited = true},
  [239] =
    {field_consequence, 3},
  [240] =
    {field_alternative, 7},
    {field_body, 6},
    {field_left, 2},
    {field_right, 4},
  [244] =
    {field_body, 6},
    {field_body, 7},
    {field_left, 2},
    {field_right, 4},
  [248] =
    {field_body, 7},
    {field_name, 2},
    {field_parameters, 3},
    {field_return_type, 5},
  [252] =
    {field_body, 6},
    {field_body, 7},
    {field_name, 2},
    {field_parameters, 4},
    {field_type_parameters, 3},
  [257] =
    {field_alternative, 7},
    {field_body, 5},
    {field_body, 6},
    {field_left, 1},
    {field_right, 3},
  [262] =
    {field_body, 6},
    {field_body, 7},
    {field_name, 1},
    {field_parameters, 2},
    {field_return_type, 4},
  [267] =
    {field_body, 7},
    {field_name, 1},
    {field_parameters, 3},
    {field_return_type, 5},
    {field_type_parameters, 2},
  [272] =
    {field_key, 1, .inherited = true},
    {field_key, 2, .inherited = true},
    {field_value, 1, .inherited = true},
    {field_value, 2, .inherited = true},
  [276] =
    {field_key, 0, .inherited = true},
    {field_key, 1, .inherited = true},
    {field_value, 0, .inherited = true},
    {field_value, 1, .inherited = true},
  [280] =
    {field_key, 2, .inherited = true},
    {field_value, 2, .inherited = true},
  [282] =
    {field_consequence, 4},
  [283] =
    {field_consequence, 3},
    {field_consequence, 4},
  [285] =
    {field_consequence, 4},
    {field_guard, 2},
  [287] =
    {field_alternative, 8},
    {field_body, 6},
    {field_body, 7},
    {field_left, 2},
    {field_right, 4},
  [292] =
    {field_body, 7},
    {field_body, 8},
    {field_name, 2},
    {field_parameters, 3},
    {field_return_type, 5},
  [297] =
    {field_body, 8},
    {field_name, 2},
    {field_parameters, 4},
    {field_return_type, 6},
    {field_type_parameters, 3},
  [302] =
    {field_body, 7},
    {field_body, 8},
    {field_name, 1},
    {field_parameters, 3},
    {field_return_type, 5},
    {field_type_parameters, 2},
  [308] =
    {field_consequence, 4},
    {field_consequence, 5},
  [310] =
    {field_consequence, 5},
    {field_guard, 3},
  [312] =
    {field_consequence, 4},
    {field_consequence, 5},
    {field_guard, 2},
  [315] =
    {field_consequence, 5},
  [316] =
    {field_body, 8},
    {field_body, 9},
    {field_name, 2},
    {field_parameters, 4},
    {field_return_type, 6},
    {field_type_parameters, 3},
  [322] =
    {field_consequence, 5},
    {field_consequence, 6},
    {field_guard, 3},
  [325] =
    {field_consequence, 5},
    {field_consequence, 6},
  [327] =
    {field_consequence, 6},
    {field_guard, 4},
  [329] =
    {field_consequence, 6},
    {field_consequence, 7},
    {field_guard, 4},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
  [1] = {
    [0] = sym_identifier,
  },
  [2] = {
    [0] = sym_list_splat,
  },
  [5] = {
    [1] = sym_identifier,
  },
  [22] = {
    [2] = alias_sym_as_pattern_target,
  },
  [33] = {
    [1] = sym_parenthesized_expression,
  },
  [37] = {
    [3] = sym_block,
  },
  [41] = {
    [3] = sym_block,
  },
  [42] = {
    [2] = sym_block,
  },
  [43] = {
    [3] = sym_block,
  },
  [44] = {
    [3] = sym_block,
  },
  [49] = {
    [0] = anon_alias_sym_notin,
    [1] = anon_alias_sym_notin,
  },
  [50] = {
    [0] = anon_alias_sym_isnot,
    [1] = anon_alias_sym_isnot,
  },
  [51] = {
    [0] = alias_sym_format_expression,
  },
  [55] = {
    [3] = sym_block,
  },
  [56] = {
    [3] = sym_block,
  },
  [60] = {
    [4] = sym_block,
  },
  [61] = {
    [3] = sym_block,
  },
  [65] = {
    [4] = sym_block,
  },
  [67] = {
    [4] = sym_block,
  },
  [68] = {
    [4] = sym_block,
  },
  [70] = {
    [0] = sym_identifier,
  },
  [80] = {
    [3] = sym_block,
  },
  [87] = {
    [5] = sym_block,
  },
  [88] = {
    [5] = sym_block,
  },
  [90] = {
    [2] = sym_block,
  },
  [92] = {
    [5] = sym_block,
  },
  [94] = {
    [5] = sym_block,
  },
  [101] = {
    [6] = sym_block,
  },
  [103] = {
    [6] = sym_block,
  },
  [104] = {
    [5] = sym_block,
  },
  [106] = {
    [3] = sym_block,
  },
  [107] = {
    [6] = sym_block,
  },
  [112] = {
    [3] = sym_block,
  },
  [113] = {
    [6] = sym_block,
  },
  [115] = {
    [7] = sym_block,
  },
  [119] = {
    [7] = sym_block,
  },
  [123] = {
    [4] = sym_block,
  },
  [125] = {
    [4] = sym_block,
  },
  [128] = {
    [8] = sym_block,
  },
  [129] = {
    [5] = sym_block,
  },
  [132] = {
    [5] = sym_block,
  },
  [134] = {
    [5] = sym_block,
  },
  [138] = {
    [6] = sym_block,
  },
};

static const uint16_t ts_non_terminal_alias_map[] = {
  sym__simple_statements, 2,
    sym__simple_statements,
    sym_block,
  sym_parenthesized_list_splat, 2,
    sym_parenthesized_list_splat,
    sym_parenthesized_expression,
  sym_list_splat_pattern, 2,
    sym_list_splat_pattern,
    sym_list_splat,
  sym_expression, 2,
    sym_expression,
    alias_sym_as_pattern_target,
  sym_interpolation, 2,
    sym_interpolation,
    alias_sym_format_expression,
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 3,
  [4] = 4,
  [5] = 5,
  [6] = 6,
  [7] = 7,
  [8] = 8,
  [9] = 9,
  [10] = 10,
  [11] = 11,
  [12] = 12,
  [13] = 13,
  [14] = 14,
  [15] = 11,
  [16] = 16,
  [17] = 16,
  [18] = 6,
  [19] = 19,
  [20] = 20,
  [21] = 21,
  [22] = 22,
  [23] = 2,
  [24] = 24,
  [25] = 25,
  [26] = 20,
  [27] = 27,
  [28] = 28,
  [29] = 29,
  [30] = 30,
  [31] = 31,
  [32] = 32,
  [33] = 4,
  [34] = 32,
  [35] = 5,
  [36] = 13,
  [37] = 22,
  [38] = 7,
  [39] = 9,
  [40] = 24,
  [41] = 41,
  [42] = 42,
  [43] = 12,
  [44] = 44,
  [45] = 19,
  [46] = 46,
  [47] = 28,
  [48] = 48,
  [49] = 44,
  [50] = 25,
  [51] = 30,
  [52] = 52,
  [53] = 14,
  [54] = 54,
  [55] = 29,
  [56] = 54,
  [57] = 31,
  [58] = 46,
  [59] = 3,
  [60] = 10,
  [61] = 27,
  [62] = 62,
  [63] = 62,
  [64] = 64,
  [65] = 62,
  [66] = 66,
  [67] = 62,
  [68] = 62,
  [69] = 62,
  [70] = 66,
  [71] = 62,
  [72] = 62,
  [73] = 73,
  [74] = 73,
  [75] = 75,
  [76] = 75,
  [77] = 77,
  [78] = 78,
  [79] = 78,
  [80] = 80,
  [81] = 77,
  [82] = 80,
  [83] = 83,
  [84] = 83,
  [85] = 85,
  [86] = 85,
  [87] = 87,
  [88] = 88,
  [89] = 89,
  [90] = 90,
  [91] = 91,
  [92] = 92,
  [93] = 93,
  [94] = 94,
  [95] = 95,
  [96] = 96,
  [97] = 87,
  [98] = 98,
  [99] = 99,
  [100] = 100,
  [101] = 101,
  [102] = 101,
  [103] = 91,
  [104] = 89,
  [105] = 92,
  [106] = 96,
  [107] = 107,
  [108] = 108,
  [109] = 98,
  [110] = 107,
  [111] = 111,
  [112] = 112,
  [113] = 99,
  [114] = 114,
  [115] = 115,
  [116] = 116,
  [117] = 117,
  [118] = 118,
  [119] = 119,
  [120] = 120,
  [121] = 121,
  [122] = 122,
  [123] = 112,
  [124] = 100,
  [125] = 122,
  [126] = 117,
  [127] = 127,
  [128] = 94,
  [129] = 108,
  [130] = 114,
  [131] = 95,
  [132] = 111,
  [133] = 93,
  [134] = 88,
  [135] = 118,
  [136] = 121,
  [137] = 137,
  [138] = 137,
  [139] = 139,
  [140] = 137,
  [141] = 139,
  [142] = 137,
  [143] = 137,
  [144] = 139,
  [145] = 139,
  [146] = 139,
  [147] = 137,
  [148] = 137,
  [149] = 139,
  [150] = 139,
  [151] = 137,
  [152] = 139,
  [153] = 153,
  [154] = 154,
  [155] = 154,
  [156] = 156,
  [157] = 157,
  [158] = 156,
  [159] = 154,
  [160] = 157,
  [161] = 161,
  [162] = 156,
  [163] = 163,
  [164] = 156,
  [165] = 157,
  [166] = 166,
  [167] = 157,
  [168] = 161,
  [169] = 157,
  [170] = 163,
  [171] = 163,
  [172] = 154,
  [173] = 157,
  [174] = 157,
  [175] = 161,
  [176] = 176,
  [177] = 161,
  [178] = 161,
  [179] = 157,
  [180] = 156,
  [181] = 156,
  [182] = 154,
  [183] = 166,
  [184] = 161,
  [185] = 161,
  [186] = 161,
  [187] = 176,
  [188] = 156,
  [189] = 189,
  [190] = 190,
  [191] = 191,
  [192] = 192,
  [193] = 191,
  [194] = 189,
  [195] = 195,
  [196] = 189,
  [197] = 195,
  [198] = 195,
  [199] = 189,
  [200] = 195,
  [201] = 190,
  [202] = 189,
  [203] = 189,
  [204] = 195,
  [205] = 195,
  [206] = 189,
  [207] = 191,
  [208] = 191,
  [209] = 189,
  [210] = 191,
  [211] = 189,
  [212] = 195,
  [213] = 191,
  [214] = 189,
  [215] = 191,
  [216] = 216,
  [217] = 191,
  [218] = 195,
  [219] = 189,
  [220] = 191,
  [221] = 221,
  [222] = 222,
  [223] = 223,
  [224] = 224,
  [225] = 224,
  [226] = 224,
  [227] = 227,
  [228] = 227,
  [229] = 229,
  [230] = 229,
  [231] = 229,
  [232] = 224,
  [233] = 229,
  [234] = 234,
  [235] = 235,
  [236] = 236,
  [237] = 235,
  [238] = 236,
  [239] = 239,
  [240] = 236,
  [241] = 234,
  [242] = 242,
  [243] = 243,
  [244] = 244,
  [245] = 245,
  [246] = 246,
  [247] = 236,
  [248] = 236,
  [249] = 236,
  [250] = 236,
  [251] = 223,
  [252] = 252,
  [253] = 253,
  [254] = 222,
  [255] = 235,
  [256] = 256,
  [257] = 236,
  [258] = 258,
  [259] = 235,
  [260] = 234,
  [261] = 261,
  [262] = 242,
  [263] = 239,
  [264] = 252,
  [265] = 261,
  [266] = 245,
  [267] = 261,
  [268] = 234,
  [269] = 269,
  [270] = 261,
  [271] = 271,
  [272] = 272,
  [273] = 272,
  [274] = 274,
  [275] = 275,
  [276] = 276,
  [277] = 277,
  [278] = 278,
  [279] = 278,
  [280] = 278,
  [281] = 272,
  [282] = 276,
  [283] = 274,
  [284] = 275,
  [285] = 275,
  [286] = 277,
  [287] = 274,
  [288] = 288,
  [289] = 272,
  [290] = 277,
  [291] = 276,
  [292] = 278,
  [293] = 288,
  [294] = 277,
  [295] = 272,
  [296] = 288,
  [297] = 276,
  [298] = 288,
  [299] = 277,
  [300] = 278,
  [301] = 274,
  [302] = 275,
  [303] = 272,
  [304] = 276,
  [305] = 274,
  [306] = 275,
  [307] = 288,
  [308] = 276,
  [309] = 275,
  [310] = 272,
  [311] = 274,
  [312] = 275,
  [313] = 288,
  [314] = 274,
  [315] = 275,
  [316] = 288,
  [317] = 277,
  [318] = 277,
  [319] = 274,
  [320] = 277,
  [321] = 276,
  [322] = 272,
  [323] = 288,
  [324] = 278,
  [325] = 276,
  [326] = 326,
  [327] = 327,
  [328] = 176,
  [329] = 329,
  [330] = 330,
  [331] = 331,
  [332] = 332,
  [333] = 327,
  [334] = 332,
  [335] = 331,
  [336] = 330,
  [337] = 337,
  [338] = 326,
  [339] = 337,
  [340] = 327,
  [341] = 332,
  [342] = 326,
  [343] = 343,
  [344] = 331,
  [345] = 330,
  [346] = 346,
  [347] = 337,
  [348] = 348,
  [349] = 348,
  [350] = 350,
  [351] = 253,
  [352] = 348,
  [353] = 253,
  [354] = 348,
  [355] = 355,
  [356] = 356,
  [357] = 355,
  [358] = 355,
  [359] = 348,
  [360] = 355,
  [361] = 348,
  [362] = 348,
  [363] = 355,
  [364] = 356,
  [365] = 356,
  [366] = 348,
  [367] = 355,
  [368] = 253,
  [369] = 355,
  [370] = 355,
  [371] = 156,
  [372] = 372,
  [373] = 372,
  [374] = 374,
  [375] = 375,
  [376] = 372,
  [377] = 377,
  [378] = 378,
  [379] = 343,
  [380] = 372,
  [381] = 374,
  [382] = 346,
  [383] = 378,
  [384] = 378,
  [385] = 385,
  [386] = 372,
  [387] = 387,
  [388] = 374,
  [389] = 378,
  [390] = 374,
  [391] = 374,
  [392] = 372,
  [393] = 372,
  [394] = 374,
  [395] = 378,
  [396] = 374,
  [397] = 372,
  [398] = 378,
  [399] = 378,
  [400] = 374,
  [401] = 401,
  [402] = 378,
  [403] = 372,
  [404] = 372,
  [405] = 374,
  [406] = 378,
  [407] = 374,
  [408] = 378,
  [409] = 176,
  [410] = 410,
  [411] = 411,
  [412] = 412,
  [413] = 176,
  [414] = 410,
  [415] = 415,
  [416] = 416,
  [417] = 417,
  [418] = 411,
  [419] = 419,
  [420] = 420,
  [421] = 421,
  [422] = 422,
  [423] = 423,
  [424] = 424,
  [425] = 425,
  [426] = 415,
  [427] = 419,
  [428] = 346,
  [429] = 416,
  [430] = 430,
  [431] = 343,
  [432] = 410,
  [433] = 343,
  [434] = 410,
  [435] = 410,
  [436] = 424,
  [437] = 416,
  [438] = 438,
  [439] = 410,
  [440] = 440,
  [441] = 410,
  [442] = 424,
  [443] = 410,
  [444] = 423,
  [445] = 176,
  [446] = 411,
  [447] = 156,
  [448] = 448,
  [449] = 410,
  [450] = 450,
  [451] = 430,
  [452] = 452,
  [453] = 410,
  [454] = 454,
  [455] = 455,
  [456] = 401,
  [457] = 346,
  [458] = 430,
  [459] = 459,
  [460] = 423,
  [461] = 461,
  [462] = 462,
  [463] = 463,
  [464] = 464,
  [465] = 465,
  [466] = 466,
  [467] = 462,
  [468] = 468,
  [469] = 461,
  [470] = 463,
  [471] = 468,
  [472] = 346,
  [473] = 466,
  [474] = 474,
  [475] = 465,
  [476] = 474,
  [477] = 464,
  [478] = 478,
  [479] = 343,
  [480] = 480,
  [481] = 481,
  [482] = 482,
  [483] = 483,
  [484] = 484,
  [485] = 485,
  [486] = 483,
  [487] = 482,
  [488] = 488,
  [489] = 484,
  [490] = 485,
  [491] = 491,
  [492] = 492,
  [493] = 493,
  [494] = 494,
  [495] = 495,
  [496] = 480,
  [497] = 497,
  [498] = 498,
  [499] = 480,
  [500] = 481,
  [501] = 501,
  [502] = 491,
  [503] = 501,
  [504] = 481,
  [505] = 505,
  [506] = 506,
  [507] = 507,
  [508] = 508,
  [509] = 509,
  [510] = 510,
  [511] = 510,
  [512] = 485,
  [513] = 513,
  [514] = 501,
  [515] = 481,
  [516] = 485,
  [517] = 484,
  [518] = 501,
  [519] = 488,
  [520] = 482,
  [521] = 508,
  [522] = 522,
  [523] = 483,
  [524] = 524,
  [525] = 484,
  [526] = 522,
  [527] = 493,
  [528] = 492,
  [529] = 485,
  [530] = 491,
  [531] = 485,
  [532] = 508,
  [533] = 510,
  [534] = 484,
  [535] = 501,
  [536] = 488,
  [537] = 491,
  [538] = 482,
  [539] = 539,
  [540] = 540,
  [541] = 541,
  [542] = 510,
  [543] = 491,
  [544] = 509,
  [545] = 488,
  [546] = 546,
  [547] = 483,
  [548] = 548,
  [549] = 548,
  [550] = 480,
  [551] = 508,
  [552] = 540,
  [553] = 488,
  [554] = 480,
  [555] = 548,
  [556] = 491,
  [557] = 485,
  [558] = 481,
  [559] = 548,
  [560] = 484,
  [561] = 548,
  [562] = 506,
  [563] = 488,
  [564] = 548,
  [565] = 565,
  [566] = 483,
  [567] = 482,
  [568] = 548,
  [569] = 482,
  [570] = 488,
  [571] = 484,
  [572] = 482,
  [573] = 501,
  [574] = 548,
  [575] = 508,
  [576] = 485,
  [577] = 483,
  [578] = 505,
  [579] = 522,
  [580] = 580,
  [581] = 501,
  [582] = 582,
  [583] = 583,
  [584] = 480,
  [585] = 491,
  [586] = 491,
  [587] = 480,
  [588] = 522,
  [589] = 481,
  [590] = 501,
  [591] = 483,
  [592] = 497,
  [593] = 498,
  [594] = 480,
  [595] = 595,
  [596] = 483,
  [597] = 583,
  [598] = 546,
  [599] = 482,
  [600] = 580,
  [601] = 495,
  [602] = 488,
  [603] = 484,
  [604] = 604,
  [605] = 605,
  [606] = 606,
  [607] = 607,
  [608] = 606,
  [609] = 609,
  [610] = 610,
  [611] = 611,
  [612] = 612,
  [613] = 613,
  [614] = 614,
  [615] = 614,
  [616] = 613,
  [617] = 610,
  [618] = 612,
  [619] = 619,
  [620] = 620,
  [621] = 621,
  [622] = 622,
  [623] = 621,
  [624] = 611,
  [625] = 620,
  [626] = 626,
  [627] = 627,
  [628] = 628,
  [629] = 629,
  [630] = 630,
  [631] = 628,
  [632] = 632,
  [633] = 633,
  [634] = 634,
  [635] = 629,
  [636] = 636,
  [637] = 630,
  [638] = 638,
  [639] = 639,
  [640] = 640,
  [641] = 641,
  [642] = 642,
  [643] = 643,
  [644] = 634,
  [645] = 645,
  [646] = 632,
  [647] = 647,
  [648] = 648,
  [649] = 649,
  [650] = 647,
  [651] = 651,
  [652] = 652,
  [653] = 653,
  [654] = 654,
  [655] = 655,
  [656] = 653,
  [657] = 647,
  [658] = 658,
  [659] = 654,
  [660] = 653,
  [661] = 661,
  [662] = 662,
  [663] = 663,
  [664] = 655,
  [665] = 652,
  [666] = 647,
  [667] = 652,
  [668] = 651,
  [669] = 649,
  [670] = 658,
  [671] = 671,
  [672] = 672,
  [673] = 673,
  [674] = 672,
  [675] = 671,
  [676] = 658,
  [677] = 223,
  [678] = 655,
  [679] = 222,
  [680] = 653,
  [681] = 655,
  [682] = 658,
  [683] = 652,
  [684] = 655,
  [685] = 658,
  [686] = 648,
  [687] = 673,
  [688] = 647,
  [689] = 653,
  [690] = 655,
  [691] = 652,
  [692] = 658,
  [693] = 661,
  [694] = 647,
  [695] = 653,
  [696] = 662,
  [697] = 652,
  [698] = 663,
  [699] = 699,
  [700] = 700,
  [701] = 701,
  [702] = 700,
  [703] = 703,
  [704] = 703,
  [705] = 705,
  [706] = 706,
  [707] = 707,
  [708] = 708,
  [709] = 709,
  [710] = 710,
  [711] = 711,
  [712] = 707,
  [713] = 705,
  [714] = 708,
  [715] = 699,
  [716] = 701,
  [717] = 711,
  [718] = 709,
  [719] = 710,
  [720] = 706,
  [721] = 721,
  [722] = 722,
  [723] = 723,
  [724] = 722,
  [725] = 723,
  [726] = 721,
  [727] = 727,
  [728] = 728,
  [729] = 729,
  [730] = 730,
  [731] = 731,
  [732] = 732,
  [733] = 733,
  [734] = 734,
  [735] = 735,
  [736] = 736,
  [737] = 737,
  [738] = 738,
  [739] = 739,
  [740] = 727,
  [741] = 741,
  [742] = 742,
  [743] = 738,
  [744] = 744,
  [745] = 745,
  [746] = 746,
  [747] = 747,
  [748] = 748,
  [749] = 749,
  [750] = 750,
  [751] = 751,
  [752] = 752,
  [753] = 753,
  [754] = 754,
  [755] = 755,
  [756] = 756,
  [757] = 757,
  [758] = 758,
  [759] = 759,
  [760] = 760,
  [761] = 761,
  [762] = 762,
  [763] = 763,
  [764] = 764,
  [765] = 756,
  [766] = 766,
  [767] = 755,
  [768] = 768,
  [769] = 769,
  [770] = 770,
  [771] = 771,
  [772] = 772,
  [773] = 734,
  [774] = 774,
  [775] = 742,
  [776] = 735,
  [777] = 746,
  [778] = 760,
  [779] = 770,
  [780] = 780,
  [781] = 744,
  [782] = 782,
  [783] = 783,
  [784] = 784,
  [785] = 729,
  [786] = 786,
  [787] = 774,
  [788] = 788,
  [789] = 741,
  [790] = 736,
  [791] = 791,
  [792] = 763,
  [793] = 784,
  [794] = 794,
  [795] = 795,
  [796] = 753,
  [797] = 752,
  [798] = 798,
  [799] = 799,
  [800] = 800,
  [801] = 801,
  [802] = 791,
  [803] = 731,
  [804] = 732,
  [805] = 751,
  [806] = 786,
  [807] = 761,
  [808] = 762,
  [809] = 764,
  [810] = 766,
  [811] = 768,
  [812] = 769,
  [813] = 798,
  [814] = 814,
  [815] = 800,
  [816] = 750,
  [817] = 817,
  [818] = 818,
  [819] = 749,
  [820] = 222,
  [821] = 818,
  [822] = 801,
  [823] = 799,
  [824] = 771,
  [825] = 742,
  [826] = 754,
  [827] = 783,
  [828] = 739,
  [829] = 738,
  [830] = 748,
  [831] = 728,
  [832] = 730,
  [833] = 737,
  [834] = 772,
  [835] = 788,
  [836] = 747,
  [837] = 837,
  [838] = 794,
  [839] = 223,
  [840] = 795,
  [841] = 758,
  [842] = 733,
  [843] = 780,
  [844] = 837,
  [845] = 782,
  [846] = 759,
  [847] = 757,
  [848] = 745,
  [849] = 814,
  [850] = 817,
  [851] = 851,
  [852] = 851,
  [853] = 851,
  [854] = 851,
  [855] = 851,
  [856] = 851,
  [857] = 857,
  [858] = 857,
  [859] = 859,
  [860] = 859,
  [861] = 859,
  [862] = 859,
  [863] = 859,
  [864] = 859,
  [865] = 859,
  [866] = 859,
  [867] = 867,
  [868] = 868,
  [869] = 869,
  [870] = 868,
  [871] = 871,
  [872] = 872,
  [873] = 869,
  [874] = 872,
  [875] = 868,
  [876] = 876,
  [877] = 877,
  [878] = 878,
  [879] = 869,
  [880] = 880,
  [881] = 871,
  [882] = 882,
  [883] = 883,
  [884] = 884,
  [885] = 885,
  [886] = 886,
  [887] = 876,
  [888] = 877,
  [889] = 872,
  [890] = 868,
  [891] = 869,
  [892] = 868,
  [893] = 868,
  [894] = 876,
  [895] = 883,
  [896] = 886,
  [897] = 878,
  [898] = 880,
  [899] = 885,
  [900] = 868,
  [901] = 886,
  [902] = 885,
  [903] = 884,
  [904] = 882,
  [905] = 871,
  [906] = 880,
  [907] = 878,
  [908] = 877,
  [909] = 877,
  [910] = 876,
  [911] = 878,
  [912] = 883,
  [913] = 884,
  [914] = 882,
  [915] = 871,
  [916] = 880,
  [917] = 877,
  [918] = 878,
  [919] = 880,
  [920] = 871,
  [921] = 882,
  [922] = 882,
  [923] = 880,
  [924] = 884,
  [925] = 885,
  [926] = 878,
  [927] = 886,
  [928] = 871,
  [929] = 877,
  [930] = 882,
  [931] = 884,
  [932] = 884,
  [933] = 885,
  [934] = 886,
  [935] = 885,
  [936] = 886,
  [937] = 876,
  [938] = 876,
  [939] = 883,
  [940] = 883,
  [941] = 872,
  [942] = 883,
  [943] = 877,
  [944] = 877,
  [945] = 878,
  [946] = 880,
  [947] = 871,
  [948] = 882,
  [949] = 884,
  [950] = 885,
  [951] = 886,
  [952] = 868,
  [953] = 878,
  [954] = 868,
  [955] = 880,
  [956] = 868,
  [957] = 871,
  [958] = 882,
  [959] = 868,
  [960] = 867,
  [961] = 884,
  [962] = 885,
  [963] = 868,
  [964] = 869,
  [965] = 886,
  [966] = 883,
  [967] = 869,
  [968] = 872,
  [969] = 876,
  [970] = 876,
  [971] = 869,
  [972] = 868,
  [973] = 869,
  [974] = 883,
  [975] = 975,
  [976] = 976,
  [977] = 977,
  [978] = 978,
  [979] = 975,
  [980] = 976,
  [981] = 981,
  [982] = 982,
  [983] = 983,
  [984] = 984,
  [985] = 985,
  [986] = 986,
  [987] = 987,
  [988] = 976,
  [989] = 989,
  [990] = 990,
  [991] = 978,
  [992] = 992,
  [993] = 975,
  [994] = 977,
  [995] = 995,
  [996] = 977,
  [997] = 978,
  [998] = 998,
  [999] = 986,
  [1000] = 638,
  [1001] = 985,
  [1002] = 977,
  [1003] = 983,
  [1004] = 975,
  [1005] = 982,
  [1006] = 976,
  [1007] = 986,
  [1008] = 977,
  [1009] = 976,
  [1010] = 981,
  [1011] = 640,
  [1012] = 1012,
  [1013] = 977,
  [1014] = 978,
  [1015] = 987,
  [1016] = 977,
  [1017] = 975,
  [1018] = 978,
  [1019] = 976,
  [1020] = 1020,
  [1021] = 976,
  [1022] = 978,
  [1023] = 989,
  [1024] = 977,
  [1025] = 985,
  [1026] = 987,
  [1027] = 995,
  [1028] = 992,
  [1029] = 990,
  [1030] = 975,
  [1031] = 995,
  [1032] = 975,
  [1033] = 641,
  [1034] = 992,
  [1035] = 639,
  [1036] = 633,
  [1037] = 1037,
  [1038] = 998,
  [1039] = 636,
  [1040] = 989,
  [1041] = 626,
  [1042] = 1042,
  [1043] = 1043,
  [1044] = 984,
  [1045] = 978,
  [1046] = 998,
  [1047] = 981,
  [1048] = 982,
  [1049] = 990,
  [1050] = 983,
  [1051] = 984,
  [1052] = 1020,
  [1053] = 982,
  [1054] = 986,
  [1055] = 985,
  [1056] = 984,
  [1057] = 1057,
  [1058] = 983,
  [1059] = 982,
  [1060] = 981,
  [1061] = 990,
  [1062] = 640,
  [1063] = 989,
  [1064] = 998,
  [1065] = 987,
  [1066] = 1066,
  [1067] = 1067,
  [1068] = 1068,
  [1069] = 1069,
  [1070] = 1070,
  [1071] = 638,
  [1072] = 987,
  [1073] = 998,
  [1074] = 626,
  [1075] = 636,
  [1076] = 1020,
  [1077] = 633,
  [1078] = 1078,
  [1079] = 1079,
  [1080] = 1080,
  [1081] = 1081,
  [1082] = 1042,
  [1083] = 1083,
  [1084] = 1084,
  [1085] = 1085,
  [1086] = 992,
  [1087] = 1087,
  [1088] = 1088,
  [1089] = 639,
  [1090] = 995,
  [1091] = 641,
  [1092] = 619,
  [1093] = 1093,
  [1094] = 645,
  [1095] = 1095,
  [1096] = 1096,
  [1097] = 995,
  [1098] = 1098,
  [1099] = 977,
  [1100] = 992,
  [1101] = 995,
  [1102] = 1102,
  [1103] = 1103,
  [1104] = 992,
  [1105] = 978,
  [1106] = 1043,
  [1107] = 1042,
  [1108] = 1012,
  [1109] = 1037,
  [1110] = 643,
  [1111] = 1111,
  [1112] = 642,
  [1113] = 1113,
  [1114] = 622,
  [1115] = 621,
  [1116] = 981,
  [1117] = 1117,
  [1118] = 982,
  [1119] = 983,
  [1120] = 1096,
  [1121] = 984,
  [1122] = 1122,
  [1123] = 985,
  [1124] = 986,
  [1125] = 989,
  [1126] = 990,
  [1127] = 1127,
  [1128] = 984,
  [1129] = 987,
  [1130] = 998,
  [1131] = 976,
  [1132] = 992,
  [1133] = 1133,
  [1134] = 981,
  [1135] = 982,
  [1136] = 983,
  [1137] = 1137,
  [1138] = 1138,
  [1139] = 984,
  [1140] = 985,
  [1141] = 1043,
  [1142] = 986,
  [1143] = 1143,
  [1144] = 989,
  [1145] = 1145,
  [1146] = 1146,
  [1147] = 990,
  [1148] = 1012,
  [1149] = 1037,
  [1150] = 975,
  [1151] = 981,
  [1152] = 998,
  [1153] = 987,
  [1154] = 1154,
  [1155] = 983,
  [1156] = 990,
  [1157] = 995,
  [1158] = 989,
  [1159] = 986,
  [1160] = 985,
  [1161] = 641,
  [1162] = 989,
  [1163] = 642,
  [1164] = 628,
  [1165] = 1020,
  [1166] = 630,
  [1167] = 629,
  [1168] = 638,
  [1169] = 1057,
  [1170] = 1154,
  [1171] = 1037,
  [1172] = 1012,
  [1173] = 1043,
  [1174] = 626,
  [1175] = 636,
  [1176] = 633,
  [1177] = 639,
  [1178] = 641,
  [1179] = 977,
  [1180] = 632,
  [1181] = 1020,
  [1182] = 645,
  [1183] = 1117,
  [1184] = 1143,
  [1185] = 1145,
  [1186] = 1146,
  [1187] = 640,
  [1188] = 992,
  [1189] = 995,
  [1190] = 622,
  [1191] = 1096,
  [1192] = 640,
  [1193] = 1127,
  [1194] = 1042,
  [1195] = 1085,
  [1196] = 1042,
  [1197] = 1111,
  [1198] = 1093,
  [1199] = 1084,
  [1200] = 619,
  [1201] = 1066,
  [1202] = 1042,
  [1203] = 1067,
  [1204] = 1069,
  [1205] = 1043,
  [1206] = 1078,
  [1207] = 1012,
  [1208] = 1020,
  [1209] = 1037,
  [1210] = 981,
  [1211] = 1122,
  [1212] = 1103,
  [1213] = 982,
  [1214] = 621,
  [1215] = 1102,
  [1216] = 983,
  [1217] = 984,
  [1218] = 1117,
  [1219] = 639,
  [1220] = 1098,
  [1221] = 1095,
  [1222] = 985,
  [1223] = 986,
  [1224] = 643,
  [1225] = 990,
  [1226] = 1096,
  [1227] = 1070,
  [1228] = 1083,
  [1229] = 1081,
  [1230] = 1080,
  [1231] = 987,
  [1232] = 998,
  [1233] = 1154,
  [1234] = 622,
  [1235] = 977,
  [1236] = 1068,
  [1237] = 1138,
  [1238] = 1133,
  [1239] = 1137,
  [1240] = 1113,
  [1241] = 1057,
  [1242] = 1043,
  [1243] = 1012,
  [1244] = 1083,
  [1245] = 1037,
  [1246] = 621,
  [1247] = 645,
  [1248] = 1081,
  [1249] = 1037,
  [1250] = 642,
  [1251] = 1080,
  [1252] = 643,
  [1253] = 645,
  [1254] = 1012,
  [1255] = 1043,
  [1256] = 1143,
  [1257] = 1145,
  [1258] = 1146,
  [1259] = 1042,
  [1260] = 1020,
  [1261] = 619,
  [1262] = 1127,
  [1263] = 1085,
  [1264] = 1084,
  [1265] = 1066,
  [1266] = 1067,
  [1267] = 1069,
  [1268] = 1078,
  [1269] = 633,
  [1270] = 636,
  [1271] = 626,
  [1272] = 1111,
  [1273] = 1093,
  [1274] = 977,
  [1275] = 1113,
  [1276] = 1137,
  [1277] = 1133,
  [1278] = 638,
  [1279] = 1122,
  [1280] = 1138,
  [1281] = 1103,
  [1282] = 1102,
  [1283] = 1098,
  [1284] = 1095,
  [1285] = 1068,
  [1286] = 1070,
  [1287] = 1095,
  [1288] = 1085,
  [1289] = 1068,
  [1290] = 1117,
  [1291] = 645,
  [1292] = 1070,
  [1293] = 1066,
  [1294] = 1067,
  [1295] = 1069,
  [1296] = 1138,
  [1297] = 1154,
  [1298] = 1066,
  [1299] = 1068,
  [1300] = 1133,
  [1301] = 1138,
  [1302] = 1067,
  [1303] = 1133,
  [1304] = 1137,
  [1305] = 1113,
  [1306] = 1057,
  [1307] = 1088,
  [1308] = 1087,
  [1309] = 1078,
  [1310] = 1079,
  [1311] = 1078,
  [1312] = 641,
  [1313] = 1154,
  [1314] = 639,
  [1315] = 1113,
  [1316] = 1137,
  [1317] = 1093,
  [1318] = 1111,
  [1319] = 1070,
  [1320] = 633,
  [1321] = 1122,
  [1322] = 636,
  [1323] = 1069,
  [1324] = 626,
  [1325] = 1133,
  [1326] = 1138,
  [1327] = 1068,
  [1328] = 1103,
  [1329] = 1102,
  [1330] = 1098,
  [1331] = 1095,
  [1332] = 642,
  [1333] = 643,
  [1334] = 627,
  [1335] = 1070,
  [1336] = 1154,
  [1337] = 1057,
  [1338] = 1084,
  [1339] = 638,
  [1340] = 1037,
  [1341] = 629,
  [1342] = 630,
  [1343] = 1012,
  [1344] = 1068,
  [1345] = 1043,
  [1346] = 1138,
  [1347] = 1133,
  [1348] = 1085,
  [1349] = 1154,
  [1350] = 1143,
  [1351] = 1093,
  [1352] = 1145,
  [1353] = 1111,
  [1354] = 1146,
  [1355] = 1355,
  [1356] = 1070,
  [1357] = 1095,
  [1358] = 1098,
  [1359] = 1102,
  [1360] = 1137,
  [1361] = 1113,
  [1362] = 1127,
  [1363] = 1363,
  [1364] = 1103,
  [1365] = 1057,
  [1366] = 1127,
  [1367] = 1117,
  [1368] = 1122,
  [1369] = 643,
  [1370] = 642,
  [1371] = 1098,
  [1372] = 1102,
  [1373] = 1103,
  [1374] = 628,
  [1375] = 1122,
  [1376] = 1078,
  [1377] = 1095,
  [1378] = 1146,
  [1379] = 1145,
  [1380] = 641,
  [1381] = 645,
  [1382] = 639,
  [1383] = 1098,
  [1384] = 1143,
  [1385] = 632,
  [1386] = 1111,
  [1387] = 1078,
  [1388] = 640,
  [1389] = 1093,
  [1390] = 1122,
  [1391] = 640,
  [1392] = 645,
  [1393] = 640,
  [1394] = 632,
  [1395] = 1102,
  [1396] = 645,
  [1397] = 633,
  [1398] = 636,
  [1399] = 628,
  [1400] = 630,
  [1401] = 629,
  [1402] = 1069,
  [1403] = 1067,
  [1404] = 1066,
  [1405] = 1069,
  [1406] = 1067,
  [1407] = 627,
  [1408] = 1093,
  [1409] = 1111,
  [1410] = 1042,
  [1411] = 626,
  [1412] = 645,
  [1413] = 643,
  [1414] = 1057,
  [1415] = 1084,
  [1416] = 1085,
  [1417] = 642,
  [1418] = 1103,
  [1419] = 629,
  [1420] = 1020,
  [1421] = 630,
  [1422] = 1066,
  [1423] = 1127,
  [1424] = 638,
  [1425] = 628,
  [1426] = 641,
  [1427] = 1084,
  [1428] = 1137,
  [1429] = 642,
  [1430] = 1127,
  [1431] = 639,
  [1432] = 1117,
  [1433] = 1117,
  [1434] = 1143,
  [1435] = 1113,
  [1436] = 1145,
  [1437] = 643,
  [1438] = 638,
  [1439] = 1146,
  [1440] = 1085,
  [1441] = 1084,
  [1442] = 645,
  [1443] = 632,
  [1444] = 1143,
  [1445] = 1145,
  [1446] = 626,
  [1447] = 636,
  [1448] = 1146,
  [1449] = 633,
  [1450] = 1057,
  [1451] = 1081,
  [1452] = 1111,
  [1453] = 627,
  [1454] = 1133,
  [1455] = 1138,
  [1456] = 1137,
  [1457] = 1068,
  [1458] = 1143,
  [1459] = 1093,
  [1460] = 627,
  [1461] = 1145,
  [1462] = 1146,
  [1463] = 1080,
  [1464] = 1154,
  [1465] = 1113,
  [1466] = 1081,
  [1467] = 1083,
  [1468] = 1070,
  [1469] = 1127,
  [1470] = 1117,
  [1471] = 1078,
  [1472] = 1095,
  [1473] = 1098,
  [1474] = 1083,
  [1475] = 1085,
  [1476] = 1080,
  [1477] = 1102,
  [1478] = 1084,
  [1479] = 1066,
  [1480] = 640,
  [1481] = 638,
  [1482] = 1103,
  [1483] = 1122,
  [1484] = 626,
  [1485] = 1067,
  [1486] = 1069,
  [1487] = 643,
  [1488] = 636,
  [1489] = 642,
  [1490] = 645,
  [1491] = 639,
  [1492] = 641,
  [1493] = 1083,
  [1494] = 1081,
  [1495] = 1080,
  [1496] = 633,
  [1497] = 641,
  [1498] = 630,
  [1499] = 638,
  [1500] = 628,
  [1501] = 632,
  [1502] = 629,
  [1503] = 636,
  [1504] = 633,
  [1505] = 639,
  [1506] = 642,
  [1507] = 640,
  [1508] = 1363,
  [1509] = 1355,
  [1510] = 643,
  [1511] = 626,
  [1512] = 645,
  [1513] = 645,
  [1514] = 645,
  [1515] = 645,
  [1516] = 1516,
  [1517] = 1517,
  [1518] = 1518,
  [1519] = 1519,
  [1520] = 1518,
  [1521] = 1521,
  [1522] = 1518,
  [1523] = 1523,
  [1524] = 1524,
  [1525] = 1525,
  [1526] = 1521,
  [1527] = 1527,
  [1528] = 1528,
  [1529] = 1529,
  [1530] = 1524,
  [1531] = 1524,
  [1532] = 1519,
  [1533] = 1527,
  [1534] = 1519,
  [1535] = 1523,
  [1536] = 1527,
  [1537] = 1519,
  [1538] = 1527,
  [1539] = 1518,
  [1540] = 1528,
  [1541] = 1529,
  [1542] = 1523,
  [1543] = 1524,
  [1544] = 1528,
  [1545] = 1525,
  [1546] = 1521,
  [1547] = 1529,
  [1548] = 1525,
  [1549] = 1525,
  [1550] = 1523,
  [1551] = 1528,
  [1552] = 1521,
  [1553] = 1529,
  [1554] = 1554,
  [1555] = 1555,
  [1556] = 1556,
  [1557] = 1554,
  [1558] = 1554,
  [1559] = 1559,
  [1560] = 1560,
  [1561] = 1561,
  [1562] = 1562,
  [1563] = 1563,
  [1564] = 1562,
  [1565] = 1563,
  [1566] = 1559,
  [1567] = 1563,
  [1568] = 1561,
  [1569] = 1559,
  [1570] = 1561,
  [1571] = 1560,
  [1572] = 1563,
  [1573] = 1560,
  [1574] = 1560,
  [1575] = 1562,
  [1576] = 1561,
  [1577] = 1559,
  [1578] = 1562,
  [1579] = 1579,
  [1580] = 1580,
  [1581] = 1581,
  [1582] = 1581,
  [1583] = 1581,
  [1584] = 1580,
  [1585] = 1581,
  [1586] = 1580,
  [1587] = 1580,
  [1588] = 1588,
  [1589] = 1589,
  [1590] = 628,
  [1591] = 632,
  [1592] = 1355,
  [1593] = 1588,
  [1594] = 1363,
  [1595] = 1589,
  [1596] = 1588,
  [1597] = 1589,
  [1598] = 629,
  [1599] = 630,
  [1600] = 1588,
  [1601] = 1588,
  [1602] = 1589,
  [1603] = 1588,
  [1604] = 1589,
  [1605] = 1589,
  [1606] = 643,
  [1607] = 642,
  [1608] = 1608,
  [1609] = 1609,
  [1610] = 1588,
  [1611] = 1611,
  [1612] = 645,
  [1613] = 1589,
  [1614] = 1589,
  [1615] = 1615,
  [1616] = 1616,
  [1617] = 1588,
  [1618] = 643,
  [1619] = 1619,
  [1620] = 1619,
  [1621] = 1619,
  [1622] = 630,
  [1623] = 1619,
  [1624] = 1619,
  [1625] = 642,
  [1626] = 1363,
  [1627] = 1355,
  [1628] = 1628,
  [1629] = 1355,
  [1630] = 629,
  [1631] = 1619,
  [1632] = 1363,
  [1633] = 1619,
  [1634] = 628,
  [1635] = 1635,
  [1636] = 1616,
  [1637] = 1609,
  [1638] = 629,
  [1639] = 1608,
  [1640] = 632,
  [1641] = 1619,
  [1642] = 630,
  [1643] = 632,
  [1644] = 645,
  [1645] = 628,
  [1646] = 1355,
  [1647] = 629,
  [1648] = 1363,
  [1649] = 1649,
  [1650] = 1619,
  [1651] = 630,
  [1652] = 628,
  [1653] = 1653,
  [1654] = 1619,
  [1655] = 632,
  [1656] = 1656,
  [1657] = 1656,
  [1658] = 1658,
  [1659] = 1656,
  [1660] = 1656,
  [1661] = 1615,
  [1662] = 1656,
  [1663] = 1656,
  [1664] = 1635,
  [1665] = 1656,
  [1666] = 1666,
  [1667] = 1658,
  [1668] = 1628,
  [1669] = 1656,
  [1670] = 1670,
  [1671] = 1670,
  [1672] = 1653,
  [1673] = 1649,
  [1674] = 1658,
  [1675] = 1611,
  [1676] = 1676,
  [1677] = 1677,
  [1678] = 1678,
  [1679] = 1679,
  [1680] = 1678,
  [1681] = 1677,
  [1682] = 1682,
  [1683] = 1682,
  [1684] = 1684,
  [1685] = 1685,
  [1686] = 1684,
  [1687] = 1687,
  [1688] = 1688,
  [1689] = 1689,
  [1690] = 1684,
  [1691] = 1684,
  [1692] = 1692,
  [1693] = 1693,
  [1694] = 1684,
  [1695] = 1684,
  [1696] = 1696,
  [1697] = 1697,
  [1698] = 1684,
  [1699] = 1699,
  [1700] = 1684,
  [1701] = 1701,
  [1702] = 1701,
  [1703] = 1701,
  [1704] = 1704,
  [1705] = 1704,
  [1706] = 1706,
  [1707] = 1706,
  [1708] = 1706,
  [1709] = 1709,
  [1710] = 1701,
  [1711] = 1704,
  [1712] = 1706,
  [1713] = 1706,
  [1714] = 1701,
  [1715] = 1701,
  [1716] = 1704,
  [1717] = 1717,
  [1718] = 1706,
  [1719] = 1706,
  [1720] = 1704,
  [1721] = 1704,
  [1722] = 1706,
  [1723] = 1701,
  [1724] = 1704,
  [1725] = 1701,
  [1726] = 1704,
  [1727] = 1727,
  [1728] = 1728,
  [1729] = 1693,
  [1730] = 1727,
  [1731] = 1728,
  [1732] = 1732,
  [1733] = 1728,
  [1734] = 1697,
  [1735] = 1685,
  [1736] = 1727,
  [1737] = 1692,
  [1738] = 1689,
  [1739] = 1728,
  [1740] = 1692,
  [1741] = 1699,
  [1742] = 1727,
  [1743] = 1728,
  [1744] = 1697,
  [1745] = 1699,
  [1746] = 1685,
  [1747] = 1728,
  [1748] = 1693,
  [1749] = 1689,
  [1750] = 1688,
  [1751] = 1687,
  [1752] = 1752,
  [1753] = 1753,
  [1754] = 1688,
  [1755] = 1753,
  [1756] = 1728,
  [1757] = 1727,
  [1758] = 1687,
  [1759] = 1727,
  [1760] = 1696,
  [1761] = 1761,
  [1762] = 1696,
  [1763] = 1728,
  [1764] = 1727,
  [1765] = 1728,
  [1766] = 1727,
  [1767] = 1727,
  [1768] = 1687,
  [1769] = 1697,
  [1770] = 1696,
  [1771] = 1688,
  [1772] = 1699,
  [1773] = 1693,
  [1774] = 1689,
  [1775] = 1697,
  [1776] = 1685,
  [1777] = 1689,
  [1778] = 1688,
  [1779] = 1779,
  [1780] = 1685,
  [1781] = 1781,
  [1782] = 1693,
  [1783] = 1687,
  [1784] = 1688,
  [1785] = 1697,
  [1786] = 1753,
  [1787] = 1692,
  [1788] = 1692,
  [1789] = 1692,
  [1790] = 1790,
  [1791] = 1699,
  [1792] = 1792,
  [1793] = 1687,
  [1794] = 1685,
  [1795] = 1696,
  [1796] = 1753,
  [1797] = 1797,
  [1798] = 1798,
  [1799] = 1696,
  [1800] = 1693,
  [1801] = 1699,
  [1802] = 1689,
  [1803] = 1803,
  [1804] = 1697,
  [1805] = 1805,
  [1806] = 1806,
  [1807] = 1807,
  [1808] = 1808,
  [1809] = 1687,
  [1810] = 1697,
  [1811] = 1699,
  [1812] = 1812,
  [1813] = 1813,
  [1814] = 1685,
  [1815] = 1807,
  [1816] = 1693,
  [1817] = 1817,
  [1818] = 1805,
  [1819] = 1692,
  [1820] = 1820,
  [1821] = 1803,
  [1822] = 1689,
  [1823] = 1696,
  [1824] = 1824,
  [1825] = 1825,
  [1826] = 1688,
  [1827] = 1806,
  [1828] = 1824,
  [1829] = 1752,
  [1830] = 1830,
  [1831] = 1807,
  [1832] = 1687,
  [1833] = 1813,
  [1834] = 1807,
  [1835] = 1807,
  [1836] = 1836,
  [1837] = 1817,
  [1838] = 1807,
  [1839] = 1817,
  [1840] = 1803,
  [1841] = 1830,
  [1842] = 1803,
  [1843] = 1692,
  [1844] = 1806,
  [1845] = 1805,
  [1846] = 1699,
  [1847] = 1807,
  [1848] = 1693,
  [1849] = 1849,
  [1850] = 1781,
  [1851] = 1696,
  [1852] = 1807,
  [1853] = 1853,
  [1854] = 1807,
  [1855] = 1685,
  [1856] = 1689,
  [1857] = 1688,
  [1858] = 1858,
  [1859] = 1859,
  [1860] = 1807,
  [1861] = 1861,
  [1862] = 1862,
  [1863] = 1798,
  [1864] = 1864,
  [1865] = 1779,
  [1866] = 1779,
  [1867] = 1867,
  [1868] = 1868,
  [1869] = 1867,
  [1870] = 1867,
  [1871] = 1871,
  [1872] = 1872,
  [1873] = 1864,
  [1874] = 1874,
  [1875] = 1864,
  [1876] = 1862,
  [1877] = 1798,
  [1878] = 1871,
  [1879] = 1879,
  [1880] = 1880,
  [1881] = 1881,
  [1882] = 1882,
  [1883] = 1883,
  [1884] = 1879,
  [1885] = 1885,
  [1886] = 1862,
  [1887] = 1812,
  [1888] = 1779,
  [1889] = 1798,
  [1890] = 1862,
  [1891] = 1891,
  [1892] = 1862,
  [1893] = 1893,
  [1894] = 1752,
  [1895] = 1812,
  [1896] = 1862,
  [1897] = 1891,
  [1898] = 1812,
  [1899] = 1899,
  [1900] = 1790,
  [1901] = 1790,
  [1902] = 1868,
  [1903] = 1903,
  [1904] = 1891,
  [1905] = 1862,
  [1906] = 1906,
  [1907] = 1885,
  [1908] = 1908,
  [1909] = 1862,
  [1910] = 1910,
  [1911] = 1752,
  [1912] = 1868,
  [1913] = 1790,
  [1914] = 1798,
  [1915] = 1915,
  [1916] = 1916,
  [1917] = 1917,
  [1918] = 1918,
  [1919] = 1919,
  [1920] = 1797,
  [1921] = 1921,
  [1922] = 1922,
  [1923] = 1923,
  [1924] = 1924,
  [1925] = 1925,
  [1926] = 1926,
  [1927] = 1927,
  [1928] = 1925,
  [1929] = 1927,
  [1930] = 1922,
  [1931] = 1931,
  [1932] = 1881,
  [1933] = 1933,
  [1934] = 1934,
  [1935] = 1935,
  [1936] = 1936,
  [1937] = 1937,
  [1938] = 1938,
  [1939] = 1925,
  [1940] = 1940,
  [1941] = 1941,
  [1942] = 1926,
  [1943] = 1797,
  [1944] = 1944,
  [1945] = 1945,
  [1946] = 1781,
  [1947] = 1947,
  [1948] = 1927,
  [1949] = 1836,
  [1950] = 1950,
  [1951] = 1945,
  [1952] = 1952,
  [1953] = 1944,
  [1954] = 1908,
  [1955] = 1955,
  [1956] = 1934,
  [1957] = 1957,
  [1958] = 1781,
  [1959] = 1959,
  [1960] = 1797,
  [1961] = 1961,
  [1962] = 1950,
  [1963] = 1963,
  [1964] = 1964,
  [1965] = 1965,
  [1966] = 1941,
  [1967] = 1944,
  [1968] = 1968,
  [1969] = 1969,
  [1970] = 1836,
  [1971] = 1971,
  [1972] = 1836,
  [1973] = 1881,
  [1974] = 1974,
  [1975] = 1947,
  [1976] = 1781,
  [1977] = 1615,
  [1978] = 1978,
  [1979] = 1979,
  [1980] = 1974,
  [1981] = 1981,
  [1982] = 1940,
  [1983] = 1983,
  [1984] = 1984,
  [1985] = 1985,
  [1986] = 1908,
  [1987] = 1959,
  [1988] = 1968,
  [1989] = 1989,
  [1990] = 1990,
  [1991] = 1790,
  [1992] = 1925,
  [1993] = 1961,
  [1994] = 1994,
  [1995] = 1965,
  [1996] = 1947,
  [1997] = 1964,
  [1998] = 1974,
  [1999] = 1922,
  [2000] = 2000,
  [2001] = 1963,
  [2002] = 1779,
  [2003] = 1957,
  [2004] = 1937,
  [2005] = 1881,
  [2006] = 1825,
  [2007] = 2007,
  [2008] = 2008,
  [2009] = 2009,
  [2010] = 1990,
  [2011] = 1908,
  [2012] = 1926,
  [2013] = 2009,
  [2014] = 1611,
  [2015] = 1940,
  [2016] = 1957,
  [2017] = 1937,
  [2018] = 1941,
  [2019] = 2019,
  [2020] = 2020,
  [2021] = 2021,
  [2022] = 2022,
  [2023] = 2007,
  [2024] = 1628,
  [2025] = 2025,
  [2026] = 2026,
  [2027] = 1955,
  [2028] = 1969,
  [2029] = 1981,
  [2030] = 2030,
  [2031] = 2031,
  [2032] = 2019,
  [2033] = 2033,
  [2034] = 1917,
  [2035] = 2035,
  [2036] = 2008,
  [2037] = 2037,
  [2038] = 1968,
  [2039] = 1959,
  [2040] = 2040,
  [2041] = 2041,
  [2042] = 1969,
  [2043] = 1955,
  [2044] = 1934,
  [2045] = 2045,
  [2046] = 2046,
  [2047] = 2026,
  [2048] = 2008,
  [2049] = 2049,
  [2050] = 2050,
  [2051] = 1968,
  [2052] = 1959,
  [2053] = 2053,
  [2054] = 2031,
  [2055] = 2040,
  [2056] = 2056,
  [2057] = 2057,
  [2058] = 2035,
  [2059] = 2059,
  [2060] = 2060,
  [2061] = 1927,
  [2062] = 1965,
  [2063] = 1964,
  [2064] = 2064,
  [2065] = 2065,
  [2066] = 2066,
  [2067] = 1864,
  [2068] = 1965,
  [2069] = 2069,
  [2070] = 2040,
  [2071] = 2071,
  [2072] = 2072,
  [2073] = 1964,
  [2074] = 2074,
  [2075] = 1917,
  [2076] = 2019,
  [2077] = 1963,
  [2078] = 2078,
  [2079] = 2057,
  [2080] = 2080,
  [2081] = 2081,
  [2082] = 2082,
  [2083] = 2083,
  [2084] = 2064,
  [2085] = 1635,
  [2086] = 2086,
  [2087] = 2087,
  [2088] = 2088,
  [2089] = 2089,
  [2090] = 2090,
  [2091] = 2091,
  [2092] = 1963,
  [2093] = 2093,
  [2094] = 2094,
  [2095] = 2095,
  [2096] = 2031,
  [2097] = 1957,
  [2098] = 1649,
  [2099] = 1836,
  [2100] = 2100,
  [2101] = 2053,
  [2102] = 1921,
  [2103] = 2083,
  [2104] = 2104,
  [2105] = 2105,
  [2106] = 2026,
  [2107] = 2031,
  [2108] = 2108,
  [2109] = 1938,
  [2110] = 1955,
  [2111] = 1969,
  [2112] = 1938,
  [2113] = 2113,
  [2114] = 2031,
  [2115] = 1938,
  [2116] = 2116,
  [2117] = 2117,
  [2118] = 2008,
  [2119] = 2033,
  [2120] = 2090,
  [2121] = 2121,
  [2122] = 1917,
  [2123] = 2089,
  [2124] = 2031,
  [2125] = 2031,
  [2126] = 2126,
  [2127] = 2040,
  [2128] = 2128,
  [2129] = 2019,
  [2130] = 1653,
  [2131] = 2059,
  [2132] = 2031,
  [2133] = 2035,
  [2134] = 2134,
  [2135] = 2059,
  [2136] = 1937,
  [2137] = 1934,
  [2138] = 2088,
  [2139] = 2139,
  [2140] = 2140,
  [2141] = 2141,
  [2142] = 2142,
  [2143] = 2143,
  [2144] = 2081,
  [2145] = 2128,
  [2146] = 2146,
  [2147] = 2022,
  [2148] = 2126,
  [2149] = 2149,
  [2150] = 2093,
  [2151] = 2151,
  [2152] = 2082,
  [2153] = 2153,
  [2154] = 2074,
  [2155] = 2104,
  [2156] = 2030,
  [2157] = 2157,
  [2158] = 2143,
  [2159] = 2159,
  [2160] = 2160,
  [2161] = 2139,
  [2162] = 2162,
  [2163] = 2021,
  [2164] = 2164,
  [2165] = 2050,
  [2166] = 2037,
  [2167] = 2121,
  [2168] = 2033,
  [2169] = 2087,
  [2170] = 2104,
  [2171] = 2171,
  [2172] = 2172,
  [2173] = 2173,
  [2174] = 2174,
  [2175] = 2025,
  [2176] = 2060,
  [2177] = 2177,
  [2178] = 2178,
  [2179] = 2117,
  [2180] = 2105,
  [2181] = 2100,
  [2182] = 2095,
  [2183] = 2183,
  [2184] = 2094,
  [2185] = 2113,
  [2186] = 2033,
  [2187] = 2091,
  [2188] = 2121,
  [2189] = 2134,
  [2190] = 2045,
  [2191] = 2104,
  [2192] = 2192,
  [2193] = 2021,
  [2194] = 2194,
  [2195] = 2172,
  [2196] = 2157,
  [2197] = 2197,
  [2198] = 2066,
  [2199] = 2078,
  [2200] = 2153,
  [2201] = 2201,
  [2202] = 2071,
  [2203] = 2071,
  [2204] = 2128,
  [2205] = 2205,
  [2206] = 2157,
  [2207] = 2172,
  [2208] = 2066,
  [2209] = 2022,
  [2210] = 2045,
  [2211] = 2134,
  [2212] = 2091,
  [2213] = 2113,
  [2214] = 2183,
  [2215] = 2126,
  [2216] = 2094,
  [2217] = 2095,
  [2218] = 2100,
  [2219] = 2093,
  [2220] = 2082,
  [2221] = 2105,
  [2222] = 2164,
  [2223] = 2223,
  [2224] = 2117,
  [2225] = 2225,
  [2226] = 2226,
  [2227] = 2030,
  [2228] = 2228,
  [2229] = 2229,
  [2230] = 2060,
  [2231] = 2183,
  [2232] = 2232,
  [2233] = 2233,
  [2234] = 2025,
  [2235] = 2037,
  [2236] = 2236,
  [2237] = 2237,
  [2238] = 2183,
  [2239] = 2037,
  [2240] = 2025,
  [2241] = 2060,
  [2242] = 2117,
  [2243] = 2172,
  [2244] = 2157,
  [2245] = 2105,
  [2246] = 2100,
  [2247] = 2030,
  [2248] = 2095,
  [2249] = 2226,
  [2250] = 2094,
  [2251] = 2093,
  [2252] = 2113,
  [2253] = 2126,
  [2254] = 2091,
  [2255] = 2022,
  [2256] = 2128,
  [2257] = 2134,
  [2258] = 2021,
  [2259] = 2121,
  [2260] = 2045,
  [2261] = 2066,
  [2262] = 2082,
  [2263] = 2263,
  [2264] = 2264,
  [2265] = 2071,
  [2266] = 2266,
  [2267] = 2267,
  [2268] = 2268,
  [2269] = 2269,
  [2270] = 2270,
  [2271] = 2236,
  [2272] = 2272,
  [2273] = 653,
  [2274] = 2274,
  [2275] = 2275,
  [2276] = 2276,
  [2277] = 2171,
  [2278] = 2159,
  [2279] = 2279,
  [2280] = 2223,
  [2281] = 2281,
  [2282] = 2282,
  [2283] = 2283,
  [2284] = 2284,
  [2285] = 2285,
  [2286] = 2286,
  [2287] = 2287,
  [2288] = 1915,
  [2289] = 2287,
  [2290] = 2290,
  [2291] = 1916,
  [2292] = 1918,
  [2293] = 2293,
  [2294] = 1919,
  [2295] = 1931,
  [2296] = 2296,
  [2297] = 2297,
  [2298] = 2298,
  [2299] = 2299,
  [2300] = 2300,
  [2301] = 1933,
  [2302] = 2302,
  [2303] = 2287,
  [2304] = 655,
  [2305] = 2305,
  [2306] = 2306,
  [2307] = 2307,
  [2308] = 2308,
  [2309] = 2309,
  [2310] = 2310,
  [2311] = 2305,
  [2312] = 2298,
  [2313] = 2313,
  [2314] = 2314,
  [2315] = 2270,
  [2316] = 2316,
  [2317] = 2317,
  [2318] = 2293,
  [2319] = 2319,
  [2320] = 2236,
  [2321] = 2321,
  [2322] = 2322,
  [2323] = 2282,
  [2324] = 1981,
  [2325] = 2325,
  [2326] = 647,
  [2327] = 2327,
  [2328] = 2285,
  [2329] = 2329,
  [2330] = 2286,
  [2331] = 2331,
  [2332] = 2309,
  [2333] = 2333,
  [2334] = 2334,
  [2335] = 2335,
  [2336] = 2284,
  [2337] = 2159,
  [2338] = 2338,
  [2339] = 2316,
  [2340] = 2340,
  [2341] = 2341,
  [2342] = 2342,
  [2343] = 2343,
  [2344] = 2321,
  [2345] = 2345,
  [2346] = 2283,
  [2347] = 2347,
  [2348] = 2335,
  [2349] = 2349,
  [2350] = 2325,
  [2351] = 2351,
  [2352] = 2333,
  [2353] = 2334,
  [2354] = 2333,
  [2355] = 2355,
  [2356] = 2356,
  [2357] = 1978,
  [2358] = 2345,
  [2359] = 2276,
  [2360] = 1615,
  [2361] = 2343,
  [2362] = 2177,
  [2363] = 2363,
  [2364] = 2269,
  [2365] = 2287,
  [2366] = 2345,
  [2367] = 2340,
  [2368] = 1921,
  [2369] = 1020,
  [2370] = 1615,
  [2371] = 2317,
  [2372] = 2298,
  [2373] = 2338,
  [2374] = 2305,
  [2375] = 2274,
  [2376] = 2334,
  [2377] = 2300,
  [2378] = 2314,
  [2379] = 2317,
  [2380] = 2298,
  [2381] = 2276,
  [2382] = 2355,
  [2383] = 2305,
  [2384] = 2384,
  [2385] = 2300,
  [2386] = 2279,
  [2387] = 2279,
  [2388] = 2341,
  [2389] = 1611,
  [2390] = 2317,
  [2391] = 2391,
  [2392] = 2298,
  [2393] = 2305,
  [2394] = 2309,
  [2395] = 2290,
  [2396] = 2307,
  [2397] = 2284,
  [2398] = 2398,
  [2399] = 2269,
  [2400] = 2285,
  [2401] = 2296,
  [2402] = 2297,
  [2403] = 2300,
  [2404] = 2297,
  [2405] = 2300,
  [2406] = 2296,
  [2407] = 2299,
  [2408] = 2281,
  [2409] = 2290,
  [2410] = 2384,
  [2411] = 2411,
  [2412] = 2307,
  [2413] = 2331,
  [2414] = 2309,
  [2415] = 2279,
  [2416] = 2305,
  [2417] = 2298,
  [2418] = 2418,
  [2419] = 2316,
  [2420] = 658,
  [2421] = 2290,
  [2422] = 1653,
  [2423] = 2276,
  [2424] = 2317,
  [2425] = 2287,
  [2426] = 652,
  [2427] = 1921,
  [2428] = 2290,
  [2429] = 2342,
  [2430] = 2302,
  [2431] = 2307,
  [2432] = 2331,
  [2433] = 2286,
  [2434] = 2293,
  [2435] = 2322,
  [2436] = 2343,
  [2437] = 2296,
  [2438] = 2338,
  [2439] = 2298,
  [2440] = 2340,
  [2441] = 2305,
  [2442] = 1615,
  [2443] = 2343,
  [2444] = 2309,
  [2445] = 2345,
  [2446] = 2272,
  [2447] = 2174,
  [2448] = 2307,
  [2449] = 2449,
  [2450] = 2300,
  [2451] = 2451,
  [2452] = 2334,
  [2453] = 1921,
  [2454] = 1981,
  [2455] = 2297,
  [2456] = 2398,
  [2457] = 2296,
  [2458] = 2316,
  [2459] = 2459,
  [2460] = 2296,
  [2461] = 2461,
  [2462] = 2287,
  [2463] = 2290,
  [2464] = 2000,
  [2465] = 2465,
  [2466] = 2297,
  [2467] = 1981,
  [2468] = 2317,
  [2469] = 2279,
  [2470] = 2276,
  [2471] = 2228,
  [2472] = 2472,
  [2473] = 2317,
  [2474] = 2178,
  [2475] = 2300,
  [2476] = 2276,
  [2477] = 2287,
  [2478] = 2411,
  [2479] = 2479,
  [2480] = 2279,
  [2481] = 2279,
  [2482] = 2225,
  [2483] = 2275,
  [2484] = 2340,
  [2485] = 2298,
  [2486] = 2305,
  [2487] = 2309,
  [2488] = 2488,
  [2489] = 2290,
  [2490] = 2307,
  [2491] = 2491,
  [2492] = 2300,
  [2493] = 2349,
  [2494] = 2325,
  [2495] = 2296,
  [2496] = 2297,
  [2497] = 2171,
  [2498] = 2298,
  [2499] = 2300,
  [2500] = 2297,
  [2501] = 2296,
  [2502] = 1042,
  [2503] = 2351,
  [2504] = 2307,
  [2505] = 2459,
  [2506] = 2309,
  [2507] = 2479,
  [2508] = 2305,
  [2509] = 2298,
  [2510] = 2290,
  [2511] = 2331,
  [2512] = 2146,
  [2513] = 2279,
  [2514] = 2159,
  [2515] = 2223,
  [2516] = 2305,
  [2517] = 2276,
  [2518] = 2276,
  [2519] = 2309,
  [2520] = 2307,
  [2521] = 2300,
  [2522] = 2287,
  [2523] = 2338,
  [2524] = 2297,
  [2525] = 2525,
  [2526] = 2236,
  [2527] = 2317,
  [2528] = 2528,
  [2529] = 2529,
  [2530] = 2530,
  [2531] = 652,
  [2532] = 2532,
  [2533] = 2533,
  [2534] = 655,
  [2535] = 2535,
  [2536] = 653,
  [2537] = 2537,
  [2538] = 2538,
  [2539] = 2539,
  [2540] = 2540,
  [2541] = 2541,
  [2542] = 2542,
  [2543] = 2543,
  [2544] = 2544,
  [2545] = 2545,
  [2546] = 1653,
  [2547] = 2547,
  [2548] = 2548,
  [2549] = 2549,
  [2550] = 2550,
  [2551] = 2551,
  [2552] = 2525,
  [2553] = 2065,
  [2554] = 1649,
  [2555] = 2555,
  [2556] = 2065,
  [2557] = 2557,
  [2558] = 2558,
  [2559] = 2559,
  [2560] = 2560,
  [2561] = 2561,
  [2562] = 2562,
  [2563] = 2563,
  [2564] = 2564,
  [2565] = 2530,
  [2566] = 2532,
  [2567] = 647,
  [2568] = 2568,
  [2569] = 2569,
  [2570] = 2549,
  [2571] = 1649,
  [2572] = 2572,
  [2573] = 2356,
  [2574] = 1628,
  [2575] = 2568,
  [2576] = 1635,
  [2577] = 2564,
  [2578] = 2578,
  [2579] = 2579,
  [2580] = 2065,
  [2581] = 2581,
  [2582] = 2582,
  [2583] = 2542,
  [2584] = 2584,
  [2585] = 1635,
  [2586] = 2586,
  [2587] = 2581,
  [2588] = 2543,
  [2589] = 2539,
  [2590] = 2586,
  [2591] = 658,
  [2592] = 2592,
  [2593] = 2593,
  [2594] = 2594,
  [2595] = 2595,
  [2596] = 2596,
  [2597] = 2568,
  [2598] = 2598,
  [2599] = 2561,
  [2600] = 1628,
  [2601] = 2563,
  [2602] = 2602,
  [2603] = 2603,
  [2604] = 2584,
  [2605] = 2605,
  [2606] = 2606,
  [2607] = 2607,
  [2608] = 2310,
  [2609] = 2609,
  [2610] = 2582,
  [2611] = 2611,
  [2612] = 2612,
  [2613] = 2532,
  [2614] = 2579,
  [2615] = 2615,
  [2616] = 2612,
  [2617] = 2563,
  [2618] = 2568,
  [2619] = 2530,
  [2620] = 2612,
  [2621] = 2621,
  [2622] = 2622,
  [2623] = 2563,
  [2624] = 2579,
  [2625] = 2532,
  [2626] = 2530,
  [2627] = 2578,
  [2628] = 2578,
  [2629] = 2629,
  [2630] = 2630,
  [2631] = 2631,
  [2632] = 2632,
  [2633] = 2629,
  [2634] = 2634,
  [2635] = 2635,
  [2636] = 2636,
  [2637] = 2637,
  [2638] = 2638,
  [2639] = 2639,
  [2640] = 2640,
  [2641] = 2641,
  [2642] = 2642,
  [2643] = 2643,
  [2644] = 2644,
  [2645] = 2645,
  [2646] = 2646,
  [2647] = 2647,
  [2648] = 2648,
  [2649] = 2649,
  [2650] = 2642,
  [2651] = 2630,
  [2652] = 2634,
  [2653] = 2653,
  [2654] = 2654,
  [2655] = 2643,
  [2656] = 2631,
  [2657] = 2638,
  [2658] = 2658,
  [2659] = 2654,
  [2660] = 2648,
  [2661] = 2634,
  [2662] = 2662,
  [2663] = 2630,
  [2664] = 2664,
  [2665] = 2654,
  [2666] = 2631,
  [2667] = 2631,
  [2668] = 2643,
  [2669] = 2643,
  [2670] = 2670,
  [2671] = 2671,
  [2672] = 2634,
  [2673] = 2635,
  [2674] = 2630,
  [2675] = 2675,
  [2676] = 2676,
  [2677] = 2637,
  [2678] = 2678,
  [2679] = 2641,
  [2680] = 2654,
  [2681] = 2642,
  [2682] = 2647,
  [2683] = 2648,
  [2684] = 2648,
  [2685] = 2629,
  [2686] = 2645,
  [2687] = 2644,
  [2688] = 2641,
  [2689] = 2689,
  [2690] = 2635,
  [2691] = 2640,
  [2692] = 2654,
  [2693] = 2648,
  [2694] = 2694,
  [2695] = 2695,
  [2696] = 2696,
  [2697] = 2676,
  [2698] = 2637,
  [2699] = 2634,
  [2700] = 2689,
  [2701] = 2642,
  [2702] = 2629,
  [2703] = 2630,
  [2704] = 2694,
  [2705] = 2644,
  [2706] = 2671,
  [2707] = 2689,
  [2708] = 2708,
  [2709] = 2658,
  [2710] = 2648,
  [2711] = 2711,
  [2712] = 2637,
  [2713] = 2713,
  [2714] = 2676,
  [2715] = 2715,
  [2716] = 2716,
  [2717] = 2717,
  [2718] = 2645,
  [2719] = 2644,
  [2720] = 2648,
  [2721] = 2670,
  [2722] = 2722,
  [2723] = 2636,
  [2724] = 2641,
  [2725] = 2717,
  [2726] = 2640,
  [2727] = 2722,
  [2728] = 2642,
  [2729] = 2716,
  [2730] = 2631,
  [2731] = 2731,
  [2732] = 2732,
  [2733] = 2733,
  [2734] = 2715,
  [2735] = 2637,
  [2736] = 2640,
  [2737] = 2737,
  [2738] = 2640,
  [2739] = 2641,
  [2740] = 2695,
  [2741] = 2695,
  [2742] = 2742,
  [2743] = 2644,
  [2744] = 2675,
  [2745] = 2645,
  [2746] = 2696,
  [2747] = 2696,
  [2748] = 2662,
  [2749] = 2648,
  [2750] = 2732,
  [2751] = 2751,
  [2752] = 2638,
  [2753] = 2642,
  [2754] = 2637,
  [2755] = 2644,
  [2756] = 2645,
  [2757] = 2636,
  [2758] = 2676,
  [2759] = 2732,
  [2760] = 2630,
  [2761] = 2675,
  [2762] = 2695,
  [2763] = 2637,
  [2764] = 2634,
  [2765] = 2643,
  [2766] = 2643,
  [2767] = 2640,
  [2768] = 2768,
  [2769] = 2689,
  [2770] = 2631,
  [2771] = 2654,
  [2772] = 2772,
  [2773] = 2630,
  [2774] = 2654,
  [2775] = 2775,
  [2776] = 2776,
  [2777] = 2638,
  [2778] = 2778,
  [2779] = 2629,
  [2780] = 2654,
  [2781] = 2689,
  [2782] = 2629,
  [2783] = 2631,
  [2784] = 2631,
  [2785] = 2643,
  [2786] = 2643,
  [2787] = 2787,
  [2788] = 2634,
  [2789] = 2789,
  [2790] = 2645,
  [2791] = 2635,
  [2792] = 2733,
  [2793] = 2630,
  [2794] = 2794,
  [2795] = 2795,
  [2796] = 2796,
  [2797] = 2796,
  [2798] = 2737,
  [2799] = 2634,
  [2800] = 2676,
  [2801] = 2642,
  [2802] = 2802,
  [2803] = 2629,
  [2804] = 2804,
  [2805] = 2805,
  [2806] = 2642,
  [2807] = 2795,
  [2808] = 2648,
  [2809] = 2641,
  [2810] = 2648,
  [2811] = 2645,
  [2812] = 2645,
  [2813] = 2644,
  [2814] = 2644,
  [2815] = 2776,
  [2816] = 2641,
  [2817] = 2640,
  [2818] = 2695,
  [2819] = 2641,
  [2820] = 2805,
  [2821] = 2646,
  [2822] = 2696,
  [2823] = 2653,
  [2824] = 2649,
  [2825] = 2772,
  [2826] = 2637,
  [2827] = 2768,
  [2828] = 2772,
  [2829] = 2640,
  [2830] = 2629,
};

static inline bool sym_identifier_character_set_1(int32_t c) {
  return (c < 43514
    ? (c < 4193
      ? (c < 2707
        ? (c < 1994
          ? (c < 931
            ? (c < 748
              ? (c < 192
                ? (c < 170
                  ? (c < 'a'
                    ? (c >= 'A' && c <= '_')
                    : c <= 'z')
                  : (c <= 170 || (c < 186
                    ? c == 181
                    : c <= 186)))
                : (c <= 214 || (c < 710
                  ? (c < 248
                    ? (c >= 216 && c <= 246)
                    : c <= 705)
                  : (c <= 721 || (c >= 736 && c <= 740)))))
              : (c <= 748 || (c < 895
                ? (c < 886
                  ? (c < 880
                    ? c == 750
                    : c <= 884)
                  : (c <= 887 || (c >= 891 && c <= 893)))
                : (c <= 895 || (c < 908
                  ? (c < 904
                    ? c == 902
                    : c <= 906)
                  : (c <= 908 || (c >= 910 && c <= 929)))))))
            : (c <= 1013 || (c < 1649
              ? (c < 1376
                ? (c < 1329
                  ? (c < 1162
                    ? (c >= 1015 && c <= 1153)
                    : c <= 1327)
                  : (c <= 1366 || c == 1369))
                : (c <= 1416 || (c < 1568
                  ? (c < 1519
                    ? (c >= 1488 && c <= 1514)
                    : c <= 1522)
                  : (c <= 1610 || (c >= 1646 && c <= 1647)))))
              : (c <= 1747 || (c < 1791
                ? (c < 1774
                  ? (c < 1765
                    ? c == 1749
                    : c <= 1766)
                  : (c <= 1775 || (c >= 1786 && c <= 1788)))
                : (c <= 1791 || (c < 1869
                  ? (c < 1810
                    ? c == 1808
                    : c <= 1839)
                  : (c <= 1957 || c == 1969))))))))
          : (c <= 2026 || (c < 2482
            ? (c < 2208
              ? (c < 2088
                ? (c < 2048
                  ? (c < 2042
                    ? (c >= 2036 && c <= 2037)
                    : c <= 2042)
                  : (c <= 2069 || (c < 2084
                    ? c == 2074
                    : c <= 2084)))
                : (c <= 2088 || (c < 2160
                  ? (c < 2144
                    ? (c >= 2112 && c <= 2136)
                    : c <= 2154)
                  : (c <= 2183 || (c >= 2185 && c <= 2190)))))
              : (c <= 2249 || (c < 2417
                ? (c < 2384
                  ? (c < 2365
                    ? (c >= 2308 && c <= 2361)
                    : c <= 2365)
                  : (c <= 2384 || (c >= 2392 && c <= 2401)))
                : (c <= 2432 || (c < 2451
                  ? (c < 2447
                    ? (c >= 2437 && c <= 2444)
                    : c <= 2448)
                  : (c <= 2472 || (c >= 2474 && c <= 2480)))))))
            : (c <= 2482 || (c < 2579
              ? (c < 2527
                ? (c < 2510
                  ? (c < 2493
                    ? (c >= 2486 && c <= 2489)
                    : c <= 2493)
                  : (c <= 2510 || (c >= 2524 && c <= 2525)))
                : (c <= 2529 || (c < 2565
                  ? (c < 2556
                    ? (c >= 2544 && c <= 2545)
                    : c <= 2556)
                  : (c <= 2570 || (c >= 2575 && c <= 2576)))))
              : (c <= 2600 || (c < 2649
                ? (c < 2613
                  ? (c < 2610
                    ? (c >= 2602 && c <= 2608)
                    : c <= 2611)
                  : (c <= 2614 || (c >= 2616 && c <= 2617)))
                : (c <= 2652 || (c < 2693
                  ? (c < 2674
                    ? c == 2654
                    : c <= 2676)
                  : (c <= 2701 || (c >= 2703 && c <= 2705)))))))))))
        : (c <= 2728 || (c < 3242
          ? (c < 2962
            ? (c < 2858
              ? (c < 2784
                ? (c < 2741
                  ? (c < 2738
                    ? (c >= 2730 && c <= 2736)
                    : c <= 2739)
                  : (c <= 2745 || (c < 2768
                    ? c == 2749
                    : c <= 2768)))
                : (c <= 2785 || (c < 2831
                  ? (c < 2821
                    ? c == 2809
                    : c <= 2828)
                  : (c <= 2832 || (c >= 2835 && c <= 2856)))))
              : (c <= 2864 || (c < 2911
                ? (c < 2877
                  ? (c < 2869
                    ? (c >= 2866 && c <= 2867)
                    : c <= 2873)
                  : (c <= 2877 || (c >= 2908 && c <= 2909)))
                : (c <= 2913 || (c < 2949
                  ? (c < 2947
                    ? c == 2929
                    : c <= 2947)
                  : (c <= 2954 || (c >= 2958 && c <= 2960)))))))
            : (c <= 2965 || (c < 3090
              ? (c < 2984
                ? (c < 2974
                  ? (c < 2972
                    ? (c >= 2969 && c <= 2970)
                    : c <= 2972)
                  : (c <= 2975 || (c >= 2979 && c <= 2980)))
                : (c <= 2986 || (c < 3077
                  ? (c < 3024
                    ? (c >= 2990 && c <= 3001)
                    : c <= 3024)
                  : (c <= 3084 || (c >= 3086 && c <= 3088)))))
              : (c <= 3112 || (c < 3168
                ? (c < 3160
                  ? (c < 3133
                    ? (c >= 3114 && c <= 3129)
                    : c <= 3133)
                  : (c <= 3162 || c == 3165))
                : (c <= 3169 || (c < 3214
                  ? (c < 3205
                    ? c == 3200
                    : c <= 3212)
                  : (c <= 3216 || (c >= 3218 && c <= 3240)))))))))
          : (c <= 3251 || (c < 3648
            ? (c < 3412
              ? (c < 3332
                ? (c < 3293
                  ? (c < 3261
                    ? (c >= 3253 && c <= 3257)
                    : c <= 3261)
                  : (c <= 3294 || (c < 3313
                    ? (c >= 3296 && c <= 3297)
                    : c <= 3314)))
                : (c <= 3340 || (c < 3389
                  ? (c < 3346
                    ? (c >= 3342 && c <= 3344)
                    : c <= 3386)
                  : (c <= 3389 || c == 3406))))
              : (c <= 3414 || (c < 3507
                ? (c < 3461
                  ? (c < 3450
                    ? (c >= 3423 && c <= 3425)
                    : c <= 3455)
                  : (c <= 3478 || (c >= 3482 && c <= 3505)))
                : (c <= 3515 || (c < 3585
                  ? (c < 3520
                    ? c == 3517
                    : c <= 3526)
                  : (c <= 3632 || c == 3634))))))
            : (c <= 3654 || (c < 3782
              ? (c < 3749
                ? (c < 3718
                  ? (c < 3716
                    ? (c >= 3713 && c <= 3714)
                    : c <= 3716)
                  : (c <= 3722 || (c >= 3724 && c <= 3747)))
                : (c <= 3749 || (c < 3773
                  ? (c < 3762
                    ? (c >= 3751 && c <= 3760)
                    : c <= 3762)
                  : (c <= 3773 || (c >= 3776 && c <= 3780)))))
              : (c <= 3782 || (c < 3976
                ? (c < 3904
                  ? (c < 3840
                    ? (c >= 3804 && c <= 3807)
                    : c <= 3840)
                  : (c <= 3911 || (c >= 3913 && c <= 3948)))
                : (c <= 3980 || (c < 4176
                  ? (c < 4159
                    ? (c >= 4096 && c <= 4138)
                    : c <= 4159)
                  : (c <= 4181 || (c >= 4186 && c <= 4189)))))))))))))
      : (c <= 4193 || (c < 8134
        ? (c < 6176
          ? (c < 4808
            ? (c < 4688
              ? (c < 4295
                ? (c < 4213
                  ? (c < 4206
                    ? (c >= 4197 && c <= 4198)
                    : c <= 4208)
                  : (c <= 4225 || (c < 4256
                    ? c == 4238
                    : c <= 4293)))
                : (c <= 4295 || (c < 4348
                  ? (c < 4304
                    ? c == 4301
                    : c <= 4346)
                  : (c <= 4680 || (c >= 4682 && c <= 4685)))))
              : (c <= 4694 || (c < 4752
                ? (c < 4704
                  ? (c < 4698
                    ? c == 4696
                    : c <= 4701)
                  : (c <= 4744 || (c >= 4746 && c <= 4749)))
                : (c <= 4784 || (c < 4800
                  ? (c < 4792
                    ? (c >= 4786 && c <= 4789)
                    : c <= 4798)
                  : (c <= 4800 || (c >= 4802 && c <= 4805)))))))
            : (c <= 4822 || (c < 5792
              ? (c < 5024
                ? (c < 4888
                  ? (c < 4882
                    ? (c >= 4824 && c <= 4880)
                    : c <= 4885)
                  : (c <= 4954 || (c >= 4992 && c <= 5007)))
                : (c <= 5109 || (c < 5743
                  ? (c < 5121
                    ? (c >= 5112 && c <= 5117)
                    : c <= 5740)
                  : (c <= 5759 || (c >= 5761 && c <= 5786)))))
              : (c <= 5866 || (c < 5984
                ? (c < 5919
                  ? (c < 5888
                    ? (c >= 5870 && c <= 5880)
                    : c <= 5905)
                  : (c <= 5937 || (c >= 5952 && c <= 5969)))
                : (c <= 5996 || (c < 6103
                  ? (c < 6016
                    ? (c >= 5998 && c <= 6000)
                    : c <= 6067)
                  : (c <= 6103 || c == 6108))))))))
          : (c <= 6264 || (c < 7312
            ? (c < 6823
              ? (c < 6512
                ? (c < 6320
                  ? (c < 6314
                    ? (c >= 6272 && c <= 6312)
                    : c <= 6314)
                  : (c <= 6389 || (c < 6480
                    ? (c >= 6400 && c <= 6430)
                    : c <= 6509)))
                : (c <= 6516 || (c < 6656
                  ? (c < 6576
                    ? (c >= 6528 && c <= 6571)
                    : c <= 6601)
                  : (c <= 6678 || (c >= 6688 && c <= 6740)))))
              : (c <= 6823 || (c < 7098
                ? (c < 7043
                  ? (c < 6981
                    ? (c >= 6917 && c <= 6963)
                    : c <= 6988)
                  : (c <= 7072 || (c >= 7086 && c <= 7087)))
                : (c <= 7141 || (c < 7258
                  ? (c < 7245
                    ? (c >= 7168 && c <= 7203)
                    : c <= 7247)
                  : (c <= 7293 || (c >= 7296 && c <= 7304)))))))
            : (c <= 7354 || (c < 8008
              ? (c < 7418
                ? (c < 7406
                  ? (c < 7401
                    ? (c >= 7357 && c <= 7359)
                    : c <= 7404)
                  : (c <= 7411 || (c >= 7413 && c <= 7414)))
                : (c <= 7418 || (c < 7960
                  ? (c < 7680
                    ? (c >= 7424 && c <= 7615)
                    : c <= 7957)
                  : (c <= 7965 || (c >= 7968 && c <= 8005)))))
              : (c <= 8013 || (c < 8031
                ? (c < 8027
                  ? (c < 8025
                    ? (c >= 8016 && c <= 8023)
                    : c <= 8025)
                  : (c <= 8027 || c == 8029))
                : (c <= 8061 || (c < 8126
                  ? (c < 8118
                    ? (c >= 8064 && c <= 8116)
                    : c <= 8124)
                  : (c <= 8126 || (c >= 8130 && c <= 8132)))))))))))
        : (c <= 8140 || (c < 12337
          ? (c < 8544
            ? (c < 8458
              ? (c < 8305
                ? (c < 8160
                  ? (c < 8150
                    ? (c >= 8144 && c <= 8147)
                    : c <= 8155)
                  : (c <= 8172 || (c < 8182
                    ? (c >= 8178 && c <= 8180)
                    : c <= 8188)))
                : (c <= 8305 || (c < 8450
                  ? (c < 8336
                    ? c == 8319
                    : c <= 8348)
                  : (c <= 8450 || c == 8455))))
              : (c <= 8467 || (c < 8488
                ? (c < 8484
                  ? (c < 8472
                    ? c == 8469
                    : c <= 8477)
                  : (c <= 8484 || c == 8486))
                : (c <= 8488 || (c < 8517
                  ? (c < 8508
                    ? (c >= 8490 && c <= 8505)
                    : c <= 8511)
                  : (c <= 8521 || c == 8526))))))
            : (c <= 8584 || (c < 11680
              ? (c < 11559
                ? (c < 11506
                  ? (c < 11499
                    ? (c >= 11264 && c <= 11492)
                    : c <= 11502)
                  : (c <= 11507 || (c >= 11520 && c <= 11557)))
                : (c <= 11559 || (c < 11631
                  ? (c < 11568
                    ? c == 11565
                    : c <= 11623)
                  : (c <= 11631 || (c >= 11648 && c <= 11670)))))
              : (c <= 11686 || (c < 11720
                ? (c < 11704
                  ? (c < 11696
                    ? (c >= 11688 && c <= 11694)
                    : c <= 11702)
                  : (c <= 11710 || (c >= 11712 && c <= 11718)))
                : (c <= 11726 || (c < 12293
                  ? (c < 11736
                    ? (c >= 11728 && c <= 11734)
                    : c <= 11742)
                  : (c <= 12295 || (c >= 12321 && c <= 12329)))))))))
          : (c <= 12341 || (c < 42891
            ? (c < 19968
              ? (c < 12549
                ? (c < 12445
                  ? (c < 12353
                    ? (c >= 12344 && c <= 12348)
                    : c <= 12438)
                  : (c <= 12447 || (c < 12540
                    ? (c >= 12449 && c <= 12538)
                    : c <= 12543)))
                : (c <= 12591 || (c < 12784
                  ? (c < 12704
                    ? (c >= 12593 && c <= 12686)
                    : c <= 12735)
                  : (c <= 12799 || (c >= 13312 && c <= 19903)))))
              : (c <= 42124 || (c < 42560
                ? (c < 42512
                  ? (c < 42240
                    ? (c >= 42192 && c <= 42237)
                    : c <= 42508)
                  : (c <= 42527 || (c >= 42538 && c <= 42539)))
                : (c <= 42606 || (c < 42775
                  ? (c < 42656
                    ? (c >= 42623 && c <= 42653)
                    : c <= 42735)
                  : (c <= 42783 || (c >= 42786 && c <= 42888)))))))
            : (c <= 42954 || (c < 43250
              ? (c < 43011
                ? (c < 42965
                  ? (c < 42963
                    ? (c >= 42960 && c <= 42961)
                    : c <= 42963)
                  : (c <= 42969 || (c >= 42994 && c <= 43009)))
                : (c <= 43013 || (c < 43072
                  ? (c < 43020
                    ? (c >= 43015 && c <= 43018)
                    : c <= 43042)
                  : (c <= 43123 || (c >= 43138 && c <= 43187)))))
              : (c <= 43255 || (c < 43360
                ? (c < 43274
                  ? (c < 43261
                    ? c == 43259
                    : c <= 43262)
                  : (c <= 43301 || (c >= 43312 && c <= 43334)))
                : (c <= 43388 || (c < 43488
                  ? (c < 43471
                    ? (c >= 43396 && c <= 43442)
                    : c <= 43471)
                  : (c <= 43492 || (c >= 43494 && c <= 43503)))))))))))))))
    : (c <= 43518 || (c < 70727
      ? (c < 66956
        ? (c < 64914
          ? (c < 43868
            ? (c < 43714
              ? (c < 43646
                ? (c < 43588
                  ? (c < 43584
                    ? (c >= 43520 && c <= 43560)
                    : c <= 43586)
                  : (c <= 43595 || (c < 43642
                    ? (c >= 43616 && c <= 43638)
                    : c <= 43642)))
                : (c <= 43695 || (c < 43705
                  ? (c < 43701
                    ? c == 43697
                    : c <= 43702)
                  : (c <= 43709 || c == 43712))))
              : (c <= 43714 || (c < 43785
                ? (c < 43762
                  ? (c < 43744
                    ? (c >= 43739 && c <= 43741)
                    : c <= 43754)
                  : (c <= 43764 || (c >= 43777 && c <= 43782)))
                : (c <= 43790 || (c < 43816
                  ? (c < 43808
                    ? (c >= 43793 && c <= 43798)
                    : c <= 43814)
                  : (c <= 43822 || (c >= 43824 && c <= 43866)))))))
            : (c <= 43881 || (c < 64287
              ? (c < 63744
                ? (c < 55216
                  ? (c < 44032
                    ? (c >= 43888 && c <= 44002)
                    : c <= 55203)
                  : (c <= 55238 || (c >= 55243 && c <= 55291)))
                : (c <= 64109 || (c < 64275
                  ? (c < 64256
                    ? (c >= 64112 && c <= 64217)
                    : c <= 64262)
                  : (c <= 64279 || c == 64285))))
              : (c <= 64296 || (c < 64323
                ? (c < 64318
                  ? (c < 64312
                    ? (c >= 64298 && c <= 64310)
                    : c <= 64316)
                  : (c <= 64318 || (c >= 64320 && c <= 64321)))
                : (c <= 64324 || (c < 64612
                  ? (c < 64467
                    ? (c >= 64326 && c <= 64433)
                    : c <= 64605)
                  : (c <= 64829 || (c >= 64848 && c <= 64911)))))))))
          : (c <= 64967 || (c < 65599
            ? (c < 65382
              ? (c < 65147
                ? (c < 65139
                  ? (c < 65137
                    ? (c >= 65008 && c <= 65017)
                    : c <= 65137)
                  : (c <= 65139 || (c < 65145
                    ? c == 65143
                    : c <= 65145)))
                : (c <= 65147 || (c < 65313
                  ? (c < 65151
                    ? c == 65149
                    : c <= 65276)
                  : (c <= 65338 || (c >= 65345 && c <= 65370)))))
              : (c <= 65437 || (c < 65498
                ? (c < 65482
                  ? (c < 65474
                    ? (c >= 65440 && c <= 65470)
                    : c <= 65479)
                  : (c <= 65487 || (c >= 65490 && c <= 65495)))
                : (c <= 65500 || (c < 65576
                  ? (c < 65549
                    ? (c >= 65536 && c <= 65547)
                    : c <= 65574)
                  : (c <= 65594 || (c >= 65596 && c <= 65597)))))))
            : (c <= 65613 || (c < 66464
              ? (c < 66208
                ? (c < 65856
                  ? (c < 65664
                    ? (c >= 65616 && c <= 65629)
                    : c <= 65786)
                  : (c <= 65908 || (c >= 66176 && c <= 66204)))
                : (c <= 66256 || (c < 66384
                  ? (c < 66349
                    ? (c >= 66304 && c <= 66335)
                    : c <= 66378)
                  : (c <= 66421 || (c >= 66432 && c <= 66461)))))
              : (c <= 66499 || (c < 66776
                ? (c < 66560
                  ? (c < 66513
                    ? (c >= 66504 && c <= 66511)
                    : c <= 66517)
                  : (c <= 66717 || (c >= 66736 && c <= 66771)))
                : (c <= 66811 || (c < 66928
                  ? (c < 66864
                    ? (c >= 66816 && c <= 66855)
                    : c <= 66915)
                  : (c <= 66938 || (c >= 66940 && c <= 66954)))))))))))
        : (c <= 66962 || (c < 68864
          ? (c < 67828
            ? (c < 67506
              ? (c < 67072
                ? (c < 66979
                  ? (c < 66967
                    ? (c >= 66964 && c <= 66965)
                    : c <= 66977)
                  : (c <= 66993 || (c < 67003
                    ? (c >= 66995 && c <= 67001)
                    : c <= 67004)))
                : (c <= 67382 || (c < 67456
                  ? (c < 67424
                    ? (c >= 67392 && c <= 67413)
                    : c <= 67431)
                  : (c <= 67461 || (c >= 67463 && c <= 67504)))))
              : (c <= 67514 || (c < 67644
                ? (c < 67594
                  ? (c < 67592
                    ? (c >= 67584 && c <= 67589)
                    : c <= 67592)
                  : (c <= 67637 || (c >= 67639 && c <= 67640)))
                : (c <= 67644 || (c < 67712
                  ? (c < 67680
                    ? (c >= 67647 && c <= 67669)
                    : c <= 67702)
                  : (c <= 67742 || (c >= 67808 && c <= 67826)))))))
            : (c <= 67829 || (c < 68224
              ? (c < 68096
                ? (c < 67968
                  ? (c < 67872
                    ? (c >= 67840 && c <= 67861)
                    : c <= 67897)
                  : (c <= 68023 || (c >= 68030 && c <= 68031)))
                : (c <= 68096 || (c < 68121
                  ? (c < 68117
                    ? (c >= 68112 && c <= 68115)
                    : c <= 68119)
                  : (c <= 68149 || (c >= 68192 && c <= 68220)))))
              : (c <= 68252 || (c < 68448
                ? (c < 68352
                  ? (c < 68297
                    ? (c >= 68288 && c <= 68295)
                    : c <= 68324)
                  : (c <= 68405 || (c >= 68416 && c <= 68437)))
                : (c <= 68466 || (c < 68736
                  ? (c < 68608
                    ? (c >= 68480 && c <= 68497)
                    : c <= 68680)
                  : (c <= 68786 || (c >= 68800 && c <= 68850)))))))))
          : (c <= 68899 || (c < 70106
            ? (c < 69749
              ? (c < 69488
                ? (c < 69376
                  ? (c < 69296
                    ? (c >= 69248 && c <= 69289)
                    : c <= 69297)
                  : (c <= 69404 || (c < 69424
                    ? c == 69415
                    : c <= 69445)))
                : (c <= 69505 || (c < 69635
                  ? (c < 69600
                    ? (c >= 69552 && c <= 69572)
                    : c <= 69622)
                  : (c <= 69687 || (c >= 69745 && c <= 69746)))))
              : (c <= 69749 || (c < 69959
                ? (c < 69891
                  ? (c < 69840
                    ? (c >= 69763 && c <= 69807)
                    : c <= 69864)
                  : (c <= 69926 || c == 69956))
                : (c <= 69959 || (c < 70019
                  ? (c < 70006
                    ? (c >= 69968 && c <= 70002)
                    : c <= 70006)
                  : (c <= 70066 || (c >= 70081 && c <= 70084)))))))
            : (c <= 70106 || (c < 70405
              ? (c < 70280
                ? (c < 70163
                  ? (c < 70144
                    ? c == 70108
                    : c <= 70161)
                  : (c <= 70187 || (c >= 70272 && c <= 70278)))
                : (c <= 70280 || (c < 70303
                  ? (c < 70287
                    ? (c >= 70282 && c <= 70285)
                    : c <= 70301)
                  : (c <= 70312 || (c >= 70320 && c <= 70366)))))
              : (c <= 70412 || (c < 70453
                ? (c < 70442
                  ? (c < 70419
                    ? (c >= 70415 && c <= 70416)
                    : c <= 70440)
                  : (c <= 70448 || (c >= 70450 && c <= 70451)))
                : (c <= 70457 || (c < 70493
                  ? (c < 70480
                    ? c == 70461
                    : c <= 70480)
                  : (c <= 70497 || (c >= 70656 && c <= 70708)))))))))))))
      : (c <= 70730 || (c < 119894
        ? (c < 73056
          ? (c < 72001
            ? (c < 71424
              ? (c < 71128
                ? (c < 70852
                  ? (c < 70784
                    ? (c >= 70751 && c <= 70753)
                    : c <= 70831)
                  : (c <= 70853 || (c < 71040
                    ? c == 70855
                    : c <= 71086)))
                : (c <= 71131 || (c < 71296
                  ? (c < 71236
                    ? (c >= 71168 && c <= 71215)
                    : c <= 71236)
                  : (c <= 71338 || c == 71352))))
              : (c <= 71450 || (c < 71945
                ? (c < 71840
                  ? (c < 71680
                    ? (c >= 71488 && c <= 71494)
                    : c <= 71723)
                  : (c <= 71903 || (c >= 71935 && c <= 71942)))
                : (c <= 71945 || (c < 71960
                  ? (c < 71957
                    ? (c >= 71948 && c <= 71955)
                    : c <= 71958)
                  : (c <= 71983 || c == 71999))))))
            : (c <= 72001 || (c < 72349
              ? (c < 72192
                ? (c < 72161
                  ? (c < 72106
                    ? (c >= 72096 && c <= 72103)
                    : c <= 72144)
                  : (c <= 72161 || c == 72163))
                : (c <= 72192 || (c < 72272
                  ? (c < 72250
                    ? (c >= 72203 && c <= 72242)
                    : c <= 72250)
                  : (c <= 72272 || (c >= 72284 && c <= 72329)))))
              : (c <= 72349 || (c < 72818
                ? (c < 72714
                  ? (c < 72704
                    ? (c >= 72368 && c <= 72440)
                    : c <= 72712)
                  : (c <= 72750 || c == 72768))
                : (c <= 72847 || (c < 72971
                  ? (c < 72968
                    ? (c >= 72960 && c <= 72966)
                    : c <= 72969)
                  : (c <= 73008 || c == 73030))))))))
          : (c <= 73061 || (c < 93952
            ? (c < 82944
              ? (c < 73728
                ? (c < 73112
                  ? (c < 73066
                    ? (c >= 73063 && c <= 73064)
                    : c <= 73097)
                  : (c <= 73112 || (c < 73648
                    ? (c >= 73440 && c <= 73458)
                    : c <= 73648)))
                : (c <= 74649 || (c < 77712
                  ? (c < 74880
                    ? (c >= 74752 && c <= 74862)
                    : c <= 75075)
                  : (c <= 77808 || (c >= 77824 && c <= 78894)))))
              : (c <= 83526 || (c < 92928
                ? (c < 92784
                  ? (c < 92736
                    ? (c >= 92160 && c <= 92728)
                    : c <= 92766)
                  : (c <= 92862 || (c >= 92880 && c <= 92909)))
                : (c <= 92975 || (c < 93053
                  ? (c < 93027
                    ? (c >= 92992 && c <= 92995)
                    : c <= 93047)
                  : (c <= 93071 || (c >= 93760 && c <= 93823)))))))
            : (c <= 94026 || (c < 110589
              ? (c < 94208
                ? (c < 94176
                  ? (c < 94099
                    ? c == 94032
                    : c <= 94111)
                  : (c <= 94177 || c == 94179))
                : (c <= 100343 || (c < 110576
                  ? (c < 101632
                    ? (c >= 100352 && c <= 101589)
                    : c <= 101640)
                  : (c <= 110579 || (c >= 110581 && c <= 110587)))))
              : (c <= 110590 || (c < 113664
                ? (c < 110948
                  ? (c < 110928
                    ? (c >= 110592 && c <= 110882)
                    : c <= 110930)
                  : (c <= 110951 || (c >= 110960 && c <= 111355)))
                : (c <= 113770 || (c < 113808
                  ? (c < 113792
                    ? (c >= 113776 && c <= 113788)
                    : c <= 113800)
                  : (c <= 113817 || (c >= 119808 && c <= 119892)))))))))))
        : (c <= 119964 || (c < 125259
          ? (c < 120572
            ? (c < 120086
              ? (c < 119995
                ? (c < 119973
                  ? (c < 119970
                    ? (c >= 119966 && c <= 119967)
                    : c <= 119970)
                  : (c <= 119974 || (c < 119982
                    ? (c >= 119977 && c <= 119980)
                    : c <= 119993)))
                : (c <= 119995 || (c < 120071
                  ? (c < 120005
                    ? (c >= 119997 && c <= 120003)
                    : c <= 120069)
                  : (c <= 120074 || (c >= 120077 && c <= 120084)))))
              : (c <= 120092 || (c < 120138
                ? (c < 120128
                  ? (c < 120123
                    ? (c >= 120094 && c <= 120121)
                    : c <= 120126)
                  : (c <= 120132 || c == 120134))
                : (c <= 120144 || (c < 120514
                  ? (c < 120488
                    ? (c >= 120146 && c <= 120485)
                    : c <= 120512)
                  : (c <= 120538 || (c >= 120540 && c <= 120570)))))))
            : (c <= 120596 || (c < 123191
              ? (c < 120714
                ? (c < 120656
                  ? (c < 120630
                    ? (c >= 120598 && c <= 120628)
                    : c <= 120654)
                  : (c <= 120686 || (c >= 120688 && c <= 120712)))
                : (c <= 120744 || (c < 122624
                  ? (c < 120772
                    ? (c >= 120746 && c <= 120770)
                    : c <= 120779)
                  : (c <= 122654 || (c >= 123136 && c <= 123180)))))
              : (c <= 123197 || (c < 124904
                ? (c < 123584
                  ? (c < 123536
                    ? c == 123214
                    : c <= 123565)
                  : (c <= 123627 || (c >= 124896 && c <= 124902)))
                : (c <= 124907 || (c < 124928
                  ? (c < 124912
                    ? (c >= 124909 && c <= 124910)
                    : c <= 124926)
                  : (c <= 125124 || (c >= 125184 && c <= 125251)))))))))
          : (c <= 125259 || (c < 126559
            ? (c < 126535
              ? (c < 126505
                ? (c < 126497
                  ? (c < 126469
                    ? (c >= 126464 && c <= 126467)
                    : c <= 126495)
                  : (c <= 126498 || (c < 126503
                    ? c == 126500
                    : c <= 126503)))
                : (c <= 126514 || (c < 126523
                  ? (c < 126521
                    ? (c >= 126516 && c <= 126519)
                    : c <= 126521)
                  : (c <= 126523 || c == 126530))))
              : (c <= 126535 || (c < 126548
                ? (c < 126541
                  ? (c < 126539
                    ? c == 126537
                    : c <= 126539)
                  : (c <= 126543 || (c >= 126545 && c <= 126546)))
                : (c <= 126548 || (c < 126555
                  ? (c < 126553
                    ? c == 126551
                    : c <= 126553)
                  : (c <= 126555 || c == 126557))))))
            : (c <= 126559 || (c < 126625
              ? (c < 126580
                ? (c < 126567
                  ? (c < 126564
                    ? (c >= 126561 && c <= 126562)
                    : c <= 126564)
                  : (c <= 126570 || (c >= 126572 && c <= 126578)))
                : (c <= 126583 || (c < 126592
                  ? (c < 126590
                    ? (c >= 126585 && c <= 126588)
                    : c <= 126590)
                  : (c <= 126601 || (c >= 126603 && c <= 126619)))))
              : (c <= 126627 || (c < 177984
                ? (c < 131072
                  ? (c < 126635
                    ? (c >= 126629 && c <= 126633)
                    : c <= 126651)
                  : (c <= 173791 || (c >= 173824 && c <= 177976)))
                : (c <= 178205 || (c < 194560
                  ? (c < 183984
                    ? (c >= 178208 && c <= 183969)
                    : c <= 191456)
                  : (c <= 195101 || (c >= 196608 && c <= 201546)))))))))))))))));
}

static inline bool sym_identifier_character_set_2(int32_t c) {
  return (c < 43514
    ? (c < 4193
      ? (c < 2707
        ? (c < 1994
          ? (c < 910
            ? (c < 736
              ? (c < 186
                ? (c < 'a'
                  ? (c < '_'
                    ? (c >= 'A' && c <= 'Z')
                    : c <= '_')
                  : (c <= 'z' || (c < 181
                    ? c == 170
                    : c <= 181)))
                : (c <= 186 || (c < 248
                  ? (c < 216
                    ? (c >= 192 && c <= 214)
                    : c <= 246)
                  : (c <= 705 || (c >= 710 && c <= 721)))))
              : (c <= 740 || (c < 891
                ? (c < 880
                  ? (c < 750
                    ? c == 748
                    : c <= 750)
                  : (c <= 884 || (c >= 886 && c <= 887)))
                : (c <= 893 || (c < 904
                  ? (c < 902
                    ? c == 895
                    : c <= 902)
                  : (c <= 906 || c == 908))))))
            : (c <= 929 || (c < 1649
              ? (c < 1376
                ? (c < 1162
                  ? (c < 1015
                    ? (c >= 931 && c <= 1013)
                    : c <= 1153)
                  : (c <= 1327 || (c < 1369
                    ? (c >= 1329 && c <= 1366)
                    : c <= 1369)))
                : (c <= 1416 || (c < 1568
                  ? (c < 1519
                    ? (c >= 1488 && c <= 1514)
                    : c <= 1522)
                  : (c <= 1610 || (c >= 1646 && c <= 1647)))))
              : (c <= 1747 || (c < 1791
                ? (c < 1774
                  ? (c < 1765
                    ? c == 1749
                    : c <= 1766)
                  : (c <= 1775 || (c >= 1786 && c <= 1788)))
                : (c <= 1791 || (c < 1869
                  ? (c < 1810
                    ? c == 1808
                    : c <= 1839)
                  : (c <= 1957 || c == 1969))))))))
          : (c <= 2026 || (c < 2482
            ? (c < 2208
              ? (c < 2088
                ? (c < 2048
                  ? (c < 2042
                    ? (c >= 2036 && c <= 2037)
                    : c <= 2042)
                  : (c <= 2069 || (c < 2084
                    ? c == 2074
                    : c <= 2084)))
                : (c <= 2088 || (c < 2160
                  ? (c < 2144
                    ? (c >= 2112 && c <= 2136)
                    : c <= 2154)
                  : (c <= 2183 || (c >= 2185 && c <= 2190)))))
              : (c <= 2249 || (c < 2417
                ? (c < 2384
                  ? (c < 2365
                    ? (c >= 2308 && c <= 2361)
                    : c <= 2365)
                  : (c <= 2384 || (c >= 2392 && c <= 2401)))
                : (c <= 2432 || (c < 2451
                  ? (c < 2447
                    ? (c >= 2437 && c <= 2444)
                    : c <= 2448)
                  : (c <= 2472 || (c >= 2474 && c <= 2480)))))))
            : (c <= 2482 || (c < 2579
              ? (c < 2527
                ? (c < 2510
                  ? (c < 2493
                    ? (c >= 2486 && c <= 2489)
                    : c <= 2493)
                  : (c <= 2510 || (c >= 2524 && c <= 2525)))
                : (c <= 2529 || (c < 2565
                  ? (c < 2556
                    ? (c >= 2544 && c <= 2545)
                    : c <= 2556)
                  : (c <= 2570 || (c >= 2575 && c <= 2576)))))
              : (c <= 2600 || (c < 2649
                ? (c < 2613
                  ? (c < 2610
                    ? (c >= 2602 && c <= 2608)
                    : c <= 2611)
                  : (c <= 2614 || (c >= 2616 && c <= 2617)))
                : (c <= 2652 || (c < 2693
                  ? (c < 2674
                    ? c == 2654
                    : c <= 2676)
                  : (c <= 2701 || (c >= 2703 && c <= 2705)))))))))))
        : (c <= 2728 || (c < 3242
          ? (c < 2962
            ? (c < 2858
              ? (c < 2784
                ? (c < 2741
                  ? (c < 2738
                    ? (c >= 2730 && c <= 2736)
                    : c <= 2739)
                  : (c <= 2745 || (c < 2768
                    ? c == 2749
                    : c <= 2768)))
                : (c <= 2785 || (c < 2831
                  ? (c < 2821
                    ? c == 2809
                    : c <= 2828)
                  : (c <= 2832 || (c >= 2835 && c <= 2856)))))
              : (c <= 2864 || (c < 2911
                ? (c < 2877
                  ? (c < 2869
                    ? (c >= 2866 && c <= 2867)
                    : c <= 2873)
                  : (c <= 2877 || (c >= 2908 && c <= 2909)))
                : (c <= 2913 || (c < 2949
                  ? (c < 2947
                    ? c == 2929
                    : c <= 2947)
                  : (c <= 2954 || (c >= 2958 && c <= 2960)))))))
            : (c <= 2965 || (c < 3090
              ? (c < 2984
                ? (c < 2974
                  ? (c < 2972
                    ? (c >= 2969 && c <= 2970)
                    : c <= 2972)
                  : (c <= 2975 || (c >= 2979 && c <= 2980)))
                : (c <= 2986 || (c < 3077
                  ? (c < 3024
                    ? (c >= 2990 && c <= 3001)
                    : c <= 3024)
                  : (c <= 3084 || (c >= 3086 && c <= 3088)))))
              : (c <= 3112 || (c < 3168
                ? (c < 3160
                  ? (c < 3133
                    ? (c >= 3114 && c <= 3129)
                    : c <= 3133)
                  : (c <= 3162 || c == 3165))
                : (c <= 3169 || (c < 3214
                  ? (c < 3205
                    ? c == 3200
                    : c <= 3212)
                  : (c <= 3216 || (c >= 3218 && c <= 3240)))))))))
          : (c <= 3251 || (c < 3648
            ? (c < 3412
              ? (c < 3332
                ? (c < 3293
                  ? (c < 3261
                    ? (c >= 3253 && c <= 3257)
                    : c <= 3261)
                  : (c <= 3294 || (c < 3313
                    ? (c >= 3296 && c <= 3297)
                    : c <= 3314)))
                : (c <= 3340 || (c < 3389
                  ? (c < 3346
                    ? (c >= 3342 && c <= 3344)
                    : c <= 3386)
                  : (c <= 3389 || c == 3406))))
              : (c <= 3414 || (c < 3507
                ? (c < 3461
                  ? (c < 3450
                    ? (c >= 3423 && c <= 3425)
                    : c <= 3455)
                  : (c <= 3478 || (c >= 3482 && c <= 3505)))
                : (c <= 3515 || (c < 3585
                  ? (c < 3520
                    ? c == 3517
                    : c <= 3526)
                  : (c <= 3632 || c == 3634))))))
            : (c <= 3654 || (c < 3782
              ? (c < 3749
                ? (c < 3718
                  ? (c < 3716
                    ? (c >= 3713 && c <= 3714)
                    : c <= 3716)
                  : (c <= 3722 || (c >= 3724 && c <= 3747)))
                : (c <= 3749 || (c < 3773
                  ? (c < 3762
                    ? (c >= 3751 && c <= 3760)
                    : c <= 3762)
                  : (c <= 3773 || (c >= 3776 && c <= 3780)))))
              : (c <= 3782 || (c < 3976
                ? (c < 3904
                  ? (c < 3840
                    ? (c >= 3804 && c <= 3807)
                    : c <= 3840)
                  : (c <= 3911 || (c >= 3913 && c <= 3948)))
                : (c <= 3980 || (c < 4176
                  ? (c < 4159
                    ? (c >= 4096 && c <= 4138)
                    : c <= 4159)
                  : (c <= 4181 || (c >= 4186 && c <= 4189)))))))))))))
      : (c <= 4193 || (c < 8134
        ? (c < 6176
          ? (c < 4808
            ? (c < 4688
              ? (c < 4295
                ? (c < 4213
                  ? (c < 4206
                    ? (c >= 4197 && c <= 4198)
                    : c <= 4208)
                  : (c <= 4225 || (c < 4256
                    ? c == 4238
                    : c <= 4293)))
                : (c <= 4295 || (c < 4348
                  ? (c < 4304
                    ? c == 4301
                    : c <= 4346)
                  : (c <= 4680 || (c >= 4682 && c <= 4685)))))
              : (c <= 4694 || (c < 4752
                ? (c < 4704
                  ? (c < 4698
                    ? c == 4696
                    : c <= 4701)
                  : (c <= 4744 || (c >= 4746 && c <= 4749)))
                : (c <= 4784 || (c < 4800
                  ? (c < 4792
                    ? (c >= 4786 && c <= 4789)
                    : c <= 4798)
                  : (c <= 4800 || (c >= 4802 && c <= 4805)))))))
            : (c <= 4822 || (c < 5792
              ? (c < 5024
                ? (c < 4888
                  ? (c < 4882
                    ? (c >= 4824 && c <= 4880)
                    : c <= 4885)
                  : (c <= 4954 || (c >= 4992 && c <= 5007)))
                : (c <= 5109 || (c < 5743
                  ? (c < 5121
                    ? (c >= 5112 && c <= 5117)
                    : c <= 5740)
                  : (c <= 5759 || (c >= 5761 && c <= 5786)))))
              : (c <= 5866 || (c < 5984
                ? (c < 5919
                  ? (c < 5888
                    ? (c >= 5870 && c <= 5880)
                    : c <= 5905)
                  : (c <= 5937 || (c >= 5952 && c <= 5969)))
                : (c <= 5996 || (c < 6103
                  ? (c < 6016
                    ? (c >= 5998 && c <= 6000)
                    : c <= 6067)
                  : (c <= 6103 || c == 6108))))))))
          : (c <= 6264 || (c < 7312
            ? (c < 6823
              ? (c < 6512
                ? (c < 6320
                  ? (c < 6314
                    ? (c >= 6272 && c <= 6312)
                    : c <= 6314)
                  : (c <= 6389 || (c < 6480
                    ? (c >= 6400 && c <= 6430)
                    : c <= 6509)))
                : (c <= 6516 || (c < 6656
                  ? (c < 6576
                    ? (c >= 6528 && c <= 6571)
                    : c <= 6601)
                  : (c <= 6678 || (c >= 6688 && c <= 6740)))))
              : (c <= 6823 || (c < 7098
                ? (c < 7043
                  ? (c < 6981
                    ? (c >= 6917 && c <= 6963)
                    : c <= 6988)
                  : (c <= 7072 || (c >= 7086 && c <= 7087)))
                : (c <= 7141 || (c < 7258
                  ? (c < 7245
                    ? (c >= 7168 && c <= 7203)
                    : c <= 7247)
                  : (c <= 7293 || (c >= 7296 && c <= 7304)))))))
            : (c <= 7354 || (c < 8008
              ? (c < 7418
                ? (c < 7406
                  ? (c < 7401
                    ? (c >= 7357 && c <= 7359)
                    : c <= 7404)
                  : (c <= 7411 || (c >= 7413 && c <= 7414)))
                : (c <= 7418 || (c < 7960
                  ? (c < 7680
                    ? (c >= 7424 && c <= 7615)
                    : c <= 7957)
                  : (c <= 7965 || (c >= 7968 && c <= 8005)))))
              : (c <= 8013 || (c < 8031
                ? (c < 8027
                  ? (c < 8025
                    ? (c >= 8016 && c <= 8023)
                    : c <= 8025)
                  : (c <= 8027 || c == 8029))
                : (c <= 8061 || (c < 8126
                  ? (c < 8118
                    ? (c >= 8064 && c <= 8116)
                    : c <= 8124)
                  : (c <= 8126 || (c >= 8130 && c <= 8132)))))))))))
        : (c <= 8140 || (c < 12337
          ? (c < 8544
            ? (c < 8458
              ? (c < 8305
                ? (c < 8160
                  ? (c < 8150
                    ? (c >= 8144 && c <= 8147)
                    : c <= 8155)
                  : (c <= 8172 || (c < 8182
                    ? (c >= 8178 && c <= 8180)
                    : c <= 8188)))
                : (c <= 8305 || (c < 8450
                  ? (c < 8336
                    ? c == 8319
                    : c <= 8348)
                  : (c <= 8450 || c == 8455))))
              : (c <= 8467 || (c < 8488
                ? (c < 8484
                  ? (c < 8472
                    ? c == 8469
                    : c <= 8477)
                  : (c <= 8484 || c == 8486))
                : (c <= 8488 || (c < 8517
                  ? (c < 8508
                    ? (c >= 8490 && c <= 8505)
                    : c <= 8511)
                  : (c <= 8521 || c == 8526))))))
            : (c <= 8584 || (c < 11680
              ? (c < 11559
                ? (c < 11506
                  ? (c < 11499
                    ? (c >= 11264 && c <= 11492)
                    : c <= 11502)
                  : (c <= 11507 || (c >= 11520 && c <= 11557)))
                : (c <= 11559 || (c < 11631
                  ? (c < 11568
                    ? c == 11565
                    : c <= 11623)
                  : (c <= 11631 || (c >= 11648 && c <= 11670)))))
              : (c <= 11686 || (c < 11720
                ? (c < 11704
                  ? (c < 11696
                    ? (c >= 11688 && c <= 11694)
                    : c <= 11702)
                  : (c <= 11710 || (c >= 11712 && c <= 11718)))
                : (c <= 11726 || (c < 12293
                  ? (c < 11736
                    ? (c >= 11728 && c <= 11734)
                    : c <= 11742)
                  : (c <= 12295 || (c >= 12321 && c <= 12329)))))))))
          : (c <= 12341 || (c < 42891
            ? (c < 19968
              ? (c < 12549
                ? (c < 12445
                  ? (c < 12353
                    ? (c >= 12344 && c <= 12348)
                    : c <= 12438)
                  : (c <= 12447 || (c < 12540
                    ? (c >= 12449 && c <= 12538)
                    : c <= 12543)))
                : (c <= 12591 || (c < 12784
                  ? (c < 12704
                    ? (c >= 12593 && c <= 12686)
                    : c <= 12735)
                  : (c <= 12799 || (c >= 13312 && c <= 19903)))))
              : (c <= 42124 || (c < 42560
                ? (c < 42512
                  ? (c < 42240
                    ? (c >= 42192 && c <= 42237)
                    : c <= 42508)
                  : (c <= 42527 || (c >= 42538 && c <= 42539)))
                : (c <= 42606 || (c < 42775
                  ? (c < 42656
                    ? (c >= 42623 && c <= 42653)
                    : c <= 42735)
                  : (c <= 42783 || (c >= 42786 && c <= 42888)))))))
            : (c <= 42954 || (c < 43250
              ? (c < 43011
                ? (c < 42965
                  ? (c < 42963
                    ? (c >= 42960 && c <= 42961)
                    : c <= 42963)
                  : (c <= 42969 || (c >= 42994 && c <= 43009)))
                : (c <= 43013 || (c < 43072
                  ? (c < 43020
                    ? (c >= 43015 && c <= 43018)
                    : c <= 43042)
                  : (c <= 43123 || (c >= 43138 && c <= 43187)))))
              : (c <= 43255 || (c < 43360
                ? (c < 43274
                  ? (c < 43261
                    ? c == 43259
                    : c <= 43262)
                  : (c <= 43301 || (c >= 43312 && c <= 43334)))
                : (c <= 43388 || (c < 43488
                  ? (c < 43471
                    ? (c >= 43396 && c <= 43442)
                    : c <= 43471)
                  : (c <= 43492 || (c >= 43494 && c <= 43503)))))))))))))))
    : (c <= 43518 || (c < 70727
      ? (c < 66956
        ? (c < 64914
          ? (c < 43868
            ? (c < 43714
              ? (c < 43646
                ? (c < 43588
                  ? (c < 43584
                    ? (c >= 43520 && c <= 43560)
                    : c <= 43586)
                  : (c <= 43595 || (c < 43642
                    ? (c >= 43616 && c <= 43638)
                    : c <= 43642)))
                : (c <= 43695 || (c < 43705
                  ? (c < 43701
                    ? c == 43697
                    : c <= 43702)
                  : (c <= 43709 || c == 43712))))
              : (c <= 43714 || (c < 43785
                ? (c < 43762
                  ? (c < 43744
                    ? (c >= 43739 && c <= 43741)
                    : c <= 43754)
                  : (c <= 43764 || (c >= 43777 && c <= 43782)))
                : (c <= 43790 || (c < 43816
                  ? (c < 43808
                    ? (c >= 43793 && c <= 43798)
                    : c <= 43814)
                  : (c <= 43822 || (c >= 43824 && c <= 43866)))))))
            : (c <= 43881 || (c < 64287
              ? (c < 63744
                ? (c < 55216
                  ? (c < 44032
                    ? (c >= 43888 && c <= 44002)
                    : c <= 55203)
                  : (c <= 55238 || (c >= 55243 && c <= 55291)))
                : (c <= 64109 || (c < 64275
                  ? (c < 64256
                    ? (c >= 64112 && c <= 64217)
                    : c <= 64262)
                  : (c <= 64279 || c == 64285))))
              : (c <= 64296 || (c < 64323
                ? (c < 64318
                  ? (c < 64312
                    ? (c >= 64298 && c <= 64310)
                    : c <= 64316)
                  : (c <= 64318 || (c >= 64320 && c <= 64321)))
                : (c <= 64324 || (c < 64612
                  ? (c < 64467
                    ? (c >= 64326 && c <= 64433)
                    : c <= 64605)
                  : (c <= 64829 || (c >= 64848 && c <= 64911)))))))))
          : (c <= 64967 || (c < 65599
            ? (c < 65382
              ? (c < 65147
                ? (c < 65139
                  ? (c < 65137
                    ? (c >= 65008 && c <= 65017)
                    : c <= 65137)
                  : (c <= 65139 || (c < 65145
                    ? c == 65143
                    : c <= 65145)))
                : (c <= 65147 || (c < 65313
                  ? (c < 65151
                    ? c == 65149
                    : c <= 65276)
                  : (c <= 65338 || (c >= 65345 && c <= 65370)))))
              : (c <= 65437 || (c < 65498
                ? (c < 65482
                  ? (c < 65474
                    ? (c >= 65440 && c <= 65470)
                    : c <= 65479)
                  : (c <= 65487 || (c >= 65490 && c <= 65495)))
                : (c <= 65500 || (c < 65576
                  ? (c < 65549
                    ? (c >= 65536 && c <= 65547)
                    : c <= 65574)
                  : (c <= 65594 || (c >= 65596 && c <= 65597)))))))
            : (c <= 65613 || (c < 66464
              ? (c < 66208
                ? (c < 65856
                  ? (c < 65664
                    ? (c >= 65616 && c <= 65629)
                    : c <= 65786)
                  : (c <= 65908 || (c >= 66176 && c <= 66204)))
                : (c <= 66256 || (c < 66384
                  ? (c < 66349
                    ? (c >= 66304 && c <= 66335)
                    : c <= 66378)
                  : (c <= 66421 || (c >= 66432 && c <= 66461)))))
              : (c <= 66499 || (c < 66776
                ? (c < 66560
                  ? (c < 66513
                    ? (c >= 66504 && c <= 66511)
                    : c <= 66517)
                  : (c <= 66717 || (c >= 66736 && c <= 66771)))
                : (c <= 66811 || (c < 66928
                  ? (c < 66864
                    ? (c >= 66816 && c <= 66855)
                    : c <= 66915)
                  : (c <= 66938 || (c >= 66940 && c <= 66954)))))))))))
        : (c <= 66962 || (c < 68864
          ? (c < 67828
            ? (c < 67506
              ? (c < 67072
                ? (c < 66979
                  ? (c < 66967
                    ? (c >= 66964 && c <= 66965)
                    : c <= 66977)
                  : (c <= 66993 || (c < 67003
                    ? (c >= 66995 && c <= 67001)
                    : c <= 67004)))
                : (c <= 67382 || (c < 67456
                  ? (c < 67424
                    ? (c >= 67392 && c <= 67413)
                    : c <= 67431)
                  : (c <= 67461 || (c >= 67463 && c <= 67504)))))
              : (c <= 67514 || (c < 67644
                ? (c < 67594
                  ? (c < 67592
                    ? (c >= 67584 && c <= 67589)
                    : c <= 67592)
                  : (c <= 67637 || (c >= 67639 && c <= 67640)))
                : (c <= 67644 || (c < 67712
                  ? (c < 67680
                    ? (c >= 67647 && c <= 67669)
                    : c <= 67702)
                  : (c <= 67742 || (c >= 67808 && c <= 67826)))))))
            : (c <= 67829 || (c < 68224
              ? (c < 68096
                ? (c < 67968
                  ? (c < 67872
                    ? (c >= 67840 && c <= 67861)
                    : c <= 67897)
                  : (c <= 68023 || (c >= 68030 && c <= 68031)))
                : (c <= 68096 || (c < 68121
                  ? (c < 68117
                    ? (c >= 68112 && c <= 68115)
                    : c <= 68119)
                  : (c <= 68149 || (c >= 68192 && c <= 68220)))))
              : (c <= 68252 || (c < 68448
                ? (c < 68352
                  ? (c < 68297
                    ? (c >= 68288 && c <= 68295)
                    : c <= 68324)
                  : (c <= 68405 || (c >= 68416 && c <= 68437)))
                : (c <= 68466 || (c < 68736
                  ? (c < 68608
                    ? (c >= 68480 && c <= 68497)
                    : c <= 68680)
                  : (c <= 68786 || (c >= 68800 && c <= 68850)))))))))
          : (c <= 68899 || (c < 70106
            ? (c < 69749
              ? (c < 69488
                ? (c < 69376
                  ? (c < 69296
                    ? (c >= 69248 && c <= 69289)
                    : c <= 69297)
                  : (c <= 69404 || (c < 69424
                    ? c == 69415
                    : c <= 69445)))
                : (c <= 69505 || (c < 69635
                  ? (c < 69600
                    ? (c >= 69552 && c <= 69572)
                    : c <= 69622)
                  : (c <= 69687 || (c >= 69745 && c <= 69746)))))
              : (c <= 69749 || (c < 69959
                ? (c < 69891
                  ? (c < 69840
                    ? (c >= 69763 && c <= 69807)
                    : c <= 69864)
                  : (c <= 69926 || c == 69956))
                : (c <= 69959 || (c < 70019
                  ? (c < 70006
                    ? (c >= 69968 && c <= 70002)
                    : c <= 70006)
                  : (c <= 70066 || (c >= 70081 && c <= 70084)))))))
            : (c <= 70106 || (c < 70405
              ? (c < 70280
                ? (c < 70163
                  ? (c < 70144
                    ? c == 70108
                    : c <= 70161)
                  : (c <= 70187 || (c >= 70272 && c <= 70278)))
                : (c <= 70280 || (c < 70303
                  ? (c < 70287
                    ? (c >= 70282 && c <= 70285)
                    : c <= 70301)
                  : (c <= 70312 || (c >= 70320 && c <= 70366)))))
              : (c <= 70412 || (c < 70453
                ? (c < 70442
                  ? (c < 70419
                    ? (c >= 70415 && c <= 70416)
                    : c <= 70440)
                  : (c <= 70448 || (c >= 70450 && c <= 70451)))
                : (c <= 70457 || (c < 70493
                  ? (c < 70480
                    ? c == 70461
                    : c <= 70480)
                  : (c <= 70497 || (c >= 70656 && c <= 70708)))))))))))))
      : (c <= 70730 || (c < 119894
        ? (c < 73056
          ? (c < 72001
            ? (c < 71424
              ? (c < 71128
                ? (c < 70852
                  ? (c < 70784
                    ? (c >= 70751 && c <= 70753)
                    : c <= 70831)
                  : (c <= 70853 || (c < 71040
                    ? c == 70855
                    : c <= 71086)))
                : (c <= 71131 || (c < 71296
                  ? (c < 71236
                    ? (c >= 71168 && c <= 71215)
                    : c <= 71236)
                  : (c <= 71338 || c == 71352))))
              : (c <= 71450 || (c < 71945
                ? (c < 71840
                  ? (c < 71680
                    ? (c >= 71488 && c <= 71494)
                    : c <= 71723)
                  : (c <= 71903 || (c >= 71935 && c <= 71942)))
                : (c <= 71945 || (c < 71960
                  ? (c < 71957
                    ? (c >= 71948 && c <= 71955)
                    : c <= 71958)
                  : (c <= 71983 || c == 71999))))))
            : (c <= 72001 || (c < 72349
              ? (c < 72192
                ? (c < 72161
                  ? (c < 72106
                    ? (c >= 72096 && c <= 72103)
                    : c <= 72144)
                  : (c <= 72161 || c == 72163))
                : (c <= 72192 || (c < 72272
                  ? (c < 72250
                    ? (c >= 72203 && c <= 72242)
                    : c <= 72250)
                  : (c <= 72272 || (c >= 72284 && c <= 72329)))))
              : (c <= 72349 || (c < 72818
                ? (c < 72714
                  ? (c < 72704
                    ? (c >= 72368 && c <= 72440)
                    : c <= 72712)
                  : (c <= 72750 || c == 72768))
                : (c <= 72847 || (c < 72971
                  ? (c < 72968
                    ? (c >= 72960 && c <= 72966)
                    : c <= 72969)
                  : (c <= 73008 || c == 73030))))))))
          : (c <= 73061 || (c < 93952
            ? (c < 82944
              ? (c < 73728
                ? (c < 73112
                  ? (c < 73066
                    ? (c >= 73063 && c <= 73064)
                    : c <= 73097)
                  : (c <= 73112 || (c < 73648
                    ? (c >= 73440 && c <= 73458)
                    : c <= 73648)))
                : (c <= 74649 || (c < 77712
                  ? (c < 74880
                    ? (c >= 74752 && c <= 74862)
                    : c <= 75075)
                  : (c <= 77808 || (c >= 77824 && c <= 78894)))))
              : (c <= 83526 || (c < 92928
                ? (c < 92784
                  ? (c < 92736
                    ? (c >= 92160 && c <= 92728)
                    : c <= 92766)
                  : (c <= 92862 || (c >= 92880 && c <= 92909)))
                : (c <= 92975 || (c < 93053
                  ? (c < 93027
                    ? (c >= 92992 && c <= 92995)
                    : c <= 93047)
                  : (c <= 93071 || (c >= 93760 && c <= 93823)))))))
            : (c <= 94026 || (c < 110589
              ? (c < 94208
                ? (c < 94176
                  ? (c < 94099
                    ? c == 94032
                    : c <= 94111)
                  : (c <= 94177 || c == 94179))
                : (c <= 100343 || (c < 110576
                  ? (c < 101632
                    ? (c >= 100352 && c <= 101589)
                    : c <= 101640)
                  : (c <= 110579 || (c >= 110581 && c <= 110587)))))
              : (c <= 110590 || (c < 113664
                ? (c < 110948
                  ? (c < 110928
                    ? (c >= 110592 && c <= 110882)
                    : c <= 110930)
                  : (c <= 110951 || (c >= 110960 && c <= 111355)))
                : (c <= 113770 || (c < 113808
                  ? (c < 113792
                    ? (c >= 113776 && c <= 113788)
                    : c <= 113800)
                  : (c <= 113817 || (c >= 119808 && c <= 119892)))))))))))
        : (c <= 119964 || (c < 125259
          ? (c < 120572
            ? (c < 120086
              ? (c < 119995
                ? (c < 119973
                  ? (c < 119970
                    ? (c >= 119966 && c <= 119967)
                    : c <= 119970)
                  : (c <= 119974 || (c < 119982
                    ? (c >= 119977 && c <= 119980)
                    : c <= 119993)))
                : (c <= 119995 || (c < 120071
                  ? (c < 120005
                    ? (c >= 119997 && c <= 120003)
                    : c <= 120069)
                  : (c <= 120074 || (c >= 120077 && c <= 120084)))))
              : (c <= 120092 || (c < 120138
                ? (c < 120128
                  ? (c < 120123
                    ? (c >= 120094 && c <= 120121)
                    : c <= 120126)
                  : (c <= 120132 || c == 120134))
                : (c <= 120144 || (c < 120514
                  ? (c < 120488
                    ? (c >= 120146 && c <= 120485)
                    : c <= 120512)
                  : (c <= 120538 || (c >= 120540 && c <= 120570)))))))
            : (c <= 120596 || (c < 123191
              ? (c < 120714
                ? (c < 120656
                  ? (c < 120630
                    ? (c >= 120598 && c <= 120628)
                    : c <= 120654)
                  : (c <= 120686 || (c >= 120688 && c <= 120712)))
                : (c <= 120744 || (c < 122624
                  ? (c < 120772
                    ? (c >= 120746 && c <= 120770)
                    : c <= 120779)
                  : (c <= 122654 || (c >= 123136 && c <= 123180)))))
              : (c <= 123197 || (c < 124904
                ? (c < 123584
                  ? (c < 123536
                    ? c == 123214
                    : c <= 123565)
                  : (c <= 123627 || (c >= 124896 && c <= 124902)))
                : (c <= 124907 || (c < 124928
                  ? (c < 124912
                    ? (c >= 124909 && c <= 124910)
                    : c <= 124926)
                  : (c <= 125124 || (c >= 125184 && c <= 125251)))))))))
          : (c <= 125259 || (c < 126559
            ? (c < 126535
              ? (c < 126505
                ? (c < 126497
                  ? (c < 126469
                    ? (c >= 126464 && c <= 126467)
                    : c <= 126495)
                  : (c <= 126498 || (c < 126503
                    ? c == 126500
                    : c <= 126503)))
                : (c <= 126514 || (c < 126523
                  ? (c < 126521
                    ? (c >= 126516 && c <= 126519)
                    : c <= 126521)
                  : (c <= 126523 || c == 126530))))
              : (c <= 126535 || (c < 126548
                ? (c < 126541
                  ? (c < 126539
                    ? c == 126537
                    : c <= 126539)
                  : (c <= 126543 || (c >= 126545 && c <= 126546)))
                : (c <= 126548 || (c < 126555
                  ? (c < 126553
                    ? c == 126551
                    : c <= 126553)
                  : (c <= 126555 || c == 126557))))))
            : (c <= 126559 || (c < 126625
              ? (c < 126580
                ? (c < 126567
                  ? (c < 126564
                    ? (c >= 126561 && c <= 126562)
                    : c <= 126564)
                  : (c <= 126570 || (c >= 126572 && c <= 126578)))
                : (c <= 126583 || (c < 126592
                  ? (c < 126590
                    ? (c >= 126585 && c <= 126588)
                    : c <= 126590)
                  : (c <= 126601 || (c >= 126603 && c <= 126619)))))
              : (c <= 126627 || (c < 177984
                ? (c < 131072
                  ? (c < 126635
                    ? (c >= 126629 && c <= 126633)
                    : c <= 126651)
                  : (c <= 173791 || (c >= 173824 && c <= 177976)))
                : (c <= 178205 || (c < 194560
                  ? (c < 183984
                    ? (c >= 178208 && c <= 183969)
                    : c <= 191456)
                  : (c <= 195101 || (c >= 196608 && c <= 201546)))))))))))))))));
}

static inline bool sym_identifier_character_set_3(int32_t c) {
  return (c < 43616
    ? (c < 3782
      ? (c < 2748
        ? (c < 2045
          ? (c < 1015
            ? (c < 710
              ? (c < 181
                ? (c < '_'
                  ? (c < 'A'
                    ? (c >= '0' && c <= '9')
                    : c <= 'Z')
                  : (c <= '_' || (c < 170
                    ? (c >= 'a' && c <= 'z')
                    : c <= 170)))
                : (c <= 181 || (c < 192
                  ? (c < 186
                    ? c == 183
                    : c <= 186)
                  : (c <= 214 || (c < 248
                    ? (c >= 216 && c <= 246)
                    : c <= 705)))))
              : (c <= 721 || (c < 891
                ? (c < 750
                  ? (c < 748
                    ? (c >= 736 && c <= 740)
                    : c <= 748)
                  : (c <= 750 || (c < 886
                    ? (c >= 768 && c <= 884)
                    : c <= 887)))
                : (c <= 893 || (c < 908
                  ? (c < 902
                    ? c == 895
                    : c <= 906)
                  : (c <= 908 || (c < 931
                    ? (c >= 910 && c <= 929)
                    : c <= 1013)))))))
            : (c <= 1153 || (c < 1519
              ? (c < 1425
                ? (c < 1329
                  ? (c < 1162
                    ? (c >= 1155 && c <= 1159)
                    : c <= 1327)
                  : (c <= 1366 || (c < 1376
                    ? c == 1369
                    : c <= 1416)))
                : (c <= 1469 || (c < 1476
                  ? (c < 1473
                    ? c == 1471
                    : c <= 1474)
                  : (c <= 1477 || (c < 1488
                    ? c == 1479
                    : c <= 1514)))))
              : (c <= 1522 || (c < 1770
                ? (c < 1646
                  ? (c < 1568
                    ? (c >= 1552 && c <= 1562)
                    : c <= 1641)
                  : (c <= 1747 || (c < 1759
                    ? (c >= 1749 && c <= 1756)
                    : c <= 1768)))
                : (c <= 1788 || (c < 1869
                  ? (c < 1808
                    ? c == 1791
                    : c <= 1866)
                  : (c <= 1969 || (c < 2042
                    ? (c >= 1984 && c <= 2037)
                    : c <= 2042)))))))))
          : (c <= 2045 || (c < 2558
            ? (c < 2451
              ? (c < 2200
                ? (c < 2144
                  ? (c < 2112
                    ? (c >= 2048 && c <= 2093)
                    : c <= 2139)
                  : (c <= 2154 || (c < 2185
                    ? (c >= 2160 && c <= 2183)
                    : c <= 2190)))
                : (c <= 2273 || (c < 2417
                  ? (c < 2406
                    ? (c >= 2275 && c <= 2403)
                    : c <= 2415)
                  : (c <= 2435 || (c < 2447
                    ? (c >= 2437 && c <= 2444)
                    : c <= 2448)))))
              : (c <= 2472 || (c < 2507
                ? (c < 2486
                  ? (c < 2482
                    ? (c >= 2474 && c <= 2480)
                    : c <= 2482)
                  : (c <= 2489 || (c < 2503
                    ? (c >= 2492 && c <= 2500)
                    : c <= 2504)))
                : (c <= 2510 || (c < 2527
                  ? (c < 2524
                    ? c == 2519
                    : c <= 2525)
                  : (c <= 2531 || (c < 2556
                    ? (c >= 2534 && c <= 2545)
                    : c <= 2556)))))))
            : (c <= 2558 || (c < 2635
              ? (c < 2610
                ? (c < 2575
                  ? (c < 2565
                    ? (c >= 2561 && c <= 2563)
                    : c <= 2570)
                  : (c <= 2576 || (c < 2602
                    ? (c >= 2579 && c <= 2600)
                    : c <= 2608)))
                : (c <= 2611 || (c < 2620
                  ? (c < 2616
                    ? (c >= 2613 && c <= 2614)
                    : c <= 2617)
                  : (c <= 2620 || (c < 2631
                    ? (c >= 2622 && c <= 2626)
                    : c <= 2632)))))
              : (c <= 2637 || (c < 2693
                ? (c < 2654
                  ? (c < 2649
                    ? c == 2641
                    : c <= 2652)
                  : (c <= 2654 || (c < 2689
                    ? (c >= 2662 && c <= 2677)
                    : c <= 2691)))
                : (c <= 2701 || (c < 2730
                  ? (c < 2707
                    ? (c >= 2703 && c <= 2705)
                    : c <= 2728)
                  : (c <= 2736 || (c < 2741
                    ? (c >= 2738 && c <= 2739)
                    : c <= 2745)))))))))))
        : (c <= 2757 || (c < 3168
          ? (c < 2958
            ? (c < 2866
              ? (c < 2809
                ? (c < 2768
                  ? (c < 2763
                    ? (c >= 2759 && c <= 2761)
                    : c <= 2765)
                  : (c <= 2768 || (c < 2790
                    ? (c >= 2784 && c <= 2787)
                    : c <= 2799)))
                : (c <= 2815 || (c < 2831
                  ? (c < 2821
                    ? (c >= 2817 && c <= 2819)
                    : c <= 2828)
                  : (c <= 2832 || (c < 2858
                    ? (c >= 2835 && c <= 2856)
                    : c <= 2864)))))
              : (c <= 2867 || (c < 2908
                ? (c < 2887
                  ? (c < 2876
                    ? (c >= 2869 && c <= 2873)
                    : c <= 2884)
                  : (c <= 2888 || (c < 2901
                    ? (c >= 2891 && c <= 2893)
                    : c <= 2903)))
                : (c <= 2909 || (c < 2929
                  ? (c < 2918
                    ? (c >= 2911 && c <= 2915)
                    : c <= 2927)
                  : (c <= 2929 || (c < 2949
                    ? (c >= 2946 && c <= 2947)
                    : c <= 2954)))))))
            : (c <= 2960 || (c < 3031
              ? (c < 2984
                ? (c < 2972
                  ? (c < 2969
                    ? (c >= 2962 && c <= 2965)
                    : c <= 2970)
                  : (c <= 2972 || (c < 2979
                    ? (c >= 2974 && c <= 2975)
                    : c <= 2980)))
                : (c <= 2986 || (c < 3014
                  ? (c < 3006
                    ? (c >= 2990 && c <= 3001)
                    : c <= 3010)
                  : (c <= 3016 || (c < 3024
                    ? (c >= 3018 && c <= 3021)
                    : c <= 3024)))))
              : (c <= 3031 || (c < 3132
                ? (c < 3086
                  ? (c < 3072
                    ? (c >= 3046 && c <= 3055)
                    : c <= 3084)
                  : (c <= 3088 || (c < 3114
                    ? (c >= 3090 && c <= 3112)
                    : c <= 3129)))
                : (c <= 3140 || (c < 3157
                  ? (c < 3146
                    ? (c >= 3142 && c <= 3144)
                    : c <= 3149)
                  : (c <= 3158 || (c < 3165
                    ? (c >= 3160 && c <= 3162)
                    : c <= 3165)))))))))
          : (c <= 3171 || (c < 3450
            ? (c < 3293
              ? (c < 3242
                ? (c < 3205
                  ? (c < 3200
                    ? (c >= 3174 && c <= 3183)
                    : c <= 3203)
                  : (c <= 3212 || (c < 3218
                    ? (c >= 3214 && c <= 3216)
                    : c <= 3240)))
                : (c <= 3251 || (c < 3270
                  ? (c < 3260
                    ? (c >= 3253 && c <= 3257)
                    : c <= 3268)
                  : (c <= 3272 || (c < 3285
                    ? (c >= 3274 && c <= 3277)
                    : c <= 3286)))))
              : (c <= 3294 || (c < 3346
                ? (c < 3313
                  ? (c < 3302
                    ? (c >= 3296 && c <= 3299)
                    : c <= 3311)
                  : (c <= 3314 || (c < 3342
                    ? (c >= 3328 && c <= 3340)
                    : c <= 3344)))
                : (c <= 3396 || (c < 3412
                  ? (c < 3402
                    ? (c >= 3398 && c <= 3400)
                    : c <= 3406)
                  : (c <= 3415 || (c < 3430
                    ? (c >= 3423 && c <= 3427)
                    : c <= 3439)))))))
            : (c <= 3455 || (c < 3570
              ? (c < 3520
                ? (c < 3482
                  ? (c < 3461
                    ? (c >= 3457 && c <= 3459)
                    : c <= 3478)
                  : (c <= 3505 || (c < 3517
                    ? (c >= 3507 && c <= 3515)
                    : c <= 3517)))
                : (c <= 3526 || (c < 3542
                  ? (c < 3535
                    ? c == 3530
                    : c <= 3540)
                  : (c <= 3542 || (c < 3558
                    ? (c >= 3544 && c <= 3551)
                    : c <= 3567)))))
              : (c <= 3571 || (c < 3718
                ? (c < 3664
                  ? (c < 3648
                    ? (c >= 3585 && c <= 3642)
                    : c <= 3662)
                  : (c <= 3673 || (c < 3716
                    ? (c >= 3713 && c <= 3714)
                    : c <= 3716)))
                : (c <= 3722 || (c < 3751
                  ? (c < 3749
                    ? (c >= 3724 && c <= 3747)
                    : c <= 3749)
                  : (c <= 3773 || (c >= 3776 && c <= 3780)))))))))))))
      : (c <= 3782 || (c < 8025
        ? (c < 5888
          ? (c < 4688
            ? (c < 3953
              ? (c < 3872
                ? (c < 3804
                  ? (c < 3792
                    ? (c >= 3784 && c <= 3789)
                    : c <= 3801)
                  : (c <= 3807 || (c < 3864
                    ? c == 3840
                    : c <= 3865)))
                : (c <= 3881 || (c < 3897
                  ? (c < 3895
                    ? c == 3893
                    : c <= 3895)
                  : (c <= 3897 || (c < 3913
                    ? (c >= 3902 && c <= 3911)
                    : c <= 3948)))))
              : (c <= 3972 || (c < 4256
                ? (c < 4038
                  ? (c < 3993
                    ? (c >= 3974 && c <= 3991)
                    : c <= 4028)
                  : (c <= 4038 || (c < 4176
                    ? (c >= 4096 && c <= 4169)
                    : c <= 4253)))
                : (c <= 4293 || (c < 4304
                  ? (c < 4301
                    ? c == 4295
                    : c <= 4301)
                  : (c <= 4346 || (c < 4682
                    ? (c >= 4348 && c <= 4680)
                    : c <= 4685)))))))
            : (c <= 4694 || (c < 4882
              ? (c < 4786
                ? (c < 4704
                  ? (c < 4698
                    ? c == 4696
                    : c <= 4701)
                  : (c <= 4744 || (c < 4752
                    ? (c >= 4746 && c <= 4749)
                    : c <= 4784)))
                : (c <= 4789 || (c < 4802
                  ? (c < 4800
                    ? (c >= 4792 && c <= 4798)
                    : c <= 4800)
                  : (c <= 4805 || (c < 4824
                    ? (c >= 4808 && c <= 4822)
                    : c <= 4880)))))
              : (c <= 4885 || (c < 5112
                ? (c < 4969
                  ? (c < 4957
                    ? (c >= 4888 && c <= 4954)
                    : c <= 4959)
                  : (c <= 4977 || (c < 5024
                    ? (c >= 4992 && c <= 5007)
                    : c <= 5109)))
                : (c <= 5117 || (c < 5761
                  ? (c < 5743
                    ? (c >= 5121 && c <= 5740)
                    : c <= 5759)
                  : (c <= 5786 || (c < 5870
                    ? (c >= 5792 && c <= 5866)
                    : c <= 5880)))))))))
          : (c <= 5909 || (c < 6688
            ? (c < 6176
              ? (c < 6016
                ? (c < 5984
                  ? (c < 5952
                    ? (c >= 5919 && c <= 5940)
                    : c <= 5971)
                  : (c <= 5996 || (c < 6002
                    ? (c >= 5998 && c <= 6000)
                    : c <= 6003)))
                : (c <= 6099 || (c < 6112
                  ? (c < 6108
                    ? c == 6103
                    : c <= 6109)
                  : (c <= 6121 || (c < 6159
                    ? (c >= 6155 && c <= 6157)
                    : c <= 6169)))))
              : (c <= 6264 || (c < 6470
                ? (c < 6400
                  ? (c < 6320
                    ? (c >= 6272 && c <= 6314)
                    : c <= 6389)
                  : (c <= 6430 || (c < 6448
                    ? (c >= 6432 && c <= 6443)
                    : c <= 6459)))
                : (c <= 6509 || (c < 6576
                  ? (c < 6528
                    ? (c >= 6512 && c <= 6516)
                    : c <= 6571)
                  : (c <= 6601 || (c < 6656
                    ? (c >= 6608 && c <= 6618)
                    : c <= 6683)))))))
            : (c <= 6750 || (c < 7232
              ? (c < 6847
                ? (c < 6800
                  ? (c < 6783
                    ? (c >= 6752 && c <= 6780)
                    : c <= 6793)
                  : (c <= 6809 || (c < 6832
                    ? c == 6823
                    : c <= 6845)))
                : (c <= 6862 || (c < 7019
                  ? (c < 6992
                    ? (c >= 6912 && c <= 6988)
                    : c <= 7001)
                  : (c <= 7027 || (c < 7168
                    ? (c >= 7040 && c <= 7155)
                    : c <= 7223)))))
              : (c <= 7241 || (c < 7380
                ? (c < 7312
                  ? (c < 7296
                    ? (c >= 7245 && c <= 7293)
                    : c <= 7304)
                  : (c <= 7354 || (c < 7376
                    ? (c >= 7357 && c <= 7359)
                    : c <= 7378)))
                : (c <= 7418 || (c < 7968
                  ? (c < 7960
                    ? (c >= 7424 && c <= 7957)
                    : c <= 7965)
                  : (c <= 8005 || (c < 8016
                    ? (c >= 8008 && c <= 8013)
                    : c <= 8023)))))))))))
        : (c <= 8025 || (c < 11720
          ? (c < 8458
            ? (c < 8178
              ? (c < 8126
                ? (c < 8031
                  ? (c < 8029
                    ? c == 8027
                    : c <= 8029)
                  : (c <= 8061 || (c < 8118
                    ? (c >= 8064 && c <= 8116)
                    : c <= 8124)))
                : (c <= 8126 || (c < 8144
                  ? (c < 8134
                    ? (c >= 8130 && c <= 8132)
                    : c <= 8140)
                  : (c <= 8147 || (c < 8160
                    ? (c >= 8150 && c <= 8155)
                    : c <= 8172)))))
              : (c <= 8180 || (c < 8336
                ? (c < 8276
                  ? (c < 8255
                    ? (c >= 8182 && c <= 8188)
                    : c <= 8256)
                  : (c <= 8276 || (c < 8319
                    ? c == 8305
                    : c <= 8319)))
                : (c <= 8348 || (c < 8421
                  ? (c < 8417
                    ? (c >= 8400 && c <= 8412)
                    : c <= 8417)
                  : (c <= 8432 || (c < 8455
                    ? c == 8450
                    : c <= 8455)))))))
            : (c <= 8467 || (c < 11499
              ? (c < 8490
                ? (c < 8484
                  ? (c < 8472
                    ? c == 8469
                    : c <= 8477)
                  : (c <= 8484 || (c < 8488
                    ? c == 8486
                    : c <= 8488)))
                : (c <= 8505 || (c < 8526
                  ? (c < 8517
                    ? (c >= 8508 && c <= 8511)
                    : c <= 8521)
                  : (c <= 8526 || (c < 11264
                    ? (c >= 8544 && c <= 8584)
                    : c <= 11492)))))
              : (c <= 11507 || (c < 11647
                ? (c < 11565
                  ? (c < 11559
                    ? (c >= 11520 && c <= 11557)
                    : c <= 11559)
                  : (c <= 11565 || (c < 11631
                    ? (c >= 11568 && c <= 11623)
                    : c <= 11631)))
                : (c <= 11670 || (c < 11696
                  ? (c < 11688
                    ? (c >= 11680 && c <= 11686)
                    : c <= 11694)
                  : (c <= 11702 || (c < 11712
                    ? (c >= 11704 && c <= 11710)
                    : c <= 11718)))))))))
          : (c <= 11726 || (c < 42623
            ? (c < 12540
              ? (c < 12337
                ? (c < 11744
                  ? (c < 11736
                    ? (c >= 11728 && c <= 11734)
                    : c <= 11742)
                  : (c <= 11775 || (c < 12321
                    ? (c >= 12293 && c <= 12295)
                    : c <= 12335)))
                : (c <= 12341 || (c < 12441
                  ? (c < 12353
                    ? (c >= 12344 && c <= 12348)
                    : c <= 12438)
                  : (c <= 12442 || (c < 12449
                    ? (c >= 12445 && c <= 12447)
                    : c <= 12538)))))
              : (c <= 12543 || (c < 19968
                ? (c < 12704
                  ? (c < 12593
                    ? (c >= 12549 && c <= 12591)
                    : c <= 12686)
                  : (c <= 12735 || (c < 13312
                    ? (c >= 12784 && c <= 12799)
                    : c <= 19903)))
                : (c <= 42124 || (c < 42512
                  ? (c < 42240
                    ? (c >= 42192 && c <= 42237)
                    : c <= 42508)
                  : (c <= 42539 || (c < 42612
                    ? (c >= 42560 && c <= 42607)
                    : c <= 42621)))))))
            : (c <= 42737 || (c < 43232
              ? (c < 42965
                ? (c < 42891
                  ? (c < 42786
                    ? (c >= 42775 && c <= 42783)
                    : c <= 42888)
                  : (c <= 42954 || (c < 42963
                    ? (c >= 42960 && c <= 42961)
                    : c <= 42963)))
                : (c <= 42969 || (c < 43072
                  ? (c < 43052
                    ? (c >= 42994 && c <= 43047)
                    : c <= 43052)
                  : (c <= 43123 || (c < 43216
                    ? (c >= 43136 && c <= 43205)
                    : c <= 43225)))))
              : (c <= 43255 || (c < 43471
                ? (c < 43312
                  ? (c < 43261
                    ? c == 43259
                    : c <= 43309)
                  : (c <= 43347 || (c < 43392
                    ? (c >= 43360 && c <= 43388)
                    : c <= 43456)))
                : (c <= 43481 || (c < 43584
                  ? (c < 43520
                    ? (c >= 43488 && c <= 43518)
                    : c <= 43574)
                  : (c <= 43597 || (c >= 43600 && c <= 43609)))))))))))))))
    : (c <= 43638 || (c < 71453
      ? (c < 67639
        ? (c < 65345
          ? (c < 64312
            ? (c < 43888
              ? (c < 43785
                ? (c < 43744
                  ? (c < 43739
                    ? (c >= 43642 && c <= 43714)
                    : c <= 43741)
                  : (c <= 43759 || (c < 43777
                    ? (c >= 43762 && c <= 43766)
                    : c <= 43782)))
                : (c <= 43790 || (c < 43816
                  ? (c < 43808
                    ? (c >= 43793 && c <= 43798)
                    : c <= 43814)
                  : (c <= 43822 || (c < 43868
                    ? (c >= 43824 && c <= 43866)
                    : c <= 43881)))))
              : (c <= 44010 || (c < 63744
                ? (c < 44032
                  ? (c < 44016
                    ? (c >= 44012 && c <= 44013)
                    : c <= 44025)
                  : (c <= 55203 || (c < 55243
                    ? (c >= 55216 && c <= 55238)
                    : c <= 55291)))
                : (c <= 64109 || (c < 64275
                  ? (c < 64256
                    ? (c >= 64112 && c <= 64217)
                    : c <= 64262)
                  : (c <= 64279 || (c < 64298
                    ? (c >= 64285 && c <= 64296)
                    : c <= 64310)))))))
            : (c <= 64316 || (c < 65075
              ? (c < 64612
                ? (c < 64323
                  ? (c < 64320
                    ? c == 64318
                    : c <= 64321)
                  : (c <= 64324 || (c < 64467
                    ? (c >= 64326 && c <= 64433)
                    : c <= 64605)))
                : (c <= 64829 || (c < 65008
                  ? (c < 64914
                    ? (c >= 64848 && c <= 64911)
                    : c <= 64967)
                  : (c <= 65017 || (c < 65056
                    ? (c >= 65024 && c <= 65039)
                    : c <= 65071)))))
              : (c <= 65076 || (c < 65147
                ? (c < 65139
                  ? (c < 65137
                    ? (c >= 65101 && c <= 65103)
                    : c <= 65137)
                  : (c <= 65139 || (c < 65145
                    ? c == 65143
                    : c <= 65145)))
                : (c <= 65147 || (c < 65296
                  ? (c < 65151
                    ? c == 65149
                    : c <= 65276)
                  : (c <= 65305 || (c < 65343
                    ? (c >= 65313 && c <= 65338)
                    : c <= 65343)))))))))
          : (c <= 65370 || (c < 66513
            ? (c < 65664
              ? (c < 65536
                ? (c < 65482
                  ? (c < 65474
                    ? (c >= 65382 && c <= 65470)
                    : c <= 65479)
                  : (c <= 65487 || (c < 65498
                    ? (c >= 65490 && c <= 65495)
                    : c <= 65500)))
                : (c <= 65547 || (c < 65596
                  ? (c < 65576
                    ? (c >= 65549 && c <= 65574)
                    : c <= 65594)
                  : (c <= 65597 || (c < 65616
                    ? (c >= 65599 && c <= 65613)
                    : c <= 65629)))))
              : (c <= 65786 || (c < 66304
                ? (c < 66176
                  ? (c < 66045
                    ? (c >= 65856 && c <= 65908)
                    : c <= 66045)
                  : (c <= 66204 || (c < 66272
                    ? (c >= 66208 && c <= 66256)
                    : c <= 66272)))
                : (c <= 66335 || (c < 66432
                  ? (c < 66384
                    ? (c >= 66349 && c <= 66378)
                    : c <= 66426)
                  : (c <= 66461 || (c < 66504
                    ? (c >= 66464 && c <= 66499)
                    : c <= 66511)))))))
            : (c <= 66517 || (c < 66979
              ? (c < 66864
                ? (c < 66736
                  ? (c < 66720
                    ? (c >= 66560 && c <= 66717)
                    : c <= 66729)
                  : (c <= 66771 || (c < 66816
                    ? (c >= 66776 && c <= 66811)
                    : c <= 66855)))
                : (c <= 66915 || (c < 66956
                  ? (c < 66940
                    ? (c >= 66928 && c <= 66938)
                    : c <= 66954)
                  : (c <= 66962 || (c < 66967
                    ? (c >= 66964 && c <= 66965)
                    : c <= 66977)))))
              : (c <= 66993 || (c < 67456
                ? (c < 67072
                  ? (c < 67003
                    ? (c >= 66995 && c <= 67001)
                    : c <= 67004)
                  : (c <= 67382 || (c < 67424
                    ? (c >= 67392 && c <= 67413)
                    : c <= 67431)))
                : (c <= 67461 || (c < 67584
                  ? (c < 67506
                    ? (c >= 67463 && c <= 67504)
                    : c <= 67514)
                  : (c <= 67589 || (c < 67594
                    ? c == 67592
                    : c <= 67637)))))))))))
        : (c <= 67640 || (c < 69956
          ? (c < 68448
            ? (c < 68101
              ? (c < 67828
                ? (c < 67680
                  ? (c < 67647
                    ? c == 67644
                    : c <= 67669)
                  : (c <= 67702 || (c < 67808
                    ? (c >= 67712 && c <= 67742)
                    : c <= 67826)))
                : (c <= 67829 || (c < 67968
                  ? (c < 67872
                    ? (c >= 67840 && c <= 67861)
                    : c <= 67897)
                  : (c <= 68023 || (c < 68096
                    ? (c >= 68030 && c <= 68031)
                    : c <= 68099)))))
              : (c <= 68102 || (c < 68192
                ? (c < 68121
                  ? (c < 68117
                    ? (c >= 68108 && c <= 68115)
                    : c <= 68119)
                  : (c <= 68149 || (c < 68159
                    ? (c >= 68152 && c <= 68154)
                    : c <= 68159)))
                : (c <= 68220 || (c < 68297
                  ? (c < 68288
                    ? (c >= 68224 && c <= 68252)
                    : c <= 68295)
                  : (c <= 68326 || (c < 68416
                    ? (c >= 68352 && c <= 68405)
                    : c <= 68437)))))))
            : (c <= 68466 || (c < 69424
              ? (c < 68912
                ? (c < 68736
                  ? (c < 68608
                    ? (c >= 68480 && c <= 68497)
                    : c <= 68680)
                  : (c <= 68786 || (c < 68864
                    ? (c >= 68800 && c <= 68850)
                    : c <= 68903)))
                : (c <= 68921 || (c < 69296
                  ? (c < 69291
                    ? (c >= 69248 && c <= 69289)
                    : c <= 69292)
                  : (c <= 69297 || (c < 69415
                    ? (c >= 69376 && c <= 69404)
                    : c <= 69415)))))
              : (c <= 69456 || (c < 69759
                ? (c < 69600
                  ? (c < 69552
                    ? (c >= 69488 && c <= 69509)
                    : c <= 69572)
                  : (c <= 69622 || (c < 69734
                    ? (c >= 69632 && c <= 69702)
                    : c <= 69749)))
                : (c <= 69818 || (c < 69872
                  ? (c < 69840
                    ? c == 69826
                    : c <= 69864)
                  : (c <= 69881 || (c < 69942
                    ? (c >= 69888 && c <= 69940)
                    : c <= 69951)))))))))
          : (c <= 69959 || (c < 70459
            ? (c < 70282
              ? (c < 70108
                ? (c < 70016
                  ? (c < 70006
                    ? (c >= 69968 && c <= 70003)
                    : c <= 70006)
                  : (c <= 70084 || (c < 70094
                    ? (c >= 70089 && c <= 70092)
                    : c <= 70106)))
                : (c <= 70108 || (c < 70206
                  ? (c < 70163
                    ? (c >= 70144 && c <= 70161)
                    : c <= 70199)
                  : (c <= 70206 || (c < 70280
                    ? (c >= 70272 && c <= 70278)
                    : c <= 70280)))))
              : (c <= 70285 || (c < 70405
                ? (c < 70320
                  ? (c < 70303
                    ? (c >= 70287 && c <= 70301)
                    : c <= 70312)
                  : (c <= 70378 || (c < 70400
                    ? (c >= 70384 && c <= 70393)
                    : c <= 70403)))
                : (c <= 70412 || (c < 70442
                  ? (c < 70419
                    ? (c >= 70415 && c <= 70416)
                    : c <= 70440)
                  : (c <= 70448 || (c < 70453
                    ? (c >= 70450 && c <= 70451)
                    : c <= 70457)))))))
            : (c <= 70468 || (c < 70855
              ? (c < 70502
                ? (c < 70480
                  ? (c < 70475
                    ? (c >= 70471 && c <= 70472)
                    : c <= 70477)
                  : (c <= 70480 || (c < 70493
                    ? c == 70487
                    : c <= 70499)))
                : (c <= 70508 || (c < 70736
                  ? (c < 70656
                    ? (c >= 70512 && c <= 70516)
                    : c <= 70730)
                  : (c <= 70745 || (c < 70784
                    ? (c >= 70750 && c <= 70753)
                    : c <= 70853)))))
              : (c <= 70855 || (c < 71236
                ? (c < 71096
                  ? (c < 71040
                    ? (c >= 70864 && c <= 70873)
                    : c <= 71093)
                  : (c <= 71104 || (c < 71168
                    ? (c >= 71128 && c <= 71133)
                    : c <= 71232)))
                : (c <= 71236 || (c < 71360
                  ? (c < 71296
                    ? (c >= 71248 && c <= 71257)
                    : c <= 71352)
                  : (c <= 71369 || (c >= 71424 && c <= 71450)))))))))))))
      : (c <= 71467 || (c < 119973
        ? (c < 77824
          ? (c < 72760
            ? (c < 72016
              ? (c < 71945
                ? (c < 71680
                  ? (c < 71488
                    ? (c >= 71472 && c <= 71481)
                    : c <= 71494)
                  : (c <= 71738 || (c < 71935
                    ? (c >= 71840 && c <= 71913)
                    : c <= 71942)))
                : (c <= 71945 || (c < 71960
                  ? (c < 71957
                    ? (c >= 71948 && c <= 71955)
                    : c <= 71958)
                  : (c <= 71989 || (c < 71995
                    ? (c >= 71991 && c <= 71992)
                    : c <= 72003)))))
              : (c <= 72025 || (c < 72263
                ? (c < 72154
                  ? (c < 72106
                    ? (c >= 72096 && c <= 72103)
                    : c <= 72151)
                  : (c <= 72161 || (c < 72192
                    ? (c >= 72163 && c <= 72164)
                    : c <= 72254)))
                : (c <= 72263 || (c < 72368
                  ? (c < 72349
                    ? (c >= 72272 && c <= 72345)
                    : c <= 72349)
                  : (c <= 72440 || (c < 72714
                    ? (c >= 72704 && c <= 72712)
                    : c <= 72758)))))))
            : (c <= 72768 || (c < 73056
              ? (c < 72968
                ? (c < 72850
                  ? (c < 72818
                    ? (c >= 72784 && c <= 72793)
                    : c <= 72847)
                  : (c <= 72871 || (c < 72960
                    ? (c >= 72873 && c <= 72886)
                    : c <= 72966)))
                : (c <= 72969 || (c < 73020
                  ? (c < 73018
                    ? (c >= 72971 && c <= 73014)
                    : c <= 73018)
                  : (c <= 73021 || (c < 73040
                    ? (c >= 73023 && c <= 73031)
                    : c <= 73049)))))
              : (c <= 73061 || (c < 73440
                ? (c < 73104
                  ? (c < 73066
                    ? (c >= 73063 && c <= 73064)
                    : c <= 73102)
                  : (c <= 73105 || (c < 73120
                    ? (c >= 73107 && c <= 73112)
                    : c <= 73129)))
                : (c <= 73462 || (c < 74752
                  ? (c < 73728
                    ? c == 73648
                    : c <= 74649)
                  : (c <= 74862 || (c < 77712
                    ? (c >= 74880 && c <= 75075)
                    : c <= 77808)))))))))
          : (c <= 78894 || (c < 110576
            ? (c < 93027
              ? (c < 92864
                ? (c < 92736
                  ? (c < 92160
                    ? (c >= 82944 && c <= 83526)
                    : c <= 92728)
                  : (c <= 92766 || (c < 92784
                    ? (c >= 92768 && c <= 92777)
                    : c <= 92862)))
                : (c <= 92873 || (c < 92928
                  ? (c < 92912
                    ? (c >= 92880 && c <= 92909)
                    : c <= 92916)
                  : (c <= 92982 || (c < 93008
                    ? (c >= 92992 && c <= 92995)
                    : c <= 93017)))))
              : (c <= 93047 || (c < 94176
                ? (c < 93952
                  ? (c < 93760
                    ? (c >= 93053 && c <= 93071)
                    : c <= 93823)
                  : (c <= 94026 || (c < 94095
                    ? (c >= 94031 && c <= 94087)
                    : c <= 94111)))
                : (c <= 94177 || (c < 94208
                  ? (c < 94192
                    ? (c >= 94179 && c <= 94180)
                    : c <= 94193)
                  : (c <= 100343 || (c < 101632
                    ? (c >= 100352 && c <= 101589)
                    : c <= 101640)))))))
            : (c <= 110579 || (c < 118528
              ? (c < 110960
                ? (c < 110592
                  ? (c < 110589
                    ? (c >= 110581 && c <= 110587)
                    : c <= 110590)
                  : (c <= 110882 || (c < 110948
                    ? (c >= 110928 && c <= 110930)
                    : c <= 110951)))
                : (c <= 111355 || (c < 113792
                  ? (c < 113776
                    ? (c >= 113664 && c <= 113770)
                    : c <= 113788)
                  : (c <= 113800 || (c < 113821
                    ? (c >= 113808 && c <= 113817)
                    : c <= 113822)))))
              : (c <= 118573 || (c < 119210
                ? (c < 119149
                  ? (c < 119141
                    ? (c >= 118576 && c <= 118598)
                    : c <= 119145)
                  : (c <= 119154 || (c < 119173
                    ? (c >= 119163 && c <= 119170)
                    : c <= 119179)))
                : (c <= 119213 || (c < 119894
                  ? (c < 119808
                    ? (c >= 119362 && c <= 119364)
                    : c <= 119892)
                  : (c <= 119964 || (c < 119970
                    ? (c >= 119966 && c <= 119967)
                    : c <= 119970)))))))))))
        : (c <= 119974 || (c < 124912
          ? (c < 120746
            ? (c < 120134
              ? (c < 120071
                ? (c < 119995
                  ? (c < 119982
                    ? (c >= 119977 && c <= 119980)
                    : c <= 119993)
                  : (c <= 119995 || (c < 120005
                    ? (c >= 119997 && c <= 120003)
                    : c <= 120069)))
                : (c <= 120074 || (c < 120094
                  ? (c < 120086
                    ? (c >= 120077 && c <= 120084)
                    : c <= 120092)
                  : (c <= 120121 || (c < 120128
                    ? (c >= 120123 && c <= 120126)
                    : c <= 120132)))))
              : (c <= 120134 || (c < 120572
                ? (c < 120488
                  ? (c < 120146
                    ? (c >= 120138 && c <= 120144)
                    : c <= 120485)
                  : (c <= 120512 || (c < 120540
                    ? (c >= 120514 && c <= 120538)
                    : c <= 120570)))
                : (c <= 120596 || (c < 120656
                  ? (c < 120630
                    ? (c >= 120598 && c <= 120628)
                    : c <= 120654)
                  : (c <= 120686 || (c < 120714
                    ? (c >= 120688 && c <= 120712)
                    : c <= 120744)))))))
            : (c <= 120770 || (c < 122907
              ? (c < 121476
                ? (c < 121344
                  ? (c < 120782
                    ? (c >= 120772 && c <= 120779)
                    : c <= 120831)
                  : (c <= 121398 || (c < 121461
                    ? (c >= 121403 && c <= 121452)
                    : c <= 121461)))
                : (c <= 121476 || (c < 122624
                  ? (c < 121505
                    ? (c >= 121499 && c <= 121503)
                    : c <= 121519)
                  : (c <= 122654 || (c < 122888
                    ? (c >= 122880 && c <= 122886)
                    : c <= 122904)))))
              : (c <= 122913 || (c < 123214
                ? (c < 123136
                  ? (c < 122918
                    ? (c >= 122915 && c <= 122916)
                    : c <= 122922)
                  : (c <= 123180 || (c < 123200
                    ? (c >= 123184 && c <= 123197)
                    : c <= 123209)))
                : (c <= 123214 || (c < 124896
                  ? (c < 123584
                    ? (c >= 123536 && c <= 123566)
                    : c <= 123641)
                  : (c <= 124902 || (c < 124909
                    ? (c >= 124904 && c <= 124907)
                    : c <= 124910)))))))))
          : (c <= 124926 || (c < 126557
            ? (c < 126521
              ? (c < 126469
                ? (c < 125184
                  ? (c < 125136
                    ? (c >= 124928 && c <= 125124)
                    : c <= 125142)
                  : (c <= 125259 || (c < 126464
                    ? (c >= 125264 && c <= 125273)
                    : c <= 126467)))
                : (c <= 126495 || (c < 126503
                  ? (c < 126500
                    ? (c >= 126497 && c <= 126498)
                    : c <= 126500)
                  : (c <= 126503 || (c < 126516
                    ? (c >= 126505 && c <= 126514)
                    : c <= 126519)))))
              : (c <= 126521 || (c < 126541
                ? (c < 126535
                  ? (c < 126530
                    ? c == 126523
                    : c <= 126530)
                  : (c <= 126535 || (c < 126539
                    ? c == 126537
                    : c <= 126539)))
                : (c <= 126543 || (c < 126551
                  ? (c < 126548
                    ? (c >= 126545 && c <= 126546)
                    : c <= 126548)
                  : (c <= 126551 || (c < 126555
                    ? c == 126553
                    : c <= 126555)))))))
            : (c <= 126557 || (c < 126629
              ? (c < 126580
                ? (c < 126564
                  ? (c < 126561
                    ? c == 126559
                    : c <= 126562)
                  : (c <= 126564 || (c < 126572
                    ? (c >= 126567 && c <= 126570)
                    : c <= 126578)))
                : (c <= 126583 || (c < 126592
                  ? (c < 126590
                    ? (c >= 126585 && c <= 126588)
                    : c <= 126590)
                  : (c <= 126601 || (c < 126625
                    ? (c >= 126603 && c <= 126619)
                    : c <= 126627)))))
              : (c <= 126633 || (c < 178208
                ? (c < 131072
                  ? (c < 130032
                    ? (c >= 126635 && c <= 126651)
                    : c <= 130041)
                  : (c <= 173791 || (c < 177984
                    ? (c >= 173824 && c <= 177976)
                    : c <= 178205)))
                : (c <= 183969 || (c < 196608
                  ? (c < 194560
                    ? (c >= 183984 && c <= 191456)
                    : c <= 195101)
                  : (c <= 201546 || (c >= 917760 && c <= 917999)))))))))))))))));
}

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(57);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ' ||
          lookahead == 8203 ||
          lookahead == 8288 ||
          lookahead == 65279) SKIP(53)
      if (lookahead == '\r') SKIP(53)
      if (lookahead == '!') ADVANCE(9);
      if (lookahead == '#') ADVANCE(167);
      if (lookahead == '%') ADVANCE(97);
      if (lookahead == '&') ADVANCE(101);
      if (lookahead == '(') ADVANCE(61);
      if (lookahead == ')') ADVANCE(62);
      if (lookahead == '*') ADVANCE(65);
      if (lookahead == '+') ADVANCE(93);
      if (lookahead == ',') ADVANCE(63);
      if (lookahead == '-') ADVANCE(87);
      if (lookahead == '.') ADVANCE(60);
      if (lookahead == '/') ADVANCE(94);
      if (lookahead == '0') ADVANCE(140);
      if (lookahead == ':') ADVANCE(72);
      if (lookahead == ';') ADVANCE(58);
      if (lookahead == '<') ADVANCE(107);
      if (lookahead == '=') ADVANCE(80);
      if (lookahead == '>') ADVANCE(115);
      if (lookahead == '@') ADVANCE(84);
      if (lookahead == '[') ADVANCE(81);
      if (lookahead == '\\') ADVANCE(133);
      if (lookahead == ']') ADVANCE(82);
      if (lookahead == '^') ADVANCE(103);
      if (lookahead == 'e') ADVANCE(163);
      if (lookahead == '{') ADVANCE(90);
      if (lookahead == '|') ADVANCE(89);
      if (lookahead == '}') ADVANCE(91);
      if (lookahead == '~') ADVANCE(106);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(139);
      if (sym_identifier_character_set_1(lookahead)) ADVANCE(166);
      END_STATE();
    case 1:
      if (lookahead == '\n') ADVANCE(168);
      END_STATE();
    case 2:
      if (lookahead == '\n') ADVANCE(132);
      END_STATE();
    case 3:
      if (lookahead == '\n') SKIP(3)
      if (lookahead == '\r') ADVANCE(135);
      if (lookahead == '#') ADVANCE(136);
      if (lookahead == '\\') ADVANCE(134);
      if (lookahead == '{') ADVANCE(90);
      if (lookahead == '}') ADVANCE(91);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ' ||
          lookahead == 8203 ||
          lookahead == 8288 ||
          lookahead == 65279) ADVANCE(135);
      if (lookahead != 0) ADVANCE(136);
      END_STATE();
    case 4:
      if (lookahead == '.') ADVANCE(5);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(146);
      END_STATE();
    case 5:
      if (lookahead == '.') ADVANCE(131);
      END_STATE();
    case 6:
      if (lookahead == '/') ADVANCE(16);
      if (lookahead == '=') ADVANCE(121);
      END_STATE();
    case 7:
      if (lookahead == '<') ADVANCE(17);
      END_STATE();
    case 8:
      if (lookahead == '=') ADVANCE(112);
      END_STATE();
    case 9:
      if (lookahead == '=') ADVANCE(112);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(137);
      END_STATE();
    case 10:
      if (lookahead == '=') ADVANCE(124);
      END_STATE();
    case 11:
      if (lookahead == '=') ADVANCE(128);
      END_STATE();
    case 12:
      if (lookahead == '=') ADVANCE(122);
      END_STATE();
    case 13:
      if (lookahead == '=') ADVANCE(129);
      END_STATE();
    case 14:
      if (lookahead == '=') ADVANCE(130);
      END_STATE();
    case 15:
      if (lookahead == '=') ADVANCE(125);
      END_STATE();
    case 16:
      if (lookahead == '=') ADVANCE(123);
      END_STATE();
    case 17:
      if (lookahead == '=') ADVANCE(127);
      END_STATE();
    case 18:
      if (lookahead == '=') ADVANCE(126);
      END_STATE();
    case 19:
      if (lookahead == '>') ADVANCE(76);
      END_STATE();
    case 20:
      if (lookahead == '>') ADVANCE(18);
      END_STATE();
    case 21:
      if (lookahead == '_') ADVANCE(28);
      if (lookahead == '0' ||
          lookahead == '1') ADVANCE(142);
      END_STATE();
    case 22:
      if (lookahead == '_') ADVANCE(39);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(143);
      END_STATE();
    case 23:
      if (lookahead == '_') ADVANCE(44);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(144);
      END_STATE();
    case 24:
      if (lookahead == '{') ADVANCE(52);
      END_STATE();
    case 25:
      if (lookahead == '}') ADVANCE(132);
      if (lookahead != 0) ADVANCE(25);
      END_STATE();
    case 26:
      if (!eof && (lookahead == 0 ||
          lookahead == '\n')) ADVANCE(168);
      if (lookahead == '\r') ADVANCE(1);
      END_STATE();
    case 27:
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(41);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(147);
      END_STATE();
    case 28:
      if (lookahead == '0' ||
          lookahead == '1') ADVANCE(142);
      END_STATE();
    case 29:
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ' ||
          lookahead == 8203 ||
          lookahead == 8288 ||
          lookahead == 65279) SKIP(29)
      if (lookahead == '\r') SKIP(29)
      if (lookahead == '!') ADVANCE(8);
      if (lookahead == '#') ADVANCE(167);
      if (lookahead == '%') ADVANCE(97);
      if (lookahead == '&') ADVANCE(101);
      if (lookahead == '(') ADVANCE(61);
      if (lookahead == '*') ADVANCE(65);
      if (lookahead == '+') ADVANCE(93);
      if (lookahead == ',') ADVANCE(63);
      if (lookahead == '-') ADVANCE(86);
      if (lookahead == '.') ADVANCE(60);
      if (lookahead == '/') ADVANCE(94);
      if (lookahead == '0') ADVANCE(140);
      if (lookahead == ':') ADVANCE(72);
      if (lookahead == ';') ADVANCE(58);
      if (lookahead == '<') ADVANCE(107);
      if (lookahead == '=') ADVANCE(80);
      if (lookahead == '>') ADVANCE(115);
      if (lookahead == '@') ADVANCE(84);
      if (lookahead == '[') ADVANCE(81);
      if (lookahead == '\\') ADVANCE(26);
      if (lookahead == '^') ADVANCE(103);
      if (lookahead == '{') ADVANCE(90);
      if (lookahead == '|') ADVANCE(89);
      if (lookahead == '~') ADVANCE(106);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(139);
      if (sym_identifier_character_set_2(lookahead)) ADVANCE(166);
      END_STATE();
    case 30:
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ' ||
          lookahead == 8203 ||
          lookahead == 8288 ||
          lookahead == 65279) SKIP(30)
      if (lookahead == '\r') SKIP(30)
      if (lookahead == '!') ADVANCE(9);
      if (lookahead == '#') ADVANCE(167);
      if (lookahead == '%') ADVANCE(96);
      if (lookahead == '&') ADVANCE(100);
      if (lookahead == '(') ADVANCE(61);
      if (lookahead == ')') ADVANCE(62);
      if (lookahead == '*') ADVANCE(66);
      if (lookahead == '+') ADVANCE(92);
      if (lookahead == ',') ADVANCE(63);
      if (lookahead == '-') ADVANCE(85);
      if (lookahead == '.') ADVANCE(60);
      if (lookahead == '/') ADVANCE(95);
      if (lookahead == '0') ADVANCE(140);
      if (lookahead == ':') ADVANCE(72);
      if (lookahead == ';') ADVANCE(58);
      if (lookahead == '<') ADVANCE(108);
      if (lookahead == '=') ADVANCE(80);
      if (lookahead == '>') ADVANCE(116);
      if (lookahead == '@') ADVANCE(83);
      if (lookahead == '[') ADVANCE(81);
      if (lookahead == '\\') ADVANCE(26);
      if (lookahead == ']') ADVANCE(82);
      if (lookahead == '^') ADVANCE(102);
      if (lookahead == '{') ADVANCE(90);
      if (lookahead == '|') ADVANCE(88);
      if (lookahead == '}') ADVANCE(91);
      if (lookahead == '~') ADVANCE(106);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(139);
      if (sym_identifier_character_set_1(lookahead)) ADVANCE(166);
      END_STATE();
    case 31:
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ' ||
          lookahead == 8203 ||
          lookahead == 8288 ||
          lookahead == 65279) SKIP(31)
      if (lookahead == '\r') SKIP(31)
      if (lookahead == '#') ADVANCE(167);
      if (lookahead == '%') ADVANCE(10);
      if (lookahead == '&') ADVANCE(11);
      if (lookahead == '(') ADVANCE(61);
      if (lookahead == '*') ADVANCE(67);
      if (lookahead == '+') ADVANCE(93);
      if (lookahead == '-') ADVANCE(86);
      if (lookahead == '.') ADVANCE(4);
      if (lookahead == '/') ADVANCE(6);
      if (lookahead == '0') ADVANCE(140);
      if (lookahead == ':') ADVANCE(71);
      if (lookahead == ';') ADVANCE(58);
      if (lookahead == '<') ADVANCE(7);
      if (lookahead == '=') ADVANCE(79);
      if (lookahead == '>') ADVANCE(20);
      if (lookahead == '@') ADVANCE(12);
      if (lookahead == '[') ADVANCE(81);
      if (lookahead == '\\') ADVANCE(26);
      if (lookahead == '^') ADVANCE(13);
      if (lookahead == '{') ADVANCE(90);
      if (lookahead == '|') ADVANCE(14);
      if (lookahead == '~') ADVANCE(106);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(139);
      if (sym_identifier_character_set_2(lookahead)) ADVANCE(166);
      END_STATE();
    case 32:
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ' ||
          lookahead == 8203 ||
          lookahead == 8288 ||
          lookahead == 65279) SKIP(32)
      if (lookahead == '\r') SKIP(32)
      if (lookahead == '!') ADVANCE(8);
      if (lookahead == '#') ADVANCE(167);
      if (lookahead == '%') ADVANCE(97);
      if (lookahead == '&') ADVANCE(101);
      if (lookahead == '(') ADVANCE(61);
      if (lookahead == ')') ADVANCE(62);
      if (lookahead == '*') ADVANCE(65);
      if (lookahead == '+') ADVANCE(93);
      if (lookahead == ',') ADVANCE(63);
      if (lookahead == '-') ADVANCE(86);
      if (lookahead == '.') ADVANCE(59);
      if (lookahead == '/') ADVANCE(94);
      if (lookahead == ':') ADVANCE(72);
      if (lookahead == ';') ADVANCE(58);
      if (lookahead == '<') ADVANCE(107);
      if (lookahead == '=') ADVANCE(80);
      if (lookahead == '>') ADVANCE(115);
      if (lookahead == '@') ADVANCE(84);
      if (lookahead == '[') ADVANCE(81);
      if (lookahead == '\\') ADVANCE(26);
      if (lookahead == ']') ADVANCE(82);
      if (lookahead == '^') ADVANCE(103);
      if (lookahead == '|') ADVANCE(89);
      if (lookahead == '}') ADVANCE(91);
      if (sym_identifier_character_set_1(lookahead)) ADVANCE(166);
      END_STATE();
    case 33:
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ' ||
          lookahead == 8203 ||
          lookahead == 8288 ||
          lookahead == 65279) SKIP(33)
      if (lookahead == '\r') SKIP(33)
      if (lookahead == '!') ADVANCE(8);
      if (lookahead == '#') ADVANCE(167);
      if (lookahead == '%') ADVANCE(97);
      if (lookahead == '&') ADVANCE(101);
      if (lookahead == '(') ADVANCE(61);
      if (lookahead == ')') ADVANCE(62);
      if (lookahead == '*') ADVANCE(65);
      if (lookahead == '+') ADVANCE(93);
      if (lookahead == ',') ADVANCE(63);
      if (lookahead == '-') ADVANCE(86);
      if (lookahead == '.') ADVANCE(59);
      if (lookahead == '/') ADVANCE(94);
      if (lookahead == ':') ADVANCE(71);
      if (lookahead == ';') ADVANCE(58);
      if (lookahead == '<') ADVANCE(107);
      if (lookahead == '=') ADVANCE(80);
      if (lookahead == '>') ADVANCE(115);
      if (lookahead == '@') ADVANCE(84);
      if (lookahead == '[') ADVANCE(81);
      if (lookahead == '\\') ADVANCE(26);
      if (lookahead == ']') ADVANCE(82);
      if (lookahead == '^') ADVANCE(103);
      if (lookahead == '|') ADVANCE(89);
      if (sym_identifier_character_set_1(lookahead)) ADVANCE(166);
      END_STATE();
    case 34:
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ' ||
          lookahead == 8203 ||
          lookahead == 8288 ||
          lookahead == 65279) SKIP(34)
      if (lookahead == '\r') SKIP(34)
      if (lookahead == '#') ADVANCE(167);
      if (lookahead == '-') ADVANCE(19);
      if (lookahead == ':') ADVANCE(71);
      if (lookahead == '\\') ADVANCE(26);
      if (lookahead == 'e') ADVANCE(163);
      if (sym_identifier_character_set_2(lookahead)) ADVANCE(166);
      END_STATE();
    case 35:
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ' ||
          lookahead == 8203 ||
          lookahead == 8288 ||
          lookahead == 65279) SKIP(35)
      if (lookahead == '\r') SKIP(35)
      if (lookahead == '!') ADVANCE(8);
      if (lookahead == '#') ADVANCE(167);
      if (lookahead == '%') ADVANCE(97);
      if (lookahead == '&') ADVANCE(101);
      if (lookahead == '(') ADVANCE(61);
      if (lookahead == '*') ADVANCE(65);
      if (lookahead == '+') ADVANCE(93);
      if (lookahead == ',') ADVANCE(63);
      if (lookahead == '-') ADVANCE(86);
      if (lookahead == '.') ADVANCE(60);
      if (lookahead == '/') ADVANCE(94);
      if (lookahead == '0') ADVANCE(140);
      if (lookahead == ':') ADVANCE(71);
      if (lookahead == ';') ADVANCE(58);
      if (lookahead == '<') ADVANCE(107);
      if (lookahead == '=') ADVANCE(80);
      if (lookahead == '>') ADVANCE(115);
      if (lookahead == '@') ADVANCE(84);
      if (lookahead == '[') ADVANCE(81);
      if (lookahead == '\\') ADVANCE(26);
      if (lookahead == '^') ADVANCE(103);
      if (lookahead == '{') ADVANCE(90);
      if (lookahead == '|') ADVANCE(89);
      if (lookahead == '~') ADVANCE(106);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(139);
      if (sym_identifier_character_set_2(lookahead)) ADVANCE(166);
      END_STATE();
    case 36:
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ' ||
          lookahead == 8203 ||
          lookahead == 8288 ||
          lookahead == 65279) SKIP(36)
      if (lookahead == '\r') SKIP(36)
      if (lookahead == '!') ADVANCE(9);
      if (lookahead == '#') ADVANCE(167);
      if (lookahead == '%') ADVANCE(96);
      if (lookahead == '&') ADVANCE(100);
      if (lookahead == '(') ADVANCE(61);
      if (lookahead == ')') ADVANCE(62);
      if (lookahead == '*') ADVANCE(66);
      if (lookahead == '+') ADVANCE(92);
      if (lookahead == ',') ADVANCE(63);
      if (lookahead == '-') ADVANCE(85);
      if (lookahead == '.') ADVANCE(60);
      if (lookahead == '/') ADVANCE(95);
      if (lookahead == '0') ADVANCE(140);
      if (lookahead == ':') ADVANCE(71);
      if (lookahead == ';') ADVANCE(58);
      if (lookahead == '<') ADVANCE(108);
      if (lookahead == '=') ADVANCE(80);
      if (lookahead == '>') ADVANCE(116);
      if (lookahead == '@') ADVANCE(83);
      if (lookahead == '[') ADVANCE(81);
      if (lookahead == '\\') ADVANCE(26);
      if (lookahead == ']') ADVANCE(82);
      if (lookahead == '^') ADVANCE(102);
      if (lookahead == '{') ADVANCE(90);
      if (lookahead == '|') ADVANCE(88);
      if (lookahead == '}') ADVANCE(91);
      if (lookahead == '~') ADVANCE(106);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(139);
      if (sym_identifier_character_set_1(lookahead)) ADVANCE(166);
      END_STATE();
    case 37:
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ' ||
          lookahead == 8203 ||
          lookahead == 8288 ||
          lookahead == 65279) SKIP(37)
      if (lookahead == '\r') SKIP(37)
      if (lookahead == '!') ADVANCE(9);
      if (lookahead == '#') ADVANCE(167);
      if (lookahead == '%') ADVANCE(96);
      if (lookahead == '&') ADVANCE(100);
      if (lookahead == '(') ADVANCE(61);
      if (lookahead == ')') ADVANCE(62);
      if (lookahead == '*') ADVANCE(66);
      if (lookahead == '+') ADVANCE(92);
      if (lookahead == ',') ADVANCE(63);
      if (lookahead == '-') ADVANCE(85);
      if (lookahead == '.') ADVANCE(59);
      if (lookahead == '/') ADVANCE(95);
      if (lookahead == ':') ADVANCE(71);
      if (lookahead == ';') ADVANCE(58);
      if (lookahead == '<') ADVANCE(108);
      if (lookahead == '=') ADVANCE(80);
      if (lookahead == '>') ADVANCE(116);
      if (lookahead == '@') ADVANCE(83);
      if (lookahead == '[') ADVANCE(81);
      if (lookahead == '\\') ADVANCE(26);
      if (lookahead == ']') ADVANCE(82);
      if (lookahead == '^') ADVANCE(102);
      if (lookahead == '|') ADVANCE(88);
      if (lookahead == '}') ADVANCE(91);
      if (sym_identifier_character_set_1(lookahead)) ADVANCE(166);
      END_STATE();
    case 38:
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ' ||
          lookahead == 8203 ||
          lookahead == 8288 ||
          lookahead == 65279) SKIP(38)
      if (lookahead == '\r') SKIP(38)
      if (lookahead == '!') ADVANCE(9);
      if (lookahead == '#') ADVANCE(167);
      if (lookahead == '%') ADVANCE(96);
      if (lookahead == '&') ADVANCE(100);
      if (lookahead == '(') ADVANCE(61);
      if (lookahead == ')') ADVANCE(62);
      if (lookahead == '*') ADVANCE(66);
      if (lookahead == '+') ADVANCE(92);
      if (lookahead == ',') ADVANCE(63);
      if (lookahead == '-') ADVANCE(85);
      if (lookahead == '.') ADVANCE(59);
      if (lookahead == '/') ADVANCE(95);
      if (lookahead == ':') ADVANCE(72);
      if (lookahead == ';') ADVANCE(58);
      if (lookahead == '<') ADVANCE(108);
      if (lookahead == '=') ADVANCE(80);
      if (lookahead == '>') ADVANCE(116);
      if (lookahead == '@') ADVANCE(83);
      if (lookahead == '[') ADVANCE(81);
      if (lookahead == '\\') ADVANCE(26);
      if (lookahead == ']') ADVANCE(82);
      if (lookahead == '^') ADVANCE(102);
      if (lookahead == '|') ADVANCE(88);
      if (lookahead == '}') ADVANCE(91);
      if (sym_identifier_character_set_1(lookahead)) ADVANCE(166);
      END_STATE();
    case 39:
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(143);
      END_STATE();
    case 40:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(132);
      END_STATE();
    case 41:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(147);
      END_STATE();
    case 42:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(40);
      END_STATE();
    case 43:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(132);
      END_STATE();
    case 44:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(144);
      END_STATE();
    case 45:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(43);
      END_STATE();
    case 46:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(45);
      END_STATE();
    case 47:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(46);
      END_STATE();
    case 48:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(47);
      END_STATE();
    case 49:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(48);
      END_STATE();
    case 50:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(49);
      END_STATE();
    case 51:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(50);
      END_STATE();
    case 52:
      if (lookahead != 0 &&
          lookahead != '}') ADVANCE(25);
      END_STATE();
    case 53:
      if (eof) ADVANCE(57);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ' ||
          lookahead == 8203 ||
          lookahead == 8288 ||
          lookahead == 65279) SKIP(53)
      if (lookahead == '\r') SKIP(53)
      if (lookahead == '!') ADVANCE(9);
      if (lookahead == '#') ADVANCE(167);
      if (lookahead == '%') ADVANCE(97);
      if (lookahead == '&') ADVANCE(101);
      if (lookahead == '(') ADVANCE(61);
      if (lookahead == ')') ADVANCE(62);
      if (lookahead == '*') ADVANCE(65);
      if (lookahead == '+') ADVANCE(93);
      if (lookahead == ',') ADVANCE(63);
      if (lookahead == '-') ADVANCE(87);
      if (lookahead == '.') ADVANCE(60);
      if (lookahead == '/') ADVANCE(94);
      if (lookahead == '0') ADVANCE(140);
      if (lookahead == ':') ADVANCE(72);
      if (lookahead == ';') ADVANCE(58);
      if (lookahead == '<') ADVANCE(107);
      if (lookahead == '=') ADVANCE(80);
      if (lookahead == '>') ADVANCE(115);
      if (lookahead == '@') ADVANCE(84);
      if (lookahead == '[') ADVANCE(81);
      if (lookahead == '\\') ADVANCE(26);
      if (lookahead == ']') ADVANCE(82);
      if (lookahead == '^') ADVANCE(103);
      if (lookahead == 'e') ADVANCE(163);
      if (lookahead == '{') ADVANCE(90);
      if (lookahead == '|') ADVANCE(89);
      if (lookahead == '}') ADVANCE(91);
      if (lookahead == '~') ADVANCE(106);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(139);
      if (sym_identifier_character_set_1(lookahead)) ADVANCE(166);
      END_STATE();
    case 54:
      if (eof) ADVANCE(57);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ' ||
          lookahead == 8203 ||
          lookahead == 8288 ||
          lookahead == 65279) SKIP(54)
      if (lookahead == '\r') SKIP(54)
      if (lookahead == '!') ADVANCE(9);
      if (lookahead == '#') ADVANCE(167);
      if (lookahead == '(') ADVANCE(61);
      if (lookahead == ')') ADVANCE(62);
      if (lookahead == '*') ADVANCE(64);
      if (lookahead == '+') ADVANCE(92);
      if (lookahead == ',') ADVANCE(63);
      if (lookahead == '-') ADVANCE(85);
      if (lookahead == '.') ADVANCE(4);
      if (lookahead == '0') ADVANCE(140);
      if (lookahead == ':') ADVANCE(71);
      if (lookahead == ';') ADVANCE(58);
      if (lookahead == '<') ADVANCE(109);
      if (lookahead == '=') ADVANCE(80);
      if (lookahead == '>') ADVANCE(114);
      if (lookahead == '@') ADVANCE(83);
      if (lookahead == '[') ADVANCE(81);
      if (lookahead == '\\') ADVANCE(26);
      if (lookahead == ']') ADVANCE(82);
      if (lookahead == '{') ADVANCE(90);
      if (lookahead == '|') ADVANCE(88);
      if (lookahead == '}') ADVANCE(91);
      if (lookahead == '~') ADVANCE(106);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(139);
      if (sym_identifier_character_set_2(lookahead)) ADVANCE(166);
      END_STATE();
    case 55:
      if (eof) ADVANCE(57);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ' ||
          lookahead == 8203 ||
          lookahead == 8288 ||
          lookahead == 65279) SKIP(55)
      if (lookahead == '\r') SKIP(55)
      if (lookahead == '#') ADVANCE(167);
      if (lookahead == '(') ADVANCE(61);
      if (lookahead == '*') ADVANCE(64);
      if (lookahead == '+') ADVANCE(92);
      if (lookahead == '-') ADVANCE(85);
      if (lookahead == '.') ADVANCE(4);
      if (lookahead == '0') ADVANCE(140);
      if (lookahead == '@') ADVANCE(83);
      if (lookahead == '[') ADVANCE(81);
      if (lookahead == '\\') ADVANCE(26);
      if (lookahead == 'e') ADVANCE(164);
      if (lookahead == '{') ADVANCE(90);
      if (lookahead == '~') ADVANCE(106);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(139);
      if (sym_identifier_character_set_2(lookahead)) ADVANCE(166);
      END_STATE();
    case 56:
      if (eof) ADVANCE(57);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ' ||
          lookahead == 8203 ||
          lookahead == 8288 ||
          lookahead == 65279) SKIP(56)
      if (lookahead == '\r') SKIP(56)
      if (lookahead == '#') ADVANCE(167);
      if (lookahead == '(') ADVANCE(61);
      if (lookahead == '*') ADVANCE(64);
      if (lookahead == '+') ADVANCE(92);
      if (lookahead == '-') ADVANCE(85);
      if (lookahead == '.') ADVANCE(4);
      if (lookahead == '0') ADVANCE(140);
      if (lookahead == '@') ADVANCE(83);
      if (lookahead == '[') ADVANCE(81);
      if (lookahead == '\\') ADVANCE(26);
      if (lookahead == 'e') ADVANCE(165);
      if (lookahead == '{') ADVANCE(90);
      if (lookahead == '~') ADVANCE(106);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(139);
      if (sym_identifier_character_set_2(lookahead)) ADVANCE(166);
      END_STATE();
    case 57:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 58:
      ACCEPT_TOKEN(anon_sym_SEMI);
      END_STATE();
    case 59:
      ACCEPT_TOKEN(anon_sym_DOT);
      END_STATE();
    case 60:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '.') ADVANCE(5);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(146);
      END_STATE();
    case 61:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 62:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 63:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 64:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 65:
      ACCEPT_TOKEN(anon_sym_STAR);
      if (lookahead == '*') ADVANCE(78);
      if (lookahead == '=') ADVANCE(120);
      END_STATE();
    case 66:
      ACCEPT_TOKEN(anon_sym_STAR);
      if (lookahead == '*') ADVANCE(77);
      END_STATE();
    case 67:
      ACCEPT_TOKEN(anon_sym_STAR);
      if (lookahead == '*') ADVANCE(15);
      if (lookahead == '=') ADVANCE(120);
      END_STATE();
    case 68:
      ACCEPT_TOKEN(anon_sym_GT_GT);
      END_STATE();
    case 69:
      ACCEPT_TOKEN(anon_sym_GT_GT);
      if (lookahead == '=') ADVANCE(126);
      END_STATE();
    case 70:
      ACCEPT_TOKEN(anon_sym_COLON_EQ);
      END_STATE();
    case 71:
      ACCEPT_TOKEN(anon_sym_COLON);
      END_STATE();
    case 72:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == '=') ADVANCE(70);
      END_STATE();
    case 73:
      ACCEPT_TOKEN(anon_sym_except);
      if (lookahead == '*') ADVANCE(75);
      if (sym_identifier_character_set_3(lookahead)) ADVANCE(166);
      END_STATE();
    case 74:
      ACCEPT_TOKEN(anon_sym_except);
      if (sym_identifier_character_set_3(lookahead)) ADVANCE(166);
      END_STATE();
    case 75:
      ACCEPT_TOKEN(anon_sym_except_STAR);
      END_STATE();
    case 76:
      ACCEPT_TOKEN(anon_sym_DASH_GT);
      END_STATE();
    case 77:
      ACCEPT_TOKEN(anon_sym_STAR_STAR);
      END_STATE();
    case 78:
      ACCEPT_TOKEN(anon_sym_STAR_STAR);
      if (lookahead == '=') ADVANCE(125);
      END_STATE();
    case 79:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 80:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '=') ADVANCE(111);
      END_STATE();
    case 81:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 82:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 83:
      ACCEPT_TOKEN(anon_sym_AT);
      END_STATE();
    case 84:
      ACCEPT_TOKEN(anon_sym_AT);
      if (lookahead == '=') ADVANCE(122);
      END_STATE();
    case 85:
      ACCEPT_TOKEN(anon_sym_DASH);
      END_STATE();
    case 86:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '=') ADVANCE(119);
      END_STATE();
    case 87:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '=') ADVANCE(119);
      if (lookahead == '>') ADVANCE(76);
      END_STATE();
    case 88:
      ACCEPT_TOKEN(anon_sym_PIPE);
      END_STATE();
    case 89:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '=') ADVANCE(130);
      END_STATE();
    case 90:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 91:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 92:
      ACCEPT_TOKEN(anon_sym_PLUS);
      END_STATE();
    case 93:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '=') ADVANCE(118);
      END_STATE();
    case 94:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '/') ADVANCE(99);
      if (lookahead == '=') ADVANCE(121);
      END_STATE();
    case 95:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '/') ADVANCE(98);
      END_STATE();
    case 96:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      END_STATE();
    case 97:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      if (lookahead == '=') ADVANCE(124);
      END_STATE();
    case 98:
      ACCEPT_TOKEN(anon_sym_SLASH_SLASH);
      END_STATE();
    case 99:
      ACCEPT_TOKEN(anon_sym_SLASH_SLASH);
      if (lookahead == '=') ADVANCE(123);
      END_STATE();
    case 100:
      ACCEPT_TOKEN(anon_sym_AMP);
      END_STATE();
    case 101:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '=') ADVANCE(128);
      END_STATE();
    case 102:
      ACCEPT_TOKEN(anon_sym_CARET);
      END_STATE();
    case 103:
      ACCEPT_TOKEN(anon_sym_CARET);
      if (lookahead == '=') ADVANCE(129);
      END_STATE();
    case 104:
      ACCEPT_TOKEN(anon_sym_LT_LT);
      END_STATE();
    case 105:
      ACCEPT_TOKEN(anon_sym_LT_LT);
      if (lookahead == '=') ADVANCE(127);
      END_STATE();
    case 106:
      ACCEPT_TOKEN(anon_sym_TILDE);
      END_STATE();
    case 107:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '<') ADVANCE(105);
      if (lookahead == '=') ADVANCE(110);
      if (lookahead == '>') ADVANCE(117);
      END_STATE();
    case 108:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '<') ADVANCE(104);
      if (lookahead == '=') ADVANCE(110);
      if (lookahead == '>') ADVANCE(117);
      END_STATE();
    case 109:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '=') ADVANCE(110);
      if (lookahead == '>') ADVANCE(117);
      END_STATE();
    case 110:
      ACCEPT_TOKEN(anon_sym_LT_EQ);
      END_STATE();
    case 111:
      ACCEPT_TOKEN(anon_sym_EQ_EQ);
      END_STATE();
    case 112:
      ACCEPT_TOKEN(anon_sym_BANG_EQ);
      END_STATE();
    case 113:
      ACCEPT_TOKEN(anon_sym_GT_EQ);
      END_STATE();
    case 114:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(113);
      END_STATE();
    case 115:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(113);
      if (lookahead == '>') ADVANCE(69);
      END_STATE();
    case 116:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(113);
      if (lookahead == '>') ADVANCE(68);
      END_STATE();
    case 117:
      ACCEPT_TOKEN(anon_sym_LT_GT);
      END_STATE();
    case 118:
      ACCEPT_TOKEN(anon_sym_PLUS_EQ);
      END_STATE();
    case 119:
      ACCEPT_TOKEN(anon_sym_DASH_EQ);
      END_STATE();
    case 120:
      ACCEPT_TOKEN(anon_sym_STAR_EQ);
      END_STATE();
    case 121:
      ACCEPT_TOKEN(anon_sym_SLASH_EQ);
      END_STATE();
    case 122:
      ACCEPT_TOKEN(anon_sym_AT_EQ);
      END_STATE();
    case 123:
      ACCEPT_TOKEN(anon_sym_SLASH_SLASH_EQ);
      END_STATE();
    case 124:
      ACCEPT_TOKEN(anon_sym_PERCENT_EQ);
      END_STATE();
    case 125:
      ACCEPT_TOKEN(anon_sym_STAR_STAR_EQ);
      END_STATE();
    case 126:
      ACCEPT_TOKEN(anon_sym_GT_GT_EQ);
      END_STATE();
    case 127:
      ACCEPT_TOKEN(anon_sym_LT_LT_EQ);
      END_STATE();
    case 128:
      ACCEPT_TOKEN(anon_sym_AMP_EQ);
      END_STATE();
    case 129:
      ACCEPT_TOKEN(anon_sym_CARET_EQ);
      END_STATE();
    case 130:
      ACCEPT_TOKEN(anon_sym_PIPE_EQ);
      END_STATE();
    case 131:
      ACCEPT_TOKEN(sym_ellipsis);
      END_STATE();
    case 132:
      ACCEPT_TOKEN(sym_escape_sequence);
      END_STATE();
    case 133:
      ACCEPT_TOKEN(sym__not_escape_sequence);
      if (!eof && (lookahead == 0)) ADVANCE(168);
      if (lookahead == '\n') ADVANCE(132);
      if (lookahead == '\r') ADVANCE(2);
      if (lookahead == 'N') ADVANCE(24);
      if (lookahead == 'U') ADVANCE(51);
      if (lookahead == 'u') ADVANCE(47);
      if (lookahead == 'x') ADVANCE(45);
      if (lookahead == '"' ||
          lookahead == '\'' ||
          lookahead == '\\' ||
          lookahead == 'a' ||
          lookahead == 'b' ||
          lookahead == 'f' ||
          lookahead == 'n' ||
          lookahead == 'r' ||
          ('t' <= lookahead && lookahead <= 'v')) ADVANCE(132);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(42);
      END_STATE();
    case 134:
      ACCEPT_TOKEN(aux_sym_format_specifier_token1);
      if (!eof && (lookahead == 0)) ADVANCE(136);
      if (lookahead == '\r') ADVANCE(136);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '{' &&
          lookahead != '}') ADVANCE(136);
      END_STATE();
    case 135:
      ACCEPT_TOKEN(aux_sym_format_specifier_token1);
      if (lookahead == '\r') ADVANCE(135);
      if (lookahead == '#') ADVANCE(136);
      if (lookahead == '\\') ADVANCE(134);
      if (lookahead == '\t' ||
          lookahead == 11 ||
          lookahead == '\f' ||
          lookahead == ' ' ||
          lookahead == 8203 ||
          lookahead == 8288 ||
          lookahead == 65279) ADVANCE(135);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '{' &&
          lookahead != '}') ADVANCE(136);
      END_STATE();
    case 136:
      ACCEPT_TOKEN(aux_sym_format_specifier_token1);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '{' &&
          lookahead != '}') ADVANCE(136);
      END_STATE();
    case 137:
      ACCEPT_TOKEN(sym_type_conversion);
      END_STATE();
    case 138:
      ACCEPT_TOKEN(sym_integer);
      END_STATE();
    case 139:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '.') ADVANCE(148);
      if (lookahead == '_') ADVANCE(141);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(27);
      if (lookahead == 'J' ||
          lookahead == 'L' ||
          lookahead == 'j' ||
          lookahead == 'l') ADVANCE(138);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(139);
      END_STATE();
    case 140:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '.') ADVANCE(148);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(21);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(22);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(23);
      if (lookahead == '_') ADVANCE(141);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(27);
      if (lookahead == 'J' ||
          lookahead == 'L' ||
          lookahead == 'j' ||
          lookahead == 'l') ADVANCE(138);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(139);
      END_STATE();
    case 141:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '.') ADVANCE(148);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(27);
      if (lookahead == 'J' ||
          lookahead == 'L' ||
          lookahead == 'j' ||
          lookahead == 'l') ADVANCE(138);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(139);
      END_STATE();
    case 142:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '_') ADVANCE(28);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(138);
      if (lookahead == '0' ||
          lookahead == '1') ADVANCE(142);
      END_STATE();
    case 143:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '_') ADVANCE(39);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(138);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(143);
      END_STATE();
    case 144:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '_') ADVANCE(44);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(138);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(144);
      END_STATE();
    case 145:
      ACCEPT_TOKEN(sym_float);
      END_STATE();
    case 146:
      ACCEPT_TOKEN(sym_float);
      if (lookahead == '_') ADVANCE(148);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(27);
      if (lookahead == 'J' ||
          lookahead == 'j') ADVANCE(145);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(146);
      END_STATE();
    case 147:
      ACCEPT_TOKEN(sym_float);
      if (lookahead == '_') ADVANCE(149);
      if (lookahead == 'J' ||
          lookahead == 'j') ADVANCE(145);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(147);
      END_STATE();
    case 148:
      ACCEPT_TOKEN(sym_float);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(27);
      if (lookahead == 'J' ||
          lookahead == 'j') ADVANCE(145);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(146);
      END_STATE();
    case 149:
      ACCEPT_TOKEN(sym_float);
      if (lookahead == 'J' ||
          lookahead == 'j') ADVANCE(145);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(147);
      END_STATE();
    case 150:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '*') ADVANCE(75);
      if (sym_identifier_character_set_3(lookahead)) ADVANCE(166);
      END_STATE();
    case 151:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'c') ADVANCE(154);
      if (sym_identifier_character_set_3(lookahead)) ADVANCE(166);
      END_STATE();
    case 152:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'c') ADVANCE(155);
      if (sym_identifier_character_set_3(lookahead)) ADVANCE(166);
      END_STATE();
    case 153:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'c') ADVANCE(156);
      if (sym_identifier_character_set_3(lookahead)) ADVANCE(166);
      END_STATE();
    case 154:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(157);
      if (sym_identifier_character_set_3(lookahead)) ADVANCE(166);
      END_STATE();
    case 155:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(158);
      if (sym_identifier_character_set_3(lookahead)) ADVANCE(166);
      END_STATE();
    case 156:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(159);
      if (sym_identifier_character_set_3(lookahead)) ADVANCE(166);
      END_STATE();
    case 157:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'p') ADVANCE(160);
      if (sym_identifier_character_set_3(lookahead)) ADVANCE(166);
      END_STATE();
    case 158:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'p') ADVANCE(161);
      if (sym_identifier_character_set_3(lookahead)) ADVANCE(166);
      END_STATE();
    case 159:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'p') ADVANCE(162);
      if (sym_identifier_character_set_3(lookahead)) ADVANCE(166);
      END_STATE();
    case 160:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(73);
      if (sym_identifier_character_set_3(lookahead)) ADVANCE(166);
      END_STATE();
    case 161:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(150);
      if (sym_identifier_character_set_3(lookahead)) ADVANCE(166);
      END_STATE();
    case 162:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(74);
      if (sym_identifier_character_set_3(lookahead)) ADVANCE(166);
      END_STATE();
    case 163:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'x') ADVANCE(151);
      if (sym_identifier_character_set_3(lookahead)) ADVANCE(166);
      END_STATE();
    case 164:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'x') ADVANCE(152);
      if (sym_identifier_character_set_3(lookahead)) ADVANCE(166);
      END_STATE();
    case 165:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'x') ADVANCE(153);
      if (sym_identifier_character_set_3(lookahead)) ADVANCE(166);
      END_STATE();
    case 166:
      ACCEPT_TOKEN(sym_identifier);
      if (sym_identifier_character_set_3(lookahead)) ADVANCE(166);
      END_STATE();
    case 167:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(167);
      END_STATE();
    case 168:
      ACCEPT_TOKEN(sym_line_continuation);
      END_STATE();
    default:
      return false;
  }
}

static bool ts_lex_keywords(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ' ||
          lookahead == 8203 ||
          lookahead == 8288 ||
          lookahead == 65279) SKIP(0)
      if (lookahead == '\r') SKIP(0)
      if (lookahead == 'F') ADVANCE(1);
      if (lookahead == 'N') ADVANCE(2);
      if (lookahead == 'T') ADVANCE(3);
      if (lookahead == '_') ADVANCE(4);
      if (lookahead == 'a') ADVANCE(5);
      if (lookahead == 'b') ADVANCE(6);
      if (lookahead == 'c') ADVANCE(7);
      if (lookahead == 'd') ADVANCE(8);
      if (lookahead == 'e') ADVANCE(9);
      if (lookahead == 'f') ADVANCE(10);
      if (lookahead == 'g') ADVANCE(11);
      if (lookahead == 'i') ADVANCE(12);
      if (lookahead == 'l') ADVANCE(13);
      if (lookahead == 'm') ADVANCE(14);
      if (lookahead == 'n') ADVANCE(15);
      if (lookahead == 'o') ADVANCE(16);
      if (lookahead == 'p') ADVANCE(17);
      if (lookahead == 'r') ADVANCE(18);
      if (lookahead == 't') ADVANCE(19);
      if (lookahead == 'w') ADVANCE(20);
      if (lookahead == 'y') ADVANCE(21);
      END_STATE();
    case 1:
      if (lookahead == 'a') ADVANCE(22);
      END_STATE();
    case 2:
      if (lookahead == 'o') ADVANCE(23);
      END_STATE();
    case 3:
      if (lookahead == 'r') ADVANCE(24);
      END_STATE();
    case 4:
      ACCEPT_TOKEN(anon_sym__);
      if (lookahead == '_') ADVANCE(25);
      END_STATE();
    case 5:
      if (lookahead == 'n') ADVANCE(26);
      if (lookahead == 's') ADVANCE(27);
      if (lookahead == 'w') ADVANCE(28);
      END_STATE();
    case 6:
      if (lookahead == 'r') ADVANCE(29);
      END_STATE();
    case 7:
      if (lookahead == 'a') ADVANCE(30);
      if (lookahead == 'l') ADVANCE(31);
      if (lookahead == 'o') ADVANCE(32);
      END_STATE();
    case 8:
      if (lookahead == 'e') ADVANCE(33);
      END_STATE();
    case 9:
      if (lookahead == 'l') ADVANCE(34);
      if (lookahead == 'x') ADVANCE(35);
      END_STATE();
    case 10:
      if (lookahead == 'i') ADVANCE(36);
      if (lookahead == 'o') ADVANCE(37);
      if (lookahead == 'r') ADVANCE(38);
      END_STATE();
    case 11:
      if (lookahead == 'l') ADVANCE(39);
      END_STATE();
    case 12:
      if (lookahead == 'f') ADVANCE(40);
      if (lookahead == 'm') ADVANCE(41);
      if (lookahead == 'n') ADVANCE(42);
      if (lookahead == 's') ADVANCE(43);
      END_STATE();
    case 13:
      if (lookahead == 'a') ADVANCE(44);
      END_STATE();
    case 14:
      if (lookahead == 'a') ADVANCE(45);
      END_STATE();
    case 15:
      if (lookahead == 'o') ADVANCE(46);
      END_STATE();
    case 16:
      if (lookahead == 'r') ADVANCE(47);
      END_STATE();
    case 17:
      if (lookahead == 'a') ADVANCE(48);
      if (lookahead == 'r') ADVANCE(49);
      END_STATE();
    case 18:
      if (lookahead == 'a') ADVANCE(50);
      if (lookahead == 'e') ADVANCE(51);
      END_STATE();
    case 19:
      if (lookahead == 'r') ADVANCE(52);
      if (lookahead == 'y') ADVANCE(53);
      END_STATE();
    case 20:
      if (lookahead == 'h') ADVANCE(54);
      if (lookahead == 'i') ADVANCE(55);
      END_STATE();
    case 21:
      if (lookahead == 'i') ADVANCE(56);
      END_STATE();
    case 22:
      if (lookahead == 'l') ADVANCE(57);
      END_STATE();
    case 23:
      if (lookahead == 'n') ADVANCE(58);
      END_STATE();
    case 24:
      if (lookahead == 'u') ADVANCE(59);
      END_STATE();
    case 25:
      if (lookahead == 'f') ADVANCE(60);
      END_STATE();
    case 26:
      if (lookahead == 'd') ADVANCE(61);
      END_STATE();
    case 27:
      ACCEPT_TOKEN(anon_sym_as);
      if (lookahead == 's') ADVANCE(62);
      if (lookahead == 'y') ADVANCE(63);
      END_STATE();
    case 28:
      if (lookahead == 'a') ADVANCE(64);
      END_STATE();
    case 29:
      if (lookahead == 'e') ADVANCE(65);
      END_STATE();
    case 30:
      if (lookahead == 's') ADVANCE(66);
      END_STATE();
    case 31:
      if (lookahead == 'a') ADVANCE(67);
      END_STATE();
    case 32:
      if (lookahead == 'n') ADVANCE(68);
      END_STATE();
    case 33:
      if (lookahead == 'f') ADVANCE(69);
      if (lookahead == 'l') ADVANCE(70);
      END_STATE();
    case 34:
      if (lookahead == 'i') ADVANCE(71);
      if (lookahead == 's') ADVANCE(72);
      END_STATE();
    case 35:
      if (lookahead == 'e') ADVANCE(73);
      END_STATE();
    case 36:
      if (lookahead == 'n') ADVANCE(74);
      END_STATE();
    case 37:
      if (lookahead == 'r') ADVANCE(75);
      END_STATE();
    case 38:
      if (lookahead == 'o') ADVANCE(76);
      END_STATE();
    case 39:
      if (lookahead == 'o') ADVANCE(77);
      END_STATE();
    case 40:
      ACCEPT_TOKEN(anon_sym_if);
      END_STATE();
    case 41:
      if (lookahead == 'p') ADVANCE(78);
      END_STATE();
    case 42:
      ACCEPT_TOKEN(anon_sym_in);
      END_STATE();
    case 43:
      ACCEPT_TOKEN(anon_sym_is);
      END_STATE();
    case 44:
      if (lookahead == 'm') ADVANCE(79);
      END_STATE();
    case 45:
      if (lookahead == 't') ADVANCE(80);
      END_STATE();
    case 46:
      if (lookahead == 'n') ADVANCE(81);
      if (lookahead == 't') ADVANCE(82);
      END_STATE();
    case 47:
      ACCEPT_TOKEN(anon_sym_or);
      END_STATE();
    case 48:
      if (lookahead == 's') ADVANCE(83);
      END_STATE();
    case 49:
      if (lookahead == 'i') ADVANCE(84);
      END_STATE();
    case 50:
      if (lookahead == 'i') ADVANCE(85);
      END_STATE();
    case 51:
      if (lookahead == 't') ADVANCE(86);
      END_STATE();
    case 52:
      if (lookahead == 'y') ADVANCE(87);
      END_STATE();
    case 53:
      if (lookahead == 'p') ADVANCE(88);
      END_STATE();
    case 54:
      if (lookahead == 'i') ADVANCE(89);
      END_STATE();
    case 55:
      if (lookahead == 't') ADVANCE(90);
      END_STATE();
    case 56:
      if (lookahead == 'e') ADVANCE(91);
      END_STATE();
    case 57:
      if (lookahead == 's') ADVANCE(92);
      END_STATE();
    case 58:
      if (lookahead == 'e') ADVANCE(93);
      END_STATE();
    case 59:
      if (lookahead == 'e') ADVANCE(94);
      END_STATE();
    case 60:
      if (lookahead == 'u') ADVANCE(95);
      END_STATE();
    case 61:
      ACCEPT_TOKEN(anon_sym_and);
      END_STATE();
    case 62:
      if (lookahead == 'e') ADVANCE(96);
      END_STATE();
    case 63:
      if (lookahead == 'n') ADVANCE(97);
      END_STATE();
    case 64:
      if (lookahead == 'i') ADVANCE(98);
      END_STATE();
    case 65:
      if (lookahead == 'a') ADVANCE(99);
      END_STATE();
    case 66:
      if (lookahead == 'e') ADVANCE(100);
      END_STATE();
    case 67:
      if (lookahead == 's') ADVANCE(101);
      END_STATE();
    case 68:
      if (lookahead == 't') ADVANCE(102);
      END_STATE();
    case 69:
      ACCEPT_TOKEN(anon_sym_def);
      END_STATE();
    case 70:
      ACCEPT_TOKEN(anon_sym_del);
      END_STATE();
    case 71:
      if (lookahead == 'f') ADVANCE(103);
      END_STATE();
    case 72:
      if (lookahead == 'e') ADVANCE(104);
      END_STATE();
    case 73:
      if (lookahead == 'c') ADVANCE(105);
      END_STATE();
    case 74:
      if (lookahead == 'a') ADVANCE(106);
      END_STATE();
    case 75:
      ACCEPT_TOKEN(anon_sym_for);
      END_STATE();
    case 76:
      if (lookahead == 'm') ADVANCE(107);
      END_STATE();
    case 77:
      if (lookahead == 'b') ADVANCE(108);
      END_STATE();
    case 78:
      if (lookahead == 'o') ADVANCE(109);
      END_STATE();
    case 79:
      if (lookahead == 'b') ADVANCE(110);
      END_STATE();
    case 80:
      if (lookahead == 'c') ADVANCE(111);
      END_STATE();
    case 81:
      if (lookahead == 'l') ADVANCE(112);
      END_STATE();
    case 82:
      ACCEPT_TOKEN(anon_sym_not);
      END_STATE();
    case 83:
      if (lookahead == 's') ADVANCE(113);
      END_STATE();
    case 84:
      if (lookahead == 'n') ADVANCE(114);
      END_STATE();
    case 85:
      if (lookahead == 's') ADVANCE(115);
      END_STATE();
    case 86:
      if (lookahead == 'u') ADVANCE(116);
      END_STATE();
    case 87:
      ACCEPT_TOKEN(anon_sym_try);
      END_STATE();
    case 88:
      if (lookahead == 'e') ADVANCE(117);
      END_STATE();
    case 89:
      if (lookahead == 'l') ADVANCE(118);
      END_STATE();
    case 90:
      if (lookahead == 'h') ADVANCE(119);
      END_STATE();
    case 91:
      if (lookahead == 'l') ADVANCE(120);
      END_STATE();
    case 92:
      if (lookahead == 'e') ADVANCE(121);
      END_STATE();
    case 93:
      ACCEPT_TOKEN(sym_none);
      END_STATE();
    case 94:
      ACCEPT_TOKEN(sym_true);
      END_STATE();
    case 95:
      if (lookahead == 't') ADVANCE(122);
      END_STATE();
    case 96:
      if (lookahead == 'r') ADVANCE(123);
      END_STATE();
    case 97:
      if (lookahead == 'c') ADVANCE(124);
      END_STATE();
    case 98:
      if (lookahead == 't') ADVANCE(125);
      END_STATE();
    case 99:
      if (lookahead == 'k') ADVANCE(126);
      END_STATE();
    case 100:
      ACCEPT_TOKEN(anon_sym_case);
      END_STATE();
    case 101:
      if (lookahead == 's') ADVANCE(127);
      END_STATE();
    case 102:
      if (lookahead == 'i') ADVANCE(128);
      END_STATE();
    case 103:
      ACCEPT_TOKEN(anon_sym_elif);
      END_STATE();
    case 104:
      ACCEPT_TOKEN(anon_sym_else);
      END_STATE();
    case 105:
      ACCEPT_TOKEN(anon_sym_exec);
      END_STATE();
    case 106:
      if (lookahead == 'l') ADVANCE(129);
      END_STATE();
    case 107:
      ACCEPT_TOKEN(anon_sym_from);
      END_STATE();
    case 108:
      if (lookahead == 'a') ADVANCE(130);
      END_STATE();
    case 109:
      if (lookahead == 'r') ADVANCE(131);
      END_STATE();
    case 110:
      if (lookahead == 'd') ADVANCE(132);
      END_STATE();
    case 111:
      if (lookahead == 'h') ADVANCE(133);
      END_STATE();
    case 112:
      if (lookahead == 'o') ADVANCE(134);
      END_STATE();
    case 113:
      ACCEPT_TOKEN(anon_sym_pass);
      END_STATE();
    case 114:
      if (lookahead == 't') ADVANCE(135);
      END_STATE();
    case 115:
      if (lookahead == 'e') ADVANCE(136);
      END_STATE();
    case 116:
      if (lookahead == 'r') ADVANCE(137);
      END_STATE();
    case 117:
      ACCEPT_TOKEN(anon_sym_type);
      END_STATE();
    case 118:
      if (lookahead == 'e') ADVANCE(138);
      END_STATE();
    case 119:
      ACCEPT_TOKEN(anon_sym_with);
      END_STATE();
    case 120:
      if (lookahead == 'd') ADVANCE(139);
      END_STATE();
    case 121:
      ACCEPT_TOKEN(sym_false);
      END_STATE();
    case 122:
      if (lookahead == 'u') ADVANCE(140);
      END_STATE();
    case 123:
      if (lookahead == 't') ADVANCE(141);
      END_STATE();
    case 124:
      ACCEPT_TOKEN(anon_sym_async);
      END_STATE();
    case 125:
      ACCEPT_TOKEN(anon_sym_await);
      END_STATE();
    case 126:
      ACCEPT_TOKEN(anon_sym_break);
      END_STATE();
    case 127:
      ACCEPT_TOKEN(anon_sym_class);
      END_STATE();
    case 128:
      if (lookahead == 'n') ADVANCE(142);
      END_STATE();
    case 129:
      if (lookahead == 'l') ADVANCE(143);
      END_STATE();
    case 130:
      if (lookahead == 'l') ADVANCE(144);
      END_STATE();
    case 131:
      if (lookahead == 't') ADVANCE(145);
      END_STATE();
    case 132:
      if (lookahead == 'a') ADVANCE(146);
      END_STATE();
    case 133:
      ACCEPT_TOKEN(anon_sym_match);
      END_STATE();
    case 134:
      if (lookahead == 'c') ADVANCE(147);
      END_STATE();
    case 135:
      ACCEPT_TOKEN(anon_sym_print);
      END_STATE();
    case 136:
      ACCEPT_TOKEN(anon_sym_raise);
      END_STATE();
    case 137:
      if (lookahead == 'n') ADVANCE(148);
      END_STATE();
    case 138:
      ACCEPT_TOKEN(anon_sym_while);
      END_STATE();
    case 139:
      ACCEPT_TOKEN(anon_sym_yield);
      END_STATE();
    case 140:
      if (lookahead == 'r') ADVANCE(149);
      END_STATE();
    case 141:
      ACCEPT_TOKEN(anon_sym_assert);
      END_STATE();
    case 142:
      if (lookahead == 'u') ADVANCE(150);
      END_STATE();
    case 143:
      if (lookahead == 'y') ADVANCE(151);
      END_STATE();
    case 144:
      ACCEPT_TOKEN(anon_sym_global);
      END_STATE();
    case 145:
      ACCEPT_TOKEN(anon_sym_import);
      END_STATE();
    case 146:
      ACCEPT_TOKEN(anon_sym_lambda);
      END_STATE();
    case 147:
      if (lookahead == 'a') ADVANCE(152);
      END_STATE();
    case 148:
      ACCEPT_TOKEN(anon_sym_return);
      END_STATE();
    case 149:
      if (lookahead == 'e') ADVANCE(153);
      END_STATE();
    case 150:
      if (lookahead == 'e') ADVANCE(154);
      END_STATE();
    case 151:
      ACCEPT_TOKEN(anon_sym_finally);
      END_STATE();
    case 152:
      if (lookahead == 'l') ADVANCE(155);
      END_STATE();
    case 153:
      if (lookahead == '_') ADVANCE(156);
      END_STATE();
    case 154:
      ACCEPT_TOKEN(anon_sym_continue);
      END_STATE();
    case 155:
      ACCEPT_TOKEN(anon_sym_nonlocal);
      END_STATE();
    case 156:
      if (lookahead == '_') ADVANCE(157);
      END_STATE();
    case 157:
      ACCEPT_TOKEN(anon_sym___future__);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0, .external_lex_state = 1},
  [1] = {.lex_state = 54, .external_lex_state = 2},
  [2] = {.lex_state = 54, .external_lex_state = 3},
  [3] = {.lex_state = 54, .external_lex_state = 3},
  [4] = {.lex_state = 54, .external_lex_state = 3},
  [5] = {.lex_state = 54, .external_lex_state = 3},
  [6] = {.lex_state = 54, .external_lex_state = 3},
  [7] = {.lex_state = 54, .external_lex_state = 3},
  [8] = {.lex_state = 54, .external_lex_state = 3},
  [9] = {.lex_state = 54, .external_lex_state = 3},
  [10] = {.lex_state = 54, .external_lex_state = 3},
  [11] = {.lex_state = 54, .external_lex_state = 3},
  [12] = {.lex_state = 54, .external_lex_state = 3},
  [13] = {.lex_state = 54, .external_lex_state = 3},
  [14] = {.lex_state = 54, .external_lex_state = 3},
  [15] = {.lex_state = 54, .external_lex_state = 3},
  [16] = {.lex_state = 54, .external_lex_state = 3},
  [17] = {.lex_state = 54, .external_lex_state = 3},
  [18] = {.lex_state = 54, .external_lex_state = 3},
  [19] = {.lex_state = 54, .external_lex_state = 3},
  [20] = {.lex_state = 54, .external_lex_state = 3},
  [21] = {.lex_state = 54, .external_lex_state = 3},
  [22] = {.lex_state = 54, .external_lex_state = 3},
  [23] = {.lex_state = 54, .external_lex_state = 3},
  [24] = {.lex_state = 54, .external_lex_state = 3},
  [25] = {.lex_state = 54, .external_lex_state = 3},
  [26] = {.lex_state = 54, .external_lex_state = 3},
  [27] = {.lex_state = 54, .external_lex_state = 3},
  [28] = {.lex_state = 54, .external_lex_state = 3},
  [29] = {.lex_state = 54, .external_lex_state = 3},
  [30] = {.lex_state = 54, .external_lex_state = 3},
  [31] = {.lex_state = 54, .external_lex_state = 3},
  [32] = {.lex_state = 54, .external_lex_state = 3},
  [33] = {.lex_state = 54, .external_lex_state = 3},
  [34] = {.lex_state = 54, .external_lex_state = 3},
  [35] = {.lex_state = 54, .external_lex_state = 3},
  [36] = {.lex_state = 54, .external_lex_state = 3},
  [37] = {.lex_state = 54, .external_lex_state = 3},
  [38] = {.lex_state = 54, .external_lex_state = 3},
  [39] = {.lex_state = 54, .external_lex_state = 3},
  [40] = {.lex_state = 54, .external_lex_state = 3},
  [41] = {.lex_state = 54, .external_lex_state = 3},
  [42] = {.lex_state = 54, .external_lex_state = 3},
  [43] = {.lex_state = 54, .external_lex_state = 3},
  [44] = {.lex_state = 54, .external_lex_state = 3},
  [45] = {.lex_state = 54, .external_lex_state = 3},
  [46] = {.lex_state = 54, .external_lex_state = 3},
  [47] = {.lex_state = 54, .external_lex_state = 3},
  [48] = {.lex_state = 54, .external_lex_state = 3},
  [49] = {.lex_state = 54, .external_lex_state = 3},
  [50] = {.lex_state = 54, .external_lex_state = 3},
  [51] = {.lex_state = 54, .external_lex_state = 3},
  [52] = {.lex_state = 54, .external_lex_state = 3},
  [53] = {.lex_state = 54, .external_lex_state = 3},
  [54] = {.lex_state = 54, .external_lex_state = 3},
  [55] = {.lex_state = 54, .external_lex_state = 3},
  [56] = {.lex_state = 54, .external_lex_state = 3},
  [57] = {.lex_state = 54, .external_lex_state = 3},
  [58] = {.lex_state = 54, .external_lex_state = 3},
  [59] = {.lex_state = 54, .external_lex_state = 3},
  [60] = {.lex_state = 54, .external_lex_state = 3},
  [61] = {.lex_state = 54, .external_lex_state = 3},
  [62] = {.lex_state = 54, .external_lex_state = 3},
  [63] = {.lex_state = 54, .external_lex_state = 3},
  [64] = {.lex_state = 54, .external_lex_state = 2},
  [65] = {.lex_state = 54, .external_lex_state = 3},
  [66] = {.lex_state = 54, .external_lex_state = 3},
  [67] = {.lex_state = 54, .external_lex_state = 3},
  [68] = {.lex_state = 54, .external_lex_state = 3},
  [69] = {.lex_state = 54, .external_lex_state = 3},
  [70] = {.lex_state = 54, .external_lex_state = 2},
  [71] = {.lex_state = 54, .external_lex_state = 3},
  [72] = {.lex_state = 54, .external_lex_state = 3},
  [73] = {.lex_state = 29, .external_lex_state = 4},
  [74] = {.lex_state = 29, .external_lex_state = 4},
  [75] = {.lex_state = 30, .external_lex_state = 5},
  [76] = {.lex_state = 30, .external_lex_state = 5},
  [77] = {.lex_state = 30, .external_lex_state = 5},
  [78] = {.lex_state = 30, .external_lex_state = 5},
  [79] = {.lex_state = 30, .external_lex_state = 5},
  [80] = {.lex_state = 30, .external_lex_state = 5},
  [81] = {.lex_state = 30, .external_lex_state = 5},
  [82] = {.lex_state = 30, .external_lex_state = 5},
  [83] = {.lex_state = 29, .external_lex_state = 4},
  [84] = {.lex_state = 29, .external_lex_state = 4},
  [85] = {.lex_state = 29, .external_lex_state = 4},
  [86] = {.lex_state = 29, .external_lex_state = 4},
  [87] = {.lex_state = 54, .external_lex_state = 5},
  [88] = {.lex_state = 54, .external_lex_state = 5},
  [89] = {.lex_state = 54, .external_lex_state = 5},
  [90] = {.lex_state = 54, .external_lex_state = 5},
  [91] = {.lex_state = 54, .external_lex_state = 5},
  [92] = {.lex_state = 54, .external_lex_state = 5},
  [93] = {.lex_state = 54, .external_lex_state = 5},
  [94] = {.lex_state = 54, .external_lex_state = 5},
  [95] = {.lex_state = 54, .external_lex_state = 5},
  [96] = {.lex_state = 54, .external_lex_state = 5},
  [97] = {.lex_state = 54, .external_lex_state = 5},
  [98] = {.lex_state = 54, .external_lex_state = 5},
  [99] = {.lex_state = 54, .external_lex_state = 5},
  [100] = {.lex_state = 54, .external_lex_state = 5},
  [101] = {.lex_state = 54, .external_lex_state = 5},
  [102] = {.lex_state = 54, .external_lex_state = 5},
  [103] = {.lex_state = 54, .external_lex_state = 5},
  [104] = {.lex_state = 54, .external_lex_state = 5},
  [105] = {.lex_state = 54, .external_lex_state = 5},
  [106] = {.lex_state = 54, .external_lex_state = 5},
  [107] = {.lex_state = 54, .external_lex_state = 5},
  [108] = {.lex_state = 54, .external_lex_state = 5},
  [109] = {.lex_state = 54, .external_lex_state = 5},
  [110] = {.lex_state = 54, .external_lex_state = 5},
  [111] = {.lex_state = 54, .external_lex_state = 5},
  [112] = {.lex_state = 54, .external_lex_state = 5},
  [113] = {.lex_state = 54, .external_lex_state = 5},
  [114] = {.lex_state = 54, .external_lex_state = 5},
  [115] = {.lex_state = 54, .external_lex_state = 5},
  [116] = {.lex_state = 54, .external_lex_state = 5},
  [117] = {.lex_state = 54, .external_lex_state = 5},
  [118] = {.lex_state = 54, .external_lex_state = 5},
  [119] = {.lex_state = 54, .external_lex_state = 5},
  [120] = {.lex_state = 54, .external_lex_state = 5},
  [121] = {.lex_state = 54, .external_lex_state = 5},
  [122] = {.lex_state = 54, .external_lex_state = 5},
  [123] = {.lex_state = 54, .external_lex_state = 5},
  [124] = {.lex_state = 54, .external_lex_state = 5},
  [125] = {.lex_state = 54, .external_lex_state = 5},
  [126] = {.lex_state = 54, .external_lex_state = 5},
  [127] = {.lex_state = 54, .external_lex_state = 5},
  [128] = {.lex_state = 54, .external_lex_state = 5},
  [129] = {.lex_state = 54, .external_lex_state = 5},
  [130] = {.lex_state = 54, .external_lex_state = 5},
  [131] = {.lex_state = 54, .external_lex_state = 5},
  [132] = {.lex_state = 54, .external_lex_state = 5},
  [133] = {.lex_state = 54, .external_lex_state = 5},
  [134] = {.lex_state = 54, .external_lex_state = 5},
  [135] = {.lex_state = 54, .external_lex_state = 5},
  [136] = {.lex_state = 54, .external_lex_state = 5},
  [137] = {.lex_state = 54, .external_lex_state = 4},
  [138] = {.lex_state = 54, .external_lex_state = 4},
  [139] = {.lex_state = 54, .external_lex_state = 4},
  [140] = {.lex_state = 54, .external_lex_state = 4},
  [141] = {.lex_state = 54, .external_lex_state = 4},
  [142] = {.lex_state = 54, .external_lex_state = 4},
  [143] = {.lex_state = 54, .external_lex_state = 4},
  [144] = {.lex_state = 54, .external_lex_state = 4},
  [145] = {.lex_state = 54, .external_lex_state = 4},
  [146] = {.lex_state = 54, .external_lex_state = 4},
  [147] = {.lex_state = 54, .external_lex_state = 4},
  [148] = {.lex_state = 54, .external_lex_state = 4},
  [149] = {.lex_state = 54, .external_lex_state = 4},
  [150] = {.lex_state = 54, .external_lex_state = 4},
  [151] = {.lex_state = 54, .external_lex_state = 4},
  [152] = {.lex_state = 54, .external_lex_state = 4},
  [153] = {.lex_state = 54, .external_lex_state = 2},
  [154] = {.lex_state = 29, .external_lex_state = 4},
  [155] = {.lex_state = 29, .external_lex_state = 4},
  [156] = {.lex_state = 35, .external_lex_state = 4},
  [157] = {.lex_state = 30, .external_lex_state = 4},
  [158] = {.lex_state = 36, .external_lex_state = 4},
  [159] = {.lex_state = 30, .external_lex_state = 6},
  [160] = {.lex_state = 30, .external_lex_state = 6},
  [161] = {.lex_state = 36, .external_lex_state = 4},
  [162] = {.lex_state = 36, .external_lex_state = 6},
  [163] = {.lex_state = 30, .external_lex_state = 6},
  [164] = {.lex_state = 36, .external_lex_state = 7},
  [165] = {.lex_state = 30, .external_lex_state = 6},
  [166] = {.lex_state = 30, .external_lex_state = 7},
  [167] = {.lex_state = 30, .external_lex_state = 2},
  [168] = {.lex_state = 36, .external_lex_state = 6},
  [169] = {.lex_state = 30, .external_lex_state = 7},
  [170] = {.lex_state = 30, .external_lex_state = 8},
  [171] = {.lex_state = 30, .external_lex_state = 7},
  [172] = {.lex_state = 30, .external_lex_state = 8},
  [173] = {.lex_state = 30, .external_lex_state = 8},
  [174] = {.lex_state = 30, .external_lex_state = 7},
  [175] = {.lex_state = 36, .external_lex_state = 7},
  [176] = {.lex_state = 35, .external_lex_state = 4},
  [177] = {.lex_state = 36, .external_lex_state = 2},
  [178] = {.lex_state = 36, .external_lex_state = 6},
  [179] = {.lex_state = 30, .external_lex_state = 8},
  [180] = {.lex_state = 36, .external_lex_state = 8},
  [181] = {.lex_state = 36, .external_lex_state = 2},
  [182] = {.lex_state = 30, .external_lex_state = 7},
  [183] = {.lex_state = 30, .external_lex_state = 7},
  [184] = {.lex_state = 36, .external_lex_state = 8},
  [185] = {.lex_state = 30, .external_lex_state = 7},
  [186] = {.lex_state = 30, .external_lex_state = 8},
  [187] = {.lex_state = 35, .external_lex_state = 2},
  [188] = {.lex_state = 35, .external_lex_state = 2},
  [189] = {.lex_state = 54, .external_lex_state = 8},
  [190] = {.lex_state = 54, .external_lex_state = 7},
  [191] = {.lex_state = 54, .external_lex_state = 7},
  [192] = {.lex_state = 54, .external_lex_state = 2},
  [193] = {.lex_state = 54, .external_lex_state = 7},
  [194] = {.lex_state = 54, .external_lex_state = 8},
  [195] = {.lex_state = 30, .external_lex_state = 6},
  [196] = {.lex_state = 54, .external_lex_state = 8},
  [197] = {.lex_state = 30, .external_lex_state = 6},
  [198] = {.lex_state = 30, .external_lex_state = 6},
  [199] = {.lex_state = 54, .external_lex_state = 8},
  [200] = {.lex_state = 30, .external_lex_state = 6},
  [201] = {.lex_state = 54, .external_lex_state = 7},
  [202] = {.lex_state = 54, .external_lex_state = 8},
  [203] = {.lex_state = 54, .external_lex_state = 8},
  [204] = {.lex_state = 30, .external_lex_state = 6},
  [205] = {.lex_state = 30, .external_lex_state = 6},
  [206] = {.lex_state = 54, .external_lex_state = 8},
  [207] = {.lex_state = 54, .external_lex_state = 7},
  [208] = {.lex_state = 54, .external_lex_state = 7},
  [209] = {.lex_state = 54, .external_lex_state = 8},
  [210] = {.lex_state = 54, .external_lex_state = 7},
  [211] = {.lex_state = 54, .external_lex_state = 8},
  [212] = {.lex_state = 30, .external_lex_state = 6},
  [213] = {.lex_state = 54, .external_lex_state = 7},
  [214] = {.lex_state = 54, .external_lex_state = 8},
  [215] = {.lex_state = 54, .external_lex_state = 7},
  [216] = {.lex_state = 54, .external_lex_state = 2},
  [217] = {.lex_state = 54, .external_lex_state = 7},
  [218] = {.lex_state = 30, .external_lex_state = 6},
  [219] = {.lex_state = 54, .external_lex_state = 8},
  [220] = {.lex_state = 54, .external_lex_state = 7},
  [221] = {.lex_state = 54, .external_lex_state = 2},
  [222] = {.lex_state = 31, .external_lex_state = 4},
  [223] = {.lex_state = 31, .external_lex_state = 4},
  [224] = {.lex_state = 30, .external_lex_state = 8},
  [225] = {.lex_state = 30, .external_lex_state = 8},
  [226] = {.lex_state = 30, .external_lex_state = 8},
  [227] = {.lex_state = 54, .external_lex_state = 2},
  [228] = {.lex_state = 54, .external_lex_state = 2},
  [229] = {.lex_state = 30, .external_lex_state = 8},
  [230] = {.lex_state = 30, .external_lex_state = 8},
  [231] = {.lex_state = 30, .external_lex_state = 8},
  [232] = {.lex_state = 30, .external_lex_state = 8},
  [233] = {.lex_state = 30, .external_lex_state = 8},
  [234] = {.lex_state = 30, .external_lex_state = 2},
  [235] = {.lex_state = 30, .external_lex_state = 2},
  [236] = {.lex_state = 30, .external_lex_state = 7},
  [237] = {.lex_state = 30, .external_lex_state = 2},
  [238] = {.lex_state = 30, .external_lex_state = 7},
  [239] = {.lex_state = 30, .external_lex_state = 2},
  [240] = {.lex_state = 30, .external_lex_state = 7},
  [241] = {.lex_state = 30, .external_lex_state = 2},
  [242] = {.lex_state = 30, .external_lex_state = 2},
  [243] = {.lex_state = 30, .external_lex_state = 2},
  [244] = {.lex_state = 30, .external_lex_state = 2},
  [245] = {.lex_state = 30, .external_lex_state = 2},
  [246] = {.lex_state = 30, .external_lex_state = 2},
  [247] = {.lex_state = 30, .external_lex_state = 7},
  [248] = {.lex_state = 30, .external_lex_state = 7},
  [249] = {.lex_state = 30, .external_lex_state = 7},
  [250] = {.lex_state = 30, .external_lex_state = 7},
  [251] = {.lex_state = 31, .external_lex_state = 2},
  [252] = {.lex_state = 30, .external_lex_state = 2},
  [253] = {.lex_state = 54, .external_lex_state = 6},
  [254] = {.lex_state = 31, .external_lex_state = 2},
  [255] = {.lex_state = 30, .external_lex_state = 2},
  [256] = {.lex_state = 54, .external_lex_state = 7},
  [257] = {.lex_state = 30, .external_lex_state = 7},
  [258] = {.lex_state = 30, .external_lex_state = 2},
  [259] = {.lex_state = 30, .external_lex_state = 2},
  [260] = {.lex_state = 30, .external_lex_state = 2},
  [261] = {.lex_state = 30, .external_lex_state = 2},
  [262] = {.lex_state = 30, .external_lex_state = 2},
  [263] = {.lex_state = 30, .external_lex_state = 2},
  [264] = {.lex_state = 30, .external_lex_state = 2},
  [265] = {.lex_state = 30, .external_lex_state = 2},
  [266] = {.lex_state = 30, .external_lex_state = 2},
  [267] = {.lex_state = 30, .external_lex_state = 2},
  [268] = {.lex_state = 30, .external_lex_state = 2},
  [269] = {.lex_state = 30, .external_lex_state = 2},
  [270] = {.lex_state = 30, .external_lex_state = 2},
  [271] = {.lex_state = 30, .external_lex_state = 7},
  [272] = {.lex_state = 30, .external_lex_state = 7},
  [273] = {.lex_state = 30, .external_lex_state = 7},
  [274] = {.lex_state = 30, .external_lex_state = 7},
  [275] = {.lex_state = 30, .external_lex_state = 7},
  [276] = {.lex_state = 30, .external_lex_state = 7},
  [277] = {.lex_state = 54, .external_lex_state = 8},
  [278] = {.lex_state = 54, .external_lex_state = 7},
  [279] = {.lex_state = 54, .external_lex_state = 7},
  [280] = {.lex_state = 54, .external_lex_state = 7},
  [281] = {.lex_state = 30, .external_lex_state = 7},
  [282] = {.lex_state = 30, .external_lex_state = 7},
  [283] = {.lex_state = 30, .external_lex_state = 7},
  [284] = {.lex_state = 30, .external_lex_state = 7},
  [285] = {.lex_state = 30, .external_lex_state = 7},
  [286] = {.lex_state = 54, .external_lex_state = 8},
  [287] = {.lex_state = 30, .external_lex_state = 7},
  [288] = {.lex_state = 54, .external_lex_state = 7},
  [289] = {.lex_state = 30, .external_lex_state = 7},
  [290] = {.lex_state = 54, .external_lex_state = 8},
  [291] = {.lex_state = 30, .external_lex_state = 7},
  [292] = {.lex_state = 54, .external_lex_state = 7},
  [293] = {.lex_state = 54, .external_lex_state = 7},
  [294] = {.lex_state = 54, .external_lex_state = 8},
  [295] = {.lex_state = 30, .external_lex_state = 7},
  [296] = {.lex_state = 54, .external_lex_state = 7},
  [297] = {.lex_state = 30, .external_lex_state = 7},
  [298] = {.lex_state = 54, .external_lex_state = 7},
  [299] = {.lex_state = 54, .external_lex_state = 8},
  [300] = {.lex_state = 54, .external_lex_state = 7},
  [301] = {.lex_state = 30, .external_lex_state = 7},
  [302] = {.lex_state = 30, .external_lex_state = 7},
  [303] = {.lex_state = 30, .external_lex_state = 7},
  [304] = {.lex_state = 30, .external_lex_state = 7},
  [305] = {.lex_state = 30, .external_lex_state = 7},
  [306] = {.lex_state = 30, .external_lex_state = 7},
  [307] = {.lex_state = 54, .external_lex_state = 7},
  [308] = {.lex_state = 30, .external_lex_state = 7},
  [309] = {.lex_state = 30, .external_lex_state = 7},
  [310] = {.lex_state = 30, .external_lex_state = 7},
  [311] = {.lex_state = 30, .external_lex_state = 7},
  [312] = {.lex_state = 30, .external_lex_state = 7},
  [313] = {.lex_state = 54, .external_lex_state = 7},
  [314] = {.lex_state = 30, .external_lex_state = 7},
  [315] = {.lex_state = 30, .external_lex_state = 7},
  [316] = {.lex_state = 54, .external_lex_state = 7},
  [317] = {.lex_state = 54, .external_lex_state = 8},
  [318] = {.lex_state = 54, .external_lex_state = 8},
  [319] = {.lex_state = 30, .external_lex_state = 7},
  [320] = {.lex_state = 54, .external_lex_state = 8},
  [321] = {.lex_state = 30, .external_lex_state = 7},
  [322] = {.lex_state = 30, .external_lex_state = 7},
  [323] = {.lex_state = 54, .external_lex_state = 7},
  [324] = {.lex_state = 54, .external_lex_state = 7},
  [325] = {.lex_state = 30, .external_lex_state = 7},
  [326] = {.lex_state = 54, .external_lex_state = 8},
  [327] = {.lex_state = 54, .external_lex_state = 6},
  [328] = {.lex_state = 36, .external_lex_state = 6},
  [329] = {.lex_state = 30, .external_lex_state = 2},
  [330] = {.lex_state = 54, .external_lex_state = 7},
  [331] = {.lex_state = 54, .external_lex_state = 7},
  [332] = {.lex_state = 54, .external_lex_state = 7},
  [333] = {.lex_state = 54, .external_lex_state = 7},
  [334] = {.lex_state = 54, .external_lex_state = 6},
  [335] = {.lex_state = 54, .external_lex_state = 6},
  [336] = {.lex_state = 54, .external_lex_state = 6},
  [337] = {.lex_state = 54, .external_lex_state = 6},
  [338] = {.lex_state = 54, .external_lex_state = 6},
  [339] = {.lex_state = 54, .external_lex_state = 7},
  [340] = {.lex_state = 54, .external_lex_state = 8},
  [341] = {.lex_state = 54, .external_lex_state = 8},
  [342] = {.lex_state = 54, .external_lex_state = 7},
  [343] = {.lex_state = 54, .external_lex_state = 6},
  [344] = {.lex_state = 54, .external_lex_state = 8},
  [345] = {.lex_state = 54, .external_lex_state = 8},
  [346] = {.lex_state = 54, .external_lex_state = 6},
  [347] = {.lex_state = 54, .external_lex_state = 8},
  [348] = {.lex_state = 30, .external_lex_state = 6},
  [349] = {.lex_state = 30, .external_lex_state = 6},
  [350] = {.lex_state = 54, .external_lex_state = 4},
  [351] = {.lex_state = 54, .external_lex_state = 7},
  [352] = {.lex_state = 30, .external_lex_state = 6},
  [353] = {.lex_state = 54, .external_lex_state = 4},
  [354] = {.lex_state = 30, .external_lex_state = 6},
  [355] = {.lex_state = 30, .external_lex_state = 6},
  [356] = {.lex_state = 54, .external_lex_state = 2},
  [357] = {.lex_state = 30, .external_lex_state = 6},
  [358] = {.lex_state = 30, .external_lex_state = 6},
  [359] = {.lex_state = 30, .external_lex_state = 6},
  [360] = {.lex_state = 30, .external_lex_state = 6},
  [361] = {.lex_state = 30, .external_lex_state = 6},
  [362] = {.lex_state = 30, .external_lex_state = 6},
  [363] = {.lex_state = 30, .external_lex_state = 6},
  [364] = {.lex_state = 54, .external_lex_state = 2},
  [365] = {.lex_state = 54, .external_lex_state = 2},
  [366] = {.lex_state = 30, .external_lex_state = 6},
  [367] = {.lex_state = 30, .external_lex_state = 6},
  [368] = {.lex_state = 54, .external_lex_state = 8},
  [369] = {.lex_state = 30, .external_lex_state = 6},
  [370] = {.lex_state = 30, .external_lex_state = 6},
  [371] = {.lex_state = 36, .external_lex_state = 7},
  [372] = {.lex_state = 54, .external_lex_state = 8},
  [373] = {.lex_state = 54, .external_lex_state = 8},
  [374] = {.lex_state = 54, .external_lex_state = 8},
  [375] = {.lex_state = 54, .external_lex_state = 8},
  [376] = {.lex_state = 54, .external_lex_state = 8},
  [377] = {.lex_state = 54, .external_lex_state = 8},
  [378] = {.lex_state = 54, .external_lex_state = 8},
  [379] = {.lex_state = 54, .external_lex_state = 4},
  [380] = {.lex_state = 54, .external_lex_state = 8},
  [381] = {.lex_state = 54, .external_lex_state = 8},
  [382] = {.lex_state = 54, .external_lex_state = 4},
  [383] = {.lex_state = 54, .external_lex_state = 8},
  [384] = {.lex_state = 54, .external_lex_state = 8},
  [385] = {.lex_state = 54, .external_lex_state = 4},
  [386] = {.lex_state = 54, .external_lex_state = 8},
  [387] = {.lex_state = 30, .external_lex_state = 2},
  [388] = {.lex_state = 54, .external_lex_state = 8},
  [389] = {.lex_state = 54, .external_lex_state = 8},
  [390] = {.lex_state = 54, .external_lex_state = 8},
  [391] = {.lex_state = 54, .external_lex_state = 8},
  [392] = {.lex_state = 54, .external_lex_state = 8},
  [393] = {.lex_state = 54, .external_lex_state = 8},
  [394] = {.lex_state = 54, .external_lex_state = 8},
  [395] = {.lex_state = 54, .external_lex_state = 8},
  [396] = {.lex_state = 54, .external_lex_state = 8},
  [397] = {.lex_state = 54, .external_lex_state = 8},
  [398] = {.lex_state = 54, .external_lex_state = 8},
  [399] = {.lex_state = 54, .external_lex_state = 8},
  [400] = {.lex_state = 54, .external_lex_state = 8},
  [401] = {.lex_state = 36, .external_lex_state = 7},
  [402] = {.lex_state = 54, .external_lex_state = 8},
  [403] = {.lex_state = 54, .external_lex_state = 8},
  [404] = {.lex_state = 54, .external_lex_state = 8},
  [405] = {.lex_state = 54, .external_lex_state = 8},
  [406] = {.lex_state = 54, .external_lex_state = 8},
  [407] = {.lex_state = 54, .external_lex_state = 8},
  [408] = {.lex_state = 54, .external_lex_state = 8},
  [409] = {.lex_state = 30, .external_lex_state = 7},
  [410] = {.lex_state = 54, .external_lex_state = 2},
  [411] = {.lex_state = 54, .external_lex_state = 2},
  [412] = {.lex_state = 54, .external_lex_state = 7},
  [413] = {.lex_state = 30, .external_lex_state = 2},
  [414] = {.lex_state = 54, .external_lex_state = 2},
  [415] = {.lex_state = 54, .external_lex_state = 2},
  [416] = {.lex_state = 54, .external_lex_state = 2},
  [417] = {.lex_state = 54, .external_lex_state = 2},
  [418] = {.lex_state = 54, .external_lex_state = 2},
  [419] = {.lex_state = 54, .external_lex_state = 2},
  [420] = {.lex_state = 54, .external_lex_state = 2},
  [421] = {.lex_state = 54, .external_lex_state = 8},
  [422] = {.lex_state = 54, .external_lex_state = 2},
  [423] = {.lex_state = 54, .external_lex_state = 2},
  [424] = {.lex_state = 54, .external_lex_state = 2},
  [425] = {.lex_state = 54, .external_lex_state = 7},
  [426] = {.lex_state = 54, .external_lex_state = 2},
  [427] = {.lex_state = 54, .external_lex_state = 2},
  [428] = {.lex_state = 54, .external_lex_state = 8},
  [429] = {.lex_state = 54, .external_lex_state = 2},
  [430] = {.lex_state = 54, .external_lex_state = 2},
  [431] = {.lex_state = 54, .external_lex_state = 7},
  [432] = {.lex_state = 54, .external_lex_state = 2},
  [433] = {.lex_state = 54, .external_lex_state = 8},
  [434] = {.lex_state = 54, .external_lex_state = 2},
  [435] = {.lex_state = 54, .external_lex_state = 2},
  [436] = {.lex_state = 54, .external_lex_state = 2},
  [437] = {.lex_state = 54, .external_lex_state = 2},
  [438] = {.lex_state = 54, .external_lex_state = 8},
  [439] = {.lex_state = 54, .external_lex_state = 2},
  [440] = {.lex_state = 54, .external_lex_state = 8},
  [441] = {.lex_state = 54, .external_lex_state = 2},
  [442] = {.lex_state = 54, .external_lex_state = 2},
  [443] = {.lex_state = 54, .external_lex_state = 2},
  [444] = {.lex_state = 54, .external_lex_state = 2},
  [445] = {.lex_state = 30, .external_lex_state = 8},
  [446] = {.lex_state = 54, .external_lex_state = 2},
  [447] = {.lex_state = 36, .external_lex_state = 2},
  [448] = {.lex_state = 54, .external_lex_state = 4},
  [449] = {.lex_state = 54, .external_lex_state = 2},
  [450] = {.lex_state = 54, .external_lex_state = 4},
  [451] = {.lex_state = 54, .external_lex_state = 2},
  [452] = {.lex_state = 54, .external_lex_state = 4},
  [453] = {.lex_state = 54, .external_lex_state = 2},
  [454] = {.lex_state = 54, .external_lex_state = 4},
  [455] = {.lex_state = 54, .external_lex_state = 4},
  [456] = {.lex_state = 36, .external_lex_state = 2},
  [457] = {.lex_state = 54, .external_lex_state = 7},
  [458] = {.lex_state = 54, .external_lex_state = 2},
  [459] = {.lex_state = 54, .external_lex_state = 4},
  [460] = {.lex_state = 54, .external_lex_state = 2},
  [461] = {.lex_state = 54, .external_lex_state = 2},
  [462] = {.lex_state = 54, .external_lex_state = 2},
  [463] = {.lex_state = 32, .external_lex_state = 4},
  [464] = {.lex_state = 54, .external_lex_state = 2},
  [465] = {.lex_state = 54, .external_lex_state = 2},
  [466] = {.lex_state = 54, .external_lex_state = 2},
  [467] = {.lex_state = 54, .external_lex_state = 2},
  [468] = {.lex_state = 54, .external_lex_state = 2},
  [469] = {.lex_state = 54, .external_lex_state = 2},
  [470] = {.lex_state = 32, .external_lex_state = 4},
  [471] = {.lex_state = 54, .external_lex_state = 2},
  [472] = {.lex_state = 54, .external_lex_state = 2},
  [473] = {.lex_state = 54, .external_lex_state = 2},
  [474] = {.lex_state = 32, .external_lex_state = 9},
  [475] = {.lex_state = 54, .external_lex_state = 2},
  [476] = {.lex_state = 32, .external_lex_state = 9},
  [477] = {.lex_state = 54, .external_lex_state = 2},
  [478] = {.lex_state = 54, .external_lex_state = 2},
  [479] = {.lex_state = 54, .external_lex_state = 2},
  [480] = {.lex_state = 54, .external_lex_state = 2},
  [481] = {.lex_state = 54, .external_lex_state = 2},
  [482] = {.lex_state = 54, .external_lex_state = 2},
  [483] = {.lex_state = 54, .external_lex_state = 2},
  [484] = {.lex_state = 54, .external_lex_state = 2},
  [485] = {.lex_state = 54, .external_lex_state = 2},
  [486] = {.lex_state = 54, .external_lex_state = 2},
  [487] = {.lex_state = 54, .external_lex_state = 2},
  [488] = {.lex_state = 54, .external_lex_state = 2},
  [489] = {.lex_state = 54, .external_lex_state = 2},
  [490] = {.lex_state = 54, .external_lex_state = 2},
  [491] = {.lex_state = 54, .external_lex_state = 2},
  [492] = {.lex_state = 55, .external_lex_state = 3},
  [493] = {.lex_state = 56, .external_lex_state = 10},
  [494] = {.lex_state = 54, .external_lex_state = 2},
  [495] = {.lex_state = 54, .external_lex_state = 2},
  [496] = {.lex_state = 54, .external_lex_state = 2},
  [497] = {.lex_state = 55, .external_lex_state = 3},
  [498] = {.lex_state = 56, .external_lex_state = 10},
  [499] = {.lex_state = 54, .external_lex_state = 2},
  [500] = {.lex_state = 54, .external_lex_state = 2},
  [501] = {.lex_state = 54, .external_lex_state = 2},
  [502] = {.lex_state = 54, .external_lex_state = 2},
  [503] = {.lex_state = 54, .external_lex_state = 2},
  [504] = {.lex_state = 54, .external_lex_state = 2},
  [505] = {.lex_state = 54, .external_lex_state = 2},
  [506] = {.lex_state = 54, .external_lex_state = 2},
  [507] = {.lex_state = 54, .external_lex_state = 2},
  [508] = {.lex_state = 54, .external_lex_state = 2},
  [509] = {.lex_state = 54, .external_lex_state = 2},
  [510] = {.lex_state = 54, .external_lex_state = 2},
  [511] = {.lex_state = 54, .external_lex_state = 2},
  [512] = {.lex_state = 54, .external_lex_state = 2},
  [513] = {.lex_state = 54, .external_lex_state = 2},
  [514] = {.lex_state = 54, .external_lex_state = 2},
  [515] = {.lex_state = 54, .external_lex_state = 2},
  [516] = {.lex_state = 54, .external_lex_state = 2},
  [517] = {.lex_state = 54, .external_lex_state = 2},
  [518] = {.lex_state = 54, .external_lex_state = 2},
  [519] = {.lex_state = 54, .external_lex_state = 2},
  [520] = {.lex_state = 54, .external_lex_state = 2},
  [521] = {.lex_state = 54, .external_lex_state = 2},
  [522] = {.lex_state = 54, .external_lex_state = 2},
  [523] = {.lex_state = 54, .external_lex_state = 2},
  [524] = {.lex_state = 54, .external_lex_state = 2},
  [525] = {.lex_state = 54, .external_lex_state = 2},
  [526] = {.lex_state = 54, .external_lex_state = 2},
  [527] = {.lex_state = 56, .external_lex_state = 11},
  [528] = {.lex_state = 55, .external_lex_state = 2},
  [529] = {.lex_state = 54, .external_lex_state = 2},
  [530] = {.lex_state = 54, .external_lex_state = 2},
  [531] = {.lex_state = 54, .external_lex_state = 2},
  [532] = {.lex_state = 54, .external_lex_state = 2},
  [533] = {.lex_state = 54, .external_lex_state = 2},
  [534] = {.lex_state = 54, .external_lex_state = 2},
  [535] = {.lex_state = 54, .external_lex_state = 2},
  [536] = {.lex_state = 54, .external_lex_state = 2},
  [537] = {.lex_state = 54, .external_lex_state = 2},
  [538] = {.lex_state = 54, .external_lex_state = 2},
  [539] = {.lex_state = 54, .external_lex_state = 2},
  [540] = {.lex_state = 54, .external_lex_state = 2},
  [541] = {.lex_state = 54, .external_lex_state = 2},
  [542] = {.lex_state = 54, .external_lex_state = 2},
  [543] = {.lex_state = 54, .external_lex_state = 2},
  [544] = {.lex_state = 54, .external_lex_state = 2},
  [545] = {.lex_state = 54, .external_lex_state = 2},
  [546] = {.lex_state = 54, .external_lex_state = 2},
  [547] = {.lex_state = 54, .external_lex_state = 2},
  [548] = {.lex_state = 54, .external_lex_state = 2},
  [549] = {.lex_state = 54, .external_lex_state = 2},
  [550] = {.lex_state = 54, .external_lex_state = 2},
  [551] = {.lex_state = 54, .external_lex_state = 2},
  [552] = {.lex_state = 54, .external_lex_state = 2},
  [553] = {.lex_state = 54, .external_lex_state = 2},
  [554] = {.lex_state = 54, .external_lex_state = 2},
  [555] = {.lex_state = 54, .external_lex_state = 2},
  [556] = {.lex_state = 54, .external_lex_state = 2},
  [557] = {.lex_state = 54, .external_lex_state = 2},
  [558] = {.lex_state = 54, .external_lex_state = 2},
  [559] = {.lex_state = 54, .external_lex_state = 2},
  [560] = {.lex_state = 54, .external_lex_state = 2},
  [561] = {.lex_state = 54, .external_lex_state = 2},
  [562] = {.lex_state = 54, .external_lex_state = 2},
  [563] = {.lex_state = 54, .external_lex_state = 2},
  [564] = {.lex_state = 54, .external_lex_state = 2},
  [565] = {.lex_state = 54, .external_lex_state = 2},
  [566] = {.lex_state = 54, .external_lex_state = 2},
  [567] = {.lex_state = 54, .external_lex_state = 2},
  [568] = {.lex_state = 54, .external_lex_state = 2},
  [569] = {.lex_state = 54, .external_lex_state = 2},
  [570] = {.lex_state = 54, .external_lex_state = 2},
  [571] = {.lex_state = 54, .external_lex_state = 2},
  [572] = {.lex_state = 54, .external_lex_state = 2},
  [573] = {.lex_state = 54, .external_lex_state = 2},
  [574] = {.lex_state = 54, .external_lex_state = 2},
  [575] = {.lex_state = 54, .external_lex_state = 2},
  [576] = {.lex_state = 54, .external_lex_state = 2},
  [577] = {.lex_state = 54, .external_lex_state = 2},
  [578] = {.lex_state = 54, .external_lex_state = 2},
  [579] = {.lex_state = 54, .external_lex_state = 2},
  [580] = {.lex_state = 54, .external_lex_state = 2},
  [581] = {.lex_state = 54, .external_lex_state = 2},
  [582] = {.lex_state = 54, .external_lex_state = 2},
  [583] = {.lex_state = 54, .external_lex_state = 2},
  [584] = {.lex_state = 54, .external_lex_state = 2},
  [585] = {.lex_state = 54, .external_lex_state = 2},
  [586] = {.lex_state = 54, .external_lex_state = 2},
  [587] = {.lex_state = 54, .external_lex_state = 2},
  [588] = {.lex_state = 54, .external_lex_state = 2},
  [589] = {.lex_state = 54, .external_lex_state = 2},
  [590] = {.lex_state = 54, .external_lex_state = 2},
  [591] = {.lex_state = 54, .external_lex_state = 2},
  [592] = {.lex_state = 55, .external_lex_state = 2},
  [593] = {.lex_state = 56, .external_lex_state = 11},
  [594] = {.lex_state = 54, .external_lex_state = 2},
  [595] = {.lex_state = 54, .external_lex_state = 2},
  [596] = {.lex_state = 54, .external_lex_state = 2},
  [597] = {.lex_state = 54, .external_lex_state = 2},
  [598] = {.lex_state = 54, .external_lex_state = 2},
  [599] = {.lex_state = 54, .external_lex_state = 2},
  [600] = {.lex_state = 54, .external_lex_state = 2},
  [601] = {.lex_state = 54, .external_lex_state = 2},
  [602] = {.lex_state = 54, .external_lex_state = 2},
  [603] = {.lex_state = 54, .external_lex_state = 2},
  [604] = {.lex_state = 54, .external_lex_state = 2},
  [605] = {.lex_state = 54, .external_lex_state = 2},
  [606] = {.lex_state = 54, .external_lex_state = 2},
  [607] = {.lex_state = 54, .external_lex_state = 2},
  [608] = {.lex_state = 54, .external_lex_state = 2},
  [609] = {.lex_state = 32, .external_lex_state = 9},
  [610] = {.lex_state = 54, .external_lex_state = 2},
  [611] = {.lex_state = 56, .external_lex_state = 10},
  [612] = {.lex_state = 54, .external_lex_state = 3},
  [613] = {.lex_state = 54, .external_lex_state = 3},
  [614] = {.lex_state = 54, .external_lex_state = 2},
  [615] = {.lex_state = 54, .external_lex_state = 3},
  [616] = {.lex_state = 54, .external_lex_state = 2},
  [617] = {.lex_state = 54, .external_lex_state = 3},
  [618] = {.lex_state = 54, .external_lex_state = 2},
  [619] = {.lex_state = 32, .external_lex_state = 9},
  [620] = {.lex_state = 55, .external_lex_state = 3},
  [621] = {.lex_state = 32, .external_lex_state = 9},
  [622] = {.lex_state = 32, .external_lex_state = 9},
  [623] = {.lex_state = 32, .external_lex_state = 9},
  [624] = {.lex_state = 56, .external_lex_state = 11},
  [625] = {.lex_state = 55, .external_lex_state = 2},
  [626] = {.lex_state = 33, .external_lex_state = 9},
  [627] = {.lex_state = 33, .external_lex_state = 9},
  [628] = {.lex_state = 33, .external_lex_state = 9},
  [629] = {.lex_state = 33, .external_lex_state = 9},
  [630] = {.lex_state = 33, .external_lex_state = 9},
  [631] = {.lex_state = 33, .external_lex_state = 9},
  [632] = {.lex_state = 33, .external_lex_state = 9},
  [633] = {.lex_state = 33, .external_lex_state = 9},
  [634] = {.lex_state = 54, .external_lex_state = 3},
  [635] = {.lex_state = 33, .external_lex_state = 9},
  [636] = {.lex_state = 33, .external_lex_state = 9},
  [637] = {.lex_state = 33, .external_lex_state = 9},
  [638] = {.lex_state = 33, .external_lex_state = 9},
  [639] = {.lex_state = 33, .external_lex_state = 9},
  [640] = {.lex_state = 33, .external_lex_state = 9},
  [641] = {.lex_state = 33, .external_lex_state = 9},
  [642] = {.lex_state = 33, .external_lex_state = 9},
  [643] = {.lex_state = 33, .external_lex_state = 9},
  [644] = {.lex_state = 54, .external_lex_state = 2},
  [645] = {.lex_state = 33, .external_lex_state = 9},
  [646] = {.lex_state = 33, .external_lex_state = 9},
  [647] = {.lex_state = 54, .external_lex_state = 3},
  [648] = {.lex_state = 55, .external_lex_state = 3},
  [649] = {.lex_state = 55, .external_lex_state = 2},
  [650] = {.lex_state = 54, .external_lex_state = 2},
  [651] = {.lex_state = 56, .external_lex_state = 11},
  [652] = {.lex_state = 54, .external_lex_state = 2},
  [653] = {.lex_state = 56, .external_lex_state = 10},
  [654] = {.lex_state = 56, .external_lex_state = 10},
  [655] = {.lex_state = 56, .external_lex_state = 10},
  [656] = {.lex_state = 54, .external_lex_state = 2},
  [657] = {.lex_state = 55, .external_lex_state = 3},
  [658] = {.lex_state = 55, .external_lex_state = 3},
  [659] = {.lex_state = 56, .external_lex_state = 11},
  [660] = {.lex_state = 55, .external_lex_state = 3},
  [661] = {.lex_state = 56, .external_lex_state = 10},
  [662] = {.lex_state = 56, .external_lex_state = 10},
  [663] = {.lex_state = 55, .external_lex_state = 3},
  [664] = {.lex_state = 55, .external_lex_state = 3},
  [665] = {.lex_state = 55, .external_lex_state = 3},
  [666] = {.lex_state = 56, .external_lex_state = 10},
  [667] = {.lex_state = 56, .external_lex_state = 10},
  [668] = {.lex_state = 56, .external_lex_state = 10},
  [669] = {.lex_state = 55, .external_lex_state = 3},
  [670] = {.lex_state = 56, .external_lex_state = 10},
  [671] = {.lex_state = 56, .external_lex_state = 10},
  [672] = {.lex_state = 55, .external_lex_state = 2},
  [673] = {.lex_state = 56, .external_lex_state = 10},
  [674] = {.lex_state = 55, .external_lex_state = 3},
  [675] = {.lex_state = 56, .external_lex_state = 11},
  [676] = {.lex_state = 54, .external_lex_state = 3},
  [677] = {.lex_state = 54, .external_lex_state = 6},
  [678] = {.lex_state = 55, .external_lex_state = 2},
  [679] = {.lex_state = 54, .external_lex_state = 6},
  [680] = {.lex_state = 56, .external_lex_state = 11},
  [681] = {.lex_state = 54, .external_lex_state = 3},
  [682] = {.lex_state = 54, .external_lex_state = 2},
  [683] = {.lex_state = 56, .external_lex_state = 11},
  [684] = {.lex_state = 54, .external_lex_state = 2},
  [685] = {.lex_state = 56, .external_lex_state = 11},
  [686] = {.lex_state = 55, .external_lex_state = 2},
  [687] = {.lex_state = 56, .external_lex_state = 11},
  [688] = {.lex_state = 56, .external_lex_state = 11},
  [689] = {.lex_state = 55, .external_lex_state = 2},
  [690] = {.lex_state = 56, .external_lex_state = 11},
  [691] = {.lex_state = 55, .external_lex_state = 2},
  [692] = {.lex_state = 55, .external_lex_state = 2},
  [693] = {.lex_state = 56, .external_lex_state = 11},
  [694] = {.lex_state = 55, .external_lex_state = 2},
  [695] = {.lex_state = 54, .external_lex_state = 3},
  [696] = {.lex_state = 56, .external_lex_state = 11},
  [697] = {.lex_state = 54, .external_lex_state = 3},
  [698] = {.lex_state = 55, .external_lex_state = 2},
  [699] = {.lex_state = 54, .external_lex_state = 3},
  [700] = {.lex_state = 54, .external_lex_state = 3},
  [701] = {.lex_state = 54, .external_lex_state = 2},
  [702] = {.lex_state = 54, .external_lex_state = 2},
  [703] = {.lex_state = 54, .external_lex_state = 2},
  [704] = {.lex_state = 54, .external_lex_state = 3},
  [705] = {.lex_state = 54, .external_lex_state = 2},
  [706] = {.lex_state = 54, .external_lex_state = 2},
  [707] = {.lex_state = 54, .external_lex_state = 3},
  [708] = {.lex_state = 54, .external_lex_state = 3},
  [709] = {.lex_state = 54, .external_lex_state = 2},
  [710] = {.lex_state = 54, .external_lex_state = 2},
  [711] = {.lex_state = 54, .external_lex_state = 3},
  [712] = {.lex_state = 54, .external_lex_state = 2},
  [713] = {.lex_state = 54, .external_lex_state = 3},
  [714] = {.lex_state = 54, .external_lex_state = 2},
  [715] = {.lex_state = 54, .external_lex_state = 2},
  [716] = {.lex_state = 54, .external_lex_state = 3},
  [717] = {.lex_state = 54, .external_lex_state = 2},
  [718] = {.lex_state = 54, .external_lex_state = 3},
  [719] = {.lex_state = 54, .external_lex_state = 3},
  [720] = {.lex_state = 54, .external_lex_state = 3},
  [721] = {.lex_state = 54, .external_lex_state = 7},
  [722] = {.lex_state = 54, .external_lex_state = 3},
  [723] = {.lex_state = 54, .external_lex_state = 2},
  [724] = {.lex_state = 54, .external_lex_state = 2},
  [725] = {.lex_state = 54, .external_lex_state = 3},
  [726] = {.lex_state = 54, .external_lex_state = 7},
  [727] = {.lex_state = 54, .external_lex_state = 2},
  [728] = {.lex_state = 54, .external_lex_state = 2},
  [729] = {.lex_state = 54, .external_lex_state = 2},
  [730] = {.lex_state = 54, .external_lex_state = 7},
  [731] = {.lex_state = 54, .external_lex_state = 2},
  [732] = {.lex_state = 54, .external_lex_state = 2},
  [733] = {.lex_state = 54, .external_lex_state = 3},
  [734] = {.lex_state = 54, .external_lex_state = 2},
  [735] = {.lex_state = 54, .external_lex_state = 2},
  [736] = {.lex_state = 54, .external_lex_state = 3},
  [737] = {.lex_state = 54, .external_lex_state = 3},
  [738] = {.lex_state = 54, .external_lex_state = 2},
  [739] = {.lex_state = 54, .external_lex_state = 3},
  [740] = {.lex_state = 54, .external_lex_state = 3},
  [741] = {.lex_state = 54, .external_lex_state = 3},
  [742] = {.lex_state = 54, .external_lex_state = 2},
  [743] = {.lex_state = 54, .external_lex_state = 2},
  [744] = {.lex_state = 54, .external_lex_state = 3},
  [745] = {.lex_state = 54, .external_lex_state = 3},
  [746] = {.lex_state = 54, .external_lex_state = 2},
  [747] = {.lex_state = 54, .external_lex_state = 3},
  [748] = {.lex_state = 54, .external_lex_state = 3},
  [749] = {.lex_state = 54, .external_lex_state = 3},
  [750] = {.lex_state = 54, .external_lex_state = 3},
  [751] = {.lex_state = 54, .external_lex_state = 3},
  [752] = {.lex_state = 54, .external_lex_state = 3},
  [753] = {.lex_state = 54, .external_lex_state = 3},
  [754] = {.lex_state = 54, .external_lex_state = 3},
  [755] = {.lex_state = 54, .external_lex_state = 2},
  [756] = {.lex_state = 54, .external_lex_state = 2},
  [757] = {.lex_state = 54, .external_lex_state = 3},
  [758] = {.lex_state = 54, .external_lex_state = 3},
  [759] = {.lex_state = 54, .external_lex_state = 3},
  [760] = {.lex_state = 54, .external_lex_state = 2},
  [761] = {.lex_state = 54, .external_lex_state = 2},
  [762] = {.lex_state = 54, .external_lex_state = 2},
  [763] = {.lex_state = 54, .external_lex_state = 3},
  [764] = {.lex_state = 54, .external_lex_state = 2},
  [765] = {.lex_state = 54, .external_lex_state = 3},
  [766] = {.lex_state = 54, .external_lex_state = 2},
  [767] = {.lex_state = 54, .external_lex_state = 3},
  [768] = {.lex_state = 54, .external_lex_state = 2},
  [769] = {.lex_state = 54, .external_lex_state = 2},
  [770] = {.lex_state = 54, .external_lex_state = 2},
  [771] = {.lex_state = 54, .external_lex_state = 3},
  [772] = {.lex_state = 54, .external_lex_state = 3},
  [773] = {.lex_state = 54, .external_lex_state = 3},
  [774] = {.lex_state = 54, .external_lex_state = 7},
  [775] = {.lex_state = 54, .external_lex_state = 2},
  [776] = {.lex_state = 54, .external_lex_state = 3},
  [777] = {.lex_state = 54, .external_lex_state = 3},
  [778] = {.lex_state = 54, .external_lex_state = 3},
  [779] = {.lex_state = 54, .external_lex_state = 3},
  [780] = {.lex_state = 54, .external_lex_state = 3},
  [781] = {.lex_state = 54, .external_lex_state = 2},
  [782] = {.lex_state = 54, .external_lex_state = 3},
  [783] = {.lex_state = 54, .external_lex_state = 3},
  [784] = {.lex_state = 54, .external_lex_state = 3},
  [785] = {.lex_state = 54, .external_lex_state = 2},
  [786] = {.lex_state = 54, .external_lex_state = 3},
  [787] = {.lex_state = 54, .external_lex_state = 8},
  [788] = {.lex_state = 54, .external_lex_state = 3},
  [789] = {.lex_state = 54, .external_lex_state = 2},
  [790] = {.lex_state = 54, .external_lex_state = 2},
  [791] = {.lex_state = 54, .external_lex_state = 2},
  [792] = {.lex_state = 54, .external_lex_state = 2},
  [793] = {.lex_state = 54, .external_lex_state = 2},
  [794] = {.lex_state = 54, .external_lex_state = 3},
  [795] = {.lex_state = 54, .external_lex_state = 3},
  [796] = {.lex_state = 54, .external_lex_state = 2},
  [797] = {.lex_state = 54, .external_lex_state = 2},
  [798] = {.lex_state = 54, .external_lex_state = 2},
  [799] = {.lex_state = 54, .external_lex_state = 3},
  [800] = {.lex_state = 54, .external_lex_state = 2},
  [801] = {.lex_state = 54, .external_lex_state = 3},
  [802] = {.lex_state = 54, .external_lex_state = 3},
  [803] = {.lex_state = 54, .external_lex_state = 3},
  [804] = {.lex_state = 54, .external_lex_state = 3},
  [805] = {.lex_state = 54, .external_lex_state = 2},
  [806] = {.lex_state = 54, .external_lex_state = 2},
  [807] = {.lex_state = 54, .external_lex_state = 3},
  [808] = {.lex_state = 54, .external_lex_state = 3},
  [809] = {.lex_state = 54, .external_lex_state = 3},
  [810] = {.lex_state = 54, .external_lex_state = 3},
  [811] = {.lex_state = 54, .external_lex_state = 3},
  [812] = {.lex_state = 54, .external_lex_state = 3},
  [813] = {.lex_state = 54, .external_lex_state = 3},
  [814] = {.lex_state = 54, .external_lex_state = 3},
  [815] = {.lex_state = 54, .external_lex_state = 3},
  [816] = {.lex_state = 54, .external_lex_state = 2},
  [817] = {.lex_state = 54, .external_lex_state = 3},
  [818] = {.lex_state = 54, .external_lex_state = 3},
  [819] = {.lex_state = 54, .external_lex_state = 2},
  [820] = {.lex_state = 54, .external_lex_state = 2},
  [821] = {.lex_state = 54, .external_lex_state = 2},
  [822] = {.lex_state = 54, .external_lex_state = 2},
  [823] = {.lex_state = 54, .external_lex_state = 2},
  [824] = {.lex_state = 54, .external_lex_state = 2},
  [825] = {.lex_state = 54, .external_lex_state = 2},
  [826] = {.lex_state = 54, .external_lex_state = 2},
  [827] = {.lex_state = 54, .external_lex_state = 2},
  [828] = {.lex_state = 54, .external_lex_state = 2},
  [829] = {.lex_state = 54, .external_lex_state = 2},
  [830] = {.lex_state = 54, .external_lex_state = 2},
  [831] = {.lex_state = 54, .external_lex_state = 2},
  [832] = {.lex_state = 54, .external_lex_state = 8},
  [833] = {.lex_state = 54, .external_lex_state = 2},
  [834] = {.lex_state = 54, .external_lex_state = 2},
  [835] = {.lex_state = 54, .external_lex_state = 2},
  [836] = {.lex_state = 54, .external_lex_state = 2},
  [837] = {.lex_state = 54, .external_lex_state = 3},
  [838] = {.lex_state = 54, .external_lex_state = 2},
  [839] = {.lex_state = 54, .external_lex_state = 2},
  [840] = {.lex_state = 54, .external_lex_state = 2},
  [841] = {.lex_state = 54, .external_lex_state = 2},
  [842] = {.lex_state = 54, .external_lex_state = 2},
  [843] = {.lex_state = 54, .external_lex_state = 2},
  [844] = {.lex_state = 54, .external_lex_state = 2},
  [845] = {.lex_state = 54, .external_lex_state = 2},
  [846] = {.lex_state = 54, .external_lex_state = 2},
  [847] = {.lex_state = 54, .external_lex_state = 2},
  [848] = {.lex_state = 54, .external_lex_state = 2},
  [849] = {.lex_state = 54, .external_lex_state = 2},
  [850] = {.lex_state = 54, .external_lex_state = 2},
  [851] = {.lex_state = 54, .external_lex_state = 2},
  [852] = {.lex_state = 54, .external_lex_state = 2},
  [853] = {.lex_state = 54, .external_lex_state = 2},
  [854] = {.lex_state = 54, .external_lex_state = 2},
  [855] = {.lex_state = 54, .external_lex_state = 2},
  [856] = {.lex_state = 54, .external_lex_state = 2},
  [857] = {.lex_state = 54, .external_lex_state = 2},
  [858] = {.lex_state = 54, .external_lex_state = 7},
  [859] = {.lex_state = 54, .external_lex_state = 2},
  [860] = {.lex_state = 54, .external_lex_state = 2},
  [861] = {.lex_state = 54, .external_lex_state = 2},
  [862] = {.lex_state = 54, .external_lex_state = 2},
  [863] = {.lex_state = 54, .external_lex_state = 2},
  [864] = {.lex_state = 54, .external_lex_state = 2},
  [865] = {.lex_state = 54, .external_lex_state = 2},
  [866] = {.lex_state = 54, .external_lex_state = 2},
  [867] = {.lex_state = 54, .external_lex_state = 2},
  [868] = {.lex_state = 54, .external_lex_state = 2},
  [869] = {.lex_state = 54, .external_lex_state = 2},
  [870] = {.lex_state = 54, .external_lex_state = 2},
  [871] = {.lex_state = 54, .external_lex_state = 2},
  [872] = {.lex_state = 54, .external_lex_state = 2},
  [873] = {.lex_state = 54, .external_lex_state = 2},
  [874] = {.lex_state = 54, .external_lex_state = 2},
  [875] = {.lex_state = 54, .external_lex_state = 2},
  [876] = {.lex_state = 54, .external_lex_state = 2},
  [877] = {.lex_state = 54, .external_lex_state = 2},
  [878] = {.lex_state = 54, .external_lex_state = 2},
  [879] = {.lex_state = 54, .external_lex_state = 2},
  [880] = {.lex_state = 54, .external_lex_state = 2},
  [881] = {.lex_state = 54, .external_lex_state = 2},
  [882] = {.lex_state = 54, .external_lex_state = 2},
  [883] = {.lex_state = 54, .external_lex_state = 2},
  [884] = {.lex_state = 54, .external_lex_state = 2},
  [885] = {.lex_state = 54, .external_lex_state = 2},
  [886] = {.lex_state = 54, .external_lex_state = 2},
  [887] = {.lex_state = 54, .external_lex_state = 2},
  [888] = {.lex_state = 54, .external_lex_state = 2},
  [889] = {.lex_state = 54, .external_lex_state = 2},
  [890] = {.lex_state = 54, .external_lex_state = 2},
  [891] = {.lex_state = 54, .external_lex_state = 2},
  [892] = {.lex_state = 54, .external_lex_state = 2},
  [893] = {.lex_state = 54, .external_lex_state = 2},
  [894] = {.lex_state = 54, .external_lex_state = 2},
  [895] = {.lex_state = 54, .external_lex_state = 2},
  [896] = {.lex_state = 54, .external_lex_state = 2},
  [897] = {.lex_state = 54, .external_lex_state = 2},
  [898] = {.lex_state = 54, .external_lex_state = 2},
  [899] = {.lex_state = 54, .external_lex_state = 2},
  [900] = {.lex_state = 54, .external_lex_state = 2},
  [901] = {.lex_state = 54, .external_lex_state = 2},
  [902] = {.lex_state = 54, .external_lex_state = 2},
  [903] = {.lex_state = 54, .external_lex_state = 2},
  [904] = {.lex_state = 54, .external_lex_state = 2},
  [905] = {.lex_state = 54, .external_lex_state = 2},
  [906] = {.lex_state = 54, .external_lex_state = 2},
  [907] = {.lex_state = 54, .external_lex_state = 2},
  [908] = {.lex_state = 54, .external_lex_state = 2},
  [909] = {.lex_state = 54, .external_lex_state = 2},
  [910] = {.lex_state = 54, .external_lex_state = 2},
  [911] = {.lex_state = 54, .external_lex_state = 2},
  [912] = {.lex_state = 54, .external_lex_state = 2},
  [913] = {.lex_state = 54, .external_lex_state = 2},
  [914] = {.lex_state = 54, .external_lex_state = 2},
  [915] = {.lex_state = 54, .external_lex_state = 2},
  [916] = {.lex_state = 54, .external_lex_state = 2},
  [917] = {.lex_state = 54, .external_lex_state = 2},
  [918] = {.lex_state = 54, .external_lex_state = 2},
  [919] = {.lex_state = 54, .external_lex_state = 2},
  [920] = {.lex_state = 54, .external_lex_state = 2},
  [921] = {.lex_state = 54, .external_lex_state = 2},
  [922] = {.lex_state = 54, .external_lex_state = 2},
  [923] = {.lex_state = 54, .external_lex_state = 2},
  [924] = {.lex_state = 54, .external_lex_state = 2},
  [925] = {.lex_state = 54, .external_lex_state = 2},
  [926] = {.lex_state = 54, .external_lex_state = 2},
  [927] = {.lex_state = 54, .external_lex_state = 2},
  [928] = {.lex_state = 54, .external_lex_state = 2},
  [929] = {.lex_state = 54, .external_lex_state = 2},
  [930] = {.lex_state = 54, .external_lex_state = 2},
  [931] = {.lex_state = 54, .external_lex_state = 2},
  [932] = {.lex_state = 54, .external_lex_state = 2},
  [933] = {.lex_state = 54, .external_lex_state = 2},
  [934] = {.lex_state = 54, .external_lex_state = 2},
  [935] = {.lex_state = 54, .external_lex_state = 2},
  [936] = {.lex_state = 54, .external_lex_state = 2},
  [937] = {.lex_state = 54, .external_lex_state = 2},
  [938] = {.lex_state = 54, .external_lex_state = 2},
  [939] = {.lex_state = 54, .external_lex_state = 2},
  [940] = {.lex_state = 54, .external_lex_state = 2},
  [941] = {.lex_state = 54, .external_lex_state = 2},
  [942] = {.lex_state = 54, .external_lex_state = 2},
  [943] = {.lex_state = 54, .external_lex_state = 2},
  [944] = {.lex_state = 54, .external_lex_state = 2},
  [945] = {.lex_state = 54, .external_lex_state = 2},
  [946] = {.lex_state = 54, .external_lex_state = 2},
  [947] = {.lex_state = 54, .external_lex_state = 2},
  [948] = {.lex_state = 54, .external_lex_state = 2},
  [949] = {.lex_state = 54, .external_lex_state = 2},
  [950] = {.lex_state = 54, .external_lex_state = 2},
  [951] = {.lex_state = 54, .external_lex_state = 2},
  [952] = {.lex_state = 54, .external_lex_state = 2},
  [953] = {.lex_state = 54, .external_lex_state = 2},
  [954] = {.lex_state = 54, .external_lex_state = 2},
  [955] = {.lex_state = 54, .external_lex_state = 2},
  [956] = {.lex_state = 54, .external_lex_state = 2},
  [957] = {.lex_state = 54, .external_lex_state = 2},
  [958] = {.lex_state = 54, .external_lex_state = 2},
  [959] = {.lex_state = 54, .external_lex_state = 2},
  [960] = {.lex_state = 54, .external_lex_state = 2},
  [961] = {.lex_state = 54, .external_lex_state = 2},
  [962] = {.lex_state = 54, .external_lex_state = 2},
  [963] = {.lex_state = 54, .external_lex_state = 2},
  [964] = {.lex_state = 54, .external_lex_state = 2},
  [965] = {.lex_state = 54, .external_lex_state = 2},
  [966] = {.lex_state = 54, .external_lex_state = 2},
  [967] = {.lex_state = 54, .external_lex_state = 2},
  [968] = {.lex_state = 54, .external_lex_state = 2},
  [969] = {.lex_state = 54, .external_lex_state = 2},
  [970] = {.lex_state = 54, .external_lex_state = 2},
  [971] = {.lex_state = 54, .external_lex_state = 2},
  [972] = {.lex_state = 54, .external_lex_state = 2},
  [973] = {.lex_state = 54, .external_lex_state = 2},
  [974] = {.lex_state = 54, .external_lex_state = 2},
  [975] = {.lex_state = 37, .external_lex_state = 4},
  [976] = {.lex_state = 37, .external_lex_state = 4},
  [977] = {.lex_state = 37, .external_lex_state = 9},
  [978] = {.lex_state = 37, .external_lex_state = 4},
  [979] = {.lex_state = 37, .external_lex_state = 6},
  [980] = {.lex_state = 37, .external_lex_state = 6},
  [981] = {.lex_state = 37, .external_lex_state = 9},
  [982] = {.lex_state = 37, .external_lex_state = 9},
  [983] = {.lex_state = 37, .external_lex_state = 9},
  [984] = {.lex_state = 37, .external_lex_state = 9},
  [985] = {.lex_state = 37, .external_lex_state = 9},
  [986] = {.lex_state = 37, .external_lex_state = 9},
  [987] = {.lex_state = 37, .external_lex_state = 9},
  [988] = {.lex_state = 37, .external_lex_state = 6},
  [989] = {.lex_state = 37, .external_lex_state = 9},
  [990] = {.lex_state = 37, .external_lex_state = 9},
  [991] = {.lex_state = 37, .external_lex_state = 6},
  [992] = {.lex_state = 37, .external_lex_state = 9},
  [993] = {.lex_state = 37, .external_lex_state = 6},
  [994] = {.lex_state = 37, .external_lex_state = 12},
  [995] = {.lex_state = 37, .external_lex_state = 9},
  [996] = {.lex_state = 37, .external_lex_state = 12},
  [997] = {.lex_state = 37, .external_lex_state = 6},
  [998] = {.lex_state = 37, .external_lex_state = 9},
  [999] = {.lex_state = 37, .external_lex_state = 12},
  [1000] = {.lex_state = 37, .external_lex_state = 12},
  [1001] = {.lex_state = 37, .external_lex_state = 12},
  [1002] = {.lex_state = 37, .external_lex_state = 13},
  [1003] = {.lex_state = 37, .external_lex_state = 12},
  [1004] = {.lex_state = 37, .external_lex_state = 2},
  [1005] = {.lex_state = 37, .external_lex_state = 12},
  [1006] = {.lex_state = 37, .external_lex_state = 2},
  [1007] = {.lex_state = 37, .external_lex_state = 12},
  [1008] = {.lex_state = 37, .external_lex_state = 14},
  [1009] = {.lex_state = 37, .external_lex_state = 7},
  [1010] = {.lex_state = 37, .external_lex_state = 12},
  [1011] = {.lex_state = 37, .external_lex_state = 12},
  [1012] = {.lex_state = 38, .external_lex_state = 9},
  [1013] = {.lex_state = 37, .external_lex_state = 9},
  [1014] = {.lex_state = 37, .external_lex_state = 7},
  [1015] = {.lex_state = 37, .external_lex_state = 12},
  [1016] = {.lex_state = 37, .external_lex_state = 15},
  [1017] = {.lex_state = 37, .external_lex_state = 8},
  [1018] = {.lex_state = 37, .external_lex_state = 7},
  [1019] = {.lex_state = 37, .external_lex_state = 8},
  [1020] = {.lex_state = 37, .external_lex_state = 4},
  [1021] = {.lex_state = 37, .external_lex_state = 7},
  [1022] = {.lex_state = 37, .external_lex_state = 8},
  [1023] = {.lex_state = 37, .external_lex_state = 12},
  [1024] = {.lex_state = 37, .external_lex_state = 14},
  [1025] = {.lex_state = 37, .external_lex_state = 12},
  [1026] = {.lex_state = 37, .external_lex_state = 12},
  [1027] = {.lex_state = 37, .external_lex_state = 12},
  [1028] = {.lex_state = 37, .external_lex_state = 12},
  [1029] = {.lex_state = 37, .external_lex_state = 12},
  [1030] = {.lex_state = 37, .external_lex_state = 7},
  [1031] = {.lex_state = 37, .external_lex_state = 12},
  [1032] = {.lex_state = 37, .external_lex_state = 7},
  [1033] = {.lex_state = 37, .external_lex_state = 12},
  [1034] = {.lex_state = 37, .external_lex_state = 12},
  [1035] = {.lex_state = 37, .external_lex_state = 12},
  [1036] = {.lex_state = 37, .external_lex_state = 12},
  [1037] = {.lex_state = 38, .external_lex_state = 9},
  [1038] = {.lex_state = 37, .external_lex_state = 12},
  [1039] = {.lex_state = 37, .external_lex_state = 12},
  [1040] = {.lex_state = 37, .external_lex_state = 12},
  [1041] = {.lex_state = 37, .external_lex_state = 12},
  [1042] = {.lex_state = 37, .external_lex_state = 4},
  [1043] = {.lex_state = 38, .external_lex_state = 9},
  [1044] = {.lex_state = 37, .external_lex_state = 12},
  [1045] = {.lex_state = 37, .external_lex_state = 2},
  [1046] = {.lex_state = 37, .external_lex_state = 12},
  [1047] = {.lex_state = 37, .external_lex_state = 12},
  [1048] = {.lex_state = 37, .external_lex_state = 12},
  [1049] = {.lex_state = 37, .external_lex_state = 12},
  [1050] = {.lex_state = 37, .external_lex_state = 12},
  [1051] = {.lex_state = 37, .external_lex_state = 12},
  [1052] = {.lex_state = 37, .external_lex_state = 6},
  [1053] = {.lex_state = 37, .external_lex_state = 14},
  [1054] = {.lex_state = 37, .external_lex_state = 13},
  [1055] = {.lex_state = 37, .external_lex_state = 13},
  [1056] = {.lex_state = 37, .external_lex_state = 13},
  [1057] = {.lex_state = 37, .external_lex_state = 9},
  [1058] = {.lex_state = 37, .external_lex_state = 13},
  [1059] = {.lex_state = 37, .external_lex_state = 13},
  [1060] = {.lex_state = 37, .external_lex_state = 13},
  [1061] = {.lex_state = 37, .external_lex_state = 13},
  [1062] = {.lex_state = 37, .external_lex_state = 9},
  [1063] = {.lex_state = 37, .external_lex_state = 13},
  [1064] = {.lex_state = 37, .external_lex_state = 14},
  [1065] = {.lex_state = 37, .external_lex_state = 14},
  [1066] = {.lex_state = 37, .external_lex_state = 9},
  [1067] = {.lex_state = 37, .external_lex_state = 9},
  [1068] = {.lex_state = 37, .external_lex_state = 9},
  [1069] = {.lex_state = 37, .external_lex_state = 9},
  [1070] = {.lex_state = 37, .external_lex_state = 9},
  [1071] = {.lex_state = 37, .external_lex_state = 9},
  [1072] = {.lex_state = 37, .external_lex_state = 13},
  [1073] = {.lex_state = 37, .external_lex_state = 13},
  [1074] = {.lex_state = 37, .external_lex_state = 9},
  [1075] = {.lex_state = 37, .external_lex_state = 9},
  [1076] = {.lex_state = 37, .external_lex_state = 6},
  [1077] = {.lex_state = 37, .external_lex_state = 9},
  [1078] = {.lex_state = 37, .external_lex_state = 9},
  [1079] = {.lex_state = 38, .external_lex_state = 14},
  [1080] = {.lex_state = 38, .external_lex_state = 12},
  [1081] = {.lex_state = 38, .external_lex_state = 12},
  [1082] = {.lex_state = 37, .external_lex_state = 6},
  [1083] = {.lex_state = 38, .external_lex_state = 12},
  [1084] = {.lex_state = 37, .external_lex_state = 9},
  [1085] = {.lex_state = 37, .external_lex_state = 9},
  [1086] = {.lex_state = 37, .external_lex_state = 14},
  [1087] = {.lex_state = 38, .external_lex_state = 14},
  [1088] = {.lex_state = 38, .external_lex_state = 14},
  [1089] = {.lex_state = 37, .external_lex_state = 9},
  [1090] = {.lex_state = 37, .external_lex_state = 14},
  [1091] = {.lex_state = 37, .external_lex_state = 9},
  [1092] = {.lex_state = 38, .external_lex_state = 12},
  [1093] = {.lex_state = 37, .external_lex_state = 9},
  [1094] = {.lex_state = 37, .external_lex_state = 9},
  [1095] = {.lex_state = 37, .external_lex_state = 9},
  [1096] = {.lex_state = 38, .external_lex_state = 14},
  [1097] = {.lex_state = 37, .external_lex_state = 13},
  [1098] = {.lex_state = 37, .external_lex_state = 9},
  [1099] = {.lex_state = 37, .external_lex_state = 15},
  [1100] = {.lex_state = 37, .external_lex_state = 15},
  [1101] = {.lex_state = 37, .external_lex_state = 15},
  [1102] = {.lex_state = 37, .external_lex_state = 9},
  [1103] = {.lex_state = 37, .external_lex_state = 9},
  [1104] = {.lex_state = 37, .external_lex_state = 13},
  [1105] = {.lex_state = 37, .external_lex_state = 8},
  [1106] = {.lex_state = 38, .external_lex_state = 12},
  [1107] = {.lex_state = 37, .external_lex_state = 6},
  [1108] = {.lex_state = 38, .external_lex_state = 12},
  [1109] = {.lex_state = 38, .external_lex_state = 12},
  [1110] = {.lex_state = 37, .external_lex_state = 9},
  [1111] = {.lex_state = 37, .external_lex_state = 9},
  [1112] = {.lex_state = 37, .external_lex_state = 9},
  [1113] = {.lex_state = 37, .external_lex_state = 9},
  [1114] = {.lex_state = 38, .external_lex_state = 12},
  [1115] = {.lex_state = 38, .external_lex_state = 12},
  [1116] = {.lex_state = 37, .external_lex_state = 15},
  [1117] = {.lex_state = 37, .external_lex_state = 9},
  [1118] = {.lex_state = 37, .external_lex_state = 15},
  [1119] = {.lex_state = 37, .external_lex_state = 15},
  [1120] = {.lex_state = 38, .external_lex_state = 9},
  [1121] = {.lex_state = 37, .external_lex_state = 15},
  [1122] = {.lex_state = 37, .external_lex_state = 9},
  [1123] = {.lex_state = 37, .external_lex_state = 15},
  [1124] = {.lex_state = 37, .external_lex_state = 15},
  [1125] = {.lex_state = 37, .external_lex_state = 15},
  [1126] = {.lex_state = 37, .external_lex_state = 15},
  [1127] = {.lex_state = 37, .external_lex_state = 9},
  [1128] = {.lex_state = 37, .external_lex_state = 14},
  [1129] = {.lex_state = 37, .external_lex_state = 15},
  [1130] = {.lex_state = 37, .external_lex_state = 15},
  [1131] = {.lex_state = 37, .external_lex_state = 8},
  [1132] = {.lex_state = 37, .external_lex_state = 14},
  [1133] = {.lex_state = 37, .external_lex_state = 9},
  [1134] = {.lex_state = 37, .external_lex_state = 14},
  [1135] = {.lex_state = 37, .external_lex_state = 14},
  [1136] = {.lex_state = 37, .external_lex_state = 14},
  [1137] = {.lex_state = 37, .external_lex_state = 9},
  [1138] = {.lex_state = 37, .external_lex_state = 9},
  [1139] = {.lex_state = 37, .external_lex_state = 14},
  [1140] = {.lex_state = 37, .external_lex_state = 14},
  [1141] = {.lex_state = 38, .external_lex_state = 12},
  [1142] = {.lex_state = 37, .external_lex_state = 14},
  [1143] = {.lex_state = 37, .external_lex_state = 9},
  [1144] = {.lex_state = 37, .external_lex_state = 14},
  [1145] = {.lex_state = 37, .external_lex_state = 9},
  [1146] = {.lex_state = 37, .external_lex_state = 9},
  [1147] = {.lex_state = 37, .external_lex_state = 14},
  [1148] = {.lex_state = 38, .external_lex_state = 12},
  [1149] = {.lex_state = 38, .external_lex_state = 12},
  [1150] = {.lex_state = 37, .external_lex_state = 8},
  [1151] = {.lex_state = 37, .external_lex_state = 14},
  [1152] = {.lex_state = 37, .external_lex_state = 14},
  [1153] = {.lex_state = 37, .external_lex_state = 14},
  [1154] = {.lex_state = 37, .external_lex_state = 9},
  [1155] = {.lex_state = 37, .external_lex_state = 14},
  [1156] = {.lex_state = 37, .external_lex_state = 14},
  [1157] = {.lex_state = 37, .external_lex_state = 14},
  [1158] = {.lex_state = 37, .external_lex_state = 14},
  [1159] = {.lex_state = 37, .external_lex_state = 14},
  [1160] = {.lex_state = 37, .external_lex_state = 14},
  [1161] = {.lex_state = 37, .external_lex_state = 14},
  [1162] = {.lex_state = 37, .external_lex_state = 15},
  [1163] = {.lex_state = 37, .external_lex_state = 12},
  [1164] = {.lex_state = 37, .external_lex_state = 12},
  [1165] = {.lex_state = 37, .external_lex_state = 8},
  [1166] = {.lex_state = 37, .external_lex_state = 12},
  [1167] = {.lex_state = 37, .external_lex_state = 12},
  [1168] = {.lex_state = 37, .external_lex_state = 12},
  [1169] = {.lex_state = 37, .external_lex_state = 12},
  [1170] = {.lex_state = 37, .external_lex_state = 12},
  [1171] = {.lex_state = 38, .external_lex_state = 14},
  [1172] = {.lex_state = 38, .external_lex_state = 14},
  [1173] = {.lex_state = 38, .external_lex_state = 14},
  [1174] = {.lex_state = 37, .external_lex_state = 12},
  [1175] = {.lex_state = 37, .external_lex_state = 12},
  [1176] = {.lex_state = 37, .external_lex_state = 12},
  [1177] = {.lex_state = 37, .external_lex_state = 12},
  [1178] = {.lex_state = 37, .external_lex_state = 12},
  [1179] = {.lex_state = 37, .external_lex_state = 15},
  [1180] = {.lex_state = 37, .external_lex_state = 12},
  [1181] = {.lex_state = 37, .external_lex_state = 7},
  [1182] = {.lex_state = 37, .external_lex_state = 12},
  [1183] = {.lex_state = 37, .external_lex_state = 12},
  [1184] = {.lex_state = 37, .external_lex_state = 12},
  [1185] = {.lex_state = 37, .external_lex_state = 12},
  [1186] = {.lex_state = 37, .external_lex_state = 12},
  [1187] = {.lex_state = 37, .external_lex_state = 14},
  [1188] = {.lex_state = 37, .external_lex_state = 15},
  [1189] = {.lex_state = 37, .external_lex_state = 15},
  [1190] = {.lex_state = 38, .external_lex_state = 14},
  [1191] = {.lex_state = 38, .external_lex_state = 13},
  [1192] = {.lex_state = 37, .external_lex_state = 12},
  [1193] = {.lex_state = 37, .external_lex_state = 12},
  [1194] = {.lex_state = 37, .external_lex_state = 8},
  [1195] = {.lex_state = 37, .external_lex_state = 12},
  [1196] = {.lex_state = 37, .external_lex_state = 7},
  [1197] = {.lex_state = 37, .external_lex_state = 12},
  [1198] = {.lex_state = 37, .external_lex_state = 12},
  [1199] = {.lex_state = 37, .external_lex_state = 12},
  [1200] = {.lex_state = 38, .external_lex_state = 15},
  [1201] = {.lex_state = 37, .external_lex_state = 12},
  [1202] = {.lex_state = 37, .external_lex_state = 7},
  [1203] = {.lex_state = 37, .external_lex_state = 12},
  [1204] = {.lex_state = 37, .external_lex_state = 12},
  [1205] = {.lex_state = 38, .external_lex_state = 13},
  [1206] = {.lex_state = 37, .external_lex_state = 12},
  [1207] = {.lex_state = 38, .external_lex_state = 13},
  [1208] = {.lex_state = 37, .external_lex_state = 2},
  [1209] = {.lex_state = 38, .external_lex_state = 13},
  [1210] = {.lex_state = 37, .external_lex_state = 15},
  [1211] = {.lex_state = 37, .external_lex_state = 12},
  [1212] = {.lex_state = 37, .external_lex_state = 12},
  [1213] = {.lex_state = 37, .external_lex_state = 15},
  [1214] = {.lex_state = 38, .external_lex_state = 14},
  [1215] = {.lex_state = 37, .external_lex_state = 12},
  [1216] = {.lex_state = 37, .external_lex_state = 15},
  [1217] = {.lex_state = 37, .external_lex_state = 15},
  [1218] = {.lex_state = 37, .external_lex_state = 12},
  [1219] = {.lex_state = 37, .external_lex_state = 14},
  [1220] = {.lex_state = 37, .external_lex_state = 12},
  [1221] = {.lex_state = 37, .external_lex_state = 12},
  [1222] = {.lex_state = 37, .external_lex_state = 15},
  [1223] = {.lex_state = 37, .external_lex_state = 15},
  [1224] = {.lex_state = 37, .external_lex_state = 12},
  [1225] = {.lex_state = 37, .external_lex_state = 15},
  [1226] = {.lex_state = 38, .external_lex_state = 15},
  [1227] = {.lex_state = 37, .external_lex_state = 12},
  [1228] = {.lex_state = 38, .external_lex_state = 15},
  [1229] = {.lex_state = 38, .external_lex_state = 15},
  [1230] = {.lex_state = 38, .external_lex_state = 15},
  [1231] = {.lex_state = 37, .external_lex_state = 15},
  [1232] = {.lex_state = 37, .external_lex_state = 15},
  [1233] = {.lex_state = 37, .external_lex_state = 12},
  [1234] = {.lex_state = 38, .external_lex_state = 15},
  [1235] = {.lex_state = 37, .external_lex_state = 12},
  [1236] = {.lex_state = 37, .external_lex_state = 12},
  [1237] = {.lex_state = 37, .external_lex_state = 12},
  [1238] = {.lex_state = 37, .external_lex_state = 12},
  [1239] = {.lex_state = 37, .external_lex_state = 12},
  [1240] = {.lex_state = 37, .external_lex_state = 12},
  [1241] = {.lex_state = 37, .external_lex_state = 12},
  [1242] = {.lex_state = 38, .external_lex_state = 14},
  [1243] = {.lex_state = 38, .external_lex_state = 14},
  [1244] = {.lex_state = 38, .external_lex_state = 14},
  [1245] = {.lex_state = 38, .external_lex_state = 14},
  [1246] = {.lex_state = 38, .external_lex_state = 15},
  [1247] = {.lex_state = 37, .external_lex_state = 12},
  [1248] = {.lex_state = 38, .external_lex_state = 14},
  [1249] = {.lex_state = 38, .external_lex_state = 15},
  [1250] = {.lex_state = 37, .external_lex_state = 12},
  [1251] = {.lex_state = 38, .external_lex_state = 14},
  [1252] = {.lex_state = 37, .external_lex_state = 12},
  [1253] = {.lex_state = 37, .external_lex_state = 12},
  [1254] = {.lex_state = 38, .external_lex_state = 15},
  [1255] = {.lex_state = 38, .external_lex_state = 15},
  [1256] = {.lex_state = 37, .external_lex_state = 12},
  [1257] = {.lex_state = 37, .external_lex_state = 12},
  [1258] = {.lex_state = 37, .external_lex_state = 12},
  [1259] = {.lex_state = 37, .external_lex_state = 2},
  [1260] = {.lex_state = 37, .external_lex_state = 7},
  [1261] = {.lex_state = 38, .external_lex_state = 14},
  [1262] = {.lex_state = 37, .external_lex_state = 12},
  [1263] = {.lex_state = 37, .external_lex_state = 12},
  [1264] = {.lex_state = 37, .external_lex_state = 12},
  [1265] = {.lex_state = 37, .external_lex_state = 12},
  [1266] = {.lex_state = 37, .external_lex_state = 12},
  [1267] = {.lex_state = 37, .external_lex_state = 12},
  [1268] = {.lex_state = 37, .external_lex_state = 12},
  [1269] = {.lex_state = 37, .external_lex_state = 14},
  [1270] = {.lex_state = 37, .external_lex_state = 14},
  [1271] = {.lex_state = 37, .external_lex_state = 14},
  [1272] = {.lex_state = 37, .external_lex_state = 12},
  [1273] = {.lex_state = 37, .external_lex_state = 12},
  [1274] = {.lex_state = 37, .external_lex_state = 14},
  [1275] = {.lex_state = 37, .external_lex_state = 12},
  [1276] = {.lex_state = 37, .external_lex_state = 12},
  [1277] = {.lex_state = 37, .external_lex_state = 12},
  [1278] = {.lex_state = 37, .external_lex_state = 14},
  [1279] = {.lex_state = 37, .external_lex_state = 12},
  [1280] = {.lex_state = 37, .external_lex_state = 12},
  [1281] = {.lex_state = 37, .external_lex_state = 12},
  [1282] = {.lex_state = 37, .external_lex_state = 12},
  [1283] = {.lex_state = 37, .external_lex_state = 12},
  [1284] = {.lex_state = 37, .external_lex_state = 12},
  [1285] = {.lex_state = 37, .external_lex_state = 12},
  [1286] = {.lex_state = 37, .external_lex_state = 12},
  [1287] = {.lex_state = 37, .external_lex_state = 14},
  [1288] = {.lex_state = 37, .external_lex_state = 14},
  [1289] = {.lex_state = 37, .external_lex_state = 14},
  [1290] = {.lex_state = 37, .external_lex_state = 14},
  [1291] = {.lex_state = 37, .external_lex_state = 15},
  [1292] = {.lex_state = 37, .external_lex_state = 14},
  [1293] = {.lex_state = 37, .external_lex_state = 13},
  [1294] = {.lex_state = 37, .external_lex_state = 13},
  [1295] = {.lex_state = 37, .external_lex_state = 13},
  [1296] = {.lex_state = 37, .external_lex_state = 14},
  [1297] = {.lex_state = 37, .external_lex_state = 14},
  [1298] = {.lex_state = 37, .external_lex_state = 14},
  [1299] = {.lex_state = 37, .external_lex_state = 14},
  [1300] = {.lex_state = 37, .external_lex_state = 14},
  [1301] = {.lex_state = 37, .external_lex_state = 14},
  [1302] = {.lex_state = 37, .external_lex_state = 14},
  [1303] = {.lex_state = 37, .external_lex_state = 14},
  [1304] = {.lex_state = 37, .external_lex_state = 14},
  [1305] = {.lex_state = 37, .external_lex_state = 14},
  [1306] = {.lex_state = 37, .external_lex_state = 14},
  [1307] = {.lex_state = 38, .external_lex_state = 14},
  [1308] = {.lex_state = 38, .external_lex_state = 14},
  [1309] = {.lex_state = 37, .external_lex_state = 13},
  [1310] = {.lex_state = 38, .external_lex_state = 14},
  [1311] = {.lex_state = 37, .external_lex_state = 14},
  [1312] = {.lex_state = 37, .external_lex_state = 13},
  [1313] = {.lex_state = 37, .external_lex_state = 14},
  [1314] = {.lex_state = 37, .external_lex_state = 13},
  [1315] = {.lex_state = 37, .external_lex_state = 15},
  [1316] = {.lex_state = 37, .external_lex_state = 15},
  [1317] = {.lex_state = 37, .external_lex_state = 15},
  [1318] = {.lex_state = 37, .external_lex_state = 15},
  [1319] = {.lex_state = 37, .external_lex_state = 14},
  [1320] = {.lex_state = 37, .external_lex_state = 13},
  [1321] = {.lex_state = 37, .external_lex_state = 13},
  [1322] = {.lex_state = 37, .external_lex_state = 13},
  [1323] = {.lex_state = 37, .external_lex_state = 14},
  [1324] = {.lex_state = 37, .external_lex_state = 13},
  [1325] = {.lex_state = 37, .external_lex_state = 15},
  [1326] = {.lex_state = 37, .external_lex_state = 15},
  [1327] = {.lex_state = 37, .external_lex_state = 15},
  [1328] = {.lex_state = 37, .external_lex_state = 13},
  [1329] = {.lex_state = 37, .external_lex_state = 13},
  [1330] = {.lex_state = 37, .external_lex_state = 13},
  [1331] = {.lex_state = 37, .external_lex_state = 13},
  [1332] = {.lex_state = 37, .external_lex_state = 14},
  [1333] = {.lex_state = 37, .external_lex_state = 14},
  [1334] = {.lex_state = 37, .external_lex_state = 9},
  [1335] = {.lex_state = 37, .external_lex_state = 13},
  [1336] = {.lex_state = 37, .external_lex_state = 13},
  [1337] = {.lex_state = 37, .external_lex_state = 14},
  [1338] = {.lex_state = 37, .external_lex_state = 13},
  [1339] = {.lex_state = 37, .external_lex_state = 13},
  [1340] = {.lex_state = 38, .external_lex_state = 15},
  [1341] = {.lex_state = 37, .external_lex_state = 14},
  [1342] = {.lex_state = 37, .external_lex_state = 14},
  [1343] = {.lex_state = 38, .external_lex_state = 15},
  [1344] = {.lex_state = 37, .external_lex_state = 13},
  [1345] = {.lex_state = 38, .external_lex_state = 15},
  [1346] = {.lex_state = 37, .external_lex_state = 13},
  [1347] = {.lex_state = 37, .external_lex_state = 13},
  [1348] = {.lex_state = 37, .external_lex_state = 13},
  [1349] = {.lex_state = 37, .external_lex_state = 15},
  [1350] = {.lex_state = 37, .external_lex_state = 14},
  [1351] = {.lex_state = 37, .external_lex_state = 13},
  [1352] = {.lex_state = 37, .external_lex_state = 14},
  [1353] = {.lex_state = 37, .external_lex_state = 13},
  [1354] = {.lex_state = 37, .external_lex_state = 14},
  [1355] = {.lex_state = 33, .external_lex_state = 9},
  [1356] = {.lex_state = 37, .external_lex_state = 15},
  [1357] = {.lex_state = 37, .external_lex_state = 15},
  [1358] = {.lex_state = 37, .external_lex_state = 15},
  [1359] = {.lex_state = 37, .external_lex_state = 15},
  [1360] = {.lex_state = 37, .external_lex_state = 13},
  [1361] = {.lex_state = 37, .external_lex_state = 13},
  [1362] = {.lex_state = 37, .external_lex_state = 13},
  [1363] = {.lex_state = 33, .external_lex_state = 9},
  [1364] = {.lex_state = 37, .external_lex_state = 15},
  [1365] = {.lex_state = 37, .external_lex_state = 13},
  [1366] = {.lex_state = 37, .external_lex_state = 14},
  [1367] = {.lex_state = 37, .external_lex_state = 15},
  [1368] = {.lex_state = 37, .external_lex_state = 15},
  [1369] = {.lex_state = 37, .external_lex_state = 14},
  [1370] = {.lex_state = 37, .external_lex_state = 14},
  [1371] = {.lex_state = 37, .external_lex_state = 14},
  [1372] = {.lex_state = 37, .external_lex_state = 14},
  [1373] = {.lex_state = 37, .external_lex_state = 14},
  [1374] = {.lex_state = 37, .external_lex_state = 14},
  [1375] = {.lex_state = 37, .external_lex_state = 14},
  [1376] = {.lex_state = 37, .external_lex_state = 14},
  [1377] = {.lex_state = 37, .external_lex_state = 14},
  [1378] = {.lex_state = 37, .external_lex_state = 14},
  [1379] = {.lex_state = 37, .external_lex_state = 14},
  [1380] = {.lex_state = 37, .external_lex_state = 15},
  [1381] = {.lex_state = 37, .external_lex_state = 15},
  [1382] = {.lex_state = 37, .external_lex_state = 15},
  [1383] = {.lex_state = 37, .external_lex_state = 14},
  [1384] = {.lex_state = 37, .external_lex_state = 14},
  [1385] = {.lex_state = 37, .external_lex_state = 14},
  [1386] = {.lex_state = 37, .external_lex_state = 14},
  [1387] = {.lex_state = 37, .external_lex_state = 15},
  [1388] = {.lex_state = 37, .external_lex_state = 13},
  [1389] = {.lex_state = 37, .external_lex_state = 14},
  [1390] = {.lex_state = 37, .external_lex_state = 14},
  [1391] = {.lex_state = 37, .external_lex_state = 14},
  [1392] = {.lex_state = 37, .external_lex_state = 13},
  [1393] = {.lex_state = 37, .external_lex_state = 15},
  [1394] = {.lex_state = 33, .external_lex_state = 9},
  [1395] = {.lex_state = 37, .external_lex_state = 14},
  [1396] = {.lex_state = 37, .external_lex_state = 14},
  [1397] = {.lex_state = 37, .external_lex_state = 15},
  [1398] = {.lex_state = 37, .external_lex_state = 15},
  [1399] = {.lex_state = 33, .external_lex_state = 9},
  [1400] = {.lex_state = 33, .external_lex_state = 9},
  [1401] = {.lex_state = 33, .external_lex_state = 9},
  [1402] = {.lex_state = 37, .external_lex_state = 15},
  [1403] = {.lex_state = 37, .external_lex_state = 15},
  [1404] = {.lex_state = 37, .external_lex_state = 15},
  [1405] = {.lex_state = 37, .external_lex_state = 14},
  [1406] = {.lex_state = 37, .external_lex_state = 14},
  [1407] = {.lex_state = 37, .external_lex_state = 14},
  [1408] = {.lex_state = 37, .external_lex_state = 14},
  [1409] = {.lex_state = 37, .external_lex_state = 14},
  [1410] = {.lex_state = 37, .external_lex_state = 8},
  [1411] = {.lex_state = 37, .external_lex_state = 15},
  [1412] = {.lex_state = 37, .external_lex_state = 14},
  [1413] = {.lex_state = 37, .external_lex_state = 15},
  [1414] = {.lex_state = 37, .external_lex_state = 15},
  [1415] = {.lex_state = 37, .external_lex_state = 15},
  [1416] = {.lex_state = 37, .external_lex_state = 15},
  [1417] = {.lex_state = 37, .external_lex_state = 15},
  [1418] = {.lex_state = 37, .external_lex_state = 14},
  [1419] = {.lex_state = 37, .external_lex_state = 15},
  [1420] = {.lex_state = 37, .external_lex_state = 8},
  [1421] = {.lex_state = 37, .external_lex_state = 15},
  [1422] = {.lex_state = 37, .external_lex_state = 14},
  [1423] = {.lex_state = 37, .external_lex_state = 14},
  [1424] = {.lex_state = 37, .external_lex_state = 15},
  [1425] = {.lex_state = 37, .external_lex_state = 15},
  [1426] = {.lex_state = 37, .external_lex_state = 14},
  [1427] = {.lex_state = 37, .external_lex_state = 14},
  [1428] = {.lex_state = 37, .external_lex_state = 14},
  [1429] = {.lex_state = 37, .external_lex_state = 13},
  [1430] = {.lex_state = 37, .external_lex_state = 15},
  [1431] = {.lex_state = 37, .external_lex_state = 14},
  [1432] = {.lex_state = 37, .external_lex_state = 14},
  [1433] = {.lex_state = 37, .external_lex_state = 13},
  [1434] = {.lex_state = 37, .external_lex_state = 13},
  [1435] = {.lex_state = 37, .external_lex_state = 14},
  [1436] = {.lex_state = 37, .external_lex_state = 13},
  [1437] = {.lex_state = 37, .external_lex_state = 13},
  [1438] = {.lex_state = 37, .external_lex_state = 14},
  [1439] = {.lex_state = 37, .external_lex_state = 13},
  [1440] = {.lex_state = 37, .external_lex_state = 14},
  [1441] = {.lex_state = 37, .external_lex_state = 14},
  [1442] = {.lex_state = 37, .external_lex_state = 14},
  [1443] = {.lex_state = 37, .external_lex_state = 15},
  [1444] = {.lex_state = 37, .external_lex_state = 15},
  [1445] = {.lex_state = 37, .external_lex_state = 15},
  [1446] = {.lex_state = 37, .external_lex_state = 14},
  [1447] = {.lex_state = 37, .external_lex_state = 14},
  [1448] = {.lex_state = 37, .external_lex_state = 15},
  [1449] = {.lex_state = 37, .external_lex_state = 14},
  [1450] = {.lex_state = 37, .external_lex_state = 15},
  [1451] = {.lex_state = 38, .external_lex_state = 14},
  [1452] = {.lex_state = 37, .external_lex_state = 15},
  [1453] = {.lex_state = 37, .external_lex_state = 13},
  [1454] = {.lex_state = 37, .external_lex_state = 15},
  [1455] = {.lex_state = 37, .external_lex_state = 15},
  [1456] = {.lex_state = 37, .external_lex_state = 15},
  [1457] = {.lex_state = 37, .external_lex_state = 15},
  [1458] = {.lex_state = 37, .external_lex_state = 15},
  [1459] = {.lex_state = 37, .external_lex_state = 15},
  [1460] = {.lex_state = 37, .external_lex_state = 15},
  [1461] = {.lex_state = 37, .external_lex_state = 15},
  [1462] = {.lex_state = 37, .external_lex_state = 15},
  [1463] = {.lex_state = 38, .external_lex_state = 12},
  [1464] = {.lex_state = 37, .external_lex_state = 15},
  [1465] = {.lex_state = 37, .external_lex_state = 15},
  [1466] = {.lex_state = 38, .external_lex_state = 12},
  [1467] = {.lex_state = 38, .external_lex_state = 12},
  [1468] = {.lex_state = 37, .external_lex_state = 15},
  [1469] = {.lex_state = 37, .external_lex_state = 15},
  [1470] = {.lex_state = 37, .external_lex_state = 15},
  [1471] = {.lex_state = 37, .external_lex_state = 15},
  [1472] = {.lex_state = 37, .external_lex_state = 15},
  [1473] = {.lex_state = 37, .external_lex_state = 15},
  [1474] = {.lex_state = 38, .external_lex_state = 14},
  [1475] = {.lex_state = 37, .external_lex_state = 15},
  [1476] = {.lex_state = 38, .external_lex_state = 14},
  [1477] = {.lex_state = 37, .external_lex_state = 15},
  [1478] = {.lex_state = 37, .external_lex_state = 15},
  [1479] = {.lex_state = 37, .external_lex_state = 15},
  [1480] = {.lex_state = 37, .external_lex_state = 15},
  [1481] = {.lex_state = 37, .external_lex_state = 15},
  [1482] = {.lex_state = 37, .external_lex_state = 15},
  [1483] = {.lex_state = 37, .external_lex_state = 15},
  [1484] = {.lex_state = 37, .external_lex_state = 15},
  [1485] = {.lex_state = 37, .external_lex_state = 15},
  [1486] = {.lex_state = 37, .external_lex_state = 15},
  [1487] = {.lex_state = 37, .external_lex_state = 15},
  [1488] = {.lex_state = 37, .external_lex_state = 15},
  [1489] = {.lex_state = 37, .external_lex_state = 15},
  [1490] = {.lex_state = 37, .external_lex_state = 15},
  [1491] = {.lex_state = 37, .external_lex_state = 15},
  [1492] = {.lex_state = 37, .external_lex_state = 15},
  [1493] = {.lex_state = 38, .external_lex_state = 15},
  [1494] = {.lex_state = 38, .external_lex_state = 15},
  [1495] = {.lex_state = 38, .external_lex_state = 15},
  [1496] = {.lex_state = 37, .external_lex_state = 15},
  [1497] = {.lex_state = 33, .external_lex_state = 13},
  [1498] = {.lex_state = 33, .external_lex_state = 13},
  [1499] = {.lex_state = 33, .external_lex_state = 13},
  [1500] = {.lex_state = 33, .external_lex_state = 13},
  [1501] = {.lex_state = 33, .external_lex_state = 13},
  [1502] = {.lex_state = 33, .external_lex_state = 13},
  [1503] = {.lex_state = 33, .external_lex_state = 13},
  [1504] = {.lex_state = 33, .external_lex_state = 13},
  [1505] = {.lex_state = 33, .external_lex_state = 13},
  [1506] = {.lex_state = 33, .external_lex_state = 13},
  [1507] = {.lex_state = 33, .external_lex_state = 13},
  [1508] = {.lex_state = 33, .external_lex_state = 13},
  [1509] = {.lex_state = 33, .external_lex_state = 13},
  [1510] = {.lex_state = 33, .external_lex_state = 13},
  [1511] = {.lex_state = 33, .external_lex_state = 13},
  [1512] = {.lex_state = 33, .external_lex_state = 13},
  [1513] = {.lex_state = 37, .external_lex_state = 14},
  [1514] = {.lex_state = 37, .external_lex_state = 15},
  [1515] = {.lex_state = 37, .external_lex_state = 12},
  [1516] = {.lex_state = 36, .external_lex_state = 2},
  [1517] = {.lex_state = 36, .external_lex_state = 2},
  [1518] = {.lex_state = 30, .external_lex_state = 7},
  [1519] = {.lex_state = 30, .external_lex_state = 7},
  [1520] = {.lex_state = 30, .external_lex_state = 7},
  [1521] = {.lex_state = 30, .external_lex_state = 7},
  [1522] = {.lex_state = 30, .external_lex_state = 7},
  [1523] = {.lex_state = 30, .external_lex_state = 7},
  [1524] = {.lex_state = 30, .external_lex_state = 8},
  [1525] = {.lex_state = 30, .external_lex_state = 7},
  [1526] = {.lex_state = 30, .external_lex_state = 7},
  [1527] = {.lex_state = 30, .external_lex_state = 8},
  [1528] = {.lex_state = 30, .external_lex_state = 8},
  [1529] = {.lex_state = 30, .external_lex_state = 7},
  [1530] = {.lex_state = 30, .external_lex_state = 8},
  [1531] = {.lex_state = 30, .external_lex_state = 8},
  [1532] = {.lex_state = 30, .external_lex_state = 7},
  [1533] = {.lex_state = 30, .external_lex_state = 8},
  [1534] = {.lex_state = 30, .external_lex_state = 7},
  [1535] = {.lex_state = 30, .external_lex_state = 7},
  [1536] = {.lex_state = 30, .external_lex_state = 8},
  [1537] = {.lex_state = 30, .external_lex_state = 7},
  [1538] = {.lex_state = 30, .external_lex_state = 8},
  [1539] = {.lex_state = 30, .external_lex_state = 7},
  [1540] = {.lex_state = 30, .external_lex_state = 8},
  [1541] = {.lex_state = 30, .external_lex_state = 7},
  [1542] = {.lex_state = 30, .external_lex_state = 7},
  [1543] = {.lex_state = 30, .external_lex_state = 8},
  [1544] = {.lex_state = 30, .external_lex_state = 8},
  [1545] = {.lex_state = 30, .external_lex_state = 7},
  [1546] = {.lex_state = 30, .external_lex_state = 7},
  [1547] = {.lex_state = 30, .external_lex_state = 7},
  [1548] = {.lex_state = 30, .external_lex_state = 7},
  [1549] = {.lex_state = 30, .external_lex_state = 7},
  [1550] = {.lex_state = 30, .external_lex_state = 7},
  [1551] = {.lex_state = 30, .external_lex_state = 8},
  [1552] = {.lex_state = 30, .external_lex_state = 7},
  [1553] = {.lex_state = 30, .external_lex_state = 7},
  [1554] = {.lex_state = 30, .external_lex_state = 2},
  [1555] = {.lex_state = 30, .external_lex_state = 2},
  [1556] = {.lex_state = 30, .external_lex_state = 2},
  [1557] = {.lex_state = 30, .external_lex_state = 2},
  [1558] = {.lex_state = 30, .external_lex_state = 2},
  [1559] = {.lex_state = 30, .external_lex_state = 6},
  [1560] = {.lex_state = 30, .external_lex_state = 6},
  [1561] = {.lex_state = 30, .external_lex_state = 6},
  [1562] = {.lex_state = 30, .external_lex_state = 6},
  [1563] = {.lex_state = 30, .external_lex_state = 6},
  [1564] = {.lex_state = 30, .external_lex_state = 6},
  [1565] = {.lex_state = 30, .external_lex_state = 6},
  [1566] = {.lex_state = 30, .external_lex_state = 6},
  [1567] = {.lex_state = 30, .external_lex_state = 6},
  [1568] = {.lex_state = 30, .external_lex_state = 6},
  [1569] = {.lex_state = 30, .external_lex_state = 6},
  [1570] = {.lex_state = 30, .external_lex_state = 6},
  [1571] = {.lex_state = 30, .external_lex_state = 6},
  [1572] = {.lex_state = 30, .external_lex_state = 6},
  [1573] = {.lex_state = 30, .external_lex_state = 6},
  [1574] = {.lex_state = 30, .external_lex_state = 6},
  [1575] = {.lex_state = 30, .external_lex_state = 6},
  [1576] = {.lex_state = 30, .external_lex_state = 6},
  [1577] = {.lex_state = 30, .external_lex_state = 6},
  [1578] = {.lex_state = 30, .external_lex_state = 6},
  [1579] = {.lex_state = 30, .external_lex_state = 2},
  [1580] = {.lex_state = 30, .external_lex_state = 2},
  [1581] = {.lex_state = 30, .external_lex_state = 2},
  [1582] = {.lex_state = 30, .external_lex_state = 2},
  [1583] = {.lex_state = 30, .external_lex_state = 2},
  [1584] = {.lex_state = 30, .external_lex_state = 2},
  [1585] = {.lex_state = 30, .external_lex_state = 2},
  [1586] = {.lex_state = 30, .external_lex_state = 2},
  [1587] = {.lex_state = 30, .external_lex_state = 2},
  [1588] = {.lex_state = 33, .external_lex_state = 9},
  [1589] = {.lex_state = 33, .external_lex_state = 9},
  [1590] = {.lex_state = 37, .external_lex_state = 12},
  [1591] = {.lex_state = 37, .external_lex_state = 12},
  [1592] = {.lex_state = 37, .external_lex_state = 12},
  [1593] = {.lex_state = 33, .external_lex_state = 13},
  [1594] = {.lex_state = 37, .external_lex_state = 12},
  [1595] = {.lex_state = 33, .external_lex_state = 13},
  [1596] = {.lex_state = 33, .external_lex_state = 14},
  [1597] = {.lex_state = 33, .external_lex_state = 14},
  [1598] = {.lex_state = 37, .external_lex_state = 12},
  [1599] = {.lex_state = 37, .external_lex_state = 12},
  [1600] = {.lex_state = 33, .external_lex_state = 15},
  [1601] = {.lex_state = 54, .external_lex_state = 12},
  [1602] = {.lex_state = 54, .external_lex_state = 12},
  [1603] = {.lex_state = 54, .external_lex_state = 12},
  [1604] = {.lex_state = 33, .external_lex_state = 15},
  [1605] = {.lex_state = 54, .external_lex_state = 12},
  [1606] = {.lex_state = 37, .external_lex_state = 14},
  [1607] = {.lex_state = 37, .external_lex_state = 14},
  [1608] = {.lex_state = 37, .external_lex_state = 14},
  [1609] = {.lex_state = 37, .external_lex_state = 14},
  [1610] = {.lex_state = 54, .external_lex_state = 14},
  [1611] = {.lex_state = 35, .external_lex_state = 9},
  [1612] = {.lex_state = 37, .external_lex_state = 14},
  [1613] = {.lex_state = 54, .external_lex_state = 14},
  [1614] = {.lex_state = 54, .external_lex_state = 15},
  [1615] = {.lex_state = 35, .external_lex_state = 9},
  [1616] = {.lex_state = 37, .external_lex_state = 14},
  [1617] = {.lex_state = 54, .external_lex_state = 15},
  [1618] = {.lex_state = 37, .external_lex_state = 13},
  [1619] = {.lex_state = 37, .external_lex_state = 13},
  [1620] = {.lex_state = 37, .external_lex_state = 13},
  [1621] = {.lex_state = 37, .external_lex_state = 13},
  [1622] = {.lex_state = 37, .external_lex_state = 15},
  [1623] = {.lex_state = 37, .external_lex_state = 13},
  [1624] = {.lex_state = 37, .external_lex_state = 13},
  [1625] = {.lex_state = 37, .external_lex_state = 13},
  [1626] = {.lex_state = 37, .external_lex_state = 14},
  [1627] = {.lex_state = 37, .external_lex_state = 14},
  [1628] = {.lex_state = 35, .external_lex_state = 9},
  [1629] = {.lex_state = 37, .external_lex_state = 15},
  [1630] = {.lex_state = 37, .external_lex_state = 15},
  [1631] = {.lex_state = 37, .external_lex_state = 13},
  [1632] = {.lex_state = 37, .external_lex_state = 15},
  [1633] = {.lex_state = 37, .external_lex_state = 13},
  [1634] = {.lex_state = 37, .external_lex_state = 15},
  [1635] = {.lex_state = 35, .external_lex_state = 9},
  [1636] = {.lex_state = 37, .external_lex_state = 13},
  [1637] = {.lex_state = 37, .external_lex_state = 13},
  [1638] = {.lex_state = 37, .external_lex_state = 14},
  [1639] = {.lex_state = 37, .external_lex_state = 13},
  [1640] = {.lex_state = 37, .external_lex_state = 13},
  [1641] = {.lex_state = 37, .external_lex_state = 13},
  [1642] = {.lex_state = 37, .external_lex_state = 14},
  [1643] = {.lex_state = 37, .external_lex_state = 15},
  [1644] = {.lex_state = 37, .external_lex_state = 13},
  [1645] = {.lex_state = 37, .external_lex_state = 14},
  [1646] = {.lex_state = 37, .external_lex_state = 13},
  [1647] = {.lex_state = 37, .external_lex_state = 13},
  [1648] = {.lex_state = 37, .external_lex_state = 13},
  [1649] = {.lex_state = 35, .external_lex_state = 9},
  [1650] = {.lex_state = 37, .external_lex_state = 13},
  [1651] = {.lex_state = 37, .external_lex_state = 13},
  [1652] = {.lex_state = 37, .external_lex_state = 13},
  [1653] = {.lex_state = 35, .external_lex_state = 9},
  [1654] = {.lex_state = 37, .external_lex_state = 13},
  [1655] = {.lex_state = 37, .external_lex_state = 14},
  [1656] = {.lex_state = 36, .external_lex_state = 13},
  [1657] = {.lex_state = 36, .external_lex_state = 13},
  [1658] = {.lex_state = 36, .external_lex_state = 13},
  [1659] = {.lex_state = 36, .external_lex_state = 13},
  [1660] = {.lex_state = 36, .external_lex_state = 13},
  [1661] = {.lex_state = 35, .external_lex_state = 13},
  [1662] = {.lex_state = 36, .external_lex_state = 13},
  [1663] = {.lex_state = 36, .external_lex_state = 13},
  [1664] = {.lex_state = 35, .external_lex_state = 13},
  [1665] = {.lex_state = 36, .external_lex_state = 13},
  [1666] = {.lex_state = 35, .external_lex_state = 9},
  [1667] = {.lex_state = 36, .external_lex_state = 13},
  [1668] = {.lex_state = 35, .external_lex_state = 13},
  [1669] = {.lex_state = 36, .external_lex_state = 13},
  [1670] = {.lex_state = 35, .external_lex_state = 13},
  [1671] = {.lex_state = 35, .external_lex_state = 13},
  [1672] = {.lex_state = 35, .external_lex_state = 13},
  [1673] = {.lex_state = 35, .external_lex_state = 13},
  [1674] = {.lex_state = 36, .external_lex_state = 13},
  [1675] = {.lex_state = 35, .external_lex_state = 13},
  [1676] = {.lex_state = 30, .external_lex_state = 14},
  [1677] = {.lex_state = 36, .external_lex_state = 13},
  [1678] = {.lex_state = 30, .external_lex_state = 14},
  [1679] = {.lex_state = 35, .external_lex_state = 13},
  [1680] = {.lex_state = 36, .external_lex_state = 13},
  [1681] = {.lex_state = 30, .external_lex_state = 14},
  [1682] = {.lex_state = 30, .external_lex_state = 13},
  [1683] = {.lex_state = 30, .external_lex_state = 13},
  [1684] = {.lex_state = 54, .external_lex_state = 12},
  [1685] = {.lex_state = 33, .external_lex_state = 9},
  [1686] = {.lex_state = 54, .external_lex_state = 12},
  [1687] = {.lex_state = 33, .external_lex_state = 9},
  [1688] = {.lex_state = 33, .external_lex_state = 9},
  [1689] = {.lex_state = 33, .external_lex_state = 9},
  [1690] = {.lex_state = 54, .external_lex_state = 12},
  [1691] = {.lex_state = 54, .external_lex_state = 12},
  [1692] = {.lex_state = 33, .external_lex_state = 9},
  [1693] = {.lex_state = 33, .external_lex_state = 9},
  [1694] = {.lex_state = 54, .external_lex_state = 12},
  [1695] = {.lex_state = 54, .external_lex_state = 12},
  [1696] = {.lex_state = 33, .external_lex_state = 9},
  [1697] = {.lex_state = 33, .external_lex_state = 9},
  [1698] = {.lex_state = 54, .external_lex_state = 12},
  [1699] = {.lex_state = 33, .external_lex_state = 9},
  [1700] = {.lex_state = 54, .external_lex_state = 12},
  [1701] = {.lex_state = 54, .external_lex_state = 15},
  [1702] = {.lex_state = 54, .external_lex_state = 15},
  [1703] = {.lex_state = 54, .external_lex_state = 15},
  [1704] = {.lex_state = 54, .external_lex_state = 14},
  [1705] = {.lex_state = 54, .external_lex_state = 14},
  [1706] = {.lex_state = 54, .external_lex_state = 14},
  [1707] = {.lex_state = 54, .external_lex_state = 14},
  [1708] = {.lex_state = 54, .external_lex_state = 14},
  [1709] = {.lex_state = 33, .external_lex_state = 9},
  [1710] = {.lex_state = 54, .external_lex_state = 15},
  [1711] = {.lex_state = 54, .external_lex_state = 14},
  [1712] = {.lex_state = 54, .external_lex_state = 14},
  [1713] = {.lex_state = 54, .external_lex_state = 14},
  [1714] = {.lex_state = 54, .external_lex_state = 15},
  [1715] = {.lex_state = 54, .external_lex_state = 15},
  [1716] = {.lex_state = 54, .external_lex_state = 14},
  [1717] = {.lex_state = 54, .external_lex_state = 14},
  [1718] = {.lex_state = 54, .external_lex_state = 14},
  [1719] = {.lex_state = 54, .external_lex_state = 14},
  [1720] = {.lex_state = 54, .external_lex_state = 14},
  [1721] = {.lex_state = 54, .external_lex_state = 14},
  [1722] = {.lex_state = 54, .external_lex_state = 14},
  [1723] = {.lex_state = 54, .external_lex_state = 15},
  [1724] = {.lex_state = 54, .external_lex_state = 14},
  [1725] = {.lex_state = 54, .external_lex_state = 15},
  [1726] = {.lex_state = 54, .external_lex_state = 14},
  [1727] = {.lex_state = 0, .external_lex_state = 16},
  [1728] = {.lex_state = 0, .external_lex_state = 16},
  [1729] = {.lex_state = 33, .external_lex_state = 14},
  [1730] = {.lex_state = 0, .external_lex_state = 16},
  [1731] = {.lex_state = 0, .external_lex_state = 16},
  [1732] = {.lex_state = 54, .external_lex_state = 12},
  [1733] = {.lex_state = 0, .external_lex_state = 16},
  [1734] = {.lex_state = 33, .external_lex_state = 14},
  [1735] = {.lex_state = 33, .external_lex_state = 14},
  [1736] = {.lex_state = 0, .external_lex_state = 16},
  [1737] = {.lex_state = 33, .external_lex_state = 14},
  [1738] = {.lex_state = 33, .external_lex_state = 14},
  [1739] = {.lex_state = 0, .external_lex_state = 16},
  [1740] = {.lex_state = 33, .external_lex_state = 13},
  [1741] = {.lex_state = 33, .external_lex_state = 13},
  [1742] = {.lex_state = 0, .external_lex_state = 16},
  [1743] = {.lex_state = 0, .external_lex_state = 16},
  [1744] = {.lex_state = 33, .external_lex_state = 13},
  [1745] = {.lex_state = 33, .external_lex_state = 14},
  [1746] = {.lex_state = 33, .external_lex_state = 13},
  [1747] = {.lex_state = 0, .external_lex_state = 16},
  [1748] = {.lex_state = 33, .external_lex_state = 13},
  [1749] = {.lex_state = 33, .external_lex_state = 13},
  [1750] = {.lex_state = 33, .external_lex_state = 13},
  [1751] = {.lex_state = 33, .external_lex_state = 14},
  [1752] = {.lex_state = 54, .external_lex_state = 12},
  [1753] = {.lex_state = 33, .external_lex_state = 9},
  [1754] = {.lex_state = 33, .external_lex_state = 14},
  [1755] = {.lex_state = 33, .external_lex_state = 14},
  [1756] = {.lex_state = 0, .external_lex_state = 16},
  [1757] = {.lex_state = 0, .external_lex_state = 16},
  [1758] = {.lex_state = 33, .external_lex_state = 13},
  [1759] = {.lex_state = 0, .external_lex_state = 16},
  [1760] = {.lex_state = 33, .external_lex_state = 14},
  [1761] = {.lex_state = 0, .external_lex_state = 16},
  [1762] = {.lex_state = 33, .external_lex_state = 13},
  [1763] = {.lex_state = 0, .external_lex_state = 16},
  [1764] = {.lex_state = 0, .external_lex_state = 16},
  [1765] = {.lex_state = 0, .external_lex_state = 16},
  [1766] = {.lex_state = 0, .external_lex_state = 16},
  [1767] = {.lex_state = 0, .external_lex_state = 16},
  [1768] = {.lex_state = 54, .external_lex_state = 12},
  [1769] = {.lex_state = 33, .external_lex_state = 15},
  [1770] = {.lex_state = 54, .external_lex_state = 12},
  [1771] = {.lex_state = 54, .external_lex_state = 12},
  [1772] = {.lex_state = 54, .external_lex_state = 12},
  [1773] = {.lex_state = 54, .external_lex_state = 12},
  [1774] = {.lex_state = 54, .external_lex_state = 12},
  [1775] = {.lex_state = 54, .external_lex_state = 12},
  [1776] = {.lex_state = 54, .external_lex_state = 12},
  [1777] = {.lex_state = 54, .external_lex_state = 12},
  [1778] = {.lex_state = 54, .external_lex_state = 12},
  [1779] = {.lex_state = 33, .external_lex_state = 13},
  [1780] = {.lex_state = 54, .external_lex_state = 12},
  [1781] = {.lex_state = 54, .external_lex_state = 12},
  [1782] = {.lex_state = 33, .external_lex_state = 15},
  [1783] = {.lex_state = 54, .external_lex_state = 12},
  [1784] = {.lex_state = 33, .external_lex_state = 15},
  [1785] = {.lex_state = 54, .external_lex_state = 12},
  [1786] = {.lex_state = 33, .external_lex_state = 15},
  [1787] = {.lex_state = 33, .external_lex_state = 15},
  [1788] = {.lex_state = 54, .external_lex_state = 12},
  [1789] = {.lex_state = 54, .external_lex_state = 12},
  [1790] = {.lex_state = 33, .external_lex_state = 13},
  [1791] = {.lex_state = 33, .external_lex_state = 15},
  [1792] = {.lex_state = 54, .external_lex_state = 9},
  [1793] = {.lex_state = 33, .external_lex_state = 15},
  [1794] = {.lex_state = 33, .external_lex_state = 15},
  [1795] = {.lex_state = 33, .external_lex_state = 15},
  [1796] = {.lex_state = 33, .external_lex_state = 13},
  [1797] = {.lex_state = 54, .external_lex_state = 12},
  [1798] = {.lex_state = 33, .external_lex_state = 13},
  [1799] = {.lex_state = 54, .external_lex_state = 12},
  [1800] = {.lex_state = 54, .external_lex_state = 12},
  [1801] = {.lex_state = 54, .external_lex_state = 12},
  [1802] = {.lex_state = 33, .external_lex_state = 15},
  [1803] = {.lex_state = 33, .external_lex_state = 13},
  [1804] = {.lex_state = 54, .external_lex_state = 15},
  [1805] = {.lex_state = 54, .external_lex_state = 14},
  [1806] = {.lex_state = 54, .external_lex_state = 12},
  [1807] = {.lex_state = 54, .external_lex_state = 15},
  [1808] = {.lex_state = 54, .external_lex_state = 9},
  [1809] = {.lex_state = 54, .external_lex_state = 15},
  [1810] = {.lex_state = 54, .external_lex_state = 14},
  [1811] = {.lex_state = 54, .external_lex_state = 14},
  [1812] = {.lex_state = 54, .external_lex_state = 2},
  [1813] = {.lex_state = 34, .external_lex_state = 17},
  [1814] = {.lex_state = 54, .external_lex_state = 14},
  [1815] = {.lex_state = 54, .external_lex_state = 15},
  [1816] = {.lex_state = 54, .external_lex_state = 14},
  [1817] = {.lex_state = 54, .external_lex_state = 12},
  [1818] = {.lex_state = 54, .external_lex_state = 15},
  [1819] = {.lex_state = 54, .external_lex_state = 15},
  [1820] = {.lex_state = 54, .external_lex_state = 9},
  [1821] = {.lex_state = 32, .external_lex_state = 14},
  [1822] = {.lex_state = 54, .external_lex_state = 14},
  [1823] = {.lex_state = 54, .external_lex_state = 14},
  [1824] = {.lex_state = 54, .external_lex_state = 13},
  [1825] = {.lex_state = 54, .external_lex_state = 12},
  [1826] = {.lex_state = 54, .external_lex_state = 14},
  [1827] = {.lex_state = 54, .external_lex_state = 15},
  [1828] = {.lex_state = 54, .external_lex_state = 13},
  [1829] = {.lex_state = 54, .external_lex_state = 9},
  [1830] = {.lex_state = 34, .external_lex_state = 17},
  [1831] = {.lex_state = 54, .external_lex_state = 15},
  [1832] = {.lex_state = 54, .external_lex_state = 14},
  [1833] = {.lex_state = 34, .external_lex_state = 17},
  [1834] = {.lex_state = 54, .external_lex_state = 15},
  [1835] = {.lex_state = 54, .external_lex_state = 15},
  [1836] = {.lex_state = 33, .external_lex_state = 13},
  [1837] = {.lex_state = 54, .external_lex_state = 14},
  [1838] = {.lex_state = 54, .external_lex_state = 15},
  [1839] = {.lex_state = 54, .external_lex_state = 15},
  [1840] = {.lex_state = 32, .external_lex_state = 15},
  [1841] = {.lex_state = 34, .external_lex_state = 17},
  [1842] = {.lex_state = 32, .external_lex_state = 12},
  [1843] = {.lex_state = 54, .external_lex_state = 14},
  [1844] = {.lex_state = 54, .external_lex_state = 14},
  [1845] = {.lex_state = 54, .external_lex_state = 12},
  [1846] = {.lex_state = 54, .external_lex_state = 15},
  [1847] = {.lex_state = 54, .external_lex_state = 15},
  [1848] = {.lex_state = 54, .external_lex_state = 15},
  [1849] = {.lex_state = 54, .external_lex_state = 9},
  [1850] = {.lex_state = 54, .external_lex_state = 9},
  [1851] = {.lex_state = 54, .external_lex_state = 15},
  [1852] = {.lex_state = 54, .external_lex_state = 15},
  [1853] = {.lex_state = 54, .external_lex_state = 9},
  [1854] = {.lex_state = 54, .external_lex_state = 15},
  [1855] = {.lex_state = 54, .external_lex_state = 15},
  [1856] = {.lex_state = 54, .external_lex_state = 15},
  [1857] = {.lex_state = 54, .external_lex_state = 15},
  [1858] = {.lex_state = 54, .external_lex_state = 9},
  [1859] = {.lex_state = 54, .external_lex_state = 9},
  [1860] = {.lex_state = 54, .external_lex_state = 15},
  [1861] = {.lex_state = 54, .external_lex_state = 9},
  [1862] = {.lex_state = 54, .external_lex_state = 12},
  [1863] = {.lex_state = 32, .external_lex_state = 14},
  [1864] = {.lex_state = 54, .external_lex_state = 12},
  [1865] = {.lex_state = 32, .external_lex_state = 12},
  [1866] = {.lex_state = 32, .external_lex_state = 15},
  [1867] = {.lex_state = 54, .external_lex_state = 15},
  [1868] = {.lex_state = 54, .external_lex_state = 12},
  [1869] = {.lex_state = 54, .external_lex_state = 14},
  [1870] = {.lex_state = 54, .external_lex_state = 12},
  [1871] = {.lex_state = 54, .external_lex_state = 13},
  [1872] = {.lex_state = 54, .external_lex_state = 9},
  [1873] = {.lex_state = 54, .external_lex_state = 14},
  [1874] = {.lex_state = 54, .external_lex_state = 13},
  [1875] = {.lex_state = 54, .external_lex_state = 15},
  [1876] = {.lex_state = 54, .external_lex_state = 12},
  [1877] = {.lex_state = 32, .external_lex_state = 12},
  [1878] = {.lex_state = 54, .external_lex_state = 13},
  [1879] = {.lex_state = 54, .external_lex_state = 13},
  [1880] = {.lex_state = 54, .external_lex_state = 15},
  [1881] = {.lex_state = 54, .external_lex_state = 13},
  [1882] = {.lex_state = 54, .external_lex_state = 14},
  [1883] = {.lex_state = 0, .external_lex_state = 16},
  [1884] = {.lex_state = 54, .external_lex_state = 13},
  [1885] = {.lex_state = 54, .external_lex_state = 13},
  [1886] = {.lex_state = 54, .external_lex_state = 12},
  [1887] = {.lex_state = 54, .external_lex_state = 8},
  [1888] = {.lex_state = 32, .external_lex_state = 14},
  [1889] = {.lex_state = 32, .external_lex_state = 15},
  [1890] = {.lex_state = 54, .external_lex_state = 12},
  [1891] = {.lex_state = 54, .external_lex_state = 12},
  [1892] = {.lex_state = 54, .external_lex_state = 12},
  [1893] = {.lex_state = 54, .external_lex_state = 15},
  [1894] = {.lex_state = 54, .external_lex_state = 14},
  [1895] = {.lex_state = 54, .external_lex_state = 6},
  [1896] = {.lex_state = 54, .external_lex_state = 12},
  [1897] = {.lex_state = 54, .external_lex_state = 15},
  [1898] = {.lex_state = 54, .external_lex_state = 7},
  [1899] = {.lex_state = 54, .external_lex_state = 9},
  [1900] = {.lex_state = 32, .external_lex_state = 15},
  [1901] = {.lex_state = 32, .external_lex_state = 12},
  [1902] = {.lex_state = 54, .external_lex_state = 14},
  [1903] = {.lex_state = 54, .external_lex_state = 15},
  [1904] = {.lex_state = 54, .external_lex_state = 14},
  [1905] = {.lex_state = 54, .external_lex_state = 12},
  [1906] = {.lex_state = 32, .external_lex_state = 13},
  [1907] = {.lex_state = 54, .external_lex_state = 13},
  [1908] = {.lex_state = 54, .external_lex_state = 13},
  [1909] = {.lex_state = 54, .external_lex_state = 12},
  [1910] = {.lex_state = 0, .external_lex_state = 16},
  [1911] = {.lex_state = 54, .external_lex_state = 15},
  [1912] = {.lex_state = 54, .external_lex_state = 15},
  [1913] = {.lex_state = 32, .external_lex_state = 14},
  [1914] = {.lex_state = 32, .external_lex_state = 9},
  [1915] = {.lex_state = 0, .external_lex_state = 16},
  [1916] = {.lex_state = 0, .external_lex_state = 16},
  [1917] = {.lex_state = 54, .external_lex_state = 13},
  [1918] = {.lex_state = 0, .external_lex_state = 16},
  [1919] = {.lex_state = 0, .external_lex_state = 16},
  [1920] = {.lex_state = 54, .external_lex_state = 14},
  [1921] = {.lex_state = 54, .external_lex_state = 12},
  [1922] = {.lex_state = 54, .external_lex_state = 14},
  [1923] = {.lex_state = 54, .external_lex_state = 13},
  [1924] = {.lex_state = 54, .external_lex_state = 15},
  [1925] = {.lex_state = 33, .external_lex_state = 15},
  [1926] = {.lex_state = 54, .external_lex_state = 14},
  [1927] = {.lex_state = 33, .external_lex_state = 13},
  [1928] = {.lex_state = 33, .external_lex_state = 15},
  [1929] = {.lex_state = 33, .external_lex_state = 14},
  [1930] = {.lex_state = 54, .external_lex_state = 12},
  [1931] = {.lex_state = 0, .external_lex_state = 16},
  [1932] = {.lex_state = 54, .external_lex_state = 12},
  [1933] = {.lex_state = 0, .external_lex_state = 16},
  [1934] = {.lex_state = 33, .external_lex_state = 14},
  [1935] = {.lex_state = 54, .external_lex_state = 13},
  [1936] = {.lex_state = 54, .external_lex_state = 9},
  [1937] = {.lex_state = 33, .external_lex_state = 14},
  [1938] = {.lex_state = 54, .external_lex_state = 13},
  [1939] = {.lex_state = 33, .external_lex_state = 15},
  [1940] = {.lex_state = 54, .external_lex_state = 14},
  [1941] = {.lex_state = 54, .external_lex_state = 15},
  [1942] = {.lex_state = 54, .external_lex_state = 15},
  [1943] = {.lex_state = 54, .external_lex_state = 15},
  [1944] = {.lex_state = 54, .external_lex_state = 14},
  [1945] = {.lex_state = 54, .external_lex_state = 14},
  [1946] = {.lex_state = 54, .external_lex_state = 14},
  [1947] = {.lex_state = 54, .external_lex_state = 15},
  [1948] = {.lex_state = 33, .external_lex_state = 9},
  [1949] = {.lex_state = 32, .external_lex_state = 14},
  [1950] = {.lex_state = 54, .external_lex_state = 13},
  [1951] = {.lex_state = 54, .external_lex_state = 12},
  [1952] = {.lex_state = 54, .external_lex_state = 14},
  [1953] = {.lex_state = 54, .external_lex_state = 12},
  [1954] = {.lex_state = 54, .external_lex_state = 12},
  [1955] = {.lex_state = 54, .external_lex_state = 13},
  [1956] = {.lex_state = 33, .external_lex_state = 9},
  [1957] = {.lex_state = 33, .external_lex_state = 14},
  [1958] = {.lex_state = 54, .external_lex_state = 13},
  [1959] = {.lex_state = 33, .external_lex_state = 9},
  [1960] = {.lex_state = 54, .external_lex_state = 9},
  [1961] = {.lex_state = 54, .external_lex_state = 13},
  [1962] = {.lex_state = 54, .external_lex_state = 14},
  [1963] = {.lex_state = 33, .external_lex_state = 14},
  [1964] = {.lex_state = 33, .external_lex_state = 14},
  [1965] = {.lex_state = 33, .external_lex_state = 14},
  [1966] = {.lex_state = 54, .external_lex_state = 14},
  [1967] = {.lex_state = 54, .external_lex_state = 15},
  [1968] = {.lex_state = 33, .external_lex_state = 9},
  [1969] = {.lex_state = 54, .external_lex_state = 13},
  [1970] = {.lex_state = 32, .external_lex_state = 15},
  [1971] = {.lex_state = 33, .external_lex_state = 9},
  [1972] = {.lex_state = 32, .external_lex_state = 12},
  [1973] = {.lex_state = 54, .external_lex_state = 14},
  [1974] = {.lex_state = 54, .external_lex_state = 14},
  [1975] = {.lex_state = 54, .external_lex_state = 14},
  [1976] = {.lex_state = 54, .external_lex_state = 15},
  [1977] = {.lex_state = 54, .external_lex_state = 12},
  [1978] = {.lex_state = 0, .external_lex_state = 16},
  [1979] = {.lex_state = 54, .external_lex_state = 15},
  [1980] = {.lex_state = 54, .external_lex_state = 15},
  [1981] = {.lex_state = 54, .external_lex_state = 12},
  [1982] = {.lex_state = 54, .external_lex_state = 12},
  [1983] = {.lex_state = 54, .external_lex_state = 14},
  [1984] = {.lex_state = 54, .external_lex_state = 9},
  [1985] = {.lex_state = 54, .external_lex_state = 14},
  [1986] = {.lex_state = 54, .external_lex_state = 15},
  [1987] = {.lex_state = 33, .external_lex_state = 14},
  [1988] = {.lex_state = 33, .external_lex_state = 14},
  [1989] = {.lex_state = 54, .external_lex_state = 15},
  [1990] = {.lex_state = 54, .external_lex_state = 14},
  [1991] = {.lex_state = 32, .external_lex_state = 9},
  [1992] = {.lex_state = 33, .external_lex_state = 15},
  [1993] = {.lex_state = 54, .external_lex_state = 13},
  [1994] = {.lex_state = 54, .external_lex_state = 13},
  [1995] = {.lex_state = 33, .external_lex_state = 9},
  [1996] = {.lex_state = 54, .external_lex_state = 12},
  [1997] = {.lex_state = 33, .external_lex_state = 9},
  [1998] = {.lex_state = 54, .external_lex_state = 12},
  [1999] = {.lex_state = 54, .external_lex_state = 15},
  [2000] = {.lex_state = 0, .external_lex_state = 16},
  [2001] = {.lex_state = 33, .external_lex_state = 9},
  [2002] = {.lex_state = 32, .external_lex_state = 9},
  [2003] = {.lex_state = 33, .external_lex_state = 13},
  [2004] = {.lex_state = 33, .external_lex_state = 9},
  [2005] = {.lex_state = 54, .external_lex_state = 15},
  [2006] = {.lex_state = 54, .external_lex_state = 12},
  [2007] = {.lex_state = 33, .external_lex_state = 14},
  [2008] = {.lex_state = 54, .external_lex_state = 13},
  [2009] = {.lex_state = 54, .external_lex_state = 14},
  [2010] = {.lex_state = 54, .external_lex_state = 13},
  [2011] = {.lex_state = 54, .external_lex_state = 14},
  [2012] = {.lex_state = 54, .external_lex_state = 12},
  [2013] = {.lex_state = 54, .external_lex_state = 13},
  [2014] = {.lex_state = 54, .external_lex_state = 12},
  [2015] = {.lex_state = 54, .external_lex_state = 15},
  [2016] = {.lex_state = 33, .external_lex_state = 9},
  [2017] = {.lex_state = 33, .external_lex_state = 13},
  [2018] = {.lex_state = 54, .external_lex_state = 12},
  [2019] = {.lex_state = 54, .external_lex_state = 13},
  [2020] = {.lex_state = 54, .external_lex_state = 13},
  [2021] = {.lex_state = 54, .external_lex_state = 13},
  [2022] = {.lex_state = 54, .external_lex_state = 13},
  [2023] = {.lex_state = 33, .external_lex_state = 13},
  [2024] = {.lex_state = 54, .external_lex_state = 12},
  [2025] = {.lex_state = 54, .external_lex_state = 13},
  [2026] = {.lex_state = 54, .external_lex_state = 12},
  [2027] = {.lex_state = 54, .external_lex_state = 15},
  [2028] = {.lex_state = 54, .external_lex_state = 15},
  [2029] = {.lex_state = 54, .external_lex_state = 9},
  [2030] = {.lex_state = 54, .external_lex_state = 13},
  [2031] = {.lex_state = 54, .external_lex_state = 13},
  [2032] = {.lex_state = 54, .external_lex_state = 12},
  [2033] = {.lex_state = 54, .external_lex_state = 12},
  [2034] = {.lex_state = 54, .external_lex_state = 12},
  [2035] = {.lex_state = 54, .external_lex_state = 14},
  [2036] = {.lex_state = 54, .external_lex_state = 12},
  [2037] = {.lex_state = 54, .external_lex_state = 13},
  [2038] = {.lex_state = 33, .external_lex_state = 15},
  [2039] = {.lex_state = 33, .external_lex_state = 15},
  [2040] = {.lex_state = 54, .external_lex_state = 12},
  [2041] = {.lex_state = 3, .external_lex_state = 12},
  [2042] = {.lex_state = 54, .external_lex_state = 12},
  [2043] = {.lex_state = 54, .external_lex_state = 12},
  [2044] = {.lex_state = 33, .external_lex_state = 15},
  [2045] = {.lex_state = 54, .external_lex_state = 13},
  [2046] = {.lex_state = 54, .external_lex_state = 13},
  [2047] = {.lex_state = 54, .external_lex_state = 14},
  [2048] = {.lex_state = 54, .external_lex_state = 15},
  [2049] = {.lex_state = 3, .external_lex_state = 12},
  [2050] = {.lex_state = 54, .external_lex_state = 9},
  [2051] = {.lex_state = 33, .external_lex_state = 13},
  [2052] = {.lex_state = 33, .external_lex_state = 13},
  [2053] = {.lex_state = 54, .external_lex_state = 12},
  [2054] = {.lex_state = 54, .external_lex_state = 13},
  [2055] = {.lex_state = 54, .external_lex_state = 12},
  [2056] = {.lex_state = 54, .external_lex_state = 13},
  [2057] = {.lex_state = 54, .external_lex_state = 13},
  [2058] = {.lex_state = 54, .external_lex_state = 12},
  [2059] = {.lex_state = 54, .external_lex_state = 12},
  [2060] = {.lex_state = 54, .external_lex_state = 13},
  [2061] = {.lex_state = 33, .external_lex_state = 15},
  [2062] = {.lex_state = 33, .external_lex_state = 15},
  [2063] = {.lex_state = 33, .external_lex_state = 13},
  [2064] = {.lex_state = 54, .external_lex_state = 13},
  [2065] = {.lex_state = 54, .external_lex_state = 12},
  [2066] = {.lex_state = 54, .external_lex_state = 13},
  [2067] = {.lex_state = 54, .external_lex_state = 13},
  [2068] = {.lex_state = 33, .external_lex_state = 13},
  [2069] = {.lex_state = 33, .external_lex_state = 15},
  [2070] = {.lex_state = 54, .external_lex_state = 12},
  [2071] = {.lex_state = 54, .external_lex_state = 13},
  [2072] = {.lex_state = 54, .external_lex_state = 13},
  [2073] = {.lex_state = 33, .external_lex_state = 15},
  [2074] = {.lex_state = 54, .external_lex_state = 9},
  [2075] = {.lex_state = 54, .external_lex_state = 14},
  [2076] = {.lex_state = 54, .external_lex_state = 14},
  [2077] = {.lex_state = 33, .external_lex_state = 15},
  [2078] = {.lex_state = 33, .external_lex_state = 14},
  [2079] = {.lex_state = 54, .external_lex_state = 13},
  [2080] = {.lex_state = 33, .external_lex_state = 9},
  [2081] = {.lex_state = 54, .external_lex_state = 9},
  [2082] = {.lex_state = 54, .external_lex_state = 13},
  [2083] = {.lex_state = 54, .external_lex_state = 13},
  [2084] = {.lex_state = 54, .external_lex_state = 13},
  [2085] = {.lex_state = 54, .external_lex_state = 12},
  [2086] = {.lex_state = 54, .external_lex_state = 9},
  [2087] = {.lex_state = 54, .external_lex_state = 9},
  [2088] = {.lex_state = 54, .external_lex_state = 13},
  [2089] = {.lex_state = 54, .external_lex_state = 13},
  [2090] = {.lex_state = 54, .external_lex_state = 13},
  [2091] = {.lex_state = 54, .external_lex_state = 13},
  [2092] = {.lex_state = 33, .external_lex_state = 13},
  [2093] = {.lex_state = 54, .external_lex_state = 13},
  [2094] = {.lex_state = 54, .external_lex_state = 13},
  [2095] = {.lex_state = 54, .external_lex_state = 13},
  [2096] = {.lex_state = 54, .external_lex_state = 13},
  [2097] = {.lex_state = 33, .external_lex_state = 15},
  [2098] = {.lex_state = 54, .external_lex_state = 12},
  [2099] = {.lex_state = 32, .external_lex_state = 9},
  [2100] = {.lex_state = 54, .external_lex_state = 13},
  [2101] = {.lex_state = 54, .external_lex_state = 12},
  [2102] = {.lex_state = 54, .external_lex_state = 9},
  [2103] = {.lex_state = 54, .external_lex_state = 13},
  [2104] = {.lex_state = 54, .external_lex_state = 13},
  [2105] = {.lex_state = 54, .external_lex_state = 13},
  [2106] = {.lex_state = 54, .external_lex_state = 15},
  [2107] = {.lex_state = 54, .external_lex_state = 13},
  [2108] = {.lex_state = 54, .external_lex_state = 13},
  [2109] = {.lex_state = 54, .external_lex_state = 12},
  [2110] = {.lex_state = 54, .external_lex_state = 14},
  [2111] = {.lex_state = 54, .external_lex_state = 14},
  [2112] = {.lex_state = 54, .external_lex_state = 14},
  [2113] = {.lex_state = 54, .external_lex_state = 13},
  [2114] = {.lex_state = 54, .external_lex_state = 13},
  [2115] = {.lex_state = 54, .external_lex_state = 15},
  [2116] = {.lex_state = 3, .external_lex_state = 12},
  [2117] = {.lex_state = 54, .external_lex_state = 13},
  [2118] = {.lex_state = 54, .external_lex_state = 14},
  [2119] = {.lex_state = 54, .external_lex_state = 13},
  [2120] = {.lex_state = 54, .external_lex_state = 13},
  [2121] = {.lex_state = 54, .external_lex_state = 13},
  [2122] = {.lex_state = 54, .external_lex_state = 15},
  [2123] = {.lex_state = 54, .external_lex_state = 13},
  [2124] = {.lex_state = 54, .external_lex_state = 13},
  [2125] = {.lex_state = 54, .external_lex_state = 13},
  [2126] = {.lex_state = 54, .external_lex_state = 13},
  [2127] = {.lex_state = 54, .external_lex_state = 12},
  [2128] = {.lex_state = 54, .external_lex_state = 13},
  [2129] = {.lex_state = 54, .external_lex_state = 15},
  [2130] = {.lex_state = 54, .external_lex_state = 12},
  [2131] = {.lex_state = 54, .external_lex_state = 14},
  [2132] = {.lex_state = 54, .external_lex_state = 13},
  [2133] = {.lex_state = 54, .external_lex_state = 15},
  [2134] = {.lex_state = 54, .external_lex_state = 13},
  [2135] = {.lex_state = 54, .external_lex_state = 15},
  [2136] = {.lex_state = 33, .external_lex_state = 15},
  [2137] = {.lex_state = 33, .external_lex_state = 13},
  [2138] = {.lex_state = 54, .external_lex_state = 13},
  [2139] = {.lex_state = 54, .external_lex_state = 18},
  [2140] = {.lex_state = 33, .external_lex_state = 13},
  [2141] = {.lex_state = 54, .external_lex_state = 9},
  [2142] = {.lex_state = 54, .external_lex_state = 12},
  [2143] = {.lex_state = 54, .external_lex_state = 12},
  [2144] = {.lex_state = 54, .external_lex_state = 14},
  [2145] = {.lex_state = 54, .external_lex_state = 14},
  [2146] = {.lex_state = 54, .external_lex_state = 14},
  [2147] = {.lex_state = 54, .external_lex_state = 14},
  [2148] = {.lex_state = 54, .external_lex_state = 14},
  [2149] = {.lex_state = 54, .external_lex_state = 9},
  [2150] = {.lex_state = 54, .external_lex_state = 14},
  [2151] = {.lex_state = 54, .external_lex_state = 9},
  [2152] = {.lex_state = 54, .external_lex_state = 14},
  [2153] = {.lex_state = 54, .external_lex_state = 13},
  [2154] = {.lex_state = 54, .external_lex_state = 14},
  [2155] = {.lex_state = 54, .external_lex_state = 15},
  [2156] = {.lex_state = 54, .external_lex_state = 14},
  [2157] = {.lex_state = 54, .external_lex_state = 14},
  [2158] = {.lex_state = 54, .external_lex_state = 12},
  [2159] = {.lex_state = 54, .external_lex_state = 13},
  [2160] = {.lex_state = 54, .external_lex_state = 9},
  [2161] = {.lex_state = 54, .external_lex_state = 18},
  [2162] = {.lex_state = 54, .external_lex_state = 9},
  [2163] = {.lex_state = 54, .external_lex_state = 14},
  [2164] = {.lex_state = 54, .external_lex_state = 18},
  [2165] = {.lex_state = 54, .external_lex_state = 14},
  [2166] = {.lex_state = 54, .external_lex_state = 14},
  [2167] = {.lex_state = 54, .external_lex_state = 14},
  [2168] = {.lex_state = 54, .external_lex_state = 14},
  [2169] = {.lex_state = 54, .external_lex_state = 14},
  [2170] = {.lex_state = 54, .external_lex_state = 14},
  [2171] = {.lex_state = 54, .external_lex_state = 13},
  [2172] = {.lex_state = 54, .external_lex_state = 15},
  [2173] = {.lex_state = 32, .external_lex_state = 13},
  [2174] = {.lex_state = 54, .external_lex_state = 9},
  [2175] = {.lex_state = 54, .external_lex_state = 14},
  [2176] = {.lex_state = 54, .external_lex_state = 14},
  [2177] = {.lex_state = 54, .external_lex_state = 9},
  [2178] = {.lex_state = 54, .external_lex_state = 9},
  [2179] = {.lex_state = 54, .external_lex_state = 14},
  [2180] = {.lex_state = 54, .external_lex_state = 14},
  [2181] = {.lex_state = 54, .external_lex_state = 14},
  [2182] = {.lex_state = 54, .external_lex_state = 14},
  [2183] = {.lex_state = 54, .external_lex_state = 14},
  [2184] = {.lex_state = 54, .external_lex_state = 14},
  [2185] = {.lex_state = 54, .external_lex_state = 14},
  [2186] = {.lex_state = 54, .external_lex_state = 15},
  [2187] = {.lex_state = 54, .external_lex_state = 14},
  [2188] = {.lex_state = 54, .external_lex_state = 15},
  [2189] = {.lex_state = 54, .external_lex_state = 14},
  [2190] = {.lex_state = 54, .external_lex_state = 14},
  [2191] = {.lex_state = 54, .external_lex_state = 12},
  [2192] = {.lex_state = 54, .external_lex_state = 9},
  [2193] = {.lex_state = 54, .external_lex_state = 15},
  [2194] = {.lex_state = 54, .external_lex_state = 13},
  [2195] = {.lex_state = 54, .external_lex_state = 15},
  [2196] = {.lex_state = 54, .external_lex_state = 14},
  [2197] = {.lex_state = 54, .external_lex_state = 13},
  [2198] = {.lex_state = 54, .external_lex_state = 14},
  [2199] = {.lex_state = 33, .external_lex_state = 13},
  [2200] = {.lex_state = 54, .external_lex_state = 13},
  [2201] = {.lex_state = 54, .external_lex_state = 9},
  [2202] = {.lex_state = 54, .external_lex_state = 12},
  [2203] = {.lex_state = 54, .external_lex_state = 14},
  [2204] = {.lex_state = 54, .external_lex_state = 15},
  [2205] = {.lex_state = 54, .external_lex_state = 13},
  [2206] = {.lex_state = 54, .external_lex_state = 14},
  [2207] = {.lex_state = 54, .external_lex_state = 15},
  [2208] = {.lex_state = 54, .external_lex_state = 12},
  [2209] = {.lex_state = 54, .external_lex_state = 15},
  [2210] = {.lex_state = 54, .external_lex_state = 12},
  [2211] = {.lex_state = 54, .external_lex_state = 12},
  [2212] = {.lex_state = 54, .external_lex_state = 12},
  [2213] = {.lex_state = 54, .external_lex_state = 12},
  [2214] = {.lex_state = 54, .external_lex_state = 14},
  [2215] = {.lex_state = 54, .external_lex_state = 15},
  [2216] = {.lex_state = 54, .external_lex_state = 12},
  [2217] = {.lex_state = 54, .external_lex_state = 12},
  [2218] = {.lex_state = 54, .external_lex_state = 12},
  [2219] = {.lex_state = 54, .external_lex_state = 15},
  [2220] = {.lex_state = 54, .external_lex_state = 15},
  [2221] = {.lex_state = 54, .external_lex_state = 12},
  [2222] = {.lex_state = 54, .external_lex_state = 18},
  [2223] = {.lex_state = 54, .external_lex_state = 13},
  [2224] = {.lex_state = 54, .external_lex_state = 12},
  [2225] = {.lex_state = 54, .external_lex_state = 9},
  [2226] = {.lex_state = 54, .external_lex_state = 13},
  [2227] = {.lex_state = 54, .external_lex_state = 15},
  [2228] = {.lex_state = 54, .external_lex_state = 9},
  [2229] = {.lex_state = 54, .external_lex_state = 18},
  [2230] = {.lex_state = 54, .external_lex_state = 12},
  [2231] = {.lex_state = 54, .external_lex_state = 14},
  [2232] = {.lex_state = 54, .external_lex_state = 9},
  [2233] = {.lex_state = 54, .external_lex_state = 9},
  [2234] = {.lex_state = 54, .external_lex_state = 12},
  [2235] = {.lex_state = 54, .external_lex_state = 12},
  [2236] = {.lex_state = 54, .external_lex_state = 13},
  [2237] = {.lex_state = 32, .external_lex_state = 13},
  [2238] = {.lex_state = 54, .external_lex_state = 14},
  [2239] = {.lex_state = 54, .external_lex_state = 15},
  [2240] = {.lex_state = 54, .external_lex_state = 15},
  [2241] = {.lex_state = 54, .external_lex_state = 15},
  [2242] = {.lex_state = 54, .external_lex_state = 15},
  [2243] = {.lex_state = 54, .external_lex_state = 15},
  [2244] = {.lex_state = 54, .external_lex_state = 14},
  [2245] = {.lex_state = 54, .external_lex_state = 15},
  [2246] = {.lex_state = 54, .external_lex_state = 15},
  [2247] = {.lex_state = 54, .external_lex_state = 12},
  [2248] = {.lex_state = 54, .external_lex_state = 15},
  [2249] = {.lex_state = 54, .external_lex_state = 13},
  [2250] = {.lex_state = 54, .external_lex_state = 15},
  [2251] = {.lex_state = 54, .external_lex_state = 12},
  [2252] = {.lex_state = 54, .external_lex_state = 15},
  [2253] = {.lex_state = 54, .external_lex_state = 12},
  [2254] = {.lex_state = 54, .external_lex_state = 15},
  [2255] = {.lex_state = 54, .external_lex_state = 12},
  [2256] = {.lex_state = 54, .external_lex_state = 12},
  [2257] = {.lex_state = 54, .external_lex_state = 15},
  [2258] = {.lex_state = 54, .external_lex_state = 12},
  [2259] = {.lex_state = 54, .external_lex_state = 12},
  [2260] = {.lex_state = 54, .external_lex_state = 15},
  [2261] = {.lex_state = 54, .external_lex_state = 15},
  [2262] = {.lex_state = 54, .external_lex_state = 12},
  [2263] = {.lex_state = 54, .external_lex_state = 9},
  [2264] = {.lex_state = 54, .external_lex_state = 9},
  [2265] = {.lex_state = 54, .external_lex_state = 15},
  [2266] = {.lex_state = 54, .external_lex_state = 9},
  [2267] = {.lex_state = 54, .external_lex_state = 13},
  [2268] = {.lex_state = 54, .external_lex_state = 9},
  [2269] = {.lex_state = 54, .external_lex_state = 14},
  [2270] = {.lex_state = 54, .external_lex_state = 13},
  [2271] = {.lex_state = 54, .external_lex_state = 12},
  [2272] = {.lex_state = 54, .external_lex_state = 13},
  [2273] = {.lex_state = 34, .external_lex_state = 17},
  [2274] = {.lex_state = 54, .external_lex_state = 19},
  [2275] = {.lex_state = 54, .external_lex_state = 19},
  [2276] = {.lex_state = 54, .external_lex_state = 12},
  [2277] = {.lex_state = 54, .external_lex_state = 15},
  [2278] = {.lex_state = 54, .external_lex_state = 15},
  [2279] = {.lex_state = 54, .external_lex_state = 9},
  [2280] = {.lex_state = 54, .external_lex_state = 15},
  [2281] = {.lex_state = 54, .external_lex_state = 13},
  [2282] = {.lex_state = 54, .external_lex_state = 13},
  [2283] = {.lex_state = 33, .external_lex_state = 13},
  [2284] = {.lex_state = 54, .external_lex_state = 14},
  [2285] = {.lex_state = 54, .external_lex_state = 14},
  [2286] = {.lex_state = 54, .external_lex_state = 15},
  [2287] = {.lex_state = 54, .external_lex_state = 9},
  [2288] = {.lex_state = 3, .external_lex_state = 12},
  [2289] = {.lex_state = 54, .external_lex_state = 9},
  [2290] = {.lex_state = 54, .external_lex_state = 12},
  [2291] = {.lex_state = 3, .external_lex_state = 12},
  [2292] = {.lex_state = 3, .external_lex_state = 12},
  [2293] = {.lex_state = 54, .external_lex_state = 12},
  [2294] = {.lex_state = 3, .external_lex_state = 12},
  [2295] = {.lex_state = 3, .external_lex_state = 12},
  [2296] = {.lex_state = 54, .external_lex_state = 14},
  [2297] = {.lex_state = 54, .external_lex_state = 14},
  [2298] = {.lex_state = 54, .external_lex_state = 15},
  [2299] = {.lex_state = 54, .external_lex_state = 19},
  [2300] = {.lex_state = 54, .external_lex_state = 15},
  [2301] = {.lex_state = 3, .external_lex_state = 12},
  [2302] = {.lex_state = 54, .external_lex_state = 14},
  [2303] = {.lex_state = 54, .external_lex_state = 9},
  [2304] = {.lex_state = 34, .external_lex_state = 17},
  [2305] = {.lex_state = 54, .external_lex_state = 15},
  [2306] = {.lex_state = 54, .external_lex_state = 12},
  [2307] = {.lex_state = 54, .external_lex_state = 14},
  [2308] = {.lex_state = 54, .external_lex_state = 15},
  [2309] = {.lex_state = 54, .external_lex_state = 14},
  [2310] = {.lex_state = 54, .external_lex_state = 9},
  [2311] = {.lex_state = 54, .external_lex_state = 15},
  [2312] = {.lex_state = 54, .external_lex_state = 15},
  [2313] = {.lex_state = 54, .external_lex_state = 15},
  [2314] = {.lex_state = 54, .external_lex_state = 14},
  [2315] = {.lex_state = 54, .external_lex_state = 13},
  [2316] = {.lex_state = 54, .external_lex_state = 15},
  [2317] = {.lex_state = 54, .external_lex_state = 14},
  [2318] = {.lex_state = 54, .external_lex_state = 14},
  [2319] = {.lex_state = 54, .external_lex_state = 9},
  [2320] = {.lex_state = 54, .external_lex_state = 14},
  [2321] = {.lex_state = 33, .external_lex_state = 13},
  [2322] = {.lex_state = 54, .external_lex_state = 14},
  [2323] = {.lex_state = 54, .external_lex_state = 14},
  [2324] = {.lex_state = 54, .external_lex_state = 14},
  [2325] = {.lex_state = 54, .external_lex_state = 13},
  [2326] = {.lex_state = 34, .external_lex_state = 17},
  [2327] = {.lex_state = 3, .external_lex_state = 12},
  [2328] = {.lex_state = 54, .external_lex_state = 14},
  [2329] = {.lex_state = 54, .external_lex_state = 14},
  [2330] = {.lex_state = 54, .external_lex_state = 14},
  [2331] = {.lex_state = 54, .external_lex_state = 12},
  [2332] = {.lex_state = 54, .external_lex_state = 14},
  [2333] = {.lex_state = 54, .external_lex_state = 13},
  [2334] = {.lex_state = 54, .external_lex_state = 14},
  [2335] = {.lex_state = 33, .external_lex_state = 13},
  [2336] = {.lex_state = 54, .external_lex_state = 14},
  [2337] = {.lex_state = 54, .external_lex_state = 12},
  [2338] = {.lex_state = 54, .external_lex_state = 14},
  [2339] = {.lex_state = 54, .external_lex_state = 15},
  [2340] = {.lex_state = 54, .external_lex_state = 15},
  [2341] = {.lex_state = 54, .external_lex_state = 19},
  [2342] = {.lex_state = 33, .external_lex_state = 13},
  [2343] = {.lex_state = 54, .external_lex_state = 12},
  [2344] = {.lex_state = 33, .external_lex_state = 13},
  [2345] = {.lex_state = 54, .external_lex_state = 12},
  [2346] = {.lex_state = 33, .external_lex_state = 13},
  [2347] = {.lex_state = 54, .external_lex_state = 13},
  [2348] = {.lex_state = 33, .external_lex_state = 13},
  [2349] = {.lex_state = 54, .external_lex_state = 12},
  [2350] = {.lex_state = 54, .external_lex_state = 13},
  [2351] = {.lex_state = 54, .external_lex_state = 14},
  [2352] = {.lex_state = 54, .external_lex_state = 13},
  [2353] = {.lex_state = 54, .external_lex_state = 14},
  [2354] = {.lex_state = 54, .external_lex_state = 13},
  [2355] = {.lex_state = 54, .external_lex_state = 13},
  [2356] = {.lex_state = 54, .external_lex_state = 9},
  [2357] = {.lex_state = 3, .external_lex_state = 12},
  [2358] = {.lex_state = 54, .external_lex_state = 12},
  [2359] = {.lex_state = 54, .external_lex_state = 12},
  [2360] = {.lex_state = 54, .external_lex_state = 15},
  [2361] = {.lex_state = 54, .external_lex_state = 12},
  [2362] = {.lex_state = 54, .external_lex_state = 14},
  [2363] = {.lex_state = 54, .external_lex_state = 13},
  [2364] = {.lex_state = 54, .external_lex_state = 12},
  [2365] = {.lex_state = 54, .external_lex_state = 9},
  [2366] = {.lex_state = 54, .external_lex_state = 12},
  [2367] = {.lex_state = 54, .external_lex_state = 15},
  [2368] = {.lex_state = 54, .external_lex_state = 14},
  [2369] = {.lex_state = 54, .external_lex_state = 9},
  [2370] = {.lex_state = 54, .external_lex_state = 14},
  [2371] = {.lex_state = 54, .external_lex_state = 14},
  [2372] = {.lex_state = 54, .external_lex_state = 15},
  [2373] = {.lex_state = 54, .external_lex_state = 14},
  [2374] = {.lex_state = 54, .external_lex_state = 15},
  [2375] = {.lex_state = 54, .external_lex_state = 19},
  [2376] = {.lex_state = 54, .external_lex_state = 14},
  [2377] = {.lex_state = 54, .external_lex_state = 15},
  [2378] = {.lex_state = 54, .external_lex_state = 15},
  [2379] = {.lex_state = 54, .external_lex_state = 14},
  [2380] = {.lex_state = 54, .external_lex_state = 15},
  [2381] = {.lex_state = 54, .external_lex_state = 12},
  [2382] = {.lex_state = 54, .external_lex_state = 13},
  [2383] = {.lex_state = 54, .external_lex_state = 15},
  [2384] = {.lex_state = 54, .external_lex_state = 14},
  [2385] = {.lex_state = 54, .external_lex_state = 15},
  [2386] = {.lex_state = 54, .external_lex_state = 9},
  [2387] = {.lex_state = 54, .external_lex_state = 9},
  [2388] = {.lex_state = 54, .external_lex_state = 19},
  [2389] = {.lex_state = 54, .external_lex_state = 13},
  [2390] = {.lex_state = 54, .external_lex_state = 14},
  [2391] = {.lex_state = 54, .external_lex_state = 12},
  [2392] = {.lex_state = 54, .external_lex_state = 15},
  [2393] = {.lex_state = 54, .external_lex_state = 15},
  [2394] = {.lex_state = 54, .external_lex_state = 14},
  [2395] = {.lex_state = 54, .external_lex_state = 12},
  [2396] = {.lex_state = 54, .external_lex_state = 14},
  [2397] = {.lex_state = 54, .external_lex_state = 14},
  [2398] = {.lex_state = 54, .external_lex_state = 13},
  [2399] = {.lex_state = 54, .external_lex_state = 15},
  [2400] = {.lex_state = 54, .external_lex_state = 14},
  [2401] = {.lex_state = 54, .external_lex_state = 14},
  [2402] = {.lex_state = 54, .external_lex_state = 14},
  [2403] = {.lex_state = 54, .external_lex_state = 15},
  [2404] = {.lex_state = 54, .external_lex_state = 14},
  [2405] = {.lex_state = 54, .external_lex_state = 15},
  [2406] = {.lex_state = 54, .external_lex_state = 14},
  [2407] = {.lex_state = 54, .external_lex_state = 19},
  [2408] = {.lex_state = 54, .external_lex_state = 13},
  [2409] = {.lex_state = 54, .external_lex_state = 12},
  [2410] = {.lex_state = 54, .external_lex_state = 15},
  [2411] = {.lex_state = 54, .external_lex_state = 12},
  [2412] = {.lex_state = 54, .external_lex_state = 14},
  [2413] = {.lex_state = 54, .external_lex_state = 12},
  [2414] = {.lex_state = 54, .external_lex_state = 14},
  [2415] = {.lex_state = 54, .external_lex_state = 9},
  [2416] = {.lex_state = 54, .external_lex_state = 15},
  [2417] = {.lex_state = 54, .external_lex_state = 15},
  [2418] = {.lex_state = 54, .external_lex_state = 14},
  [2419] = {.lex_state = 54, .external_lex_state = 15},
  [2420] = {.lex_state = 34, .external_lex_state = 17},
  [2421] = {.lex_state = 54, .external_lex_state = 12},
  [2422] = {.lex_state = 54, .external_lex_state = 14},
  [2423] = {.lex_state = 54, .external_lex_state = 12},
  [2424] = {.lex_state = 54, .external_lex_state = 14},
  [2425] = {.lex_state = 54, .external_lex_state = 9},
  [2426] = {.lex_state = 34, .external_lex_state = 17},
  [2427] = {.lex_state = 54, .external_lex_state = 13},
  [2428] = {.lex_state = 54, .external_lex_state = 12},
  [2429] = {.lex_state = 33, .external_lex_state = 13},
  [2430] = {.lex_state = 54, .external_lex_state = 13},
  [2431] = {.lex_state = 54, .external_lex_state = 14},
  [2432] = {.lex_state = 54, .external_lex_state = 12},
  [2433] = {.lex_state = 54, .external_lex_state = 12},
  [2434] = {.lex_state = 54, .external_lex_state = 15},
  [2435] = {.lex_state = 54, .external_lex_state = 13},
  [2436] = {.lex_state = 54, .external_lex_state = 12},
  [2437] = {.lex_state = 54, .external_lex_state = 14},
  [2438] = {.lex_state = 54, .external_lex_state = 14},
  [2439] = {.lex_state = 54, .external_lex_state = 15},
  [2440] = {.lex_state = 54, .external_lex_state = 15},
  [2441] = {.lex_state = 54, .external_lex_state = 15},
  [2442] = {.lex_state = 54, .external_lex_state = 13},
  [2443] = {.lex_state = 54, .external_lex_state = 12},
  [2444] = {.lex_state = 54, .external_lex_state = 14},
  [2445] = {.lex_state = 54, .external_lex_state = 12},
  [2446] = {.lex_state = 54, .external_lex_state = 13},
  [2447] = {.lex_state = 54, .external_lex_state = 14},
  [2448] = {.lex_state = 54, .external_lex_state = 14},
  [2449] = {.lex_state = 54, .external_lex_state = 9},
  [2450] = {.lex_state = 54, .external_lex_state = 15},
  [2451] = {.lex_state = 54, .external_lex_state = 13},
  [2452] = {.lex_state = 54, .external_lex_state = 14},
  [2453] = {.lex_state = 54, .external_lex_state = 15},
  [2454] = {.lex_state = 54, .external_lex_state = 13},
  [2455] = {.lex_state = 54, .external_lex_state = 14},
  [2456] = {.lex_state = 54, .external_lex_state = 13},
  [2457] = {.lex_state = 54, .external_lex_state = 14},
  [2458] = {.lex_state = 54, .external_lex_state = 15},
  [2459] = {.lex_state = 54, .external_lex_state = 14},
  [2460] = {.lex_state = 54, .external_lex_state = 14},
  [2461] = {.lex_state = 54, .external_lex_state = 13},
  [2462] = {.lex_state = 54, .external_lex_state = 9},
  [2463] = {.lex_state = 54, .external_lex_state = 12},
  [2464] = {.lex_state = 3, .external_lex_state = 12},
  [2465] = {.lex_state = 54, .external_lex_state = 14},
  [2466] = {.lex_state = 54, .external_lex_state = 14},
  [2467] = {.lex_state = 54, .external_lex_state = 15},
  [2468] = {.lex_state = 54, .external_lex_state = 14},
  [2469] = {.lex_state = 54, .external_lex_state = 9},
  [2470] = {.lex_state = 54, .external_lex_state = 12},
  [2471] = {.lex_state = 54, .external_lex_state = 14},
  [2472] = {.lex_state = 54, .external_lex_state = 9},
  [2473] = {.lex_state = 54, .external_lex_state = 14},
  [2474] = {.lex_state = 54, .external_lex_state = 14},
  [2475] = {.lex_state = 54, .external_lex_state = 15},
  [2476] = {.lex_state = 54, .external_lex_state = 12},
  [2477] = {.lex_state = 54, .external_lex_state = 9},
  [2478] = {.lex_state = 54, .external_lex_state = 12},
  [2479] = {.lex_state = 54, .external_lex_state = 14},
  [2480] = {.lex_state = 54, .external_lex_state = 9},
  [2481] = {.lex_state = 54, .external_lex_state = 9},
  [2482] = {.lex_state = 54, .external_lex_state = 14},
  [2483] = {.lex_state = 54, .external_lex_state = 19},
  [2484] = {.lex_state = 54, .external_lex_state = 15},
  [2485] = {.lex_state = 54, .external_lex_state = 15},
  [2486] = {.lex_state = 54, .external_lex_state = 15},
  [2487] = {.lex_state = 54, .external_lex_state = 14},
  [2488] = {.lex_state = 54, .external_lex_state = 12},
  [2489] = {.lex_state = 54, .external_lex_state = 12},
  [2490] = {.lex_state = 54, .external_lex_state = 14},
  [2491] = {.lex_state = 54, .external_lex_state = 13},
  [2492] = {.lex_state = 54, .external_lex_state = 15},
  [2493] = {.lex_state = 54, .external_lex_state = 12},
  [2494] = {.lex_state = 54, .external_lex_state = 13},
  [2495] = {.lex_state = 54, .external_lex_state = 14},
  [2496] = {.lex_state = 54, .external_lex_state = 14},
  [2497] = {.lex_state = 54, .external_lex_state = 14},
  [2498] = {.lex_state = 54, .external_lex_state = 15},
  [2499] = {.lex_state = 54, .external_lex_state = 15},
  [2500] = {.lex_state = 54, .external_lex_state = 14},
  [2501] = {.lex_state = 54, .external_lex_state = 14},
  [2502] = {.lex_state = 54, .external_lex_state = 9},
  [2503] = {.lex_state = 54, .external_lex_state = 13},
  [2504] = {.lex_state = 54, .external_lex_state = 14},
  [2505] = {.lex_state = 54, .external_lex_state = 13},
  [2506] = {.lex_state = 54, .external_lex_state = 14},
  [2507] = {.lex_state = 54, .external_lex_state = 13},
  [2508] = {.lex_state = 54, .external_lex_state = 15},
  [2509] = {.lex_state = 54, .external_lex_state = 15},
  [2510] = {.lex_state = 54, .external_lex_state = 12},
  [2511] = {.lex_state = 54, .external_lex_state = 12},
  [2512] = {.lex_state = 54, .external_lex_state = 13},
  [2513] = {.lex_state = 54, .external_lex_state = 9},
  [2514] = {.lex_state = 54, .external_lex_state = 14},
  [2515] = {.lex_state = 54, .external_lex_state = 14},
  [2516] = {.lex_state = 54, .external_lex_state = 15},
  [2517] = {.lex_state = 54, .external_lex_state = 12},
  [2518] = {.lex_state = 54, .external_lex_state = 12},
  [2519] = {.lex_state = 54, .external_lex_state = 14},
  [2520] = {.lex_state = 54, .external_lex_state = 14},
  [2521] = {.lex_state = 54, .external_lex_state = 15},
  [2522] = {.lex_state = 54, .external_lex_state = 9},
  [2523] = {.lex_state = 54, .external_lex_state = 14},
  [2524] = {.lex_state = 54, .external_lex_state = 14},
  [2525] = {.lex_state = 54, .external_lex_state = 14},
  [2526] = {.lex_state = 54, .external_lex_state = 15},
  [2527] = {.lex_state = 54, .external_lex_state = 14},
  [2528] = {.lex_state = 54, .external_lex_state = 18},
  [2529] = {.lex_state = 54, .external_lex_state = 9},
  [2530] = {.lex_state = 54, .external_lex_state = 13},
  [2531] = {.lex_state = 54, .external_lex_state = 18},
  [2532] = {.lex_state = 54, .external_lex_state = 13},
  [2533] = {.lex_state = 54, .external_lex_state = 9},
  [2534] = {.lex_state = 54, .external_lex_state = 18},
  [2535] = {.lex_state = 54, .external_lex_state = 12},
  [2536] = {.lex_state = 54, .external_lex_state = 18},
  [2537] = {.lex_state = 54, .external_lex_state = 9},
  [2538] = {.lex_state = 34, .external_lex_state = 13},
  [2539] = {.lex_state = 54, .external_lex_state = 13},
  [2540] = {.lex_state = 54, .external_lex_state = 9},
  [2541] = {.lex_state = 54, .external_lex_state = 9},
  [2542] = {.lex_state = 54, .external_lex_state = 13},
  [2543] = {.lex_state = 54, .external_lex_state = 13},
  [2544] = {.lex_state = 54, .external_lex_state = 9},
  [2545] = {.lex_state = 54, .external_lex_state = 18},
  [2546] = {.lex_state = 54, .external_lex_state = 15},
  [2547] = {.lex_state = 54, .external_lex_state = 18},
  [2548] = {.lex_state = 54, .external_lex_state = 18},
  [2549] = {.lex_state = 54, .external_lex_state = 13},
  [2550] = {.lex_state = 54, .external_lex_state = 18},
  [2551] = {.lex_state = 54, .external_lex_state = 9},
  [2552] = {.lex_state = 54, .external_lex_state = 13},
  [2553] = {.lex_state = 54, .external_lex_state = 9},
  [2554] = {.lex_state = 54, .external_lex_state = 14},
  [2555] = {.lex_state = 54, .external_lex_state = 18},
  [2556] = {.lex_state = 54, .external_lex_state = 14},
  [2557] = {.lex_state = 54, .external_lex_state = 9},
  [2558] = {.lex_state = 54, .external_lex_state = 18},
  [2559] = {.lex_state = 54, .external_lex_state = 9},
  [2560] = {.lex_state = 54, .external_lex_state = 18},
  [2561] = {.lex_state = 54, .external_lex_state = 13},
  [2562] = {.lex_state = 54, .external_lex_state = 18},
  [2563] = {.lex_state = 54, .external_lex_state = 13},
  [2564] = {.lex_state = 54, .external_lex_state = 14},
  [2565] = {.lex_state = 54, .external_lex_state = 13},
  [2566] = {.lex_state = 54, .external_lex_state = 13},
  [2567] = {.lex_state = 54, .external_lex_state = 18},
  [2568] = {.lex_state = 54, .external_lex_state = 13},
  [2569] = {.lex_state = 54, .external_lex_state = 18},
  [2570] = {.lex_state = 54, .external_lex_state = 14},
  [2571] = {.lex_state = 54, .external_lex_state = 15},
  [2572] = {.lex_state = 34, .external_lex_state = 13},
  [2573] = {.lex_state = 54, .external_lex_state = 14},
  [2574] = {.lex_state = 54, .external_lex_state = 14},
  [2575] = {.lex_state = 54, .external_lex_state = 13},
  [2576] = {.lex_state = 54, .external_lex_state = 14},
  [2577] = {.lex_state = 54, .external_lex_state = 13},
  [2578] = {.lex_state = 54, .external_lex_state = 14},
  [2579] = {.lex_state = 54, .external_lex_state = 14},
  [2580] = {.lex_state = 54, .external_lex_state = 15},
  [2581] = {.lex_state = 34, .external_lex_state = 13},
  [2582] = {.lex_state = 34, .external_lex_state = 13},
  [2583] = {.lex_state = 54, .external_lex_state = 13},
  [2584] = {.lex_state = 34, .external_lex_state = 13},
  [2585] = {.lex_state = 54, .external_lex_state = 15},
  [2586] = {.lex_state = 34, .external_lex_state = 13},
  [2587] = {.lex_state = 34, .external_lex_state = 13},
  [2588] = {.lex_state = 54, .external_lex_state = 13},
  [2589] = {.lex_state = 54, .external_lex_state = 14},
  [2590] = {.lex_state = 34, .external_lex_state = 13},
  [2591] = {.lex_state = 54, .external_lex_state = 18},
  [2592] = {.lex_state = 54, .external_lex_state = 9},
  [2593] = {.lex_state = 54, .external_lex_state = 18},
  [2594] = {.lex_state = 54, .external_lex_state = 9},
  [2595] = {.lex_state = 54, .external_lex_state = 12},
  [2596] = {.lex_state = 54, .external_lex_state = 18},
  [2597] = {.lex_state = 54, .external_lex_state = 13},
  [2598] = {.lex_state = 54, .external_lex_state = 18},
  [2599] = {.lex_state = 54, .external_lex_state = 14},
  [2600] = {.lex_state = 54, .external_lex_state = 15},
  [2601] = {.lex_state = 54, .external_lex_state = 13},
  [2602] = {.lex_state = 54, .external_lex_state = 14},
  [2603] = {.lex_state = 54, .external_lex_state = 15},
  [2604] = {.lex_state = 34, .external_lex_state = 13},
  [2605] = {.lex_state = 54, .external_lex_state = 13},
  [2606] = {.lex_state = 54, .external_lex_state = 9},
  [2607] = {.lex_state = 54, .external_lex_state = 9},
  [2608] = {.lex_state = 54, .external_lex_state = 14},
  [2609] = {.lex_state = 54, .external_lex_state = 9},
  [2610] = {.lex_state = 34, .external_lex_state = 13},
  [2611] = {.lex_state = 54, .external_lex_state = 14},
  [2612] = {.lex_state = 54, .external_lex_state = 12},
  [2613] = {.lex_state = 54, .external_lex_state = 13},
  [2614] = {.lex_state = 54, .external_lex_state = 12},
  [2615] = {.lex_state = 54, .external_lex_state = 9},
  [2616] = {.lex_state = 54, .external_lex_state = 14},
  [2617] = {.lex_state = 54, .external_lex_state = 13},
  [2618] = {.lex_state = 54, .external_lex_state = 13},
  [2619] = {.lex_state = 54, .external_lex_state = 13},
  [2620] = {.lex_state = 54, .external_lex_state = 15},
  [2621] = {.lex_state = 54, .external_lex_state = 9},
  [2622] = {.lex_state = 54, .external_lex_state = 9},
  [2623] = {.lex_state = 54, .external_lex_state = 13},
  [2624] = {.lex_state = 54, .external_lex_state = 15},
  [2625] = {.lex_state = 54, .external_lex_state = 13},
  [2626] = {.lex_state = 54, .external_lex_state = 13},
  [2627] = {.lex_state = 54, .external_lex_state = 15},
  [2628] = {.lex_state = 54, .external_lex_state = 12},
  [2629] = {.lex_state = 29, .external_lex_state = 13},
  [2630] = {.lex_state = 54, .external_lex_state = 14},
  [2631] = {.lex_state = 54, .external_lex_state = 12},
  [2632] = {.lex_state = 54, .external_lex_state = 13},
  [2633] = {.lex_state = 29, .external_lex_state = 13},
  [2634] = {.lex_state = 54, .external_lex_state = 15},
  [2635] = {.lex_state = 54, .external_lex_state = 13},
  [2636] = {.lex_state = 54, .external_lex_state = 13},
  [2637] = {.lex_state = 54, .external_lex_state = 14},
  [2638] = {.lex_state = 54, .external_lex_state = 13},
  [2639] = {.lex_state = 54, .external_lex_state = 13},
  [2640] = {.lex_state = 54, .external_lex_state = 15},
  [2641] = {.lex_state = 54, .external_lex_state = 12},
  [2642] = {.lex_state = 54, .external_lex_state = 13},
  [2643] = {.lex_state = 54, .external_lex_state = 12},
  [2644] = {.lex_state = 54, .external_lex_state = 12},
  [2645] = {.lex_state = 54, .external_lex_state = 13},
  [2646] = {.lex_state = 54, .external_lex_state = 13},
  [2647] = {.lex_state = 54, .external_lex_state = 12},
  [2648] = {.lex_state = 54, .external_lex_state = 13},
  [2649] = {.lex_state = 54, .external_lex_state = 13},
  [2650] = {.lex_state = 54, .external_lex_state = 13},
  [2651] = {.lex_state = 54, .external_lex_state = 14},
  [2652] = {.lex_state = 54, .external_lex_state = 15},
  [2653] = {.lex_state = 54, .external_lex_state = 13},
  [2654] = {.lex_state = 54, .external_lex_state = 14},
  [2655] = {.lex_state = 54, .external_lex_state = 12},
  [2656] = {.lex_state = 54, .external_lex_state = 12},
  [2657] = {.lex_state = 54, .external_lex_state = 13},
  [2658] = {.lex_state = 54, .external_lex_state = 13},
  [2659] = {.lex_state = 54, .external_lex_state = 14},
  [2660] = {.lex_state = 54, .external_lex_state = 13},
  [2661] = {.lex_state = 54, .external_lex_state = 15},
  [2662] = {.lex_state = 54, .external_lex_state = 12},
  [2663] = {.lex_state = 54, .external_lex_state = 14},
  [2664] = {.lex_state = 54, .external_lex_state = 14},
  [2665] = {.lex_state = 54, .external_lex_state = 14},
  [2666] = {.lex_state = 54, .external_lex_state = 12},
  [2667] = {.lex_state = 54, .external_lex_state = 12},
  [2668] = {.lex_state = 54, .external_lex_state = 12},
  [2669] = {.lex_state = 54, .external_lex_state = 12},
  [2670] = {.lex_state = 54, .external_lex_state = 13},
  [2671] = {.lex_state = 54, .external_lex_state = 13},
  [2672] = {.lex_state = 54, .external_lex_state = 15},
  [2673] = {.lex_state = 54, .external_lex_state = 13},
  [2674] = {.lex_state = 54, .external_lex_state = 14},
  [2675] = {.lex_state = 54, .external_lex_state = 13},
  [2676] = {.lex_state = 54, .external_lex_state = 13},
  [2677] = {.lex_state = 54, .external_lex_state = 14},
  [2678] = {.lex_state = 54, .external_lex_state = 13},
  [2679] = {.lex_state = 54, .external_lex_state = 12},
  [2680] = {.lex_state = 54, .external_lex_state = 14},
  [2681] = {.lex_state = 54, .external_lex_state = 13},
  [2682] = {.lex_state = 54, .external_lex_state = 12},
  [2683] = {.lex_state = 54, .external_lex_state = 13},
  [2684] = {.lex_state = 54, .external_lex_state = 13},
  [2685] = {.lex_state = 29, .external_lex_state = 13},
  [2686] = {.lex_state = 54, .external_lex_state = 13},
  [2687] = {.lex_state = 54, .external_lex_state = 12},
  [2688] = {.lex_state = 54, .external_lex_state = 12},
  [2689] = {.lex_state = 54, .external_lex_state = 14},
  [2690] = {.lex_state = 54, .external_lex_state = 13},
  [2691] = {.lex_state = 54, .external_lex_state = 15},
  [2692] = {.lex_state = 54, .external_lex_state = 14},
  [2693] = {.lex_state = 54, .external_lex_state = 13},
  [2694] = {.lex_state = 54, .external_lex_state = 13},
  [2695] = {.lex_state = 54, .external_lex_state = 15},
  [2696] = {.lex_state = 54, .external_lex_state = 13},
  [2697] = {.lex_state = 54, .external_lex_state = 13},
  [2698] = {.lex_state = 54, .external_lex_state = 14},
  [2699] = {.lex_state = 54, .external_lex_state = 15},
  [2700] = {.lex_state = 54, .external_lex_state = 14},
  [2701] = {.lex_state = 54, .external_lex_state = 13},
  [2702] = {.lex_state = 29, .external_lex_state = 13},
  [2703] = {.lex_state = 54, .external_lex_state = 14},
  [2704] = {.lex_state = 54, .external_lex_state = 13},
  [2705] = {.lex_state = 54, .external_lex_state = 12},
  [2706] = {.lex_state = 54, .external_lex_state = 13},
  [2707] = {.lex_state = 54, .external_lex_state = 14},
  [2708] = {.lex_state = 54, .external_lex_state = 13},
  [2709] = {.lex_state = 54, .external_lex_state = 13},
  [2710] = {.lex_state = 54, .external_lex_state = 13},
  [2711] = {.lex_state = 54, .external_lex_state = 13},
  [2712] = {.lex_state = 54, .external_lex_state = 14},
  [2713] = {.lex_state = 54, .external_lex_state = 13},
  [2714] = {.lex_state = 54, .external_lex_state = 13},
  [2715] = {.lex_state = 54, .external_lex_state = 13},
  [2716] = {.lex_state = 54, .external_lex_state = 13},
  [2717] = {.lex_state = 54, .external_lex_state = 13},
  [2718] = {.lex_state = 54, .external_lex_state = 13},
  [2719] = {.lex_state = 54, .external_lex_state = 12},
  [2720] = {.lex_state = 54, .external_lex_state = 13},
  [2721] = {.lex_state = 54, .external_lex_state = 13},
  [2722] = {.lex_state = 54, .external_lex_state = 12},
  [2723] = {.lex_state = 54, .external_lex_state = 13},
  [2724] = {.lex_state = 54, .external_lex_state = 12},
  [2725] = {.lex_state = 54, .external_lex_state = 13},
  [2726] = {.lex_state = 54, .external_lex_state = 15},
  [2727] = {.lex_state = 54, .external_lex_state = 12},
  [2728] = {.lex_state = 54, .external_lex_state = 13},
  [2729] = {.lex_state = 54, .external_lex_state = 13},
  [2730] = {.lex_state = 54, .external_lex_state = 12},
  [2731] = {.lex_state = 54, .external_lex_state = 13},
  [2732] = {.lex_state = 54, .external_lex_state = 13},
  [2733] = {.lex_state = 54, .external_lex_state = 13},
  [2734] = {.lex_state = 54, .external_lex_state = 13},
  [2735] = {.lex_state = 54, .external_lex_state = 14},
  [2736] = {.lex_state = 54, .external_lex_state = 15},
  [2737] = {.lex_state = 54, .external_lex_state = 12},
  [2738] = {.lex_state = 54, .external_lex_state = 15},
  [2739] = {.lex_state = 54, .external_lex_state = 12},
  [2740] = {.lex_state = 54, .external_lex_state = 15},
  [2741] = {.lex_state = 54, .external_lex_state = 15},
  [2742] = {.lex_state = 54, .external_lex_state = 14},
  [2743] = {.lex_state = 54, .external_lex_state = 12},
  [2744] = {.lex_state = 54, .external_lex_state = 13},
  [2745] = {.lex_state = 54, .external_lex_state = 13},
  [2746] = {.lex_state = 54, .external_lex_state = 13},
  [2747] = {.lex_state = 54, .external_lex_state = 13},
  [2748] = {.lex_state = 54, .external_lex_state = 12},
  [2749] = {.lex_state = 54, .external_lex_state = 13},
  [2750] = {.lex_state = 54, .external_lex_state = 13},
  [2751] = {.lex_state = 54, .external_lex_state = 13},
  [2752] = {.lex_state = 54, .external_lex_state = 13},
  [2753] = {.lex_state = 54, .external_lex_state = 13},
  [2754] = {.lex_state = 54, .external_lex_state = 14},
  [2755] = {.lex_state = 54, .external_lex_state = 12},
  [2756] = {.lex_state = 54, .external_lex_state = 13},
  [2757] = {.lex_state = 54, .external_lex_state = 13},
  [2758] = {.lex_state = 54, .external_lex_state = 13},
  [2759] = {.lex_state = 54, .external_lex_state = 13},
  [2760] = {.lex_state = 54, .external_lex_state = 14},
  [2761] = {.lex_state = 54, .external_lex_state = 13},
  [2762] = {.lex_state = 54, .external_lex_state = 15},
  [2763] = {.lex_state = 54, .external_lex_state = 14},
  [2764] = {.lex_state = 54, .external_lex_state = 15},
  [2765] = {.lex_state = 54, .external_lex_state = 12},
  [2766] = {.lex_state = 54, .external_lex_state = 12},
  [2767] = {.lex_state = 54, .external_lex_state = 15},
  [2768] = {.lex_state = 54, .external_lex_state = 13},
  [2769] = {.lex_state = 54, .external_lex_state = 14},
  [2770] = {.lex_state = 54, .external_lex_state = 12},
  [2771] = {.lex_state = 54, .external_lex_state = 14},
  [2772] = {.lex_state = 54, .external_lex_state = 13},
  [2773] = {.lex_state = 54, .external_lex_state = 14},
  [2774] = {.lex_state = 54, .external_lex_state = 14},
  [2775] = {.lex_state = 54, .external_lex_state = 14},
  [2776] = {.lex_state = 54, .external_lex_state = 13},
  [2777] = {.lex_state = 54, .external_lex_state = 13},
  [2778] = {.lex_state = 54, .external_lex_state = 13},
  [2779] = {.lex_state = 29, .external_lex_state = 13},
  [2780] = {.lex_state = 54, .external_lex_state = 14},
  [2781] = {.lex_state = 54, .external_lex_state = 14},
  [2782] = {.lex_state = 29, .external_lex_state = 13},
  [2783] = {.lex_state = 54, .external_lex_state = 12},
  [2784] = {.lex_state = 54, .external_lex_state = 12},
  [2785] = {.lex_state = 54, .external_lex_state = 12},
  [2786] = {.lex_state = 54, .external_lex_state = 12},
  [2787] = {.lex_state = 54, .external_lex_state = 13},
  [2788] = {.lex_state = 54, .external_lex_state = 15},
  [2789] = {.lex_state = 54, .external_lex_state = 13},
  [2790] = {.lex_state = 54, .external_lex_state = 13},
  [2791] = {.lex_state = 54, .external_lex_state = 13},
  [2792] = {.lex_state = 54, .external_lex_state = 13},
  [2793] = {.lex_state = 54, .external_lex_state = 14},
  [2794] = {.lex_state = 54, .external_lex_state = 13},
  [2795] = {.lex_state = 54, .external_lex_state = 13},
  [2796] = {.lex_state = 54, .external_lex_state = 13},
  [2797] = {.lex_state = 54, .external_lex_state = 13},
  [2798] = {.lex_state = 54, .external_lex_state = 12},
  [2799] = {.lex_state = 54, .external_lex_state = 15},
  [2800] = {.lex_state = 54, .external_lex_state = 13},
  [2801] = {.lex_state = 54, .external_lex_state = 13},
  [2802] = {.lex_state = 54, .external_lex_state = 13},
  [2803] = {.lex_state = 29, .external_lex_state = 13},
  [2804] = {.lex_state = 54, .external_lex_state = 13},
  [2805] = {.lex_state = 54, .external_lex_state = 13},
  [2806] = {.lex_state = 54, .external_lex_state = 13},
  [2807] = {.lex_state = 54, .external_lex_state = 13},
  [2808] = {.lex_state = 54, .external_lex_state = 13},
  [2809] = {.lex_state = 54, .external_lex_state = 12},
  [2810] = {.lex_state = 54, .external_lex_state = 13},
  [2811] = {.lex_state = 54, .external_lex_state = 13},
  [2812] = {.lex_state = 54, .external_lex_state = 13},
  [2813] = {.lex_state = 54, .external_lex_state = 12},
  [2814] = {.lex_state = 54, .external_lex_state = 12},
  [2815] = {.lex_state = 54, .external_lex_state = 13},
  [2816] = {.lex_state = 54, .external_lex_state = 12},
  [2817] = {.lex_state = 54, .external_lex_state = 15},
  [2818] = {.lex_state = 54, .external_lex_state = 15},
  [2819] = {.lex_state = 54, .external_lex_state = 12},
  [2820] = {.lex_state = 54, .external_lex_state = 13},
  [2821] = {.lex_state = 54, .external_lex_state = 13},
  [2822] = {.lex_state = 54, .external_lex_state = 13},
  [2823] = {.lex_state = 54, .external_lex_state = 13},
  [2824] = {.lex_state = 54, .external_lex_state = 13},
  [2825] = {.lex_state = 54, .external_lex_state = 13},
  [2826] = {.lex_state = 54, .external_lex_state = 14},
  [2827] = {.lex_state = 54, .external_lex_state = 13},
  [2828] = {.lex_state = 54, .external_lex_state = 13},
  [2829] = {.lex_state = 54, .external_lex_state = 15},
  [2830] = {.lex_state = 29, .external_lex_state = 13},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [0] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [sym_identifier] = ACTIONS(1),
    [anon_sym_SEMI] = ACTIONS(1),
    [anon_sym_import] = ACTIONS(1),
    [anon_sym_DOT] = ACTIONS(1),
    [anon_sym_from] = ACTIONS(1),
    [anon_sym___future__] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_as] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym_print] = ACTIONS(1),
    [anon_sym_GT_GT] = ACTIONS(1),
    [anon_sym_assert] = ACTIONS(1),
    [anon_sym_COLON_EQ] = ACTIONS(1),
    [anon_sym_return] = ACTIONS(1),
    [anon_sym_del] = ACTIONS(1),
    [anon_sym_raise] = ACTIONS(1),
    [anon_sym_pass] = ACTIONS(1),
    [anon_sym_break] = ACTIONS(1),
    [anon_sym_continue] = ACTIONS(1),
    [anon_sym_if] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym_elif] = ACTIONS(1),
    [anon_sym_else] = ACTIONS(1),
    [anon_sym_match] = ACTIONS(1),
    [anon_sym_case] = ACTIONS(1),
    [anon_sym_async] = ACTIONS(1),
    [anon_sym_for] = ACTIONS(1),
    [anon_sym_in] = ACTIONS(1),
    [anon_sym_while] = ACTIONS(1),
    [anon_sym_try] = ACTIONS(1),
    [anon_sym_except] = ACTIONS(1),
    [anon_sym_except_STAR] = ACTIONS(1),
    [anon_sym_finally] = ACTIONS(1),
    [anon_sym_with] = ACTIONS(1),
    [anon_sym_def] = ACTIONS(1),
    [anon_sym_DASH_GT] = ACTIONS(1),
    [anon_sym_STAR_STAR] = ACTIONS(1),
    [anon_sym_global] = ACTIONS(1),
    [anon_sym_nonlocal] = ACTIONS(1),
    [anon_sym_exec] = ACTIONS(1),
    [anon_sym_type] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_class] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_AT] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [anon_sym__] = ACTIONS(1),
    [anon_sym_PIPE] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [anon_sym_PLUS] = ACTIONS(1),
    [anon_sym_not] = ACTIONS(1),
    [anon_sym_and] = ACTIONS(1),
    [anon_sym_or] = ACTIONS(1),
    [anon_sym_SLASH] = ACTIONS(1),
    [anon_sym_PERCENT] = ACTIONS(1),
    [anon_sym_SLASH_SLASH] = ACTIONS(1),
    [anon_sym_AMP] = ACTIONS(1),
    [anon_sym_CARET] = ACTIONS(1),
    [anon_sym_LT_LT] = ACTIONS(1),
    [anon_sym_TILDE] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [anon_sym_LT_EQ] = ACTIONS(1),
    [anon_sym_EQ_EQ] = ACTIONS(1),
    [anon_sym_BANG_EQ] = ACTIONS(1),
    [anon_sym_GT_EQ] = ACTIONS(1),
    [anon_sym_GT] = ACTIONS(1),
    [anon_sym_LT_GT] = ACTIONS(1),
    [anon_sym_is] = ACTIONS(1),
    [anon_sym_lambda] = ACTIONS(1),
    [anon_sym_PLUS_EQ] = ACTIONS(1),
    [anon_sym_DASH_EQ] = ACTIONS(1),
    [anon_sym_STAR_EQ] = ACTIONS(1),
    [anon_sym_SLASH_EQ] = ACTIONS(1),
    [anon_sym_AT_EQ] = ACTIONS(1),
    [anon_sym_SLASH_SLASH_EQ] = ACTIONS(1),
    [anon_sym_PERCENT_EQ] = ACTIONS(1),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(1),
    [anon_sym_GT_GT_EQ] = ACTIONS(1),
    [anon_sym_LT_LT_EQ] = ACTIONS(1),
    [anon_sym_AMP_EQ] = ACTIONS(1),
    [anon_sym_CARET_EQ] = ACTIONS(1),
    [anon_sym_PIPE_EQ] = ACTIONS(1),
    [anon_sym_yield] = ACTIONS(1),
    [sym_ellipsis] = ACTIONS(1),
    [sym_escape_sequence] = ACTIONS(1),
    [sym__not_escape_sequence] = ACTIONS(1),
    [sym_type_conversion] = ACTIONS(1),
    [sym_integer] = ACTIONS(1),
    [sym_float] = ACTIONS(1),
    [anon_sym_await] = ACTIONS(1),
    [sym_true] = ACTIONS(1),
    [sym_false] = ACTIONS(1),
    [sym_none] = ACTIONS(1),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(5),
    [sym__newline] = ACTIONS(1),
    [sym__indent] = ACTIONS(1),
    [sym__dedent] = ACTIONS(1),
    [sym_string_start] = ACTIONS(1),
    [sym__string_content] = ACTIONS(1),
    [sym_escape_interpolation] = ACTIONS(1),
    [sym_string_end] = ACTIONS(1),
  },
  [1] = {
    [sym_module] = STATE(2789),
    [sym__statement] = STATE(64),
    [sym__simple_statements] = STATE(64),
    [sym_import_statement] = STATE(2289),
    [sym_future_import_statement] = STATE(2289),
    [sym_import_from_statement] = STATE(2289),
    [sym_print_statement] = STATE(2289),
    [sym_assert_statement] = STATE(2289),
    [sym_expression_statement] = STATE(2289),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2289),
    [sym_delete_statement] = STATE(2289),
    [sym_raise_statement] = STATE(2289),
    [sym_pass_statement] = STATE(2289),
    [sym_break_statement] = STATE(2289),
    [sym_continue_statement] = STATE(2289),
    [sym_if_statement] = STATE(64),
    [sym_match_statement] = STATE(64),
    [sym_for_statement] = STATE(64),
    [sym_while_statement] = STATE(64),
    [sym_try_statement] = STATE(64),
    [sym_with_statement] = STATE(64),
    [sym_function_definition] = STATE(64),
    [sym_global_statement] = STATE(2289),
    [sym_nonlocal_statement] = STATE(2289),
    [sym_exec_statement] = STATE(2289),
    [sym_type_alias_statement] = STATE(2289),
    [sym_class_definition] = STATE(64),
    [sym_decorated_definition] = STATE(64),
    [sym_decorator] = STATE(1824),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(64),
    [aux_sym_decorated_definition_repeat1] = STATE(1824),
    [ts_builtin_sym_end] = ACTIONS(7),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_match] = ACTIONS(37),
    [anon_sym_async] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(43),
    [anon_sym_try] = ACTIONS(45),
    [anon_sym_with] = ACTIONS(47),
    [anon_sym_def] = ACTIONS(49),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(59),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_string_start] = ACTIONS(81),
  },
  [2] = {
    [sym__statement] = STATE(63),
    [sym__simple_statements] = STATE(63),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(63),
    [sym_match_statement] = STATE(63),
    [sym_for_statement] = STATE(63),
    [sym_while_statement] = STATE(63),
    [sym_try_statement] = STATE(63),
    [sym_with_statement] = STATE(63),
    [sym_function_definition] = STATE(63),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(63),
    [sym_decorated_definition] = STATE(63),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(725),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(63),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(101),
    [sym_string_start] = ACTIONS(81),
  },
  [3] = {
    [sym__statement] = STATE(72),
    [sym__simple_statements] = STATE(72),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(72),
    [sym_match_statement] = STATE(72),
    [sym_for_statement] = STATE(72),
    [sym_while_statement] = STATE(72),
    [sym_try_statement] = STATE(72),
    [sym_with_statement] = STATE(72),
    [sym_function_definition] = STATE(72),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(72),
    [sym_decorated_definition] = STATE(72),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(673),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(72),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(103),
    [sym_string_start] = ACTIONS(81),
  },
  [4] = {
    [sym__statement] = STATE(71),
    [sym__simple_statements] = STATE(71),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(71),
    [sym_match_statement] = STATE(71),
    [sym_for_statement] = STATE(71),
    [sym_while_statement] = STATE(71),
    [sym_try_statement] = STATE(71),
    [sym_with_statement] = STATE(71),
    [sym_function_definition] = STATE(71),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(71),
    [sym_decorated_definition] = STATE(71),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(669),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(71),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(105),
    [sym_string_start] = ACTIONS(81),
  },
  [5] = {
    [sym__statement] = STATE(63),
    [sym__simple_statements] = STATE(63),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(63),
    [sym_match_statement] = STATE(63),
    [sym_for_statement] = STATE(63),
    [sym_while_statement] = STATE(63),
    [sym_try_statement] = STATE(63),
    [sym_with_statement] = STATE(63),
    [sym_function_definition] = STATE(63),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(63),
    [sym_decorated_definition] = STATE(63),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(811),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(63),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(101),
    [sym_string_start] = ACTIONS(81),
  },
  [6] = {
    [sym__statement] = STATE(63),
    [sym__simple_statements] = STATE(63),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(63),
    [sym_match_statement] = STATE(63),
    [sym_for_statement] = STATE(63),
    [sym_while_statement] = STATE(63),
    [sym_try_statement] = STATE(63),
    [sym_with_statement] = STATE(63),
    [sym_function_definition] = STATE(63),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(63),
    [sym_decorated_definition] = STATE(63),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(788),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(63),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(101),
    [sym_string_start] = ACTIONS(81),
  },
  [7] = {
    [sym__statement] = STATE(63),
    [sym__simple_statements] = STATE(63),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(63),
    [sym_match_statement] = STATE(63),
    [sym_for_statement] = STATE(63),
    [sym_while_statement] = STATE(63),
    [sym_try_statement] = STATE(63),
    [sym_with_statement] = STATE(63),
    [sym_function_definition] = STATE(63),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(63),
    [sym_decorated_definition] = STATE(63),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(700),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(63),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(101),
    [sym_string_start] = ACTIONS(81),
  },
  [8] = {
    [sym__statement] = STATE(69),
    [sym__simple_statements] = STATE(69),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(69),
    [sym_match_statement] = STATE(69),
    [sym_for_statement] = STATE(69),
    [sym_while_statement] = STATE(69),
    [sym_try_statement] = STATE(69),
    [sym_with_statement] = STATE(69),
    [sym_function_definition] = STATE(69),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(69),
    [sym_decorated_definition] = STATE(69),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(2562),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(69),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(107),
    [sym_string_start] = ACTIONS(81),
  },
  [9] = {
    [sym__statement] = STATE(63),
    [sym__simple_statements] = STATE(63),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(63),
    [sym_match_statement] = STATE(63),
    [sym_for_statement] = STATE(63),
    [sym_while_statement] = STATE(63),
    [sym_try_statement] = STATE(63),
    [sym_with_statement] = STATE(63),
    [sym_function_definition] = STATE(63),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(63),
    [sym_decorated_definition] = STATE(63),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(708),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(63),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(101),
    [sym_string_start] = ACTIONS(81),
  },
  [10] = {
    [sym__statement] = STATE(65),
    [sym__simple_statements] = STATE(65),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(65),
    [sym_match_statement] = STATE(65),
    [sym_for_statement] = STATE(65),
    [sym_while_statement] = STATE(65),
    [sym_try_statement] = STATE(65),
    [sym_with_statement] = STATE(65),
    [sym_function_definition] = STATE(65),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(65),
    [sym_decorated_definition] = STATE(65),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(819),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(65),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(109),
    [sym_string_start] = ACTIONS(81),
  },
  [11] = {
    [sym__statement] = STATE(65),
    [sym__simple_statements] = STATE(65),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(65),
    [sym_match_statement] = STATE(65),
    [sym_for_statement] = STATE(65),
    [sym_while_statement] = STATE(65),
    [sym_try_statement] = STATE(65),
    [sym_with_statement] = STATE(65),
    [sym_function_definition] = STATE(65),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(65),
    [sym_decorated_definition] = STATE(65),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(823),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(65),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(109),
    [sym_string_start] = ACTIONS(81),
  },
  [12] = {
    [sym__statement] = STATE(63),
    [sym__simple_statements] = STATE(63),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(63),
    [sym_match_statement] = STATE(63),
    [sym_for_statement] = STATE(63),
    [sym_while_statement] = STATE(63),
    [sym_try_statement] = STATE(63),
    [sym_with_statement] = STATE(63),
    [sym_function_definition] = STATE(63),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(63),
    [sym_decorated_definition] = STATE(63),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(814),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(63),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(101),
    [sym_string_start] = ACTIONS(81),
  },
  [13] = {
    [sym__statement] = STATE(72),
    [sym__simple_statements] = STATE(72),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(72),
    [sym_match_statement] = STATE(72),
    [sym_for_statement] = STATE(72),
    [sym_while_statement] = STATE(72),
    [sym_try_statement] = STATE(72),
    [sym_with_statement] = STATE(72),
    [sym_function_definition] = STATE(72),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(72),
    [sym_decorated_definition] = STATE(72),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(661),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(72),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(103),
    [sym_string_start] = ACTIONS(81),
  },
  [14] = {
    [sym__statement] = STATE(65),
    [sym__simple_statements] = STATE(65),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(65),
    [sym_match_statement] = STATE(65),
    [sym_for_statement] = STATE(65),
    [sym_while_statement] = STATE(65),
    [sym_try_statement] = STATE(65),
    [sym_with_statement] = STATE(65),
    [sym_function_definition] = STATE(65),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(65),
    [sym_decorated_definition] = STATE(65),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(836),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(65),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(109),
    [sym_string_start] = ACTIONS(81),
  },
  [15] = {
    [sym__statement] = STATE(63),
    [sym__simple_statements] = STATE(63),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(63),
    [sym_match_statement] = STATE(63),
    [sym_for_statement] = STATE(63),
    [sym_while_statement] = STATE(63),
    [sym_try_statement] = STATE(63),
    [sym_with_statement] = STATE(63),
    [sym_function_definition] = STATE(63),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(63),
    [sym_decorated_definition] = STATE(63),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(799),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(63),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(101),
    [sym_string_start] = ACTIONS(81),
  },
  [16] = {
    [sym__statement] = STATE(63),
    [sym__simple_statements] = STATE(63),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(63),
    [sym_match_statement] = STATE(63),
    [sym_for_statement] = STATE(63),
    [sym_while_statement] = STATE(63),
    [sym_try_statement] = STATE(63),
    [sym_with_statement] = STATE(63),
    [sym_function_definition] = STATE(63),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(63),
    [sym_decorated_definition] = STATE(63),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(803),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(63),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(101),
    [sym_string_start] = ACTIONS(81),
  },
  [17] = {
    [sym__statement] = STATE(65),
    [sym__simple_statements] = STATE(65),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(65),
    [sym_match_statement] = STATE(65),
    [sym_for_statement] = STATE(65),
    [sym_while_statement] = STATE(65),
    [sym_try_statement] = STATE(65),
    [sym_with_statement] = STATE(65),
    [sym_function_definition] = STATE(65),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(65),
    [sym_decorated_definition] = STATE(65),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(731),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(65),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(109),
    [sym_string_start] = ACTIONS(81),
  },
  [18] = {
    [sym__statement] = STATE(65),
    [sym__simple_statements] = STATE(65),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(65),
    [sym_match_statement] = STATE(65),
    [sym_for_statement] = STATE(65),
    [sym_while_statement] = STATE(65),
    [sym_try_statement] = STATE(65),
    [sym_with_statement] = STATE(65),
    [sym_function_definition] = STATE(65),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(65),
    [sym_decorated_definition] = STATE(65),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(835),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(65),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(109),
    [sym_string_start] = ACTIONS(81),
  },
  [19] = {
    [sym__statement] = STATE(65),
    [sym__simple_statements] = STATE(65),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(65),
    [sym_match_statement] = STATE(65),
    [sym_for_statement] = STATE(65),
    [sym_while_statement] = STATE(65),
    [sym_try_statement] = STATE(65),
    [sym_with_statement] = STATE(65),
    [sym_function_definition] = STATE(65),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(65),
    [sym_decorated_definition] = STATE(65),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(712),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(65),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(109),
    [sym_string_start] = ACTIONS(81),
  },
  [20] = {
    [sym__statement] = STATE(65),
    [sym__simple_statements] = STATE(65),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(65),
    [sym_match_statement] = STATE(65),
    [sym_for_statement] = STATE(65),
    [sym_while_statement] = STATE(65),
    [sym_try_statement] = STATE(65),
    [sym_with_statement] = STATE(65),
    [sym_function_definition] = STATE(65),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(65),
    [sym_decorated_definition] = STATE(65),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(732),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(65),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(109),
    [sym_string_start] = ACTIONS(81),
  },
  [21] = {
    [sym__statement] = STATE(69),
    [sym__simple_statements] = STATE(69),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(69),
    [sym_match_statement] = STATE(69),
    [sym_for_statement] = STATE(69),
    [sym_while_statement] = STATE(69),
    [sym_try_statement] = STATE(69),
    [sym_with_statement] = STATE(69),
    [sym_function_definition] = STATE(69),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(69),
    [sym_decorated_definition] = STATE(69),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(2569),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(69),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(107),
    [sym_string_start] = ACTIONS(81),
  },
  [22] = {
    [sym__statement] = STATE(65),
    [sym__simple_statements] = STATE(65),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(65),
    [sym_match_statement] = STATE(65),
    [sym_for_statement] = STATE(65),
    [sym_while_statement] = STATE(65),
    [sym_try_statement] = STATE(65),
    [sym_with_statement] = STATE(65),
    [sym_function_definition] = STATE(65),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(65),
    [sym_decorated_definition] = STATE(65),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(734),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(65),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(109),
    [sym_string_start] = ACTIONS(81),
  },
  [23] = {
    [sym__statement] = STATE(65),
    [sym__simple_statements] = STATE(65),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(65),
    [sym_match_statement] = STATE(65),
    [sym_for_statement] = STATE(65),
    [sym_while_statement] = STATE(65),
    [sym_try_statement] = STATE(65),
    [sym_with_statement] = STATE(65),
    [sym_function_definition] = STATE(65),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(65),
    [sym_decorated_definition] = STATE(65),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(723),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(65),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(109),
    [sym_string_start] = ACTIONS(81),
  },
  [24] = {
    [sym__statement] = STATE(65),
    [sym__simple_statements] = STATE(65),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(65),
    [sym_match_statement] = STATE(65),
    [sym_for_statement] = STATE(65),
    [sym_while_statement] = STATE(65),
    [sym_try_statement] = STATE(65),
    [sym_with_statement] = STATE(65),
    [sym_function_definition] = STATE(65),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(65),
    [sym_decorated_definition] = STATE(65),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(618),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(65),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(109),
    [sym_string_start] = ACTIONS(81),
  },
  [25] = {
    [sym__statement] = STATE(65),
    [sym__simple_statements] = STATE(65),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(65),
    [sym_match_statement] = STATE(65),
    [sym_for_statement] = STATE(65),
    [sym_while_statement] = STATE(65),
    [sym_try_statement] = STATE(65),
    [sym_with_statement] = STATE(65),
    [sym_function_definition] = STATE(65),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(65),
    [sym_decorated_definition] = STATE(65),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(715),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(65),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(109),
    [sym_string_start] = ACTIONS(81),
  },
  [26] = {
    [sym__statement] = STATE(63),
    [sym__simple_statements] = STATE(63),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(63),
    [sym_match_statement] = STATE(63),
    [sym_for_statement] = STATE(63),
    [sym_while_statement] = STATE(63),
    [sym_try_statement] = STATE(63),
    [sym_with_statement] = STATE(63),
    [sym_function_definition] = STATE(63),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(63),
    [sym_decorated_definition] = STATE(63),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(804),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(63),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(101),
    [sym_string_start] = ACTIONS(81),
  },
  [27] = {
    [sym__statement] = STATE(65),
    [sym__simple_statements] = STATE(65),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(65),
    [sym_match_statement] = STATE(65),
    [sym_for_statement] = STATE(65),
    [sym_while_statement] = STATE(65),
    [sym_try_statement] = STATE(65),
    [sym_with_statement] = STATE(65),
    [sym_function_definition] = STATE(65),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(65),
    [sym_decorated_definition] = STATE(65),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(841),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(65),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(109),
    [sym_string_start] = ACTIONS(81),
  },
  [28] = {
    [sym__statement] = STATE(63),
    [sym__simple_statements] = STATE(63),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(63),
    [sym_match_statement] = STATE(63),
    [sym_for_statement] = STATE(63),
    [sym_while_statement] = STATE(63),
    [sym_try_statement] = STATE(63),
    [sym_with_statement] = STATE(63),
    [sym_function_definition] = STATE(63),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(63),
    [sym_decorated_definition] = STATE(63),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(817),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(63),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(101),
    [sym_string_start] = ACTIONS(81),
  },
  [29] = {
    [sym__statement] = STATE(65),
    [sym__simple_statements] = STATE(65),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(65),
    [sym_match_statement] = STATE(65),
    [sym_for_statement] = STATE(65),
    [sym_while_statement] = STATE(65),
    [sym_try_statement] = STATE(65),
    [sym_with_statement] = STATE(65),
    [sym_function_definition] = STATE(65),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(65),
    [sym_decorated_definition] = STATE(65),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(764),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(65),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(109),
    [sym_string_start] = ACTIONS(81),
  },
  [30] = {
    [sym__statement] = STATE(63),
    [sym__simple_statements] = STATE(63),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(63),
    [sym_match_statement] = STATE(63),
    [sym_for_statement] = STATE(63),
    [sym_while_statement] = STATE(63),
    [sym_try_statement] = STATE(63),
    [sym_with_statement] = STATE(63),
    [sym_function_definition] = STATE(63),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(63),
    [sym_decorated_definition] = STATE(63),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(777),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(63),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(101),
    [sym_string_start] = ACTIONS(81),
  },
  [31] = {
    [sym__statement] = STATE(63),
    [sym__simple_statements] = STATE(63),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(63),
    [sym_match_statement] = STATE(63),
    [sym_for_statement] = STATE(63),
    [sym_while_statement] = STATE(63),
    [sym_try_statement] = STATE(63),
    [sym_with_statement] = STATE(63),
    [sym_function_definition] = STATE(63),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(63),
    [sym_decorated_definition] = STATE(63),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(818),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(63),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(101),
    [sym_string_start] = ACTIONS(81),
  },
  [32] = {
    [sym__statement] = STATE(68),
    [sym__simple_statements] = STATE(68),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(68),
    [sym_match_statement] = STATE(68),
    [sym_for_statement] = STATE(68),
    [sym_while_statement] = STATE(68),
    [sym_try_statement] = STATE(68),
    [sym_with_statement] = STATE(68),
    [sym_function_definition] = STATE(68),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(68),
    [sym_decorated_definition] = STATE(68),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(651),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(68),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(111),
    [sym_string_start] = ACTIONS(81),
  },
  [33] = {
    [sym__statement] = STATE(67),
    [sym__simple_statements] = STATE(67),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(67),
    [sym_match_statement] = STATE(67),
    [sym_for_statement] = STATE(67),
    [sym_while_statement] = STATE(67),
    [sym_try_statement] = STATE(67),
    [sym_with_statement] = STATE(67),
    [sym_function_definition] = STATE(67),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(67),
    [sym_decorated_definition] = STATE(67),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(649),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(67),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(113),
    [sym_string_start] = ACTIONS(81),
  },
  [34] = {
    [sym__statement] = STATE(72),
    [sym__simple_statements] = STATE(72),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(72),
    [sym_match_statement] = STATE(72),
    [sym_for_statement] = STATE(72),
    [sym_while_statement] = STATE(72),
    [sym_try_statement] = STATE(72),
    [sym_with_statement] = STATE(72),
    [sym_function_definition] = STATE(72),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(72),
    [sym_decorated_definition] = STATE(72),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(668),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(72),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(103),
    [sym_string_start] = ACTIONS(81),
  },
  [35] = {
    [sym__statement] = STATE(65),
    [sym__simple_statements] = STATE(65),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(65),
    [sym_match_statement] = STATE(65),
    [sym_for_statement] = STATE(65),
    [sym_while_statement] = STATE(65),
    [sym_try_statement] = STATE(65),
    [sym_with_statement] = STATE(65),
    [sym_function_definition] = STATE(65),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(65),
    [sym_decorated_definition] = STATE(65),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(768),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(65),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(109),
    [sym_string_start] = ACTIONS(81),
  },
  [36] = {
    [sym__statement] = STATE(68),
    [sym__simple_statements] = STATE(68),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(68),
    [sym_match_statement] = STATE(68),
    [sym_for_statement] = STATE(68),
    [sym_while_statement] = STATE(68),
    [sym_try_statement] = STATE(68),
    [sym_with_statement] = STATE(68),
    [sym_function_definition] = STATE(68),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(68),
    [sym_decorated_definition] = STATE(68),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(693),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(68),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(111),
    [sym_string_start] = ACTIONS(81),
  },
  [37] = {
    [sym__statement] = STATE(63),
    [sym__simple_statements] = STATE(63),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(63),
    [sym_match_statement] = STATE(63),
    [sym_for_statement] = STATE(63),
    [sym_while_statement] = STATE(63),
    [sym_try_statement] = STATE(63),
    [sym_with_statement] = STATE(63),
    [sym_function_definition] = STATE(63),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(63),
    [sym_decorated_definition] = STATE(63),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(773),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(63),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(101),
    [sym_string_start] = ACTIONS(81),
  },
  [38] = {
    [sym__statement] = STATE(65),
    [sym__simple_statements] = STATE(65),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(65),
    [sym_match_statement] = STATE(65),
    [sym_for_statement] = STATE(65),
    [sym_while_statement] = STATE(65),
    [sym_try_statement] = STATE(65),
    [sym_with_statement] = STATE(65),
    [sym_function_definition] = STATE(65),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(65),
    [sym_decorated_definition] = STATE(65),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(702),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(65),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(109),
    [sym_string_start] = ACTIONS(81),
  },
  [39] = {
    [sym__statement] = STATE(65),
    [sym__simple_statements] = STATE(65),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(65),
    [sym_match_statement] = STATE(65),
    [sym_for_statement] = STATE(65),
    [sym_while_statement] = STATE(65),
    [sym_try_statement] = STATE(65),
    [sym_with_statement] = STATE(65),
    [sym_function_definition] = STATE(65),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(65),
    [sym_decorated_definition] = STATE(65),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(714),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(65),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(109),
    [sym_string_start] = ACTIONS(81),
  },
  [40] = {
    [sym__statement] = STATE(63),
    [sym__simple_statements] = STATE(63),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(63),
    [sym_match_statement] = STATE(63),
    [sym_for_statement] = STATE(63),
    [sym_while_statement] = STATE(63),
    [sym_try_statement] = STATE(63),
    [sym_with_statement] = STATE(63),
    [sym_function_definition] = STATE(63),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(63),
    [sym_decorated_definition] = STATE(63),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(612),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(63),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(101),
    [sym_string_start] = ACTIONS(81),
  },
  [41] = {
    [sym__statement] = STATE(69),
    [sym__simple_statements] = STATE(69),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(69),
    [sym_match_statement] = STATE(69),
    [sym_for_statement] = STATE(69),
    [sym_while_statement] = STATE(69),
    [sym_try_statement] = STATE(69),
    [sym_with_statement] = STATE(69),
    [sym_function_definition] = STATE(69),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(69),
    [sym_decorated_definition] = STATE(69),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(2596),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(69),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(107),
    [sym_string_start] = ACTIONS(81),
  },
  [42] = {
    [sym__statement] = STATE(69),
    [sym__simple_statements] = STATE(69),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(69),
    [sym_match_statement] = STATE(69),
    [sym_for_statement] = STATE(69),
    [sym_while_statement] = STATE(69),
    [sym_try_statement] = STATE(69),
    [sym_with_statement] = STATE(69),
    [sym_function_definition] = STATE(69),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(69),
    [sym_decorated_definition] = STATE(69),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(2558),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(69),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(107),
    [sym_string_start] = ACTIONS(81),
  },
  [43] = {
    [sym__statement] = STATE(65),
    [sym__simple_statements] = STATE(65),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(65),
    [sym_match_statement] = STATE(65),
    [sym_for_statement] = STATE(65),
    [sym_while_statement] = STATE(65),
    [sym_try_statement] = STATE(65),
    [sym_with_statement] = STATE(65),
    [sym_function_definition] = STATE(65),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(65),
    [sym_decorated_definition] = STATE(65),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(849),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(65),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(109),
    [sym_string_start] = ACTIONS(81),
  },
  [44] = {
    [sym__statement] = STATE(67),
    [sym__simple_statements] = STATE(67),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(67),
    [sym_match_statement] = STATE(67),
    [sym_for_statement] = STATE(67),
    [sym_while_statement] = STATE(67),
    [sym_try_statement] = STATE(67),
    [sym_with_statement] = STATE(67),
    [sym_function_definition] = STATE(67),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(67),
    [sym_decorated_definition] = STATE(67),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(672),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(67),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(113),
    [sym_string_start] = ACTIONS(81),
  },
  [45] = {
    [sym__statement] = STATE(63),
    [sym__simple_statements] = STATE(63),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(63),
    [sym_match_statement] = STATE(63),
    [sym_for_statement] = STATE(63),
    [sym_while_statement] = STATE(63),
    [sym_try_statement] = STATE(63),
    [sym_with_statement] = STATE(63),
    [sym_function_definition] = STATE(63),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(63),
    [sym_decorated_definition] = STATE(63),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(707),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(63),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(101),
    [sym_string_start] = ACTIONS(81),
  },
  [46] = {
    [sym__statement] = STATE(63),
    [sym__simple_statements] = STATE(63),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(63),
    [sym_match_statement] = STATE(63),
    [sym_for_statement] = STATE(63),
    [sym_while_statement] = STATE(63),
    [sym_try_statement] = STATE(63),
    [sym_with_statement] = STATE(63),
    [sym_function_definition] = STATE(63),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(63),
    [sym_decorated_definition] = STATE(63),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(779),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(63),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(101),
    [sym_string_start] = ACTIONS(81),
  },
  [47] = {
    [sym__statement] = STATE(65),
    [sym__simple_statements] = STATE(65),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(65),
    [sym_match_statement] = STATE(65),
    [sym_for_statement] = STATE(65),
    [sym_while_statement] = STATE(65),
    [sym_try_statement] = STATE(65),
    [sym_with_statement] = STATE(65),
    [sym_function_definition] = STATE(65),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(65),
    [sym_decorated_definition] = STATE(65),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(850),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(65),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(109),
    [sym_string_start] = ACTIONS(81),
  },
  [48] = {
    [sym__statement] = STATE(69),
    [sym__simple_statements] = STATE(69),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(69),
    [sym_match_statement] = STATE(69),
    [sym_for_statement] = STATE(69),
    [sym_while_statement] = STATE(69),
    [sym_try_statement] = STATE(69),
    [sym_with_statement] = STATE(69),
    [sym_function_definition] = STATE(69),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(69),
    [sym_decorated_definition] = STATE(69),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(2545),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(69),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(107),
    [sym_string_start] = ACTIONS(81),
  },
  [49] = {
    [sym__statement] = STATE(71),
    [sym__simple_statements] = STATE(71),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(71),
    [sym_match_statement] = STATE(71),
    [sym_for_statement] = STATE(71),
    [sym_while_statement] = STATE(71),
    [sym_try_statement] = STATE(71),
    [sym_with_statement] = STATE(71),
    [sym_function_definition] = STATE(71),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(71),
    [sym_decorated_definition] = STATE(71),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(674),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(71),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(105),
    [sym_string_start] = ACTIONS(81),
  },
  [50] = {
    [sym__statement] = STATE(63),
    [sym__simple_statements] = STATE(63),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(63),
    [sym_match_statement] = STATE(63),
    [sym_for_statement] = STATE(63),
    [sym_while_statement] = STATE(63),
    [sym_try_statement] = STATE(63),
    [sym_with_statement] = STATE(63),
    [sym_function_definition] = STATE(63),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(63),
    [sym_decorated_definition] = STATE(63),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(699),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(63),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(101),
    [sym_string_start] = ACTIONS(81),
  },
  [51] = {
    [sym__statement] = STATE(65),
    [sym__simple_statements] = STATE(65),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(65),
    [sym_match_statement] = STATE(65),
    [sym_for_statement] = STATE(65),
    [sym_while_statement] = STATE(65),
    [sym_try_statement] = STATE(65),
    [sym_with_statement] = STATE(65),
    [sym_function_definition] = STATE(65),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(65),
    [sym_decorated_definition] = STATE(65),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(746),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(65),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(109),
    [sym_string_start] = ACTIONS(81),
  },
  [52] = {
    [sym__statement] = STATE(69),
    [sym__simple_statements] = STATE(69),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(69),
    [sym_match_statement] = STATE(69),
    [sym_for_statement] = STATE(69),
    [sym_while_statement] = STATE(69),
    [sym_try_statement] = STATE(69),
    [sym_with_statement] = STATE(69),
    [sym_function_definition] = STATE(69),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(69),
    [sym_decorated_definition] = STATE(69),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(2548),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(69),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(107),
    [sym_string_start] = ACTIONS(81),
  },
  [53] = {
    [sym__statement] = STATE(63),
    [sym__simple_statements] = STATE(63),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(63),
    [sym_match_statement] = STATE(63),
    [sym_for_statement] = STATE(63),
    [sym_while_statement] = STATE(63),
    [sym_try_statement] = STATE(63),
    [sym_with_statement] = STATE(63),
    [sym_function_definition] = STATE(63),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(63),
    [sym_decorated_definition] = STATE(63),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(747),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(63),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(101),
    [sym_string_start] = ACTIONS(81),
  },
  [54] = {
    [sym__statement] = STATE(62),
    [sym__simple_statements] = STATE(62),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(62),
    [sym_match_statement] = STATE(62),
    [sym_for_statement] = STATE(62),
    [sym_while_statement] = STATE(62),
    [sym_try_statement] = STATE(62),
    [sym_with_statement] = STATE(62),
    [sym_function_definition] = STATE(62),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(62),
    [sym_decorated_definition] = STATE(62),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(1813),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(62),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(115),
    [sym_string_start] = ACTIONS(81),
  },
  [55] = {
    [sym__statement] = STATE(63),
    [sym__simple_statements] = STATE(63),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(63),
    [sym_match_statement] = STATE(63),
    [sym_for_statement] = STATE(63),
    [sym_while_statement] = STATE(63),
    [sym_try_statement] = STATE(63),
    [sym_with_statement] = STATE(63),
    [sym_function_definition] = STATE(63),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(63),
    [sym_decorated_definition] = STATE(63),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(809),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(63),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(101),
    [sym_string_start] = ACTIONS(81),
  },
  [56] = {
    [sym__statement] = STATE(62),
    [sym__simple_statements] = STATE(62),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(62),
    [sym_match_statement] = STATE(62),
    [sym_for_statement] = STATE(62),
    [sym_while_statement] = STATE(62),
    [sym_try_statement] = STATE(62),
    [sym_with_statement] = STATE(62),
    [sym_function_definition] = STATE(62),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(62),
    [sym_decorated_definition] = STATE(62),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(1833),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(62),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(115),
    [sym_string_start] = ACTIONS(81),
  },
  [57] = {
    [sym__statement] = STATE(65),
    [sym__simple_statements] = STATE(65),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(65),
    [sym_match_statement] = STATE(65),
    [sym_for_statement] = STATE(65),
    [sym_while_statement] = STATE(65),
    [sym_try_statement] = STATE(65),
    [sym_with_statement] = STATE(65),
    [sym_function_definition] = STATE(65),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(65),
    [sym_decorated_definition] = STATE(65),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(821),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(65),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(109),
    [sym_string_start] = ACTIONS(81),
  },
  [58] = {
    [sym__statement] = STATE(65),
    [sym__simple_statements] = STATE(65),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(65),
    [sym_match_statement] = STATE(65),
    [sym_for_statement] = STATE(65),
    [sym_while_statement] = STATE(65),
    [sym_try_statement] = STATE(65),
    [sym_with_statement] = STATE(65),
    [sym_function_definition] = STATE(65),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(65),
    [sym_decorated_definition] = STATE(65),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(770),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(65),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(109),
    [sym_string_start] = ACTIONS(81),
  },
  [59] = {
    [sym__statement] = STATE(68),
    [sym__simple_statements] = STATE(68),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(68),
    [sym_match_statement] = STATE(68),
    [sym_for_statement] = STATE(68),
    [sym_while_statement] = STATE(68),
    [sym_try_statement] = STATE(68),
    [sym_with_statement] = STATE(68),
    [sym_function_definition] = STATE(68),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(68),
    [sym_decorated_definition] = STATE(68),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(687),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(68),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(111),
    [sym_string_start] = ACTIONS(81),
  },
  [60] = {
    [sym__statement] = STATE(63),
    [sym__simple_statements] = STATE(63),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(63),
    [sym_match_statement] = STATE(63),
    [sym_for_statement] = STATE(63),
    [sym_while_statement] = STATE(63),
    [sym_try_statement] = STATE(63),
    [sym_with_statement] = STATE(63),
    [sym_function_definition] = STATE(63),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(63),
    [sym_decorated_definition] = STATE(63),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(749),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(63),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(101),
    [sym_string_start] = ACTIONS(81),
  },
  [61] = {
    [sym__statement] = STATE(63),
    [sym__simple_statements] = STATE(63),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(63),
    [sym_match_statement] = STATE(63),
    [sym_for_statement] = STATE(63),
    [sym_while_statement] = STATE(63),
    [sym_try_statement] = STATE(63),
    [sym_with_statement] = STATE(63),
    [sym_function_definition] = STATE(63),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(63),
    [sym_decorated_definition] = STATE(63),
    [sym_decorator] = STATE(1828),
    [sym_block] = STATE(758),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(63),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(101),
    [sym_string_start] = ACTIONS(81),
  },
  [62] = {
    [sym__statement] = STATE(66),
    [sym__simple_statements] = STATE(66),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(66),
    [sym_match_statement] = STATE(66),
    [sym_for_statement] = STATE(66),
    [sym_while_statement] = STATE(66),
    [sym_try_statement] = STATE(66),
    [sym_with_statement] = STATE(66),
    [sym_function_definition] = STATE(66),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(66),
    [sym_decorated_definition] = STATE(66),
    [sym_decorator] = STATE(1828),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(66),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(117),
    [sym_string_start] = ACTIONS(81),
  },
  [63] = {
    [sym__statement] = STATE(66),
    [sym__simple_statements] = STATE(66),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(66),
    [sym_match_statement] = STATE(66),
    [sym_for_statement] = STATE(66),
    [sym_while_statement] = STATE(66),
    [sym_try_statement] = STATE(66),
    [sym_with_statement] = STATE(66),
    [sym_function_definition] = STATE(66),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(66),
    [sym_decorated_definition] = STATE(66),
    [sym_decorator] = STATE(1828),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(66),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(119),
    [sym_string_start] = ACTIONS(81),
  },
  [64] = {
    [sym__statement] = STATE(70),
    [sym__simple_statements] = STATE(70),
    [sym_import_statement] = STATE(2289),
    [sym_future_import_statement] = STATE(2289),
    [sym_import_from_statement] = STATE(2289),
    [sym_print_statement] = STATE(2289),
    [sym_assert_statement] = STATE(2289),
    [sym_expression_statement] = STATE(2289),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2289),
    [sym_delete_statement] = STATE(2289),
    [sym_raise_statement] = STATE(2289),
    [sym_pass_statement] = STATE(2289),
    [sym_break_statement] = STATE(2289),
    [sym_continue_statement] = STATE(2289),
    [sym_if_statement] = STATE(70),
    [sym_match_statement] = STATE(70),
    [sym_for_statement] = STATE(70),
    [sym_while_statement] = STATE(70),
    [sym_try_statement] = STATE(70),
    [sym_with_statement] = STATE(70),
    [sym_function_definition] = STATE(70),
    [sym_global_statement] = STATE(2289),
    [sym_nonlocal_statement] = STATE(2289),
    [sym_exec_statement] = STATE(2289),
    [sym_type_alias_statement] = STATE(2289),
    [sym_class_definition] = STATE(70),
    [sym_decorated_definition] = STATE(70),
    [sym_decorator] = STATE(1824),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(70),
    [aux_sym_decorated_definition_repeat1] = STATE(1824),
    [ts_builtin_sym_end] = ACTIONS(121),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_match] = ACTIONS(37),
    [anon_sym_async] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_while] = ACTIONS(43),
    [anon_sym_try] = ACTIONS(45),
    [anon_sym_with] = ACTIONS(47),
    [anon_sym_def] = ACTIONS(49),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(59),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_string_start] = ACTIONS(81),
  },
  [65] = {
    [sym__statement] = STATE(66),
    [sym__simple_statements] = STATE(66),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(66),
    [sym_match_statement] = STATE(66),
    [sym_for_statement] = STATE(66),
    [sym_while_statement] = STATE(66),
    [sym_try_statement] = STATE(66),
    [sym_with_statement] = STATE(66),
    [sym_function_definition] = STATE(66),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(66),
    [sym_decorated_definition] = STATE(66),
    [sym_decorator] = STATE(1828),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(66),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(123),
    [sym_string_start] = ACTIONS(81),
  },
  [66] = {
    [sym__statement] = STATE(66),
    [sym__simple_statements] = STATE(66),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(66),
    [sym_match_statement] = STATE(66),
    [sym_for_statement] = STATE(66),
    [sym_while_statement] = STATE(66),
    [sym_try_statement] = STATE(66),
    [sym_with_statement] = STATE(66),
    [sym_function_definition] = STATE(66),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(66),
    [sym_decorated_definition] = STATE(66),
    [sym_decorator] = STATE(1828),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(66),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(125),
    [anon_sym_import] = ACTIONS(128),
    [anon_sym_from] = ACTIONS(131),
    [anon_sym_LPAREN] = ACTIONS(134),
    [anon_sym_STAR] = ACTIONS(137),
    [anon_sym_print] = ACTIONS(140),
    [anon_sym_assert] = ACTIONS(143),
    [anon_sym_return] = ACTIONS(146),
    [anon_sym_del] = ACTIONS(149),
    [anon_sym_raise] = ACTIONS(152),
    [anon_sym_pass] = ACTIONS(155),
    [anon_sym_break] = ACTIONS(158),
    [anon_sym_continue] = ACTIONS(161),
    [anon_sym_if] = ACTIONS(164),
    [anon_sym_match] = ACTIONS(167),
    [anon_sym_async] = ACTIONS(170),
    [anon_sym_for] = ACTIONS(173),
    [anon_sym_while] = ACTIONS(176),
    [anon_sym_try] = ACTIONS(179),
    [anon_sym_with] = ACTIONS(182),
    [anon_sym_def] = ACTIONS(185),
    [anon_sym_global] = ACTIONS(188),
    [anon_sym_nonlocal] = ACTIONS(191),
    [anon_sym_exec] = ACTIONS(194),
    [anon_sym_type] = ACTIONS(197),
    [anon_sym_class] = ACTIONS(200),
    [anon_sym_LBRACK] = ACTIONS(203),
    [anon_sym_AT] = ACTIONS(206),
    [anon_sym_DASH] = ACTIONS(209),
    [anon_sym_LBRACE] = ACTIONS(212),
    [anon_sym_PLUS] = ACTIONS(209),
    [anon_sym_not] = ACTIONS(215),
    [anon_sym_TILDE] = ACTIONS(209),
    [anon_sym_lambda] = ACTIONS(218),
    [anon_sym_yield] = ACTIONS(221),
    [sym_ellipsis] = ACTIONS(224),
    [sym_integer] = ACTIONS(227),
    [sym_float] = ACTIONS(224),
    [anon_sym_await] = ACTIONS(230),
    [sym_true] = ACTIONS(227),
    [sym_false] = ACTIONS(227),
    [sym_none] = ACTIONS(227),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(233),
    [sym_string_start] = ACTIONS(235),
  },
  [67] = {
    [sym__statement] = STATE(66),
    [sym__simple_statements] = STATE(66),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(66),
    [sym_match_statement] = STATE(66),
    [sym_for_statement] = STATE(66),
    [sym_while_statement] = STATE(66),
    [sym_try_statement] = STATE(66),
    [sym_with_statement] = STATE(66),
    [sym_function_definition] = STATE(66),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(66),
    [sym_decorated_definition] = STATE(66),
    [sym_decorator] = STATE(1828),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(66),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(238),
    [sym_string_start] = ACTIONS(81),
  },
  [68] = {
    [sym__statement] = STATE(66),
    [sym__simple_statements] = STATE(66),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(66),
    [sym_match_statement] = STATE(66),
    [sym_for_statement] = STATE(66),
    [sym_while_statement] = STATE(66),
    [sym_try_statement] = STATE(66),
    [sym_with_statement] = STATE(66),
    [sym_function_definition] = STATE(66),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(66),
    [sym_decorated_definition] = STATE(66),
    [sym_decorator] = STATE(1828),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(66),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(240),
    [sym_string_start] = ACTIONS(81),
  },
  [69] = {
    [sym__statement] = STATE(66),
    [sym__simple_statements] = STATE(66),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(66),
    [sym_match_statement] = STATE(66),
    [sym_for_statement] = STATE(66),
    [sym_while_statement] = STATE(66),
    [sym_try_statement] = STATE(66),
    [sym_with_statement] = STATE(66),
    [sym_function_definition] = STATE(66),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(66),
    [sym_decorated_definition] = STATE(66),
    [sym_decorator] = STATE(1828),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(66),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(242),
    [sym_string_start] = ACTIONS(81),
  },
  [70] = {
    [sym__statement] = STATE(70),
    [sym__simple_statements] = STATE(70),
    [sym_import_statement] = STATE(2289),
    [sym_future_import_statement] = STATE(2289),
    [sym_import_from_statement] = STATE(2289),
    [sym_print_statement] = STATE(2289),
    [sym_assert_statement] = STATE(2289),
    [sym_expression_statement] = STATE(2289),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2289),
    [sym_delete_statement] = STATE(2289),
    [sym_raise_statement] = STATE(2289),
    [sym_pass_statement] = STATE(2289),
    [sym_break_statement] = STATE(2289),
    [sym_continue_statement] = STATE(2289),
    [sym_if_statement] = STATE(70),
    [sym_match_statement] = STATE(70),
    [sym_for_statement] = STATE(70),
    [sym_while_statement] = STATE(70),
    [sym_try_statement] = STATE(70),
    [sym_with_statement] = STATE(70),
    [sym_function_definition] = STATE(70),
    [sym_global_statement] = STATE(2289),
    [sym_nonlocal_statement] = STATE(2289),
    [sym_exec_statement] = STATE(2289),
    [sym_type_alias_statement] = STATE(2289),
    [sym_class_definition] = STATE(70),
    [sym_decorated_definition] = STATE(70),
    [sym_decorator] = STATE(1824),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(70),
    [aux_sym_decorated_definition_repeat1] = STATE(1824),
    [ts_builtin_sym_end] = ACTIONS(233),
    [sym_identifier] = ACTIONS(125),
    [anon_sym_import] = ACTIONS(128),
    [anon_sym_from] = ACTIONS(131),
    [anon_sym_LPAREN] = ACTIONS(134),
    [anon_sym_STAR] = ACTIONS(137),
    [anon_sym_print] = ACTIONS(140),
    [anon_sym_assert] = ACTIONS(143),
    [anon_sym_return] = ACTIONS(146),
    [anon_sym_del] = ACTIONS(149),
    [anon_sym_raise] = ACTIONS(152),
    [anon_sym_pass] = ACTIONS(155),
    [anon_sym_break] = ACTIONS(158),
    [anon_sym_continue] = ACTIONS(161),
    [anon_sym_if] = ACTIONS(244),
    [anon_sym_match] = ACTIONS(247),
    [anon_sym_async] = ACTIONS(250),
    [anon_sym_for] = ACTIONS(253),
    [anon_sym_while] = ACTIONS(256),
    [anon_sym_try] = ACTIONS(259),
    [anon_sym_with] = ACTIONS(262),
    [anon_sym_def] = ACTIONS(265),
    [anon_sym_global] = ACTIONS(188),
    [anon_sym_nonlocal] = ACTIONS(191),
    [anon_sym_exec] = ACTIONS(194),
    [anon_sym_type] = ACTIONS(197),
    [anon_sym_class] = ACTIONS(268),
    [anon_sym_LBRACK] = ACTIONS(203),
    [anon_sym_AT] = ACTIONS(206),
    [anon_sym_DASH] = ACTIONS(209),
    [anon_sym_LBRACE] = ACTIONS(212),
    [anon_sym_PLUS] = ACTIONS(209),
    [anon_sym_not] = ACTIONS(215),
    [anon_sym_TILDE] = ACTIONS(209),
    [anon_sym_lambda] = ACTIONS(218),
    [anon_sym_yield] = ACTIONS(221),
    [sym_ellipsis] = ACTIONS(224),
    [sym_integer] = ACTIONS(227),
    [sym_float] = ACTIONS(224),
    [anon_sym_await] = ACTIONS(230),
    [sym_true] = ACTIONS(227),
    [sym_false] = ACTIONS(227),
    [sym_none] = ACTIONS(227),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_string_start] = ACTIONS(235),
  },
  [71] = {
    [sym__statement] = STATE(66),
    [sym__simple_statements] = STATE(66),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(66),
    [sym_match_statement] = STATE(66),
    [sym_for_statement] = STATE(66),
    [sym_while_statement] = STATE(66),
    [sym_try_statement] = STATE(66),
    [sym_with_statement] = STATE(66),
    [sym_function_definition] = STATE(66),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(66),
    [sym_decorated_definition] = STATE(66),
    [sym_decorator] = STATE(1828),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(66),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(271),
    [sym_string_start] = ACTIONS(81),
  },
  [72] = {
    [sym__statement] = STATE(66),
    [sym__simple_statements] = STATE(66),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_if_statement] = STATE(66),
    [sym_match_statement] = STATE(66),
    [sym_for_statement] = STATE(66),
    [sym_while_statement] = STATE(66),
    [sym_try_statement] = STATE(66),
    [sym_with_statement] = STATE(66),
    [sym_function_definition] = STATE(66),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_class_definition] = STATE(66),
    [sym_decorated_definition] = STATE(66),
    [sym_decorator] = STATE(1828),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [aux_sym_module_repeat1] = STATE(66),
    [aux_sym_decorated_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_match] = ACTIONS(85),
    [anon_sym_async] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_while] = ACTIONS(91),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_with] = ACTIONS(95),
    [anon_sym_def] = ACTIONS(97),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_class] = ACTIONS(99),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_AT] = ACTIONS(63),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__dedent] = ACTIONS(273),
    [sym_string_start] = ACTIONS(81),
  },
  [73] = {
    [sym_named_expression] = STATE(1758),
    [sym__named_expression_lhs] = STATE(2779),
    [sym_list_splat_pattern] = STATE(1433),
    [sym_as_pattern] = STATE(1758),
    [sym_expression] = STATE(1796),
    [sym_primary_expression] = STATE(1002),
    [sym_not_operator] = STATE(1758),
    [sym_boolean_operator] = STATE(1758),
    [sym_binary_operator] = STATE(1365),
    [sym_unary_operator] = STATE(1365),
    [sym_comparison_operator] = STATE(1758),
    [sym_lambda] = STATE(1758),
    [sym_attribute] = STATE(1365),
    [sym_subscript] = STATE(1365),
    [sym_call] = STATE(1365),
    [sym_type] = STATE(2140),
    [sym_splat_type] = STATE(2137),
    [sym_generic_type] = STATE(2137),
    [sym_union_type] = STATE(2137),
    [sym_constrained_type] = STATE(2137),
    [sym_member_type] = STATE(2137),
    [sym_list] = STATE(1365),
    [sym_set] = STATE(1365),
    [sym_tuple] = STATE(1365),
    [sym_dictionary] = STATE(1365),
    [sym_list_comprehension] = STATE(1365),
    [sym_dictionary_comprehension] = STATE(1365),
    [sym_set_comprehension] = STATE(1365),
    [sym_generator_expression] = STATE(1365),
    [sym_parenthesized_expression] = STATE(1365),
    [sym_conditional_expression] = STATE(1758),
    [sym_concatenated_string] = STATE(1365),
    [sym_string] = STATE(1004),
    [sym_await] = STATE(1365),
    [sym_identifier] = ACTIONS(275),
    [anon_sym_SEMI] = ACTIONS(277),
    [anon_sym_DOT] = ACTIONS(279),
    [anon_sym_LPAREN] = ACTIONS(281),
    [anon_sym_COMMA] = ACTIONS(284),
    [anon_sym_as] = ACTIONS(279),
    [anon_sym_STAR] = ACTIONS(287),
    [anon_sym_print] = ACTIONS(290),
    [anon_sym_GT_GT] = ACTIONS(279),
    [anon_sym_COLON_EQ] = ACTIONS(292),
    [anon_sym_if] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(294),
    [anon_sym_match] = ACTIONS(290),
    [anon_sym_async] = ACTIONS(290),
    [anon_sym_in] = ACTIONS(279),
    [anon_sym_STAR_STAR] = ACTIONS(297),
    [anon_sym_exec] = ACTIONS(290),
    [anon_sym_type] = ACTIONS(300),
    [anon_sym_EQ] = ACTIONS(302),
    [anon_sym_LBRACK] = ACTIONS(304),
    [anon_sym_AT] = ACTIONS(279),
    [anon_sym_DASH] = ACTIONS(307),
    [anon_sym_PIPE] = ACTIONS(279),
    [anon_sym_LBRACE] = ACTIONS(310),
    [anon_sym_PLUS] = ACTIONS(307),
    [anon_sym_not] = ACTIONS(312),
    [anon_sym_and] = ACTIONS(279),
    [anon_sym_or] = ACTIONS(279),
    [anon_sym_SLASH] = ACTIONS(279),
    [anon_sym_PERCENT] = ACTIONS(279),
    [anon_sym_SLASH_SLASH] = ACTIONS(279),
    [anon_sym_AMP] = ACTIONS(279),
    [anon_sym_CARET] = ACTIONS(279),
    [anon_sym_LT_LT] = ACTIONS(279),
    [anon_sym_TILDE] = ACTIONS(315),
    [anon_sym_LT] = ACTIONS(279),
    [anon_sym_LT_EQ] = ACTIONS(277),
    [anon_sym_EQ_EQ] = ACTIONS(277),
    [anon_sym_BANG_EQ] = ACTIONS(277),
    [anon_sym_GT_EQ] = ACTIONS(277),
    [anon_sym_GT] = ACTIONS(279),
    [anon_sym_LT_GT] = ACTIONS(277),
    [anon_sym_is] = ACTIONS(279),
    [anon_sym_lambda] = ACTIONS(317),
    [anon_sym_PLUS_EQ] = ACTIONS(319),
    [anon_sym_DASH_EQ] = ACTIONS(319),
    [anon_sym_STAR_EQ] = ACTIONS(319),
    [anon_sym_SLASH_EQ] = ACTIONS(319),
    [anon_sym_AT_EQ] = ACTIONS(319),
    [anon_sym_SLASH_SLASH_EQ] = ACTIONS(319),
    [anon_sym_PERCENT_EQ] = ACTIONS(319),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(319),
    [anon_sym_GT_GT_EQ] = ACTIONS(319),
    [anon_sym_LT_LT_EQ] = ACTIONS(319),
    [anon_sym_AMP_EQ] = ACTIONS(319),
    [anon_sym_CARET_EQ] = ACTIONS(319),
    [anon_sym_PIPE_EQ] = ACTIONS(319),
    [sym_ellipsis] = ACTIONS(321),
    [sym_integer] = ACTIONS(323),
    [sym_float] = ACTIONS(321),
    [anon_sym_await] = ACTIONS(325),
    [sym_true] = ACTIONS(323),
    [sym_false] = ACTIONS(323),
    [sym_none] = ACTIONS(323),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(277),
    [sym_string_start] = ACTIONS(327),
  },
  [74] = {
    [sym_named_expression] = STATE(1758),
    [sym__named_expression_lhs] = STATE(2779),
    [sym_list_splat_pattern] = STATE(1433),
    [sym_as_pattern] = STATE(1758),
    [sym_expression] = STATE(1796),
    [sym_primary_expression] = STATE(1002),
    [sym_not_operator] = STATE(1758),
    [sym_boolean_operator] = STATE(1758),
    [sym_binary_operator] = STATE(1365),
    [sym_unary_operator] = STATE(1365),
    [sym_comparison_operator] = STATE(1758),
    [sym_lambda] = STATE(1758),
    [sym_attribute] = STATE(1365),
    [sym_subscript] = STATE(1365),
    [sym_call] = STATE(1365),
    [sym_type] = STATE(2140),
    [sym_splat_type] = STATE(2137),
    [sym_generic_type] = STATE(2137),
    [sym_union_type] = STATE(2137),
    [sym_constrained_type] = STATE(2137),
    [sym_member_type] = STATE(2137),
    [sym_list] = STATE(1365),
    [sym_set] = STATE(1365),
    [sym_tuple] = STATE(1365),
    [sym_dictionary] = STATE(1365),
    [sym_list_comprehension] = STATE(1365),
    [sym_dictionary_comprehension] = STATE(1365),
    [sym_set_comprehension] = STATE(1365),
    [sym_generator_expression] = STATE(1365),
    [sym_parenthesized_expression] = STATE(1365),
    [sym_conditional_expression] = STATE(1758),
    [sym_concatenated_string] = STATE(1365),
    [sym_string] = STATE(1004),
    [sym_await] = STATE(1365),
    [sym_identifier] = ACTIONS(275),
    [anon_sym_SEMI] = ACTIONS(277),
    [anon_sym_DOT] = ACTIONS(279),
    [anon_sym_LPAREN] = ACTIONS(281),
    [anon_sym_COMMA] = ACTIONS(284),
    [anon_sym_as] = ACTIONS(279),
    [anon_sym_STAR] = ACTIONS(287),
    [anon_sym_print] = ACTIONS(290),
    [anon_sym_GT_GT] = ACTIONS(279),
    [anon_sym_COLON_EQ] = ACTIONS(292),
    [anon_sym_if] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(302),
    [anon_sym_match] = ACTIONS(290),
    [anon_sym_async] = ACTIONS(290),
    [anon_sym_in] = ACTIONS(279),
    [anon_sym_STAR_STAR] = ACTIONS(297),
    [anon_sym_exec] = ACTIONS(290),
    [anon_sym_type] = ACTIONS(300),
    [anon_sym_EQ] = ACTIONS(302),
    [anon_sym_LBRACK] = ACTIONS(304),
    [anon_sym_AT] = ACTIONS(279),
    [anon_sym_DASH] = ACTIONS(307),
    [anon_sym_PIPE] = ACTIONS(279),
    [anon_sym_LBRACE] = ACTIONS(310),
    [anon_sym_PLUS] = ACTIONS(307),
    [anon_sym_not] = ACTIONS(312),
    [anon_sym_and] = ACTIONS(279),
    [anon_sym_or] = ACTIONS(279),
    [anon_sym_SLASH] = ACTIONS(279),
    [anon_sym_PERCENT] = ACTIONS(279),
    [anon_sym_SLASH_SLASH] = ACTIONS(279),
    [anon_sym_AMP] = ACTIONS(279),
    [anon_sym_CARET] = ACTIONS(279),
    [anon_sym_LT_LT] = ACTIONS(279),
    [anon_sym_TILDE] = ACTIONS(315),
    [anon_sym_LT] = ACTIONS(279),
    [anon_sym_LT_EQ] = ACTIONS(277),
    [anon_sym_EQ_EQ] = ACTIONS(277),
    [anon_sym_BANG_EQ] = ACTIONS(277),
    [anon_sym_GT_EQ] = ACTIONS(277),
    [anon_sym_GT] = ACTIONS(279),
    [anon_sym_LT_GT] = ACTIONS(277),
    [anon_sym_is] = ACTIONS(279),
    [anon_sym_lambda] = ACTIONS(317),
    [anon_sym_PLUS_EQ] = ACTIONS(319),
    [anon_sym_DASH_EQ] = ACTIONS(319),
    [anon_sym_STAR_EQ] = ACTIONS(319),
    [anon_sym_SLASH_EQ] = ACTIONS(319),
    [anon_sym_AT_EQ] = ACTIONS(319),
    [anon_sym_SLASH_SLASH_EQ] = ACTIONS(319),
    [anon_sym_PERCENT_EQ] = ACTIONS(319),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(319),
    [anon_sym_GT_GT_EQ] = ACTIONS(319),
    [anon_sym_LT_LT_EQ] = ACTIONS(319),
    [anon_sym_AMP_EQ] = ACTIONS(319),
    [anon_sym_CARET_EQ] = ACTIONS(319),
    [anon_sym_PIPE_EQ] = ACTIONS(319),
    [sym_ellipsis] = ACTIONS(321),
    [sym_integer] = ACTIONS(323),
    [sym_float] = ACTIONS(321),
    [anon_sym_await] = ACTIONS(325),
    [sym_true] = ACTIONS(323),
    [sym_false] = ACTIONS(323),
    [sym_none] = ACTIONS(323),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(277),
    [sym_string_start] = ACTIONS(327),
  },
  [75] = {
    [sym__simple_statements] = STATE(815),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(629),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1709),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(630),
    [sym_subscript] = STATE(630),
    [sym_call] = STATE(1057),
    [sym_type] = STATE(2063),
    [sym_splat_type] = STATE(2137),
    [sym_generic_type] = STATE(2137),
    [sym_union_type] = STATE(2137),
    [sym_constrained_type] = STATE(2137),
    [sym_member_type] = STATE(2137),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(329),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(331),
    [anon_sym_STAR] = ACTIONS(333),
    [anon_sym_print] = ACTIONS(335),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(337),
    [anon_sym_async] = ACTIONS(337),
    [anon_sym_STAR_STAR] = ACTIONS(339),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(341),
    [anon_sym_type] = ACTIONS(343),
    [anon_sym_LBRACK] = ACTIONS(345),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(347),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(349),
    [sym__indent] = ACTIONS(351),
    [sym_string_start] = ACTIONS(81),
  },
  [76] = {
    [sym__simple_statements] = STATE(800),
    [sym_import_statement] = STATE(2289),
    [sym_future_import_statement] = STATE(2289),
    [sym_import_from_statement] = STATE(2289),
    [sym_print_statement] = STATE(2289),
    [sym_assert_statement] = STATE(2289),
    [sym_expression_statement] = STATE(2289),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2289),
    [sym_delete_statement] = STATE(2289),
    [sym_raise_statement] = STATE(2289),
    [sym_pass_statement] = STATE(2289),
    [sym_break_statement] = STATE(2289),
    [sym_continue_statement] = STATE(2289),
    [sym_global_statement] = STATE(2289),
    [sym_nonlocal_statement] = STATE(2289),
    [sym_exec_statement] = STATE(2289),
    [sym_type_alias_statement] = STATE(2289),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(629),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1709),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(630),
    [sym_subscript] = STATE(630),
    [sym_call] = STATE(1057),
    [sym_type] = STATE(2063),
    [sym_splat_type] = STATE(2137),
    [sym_generic_type] = STATE(2137),
    [sym_union_type] = STATE(2137),
    [sym_constrained_type] = STATE(2137),
    [sym_member_type] = STATE(2137),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(329),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(331),
    [anon_sym_STAR] = ACTIONS(333),
    [anon_sym_print] = ACTIONS(335),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(337),
    [anon_sym_async] = ACTIONS(337),
    [anon_sym_STAR_STAR] = ACTIONS(339),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(341),
    [anon_sym_type] = ACTIONS(343),
    [anon_sym_LBRACK] = ACTIONS(345),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(347),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(353),
    [sym__indent] = ACTIONS(355),
    [sym_string_start] = ACTIONS(81),
  },
  [77] = {
    [sym__simple_statements] = STATE(802),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(629),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1709),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(630),
    [sym_subscript] = STATE(630),
    [sym_call] = STATE(1057),
    [sym_type] = STATE(2063),
    [sym_splat_type] = STATE(2137),
    [sym_generic_type] = STATE(2137),
    [sym_union_type] = STATE(2137),
    [sym_constrained_type] = STATE(2137),
    [sym_member_type] = STATE(2137),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(329),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(331),
    [anon_sym_STAR] = ACTIONS(333),
    [anon_sym_print] = ACTIONS(335),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(337),
    [anon_sym_async] = ACTIONS(337),
    [anon_sym_STAR_STAR] = ACTIONS(339),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(341),
    [anon_sym_type] = ACTIONS(343),
    [anon_sym_LBRACK] = ACTIONS(345),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(347),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(357),
    [sym__indent] = ACTIONS(359),
    [sym_string_start] = ACTIONS(81),
  },
  [78] = {
    [sym__simple_statements] = STATE(808),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(629),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1709),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(630),
    [sym_subscript] = STATE(630),
    [sym_call] = STATE(1057),
    [sym_type] = STATE(2063),
    [sym_splat_type] = STATE(2137),
    [sym_generic_type] = STATE(2137),
    [sym_union_type] = STATE(2137),
    [sym_constrained_type] = STATE(2137),
    [sym_member_type] = STATE(2137),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(329),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(331),
    [anon_sym_STAR] = ACTIONS(333),
    [anon_sym_print] = ACTIONS(335),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(337),
    [anon_sym_async] = ACTIONS(337),
    [anon_sym_STAR_STAR] = ACTIONS(339),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(341),
    [anon_sym_type] = ACTIONS(343),
    [anon_sym_LBRACK] = ACTIONS(345),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(347),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(361),
    [sym__indent] = ACTIONS(363),
    [sym_string_start] = ACTIONS(81),
  },
  [79] = {
    [sym__simple_statements] = STATE(762),
    [sym_import_statement] = STATE(2289),
    [sym_future_import_statement] = STATE(2289),
    [sym_import_from_statement] = STATE(2289),
    [sym_print_statement] = STATE(2289),
    [sym_assert_statement] = STATE(2289),
    [sym_expression_statement] = STATE(2289),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2289),
    [sym_delete_statement] = STATE(2289),
    [sym_raise_statement] = STATE(2289),
    [sym_pass_statement] = STATE(2289),
    [sym_break_statement] = STATE(2289),
    [sym_continue_statement] = STATE(2289),
    [sym_global_statement] = STATE(2289),
    [sym_nonlocal_statement] = STATE(2289),
    [sym_exec_statement] = STATE(2289),
    [sym_type_alias_statement] = STATE(2289),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(629),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1709),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(630),
    [sym_subscript] = STATE(630),
    [sym_call] = STATE(1057),
    [sym_type] = STATE(2063),
    [sym_splat_type] = STATE(2137),
    [sym_generic_type] = STATE(2137),
    [sym_union_type] = STATE(2137),
    [sym_constrained_type] = STATE(2137),
    [sym_member_type] = STATE(2137),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(329),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(331),
    [anon_sym_STAR] = ACTIONS(333),
    [anon_sym_print] = ACTIONS(335),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(337),
    [anon_sym_async] = ACTIONS(337),
    [anon_sym_STAR_STAR] = ACTIONS(339),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(341),
    [anon_sym_type] = ACTIONS(343),
    [anon_sym_LBRACK] = ACTIONS(345),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(347),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(365),
    [sym__indent] = ACTIONS(367),
    [sym_string_start] = ACTIONS(81),
  },
  [80] = {
    [sym__simple_statements] = STATE(812),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(629),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1709),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(630),
    [sym_subscript] = STATE(630),
    [sym_call] = STATE(1057),
    [sym_type] = STATE(2063),
    [sym_splat_type] = STATE(2137),
    [sym_generic_type] = STATE(2137),
    [sym_union_type] = STATE(2137),
    [sym_constrained_type] = STATE(2137),
    [sym_member_type] = STATE(2137),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(329),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(331),
    [anon_sym_STAR] = ACTIONS(333),
    [anon_sym_print] = ACTIONS(335),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(337),
    [anon_sym_async] = ACTIONS(337),
    [anon_sym_STAR_STAR] = ACTIONS(339),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(341),
    [anon_sym_type] = ACTIONS(343),
    [anon_sym_LBRACK] = ACTIONS(345),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(347),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(369),
    [sym__indent] = ACTIONS(371),
    [sym_string_start] = ACTIONS(81),
  },
  [81] = {
    [sym__simple_statements] = STATE(791),
    [sym_import_statement] = STATE(2289),
    [sym_future_import_statement] = STATE(2289),
    [sym_import_from_statement] = STATE(2289),
    [sym_print_statement] = STATE(2289),
    [sym_assert_statement] = STATE(2289),
    [sym_expression_statement] = STATE(2289),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2289),
    [sym_delete_statement] = STATE(2289),
    [sym_raise_statement] = STATE(2289),
    [sym_pass_statement] = STATE(2289),
    [sym_break_statement] = STATE(2289),
    [sym_continue_statement] = STATE(2289),
    [sym_global_statement] = STATE(2289),
    [sym_nonlocal_statement] = STATE(2289),
    [sym_exec_statement] = STATE(2289),
    [sym_type_alias_statement] = STATE(2289),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(629),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1709),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(630),
    [sym_subscript] = STATE(630),
    [sym_call] = STATE(1057),
    [sym_type] = STATE(2063),
    [sym_splat_type] = STATE(2137),
    [sym_generic_type] = STATE(2137),
    [sym_union_type] = STATE(2137),
    [sym_constrained_type] = STATE(2137),
    [sym_member_type] = STATE(2137),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(329),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(331),
    [anon_sym_STAR] = ACTIONS(333),
    [anon_sym_print] = ACTIONS(335),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(337),
    [anon_sym_async] = ACTIONS(337),
    [anon_sym_STAR_STAR] = ACTIONS(339),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(341),
    [anon_sym_type] = ACTIONS(343),
    [anon_sym_LBRACK] = ACTIONS(345),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(347),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(373),
    [sym__indent] = ACTIONS(375),
    [sym_string_start] = ACTIONS(81),
  },
  [82] = {
    [sym__simple_statements] = STATE(769),
    [sym_import_statement] = STATE(2289),
    [sym_future_import_statement] = STATE(2289),
    [sym_import_from_statement] = STATE(2289),
    [sym_print_statement] = STATE(2289),
    [sym_assert_statement] = STATE(2289),
    [sym_expression_statement] = STATE(2289),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2289),
    [sym_delete_statement] = STATE(2289),
    [sym_raise_statement] = STATE(2289),
    [sym_pass_statement] = STATE(2289),
    [sym_break_statement] = STATE(2289),
    [sym_continue_statement] = STATE(2289),
    [sym_global_statement] = STATE(2289),
    [sym_nonlocal_statement] = STATE(2289),
    [sym_exec_statement] = STATE(2289),
    [sym_type_alias_statement] = STATE(2289),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(629),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1709),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(630),
    [sym_subscript] = STATE(630),
    [sym_call] = STATE(1057),
    [sym_type] = STATE(2063),
    [sym_splat_type] = STATE(2137),
    [sym_generic_type] = STATE(2137),
    [sym_union_type] = STATE(2137),
    [sym_constrained_type] = STATE(2137),
    [sym_member_type] = STATE(2137),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(329),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(331),
    [anon_sym_STAR] = ACTIONS(333),
    [anon_sym_print] = ACTIONS(335),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(337),
    [anon_sym_async] = ACTIONS(337),
    [anon_sym_STAR_STAR] = ACTIONS(339),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(341),
    [anon_sym_type] = ACTIONS(343),
    [anon_sym_LBRACK] = ACTIONS(345),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(347),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(377),
    [sym__indent] = ACTIONS(379),
    [sym_string_start] = ACTIONS(81),
  },
  [83] = {
    [sym_chevron] = STATE(2162),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_list_splat_pattern] = STATE(1117),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1861),
    [sym_primary_expression] = STATE(977),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_attribute] = STATE(1057),
    [sym_subscript] = STATE(1057),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(381),
    [anon_sym_SEMI] = ACTIONS(277),
    [anon_sym_DOT] = ACTIONS(279),
    [anon_sym_LPAREN] = ACTIONS(383),
    [anon_sym_COMMA] = ACTIONS(284),
    [anon_sym_as] = ACTIONS(279),
    [anon_sym_STAR] = ACTIONS(386),
    [anon_sym_print] = ACTIONS(389),
    [anon_sym_GT_GT] = ACTIONS(391),
    [anon_sym_COLON_EQ] = ACTIONS(292),
    [anon_sym_if] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(302),
    [anon_sym_match] = ACTIONS(389),
    [anon_sym_async] = ACTIONS(389),
    [anon_sym_in] = ACTIONS(279),
    [anon_sym_STAR_STAR] = ACTIONS(279),
    [anon_sym_exec] = ACTIONS(389),
    [anon_sym_type] = ACTIONS(393),
    [anon_sym_EQ] = ACTIONS(302),
    [anon_sym_LBRACK] = ACTIONS(395),
    [anon_sym_AT] = ACTIONS(279),
    [anon_sym_DASH] = ACTIONS(398),
    [anon_sym_PIPE] = ACTIONS(279),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(398),
    [anon_sym_not] = ACTIONS(401),
    [anon_sym_and] = ACTIONS(279),
    [anon_sym_or] = ACTIONS(279),
    [anon_sym_SLASH] = ACTIONS(279),
    [anon_sym_PERCENT] = ACTIONS(279),
    [anon_sym_SLASH_SLASH] = ACTIONS(279),
    [anon_sym_AMP] = ACTIONS(279),
    [anon_sym_CARET] = ACTIONS(279),
    [anon_sym_LT_LT] = ACTIONS(279),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_LT] = ACTIONS(279),
    [anon_sym_LT_EQ] = ACTIONS(277),
    [anon_sym_EQ_EQ] = ACTIONS(277),
    [anon_sym_BANG_EQ] = ACTIONS(277),
    [anon_sym_GT_EQ] = ACTIONS(277),
    [anon_sym_GT] = ACTIONS(279),
    [anon_sym_LT_GT] = ACTIONS(277),
    [anon_sym_is] = ACTIONS(279),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_PLUS_EQ] = ACTIONS(319),
    [anon_sym_DASH_EQ] = ACTIONS(319),
    [anon_sym_STAR_EQ] = ACTIONS(319),
    [anon_sym_SLASH_EQ] = ACTIONS(319),
    [anon_sym_AT_EQ] = ACTIONS(319),
    [anon_sym_SLASH_SLASH_EQ] = ACTIONS(319),
    [anon_sym_PERCENT_EQ] = ACTIONS(319),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(319),
    [anon_sym_GT_GT_EQ] = ACTIONS(319),
    [anon_sym_LT_LT_EQ] = ACTIONS(319),
    [anon_sym_AMP_EQ] = ACTIONS(319),
    [anon_sym_CARET_EQ] = ACTIONS(319),
    [anon_sym_PIPE_EQ] = ACTIONS(319),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(404),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(277),
    [sym_string_start] = ACTIONS(81),
  },
  [84] = {
    [sym_chevron] = STATE(2162),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_list_splat_pattern] = STATE(1117),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1861),
    [sym_primary_expression] = STATE(977),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_attribute] = STATE(1057),
    [sym_subscript] = STATE(1057),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(381),
    [anon_sym_SEMI] = ACTIONS(277),
    [anon_sym_DOT] = ACTIONS(279),
    [anon_sym_LPAREN] = ACTIONS(383),
    [anon_sym_COMMA] = ACTIONS(284),
    [anon_sym_as] = ACTIONS(279),
    [anon_sym_STAR] = ACTIONS(386),
    [anon_sym_print] = ACTIONS(389),
    [anon_sym_GT_GT] = ACTIONS(391),
    [anon_sym_COLON_EQ] = ACTIONS(292),
    [anon_sym_if] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(294),
    [anon_sym_match] = ACTIONS(389),
    [anon_sym_async] = ACTIONS(389),
    [anon_sym_in] = ACTIONS(279),
    [anon_sym_STAR_STAR] = ACTIONS(279),
    [anon_sym_exec] = ACTIONS(389),
    [anon_sym_type] = ACTIONS(393),
    [anon_sym_EQ] = ACTIONS(302),
    [anon_sym_LBRACK] = ACTIONS(395),
    [anon_sym_AT] = ACTIONS(279),
    [anon_sym_DASH] = ACTIONS(398),
    [anon_sym_PIPE] = ACTIONS(279),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(398),
    [anon_sym_not] = ACTIONS(401),
    [anon_sym_and] = ACTIONS(279),
    [anon_sym_or] = ACTIONS(279),
    [anon_sym_SLASH] = ACTIONS(279),
    [anon_sym_PERCENT] = ACTIONS(279),
    [anon_sym_SLASH_SLASH] = ACTIONS(279),
    [anon_sym_AMP] = ACTIONS(279),
    [anon_sym_CARET] = ACTIONS(279),
    [anon_sym_LT_LT] = ACTIONS(279),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_LT] = ACTIONS(279),
    [anon_sym_LT_EQ] = ACTIONS(277),
    [anon_sym_EQ_EQ] = ACTIONS(277),
    [anon_sym_BANG_EQ] = ACTIONS(277),
    [anon_sym_GT_EQ] = ACTIONS(277),
    [anon_sym_GT] = ACTIONS(279),
    [anon_sym_LT_GT] = ACTIONS(277),
    [anon_sym_is] = ACTIONS(279),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_PLUS_EQ] = ACTIONS(319),
    [anon_sym_DASH_EQ] = ACTIONS(319),
    [anon_sym_STAR_EQ] = ACTIONS(319),
    [anon_sym_SLASH_EQ] = ACTIONS(319),
    [anon_sym_AT_EQ] = ACTIONS(319),
    [anon_sym_SLASH_SLASH_EQ] = ACTIONS(319),
    [anon_sym_PERCENT_EQ] = ACTIONS(319),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(319),
    [anon_sym_GT_GT_EQ] = ACTIONS(319),
    [anon_sym_LT_LT_EQ] = ACTIONS(319),
    [anon_sym_AMP_EQ] = ACTIONS(319),
    [anon_sym_CARET_EQ] = ACTIONS(319),
    [anon_sym_PIPE_EQ] = ACTIONS(319),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(404),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(277),
    [sym_string_start] = ACTIONS(81),
  },
  [85] = {
    [sym_named_expression] = STATE(1758),
    [sym__named_expression_lhs] = STATE(2779),
    [sym_list_splat_pattern] = STATE(1433),
    [sym_as_pattern] = STATE(1758),
    [sym_expression] = STATE(1871),
    [sym_primary_expression] = STATE(1002),
    [sym_not_operator] = STATE(1758),
    [sym_boolean_operator] = STATE(1758),
    [sym_binary_operator] = STATE(1365),
    [sym_unary_operator] = STATE(1365),
    [sym_comparison_operator] = STATE(1758),
    [sym_lambda] = STATE(1758),
    [sym_attribute] = STATE(1365),
    [sym_subscript] = STATE(1365),
    [sym_call] = STATE(1365),
    [sym_list] = STATE(1365),
    [sym_set] = STATE(1365),
    [sym_tuple] = STATE(1365),
    [sym_dictionary] = STATE(1365),
    [sym_list_comprehension] = STATE(1365),
    [sym_dictionary_comprehension] = STATE(1365),
    [sym_set_comprehension] = STATE(1365),
    [sym_generator_expression] = STATE(1365),
    [sym_parenthesized_expression] = STATE(1365),
    [sym_conditional_expression] = STATE(1758),
    [sym_concatenated_string] = STATE(1365),
    [sym_string] = STATE(1004),
    [sym_await] = STATE(1365),
    [sym_identifier] = ACTIONS(406),
    [anon_sym_SEMI] = ACTIONS(277),
    [anon_sym_DOT] = ACTIONS(279),
    [anon_sym_LPAREN] = ACTIONS(408),
    [anon_sym_COMMA] = ACTIONS(284),
    [anon_sym_as] = ACTIONS(279),
    [anon_sym_STAR] = ACTIONS(410),
    [anon_sym_print] = ACTIONS(290),
    [anon_sym_GT_GT] = ACTIONS(279),
    [anon_sym_COLON_EQ] = ACTIONS(292),
    [anon_sym_if] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(302),
    [anon_sym_match] = ACTIONS(290),
    [anon_sym_async] = ACTIONS(290),
    [anon_sym_in] = ACTIONS(279),
    [anon_sym_STAR_STAR] = ACTIONS(279),
    [anon_sym_exec] = ACTIONS(290),
    [anon_sym_type] = ACTIONS(300),
    [anon_sym_EQ] = ACTIONS(302),
    [anon_sym_LBRACK] = ACTIONS(412),
    [anon_sym_AT] = ACTIONS(279),
    [anon_sym_DASH] = ACTIONS(414),
    [anon_sym_PIPE] = ACTIONS(279),
    [anon_sym_LBRACE] = ACTIONS(310),
    [anon_sym_PLUS] = ACTIONS(414),
    [anon_sym_not] = ACTIONS(416),
    [anon_sym_and] = ACTIONS(279),
    [anon_sym_or] = ACTIONS(279),
    [anon_sym_SLASH] = ACTIONS(279),
    [anon_sym_PERCENT] = ACTIONS(279),
    [anon_sym_SLASH_SLASH] = ACTIONS(279),
    [anon_sym_AMP] = ACTIONS(279),
    [anon_sym_CARET] = ACTIONS(279),
    [anon_sym_LT_LT] = ACTIONS(279),
    [anon_sym_TILDE] = ACTIONS(315),
    [anon_sym_LT] = ACTIONS(279),
    [anon_sym_LT_EQ] = ACTIONS(277),
    [anon_sym_EQ_EQ] = ACTIONS(277),
    [anon_sym_BANG_EQ] = ACTIONS(277),
    [anon_sym_GT_EQ] = ACTIONS(277),
    [anon_sym_GT] = ACTIONS(279),
    [anon_sym_LT_GT] = ACTIONS(277),
    [anon_sym_is] = ACTIONS(279),
    [anon_sym_lambda] = ACTIONS(317),
    [anon_sym_PLUS_EQ] = ACTIONS(319),
    [anon_sym_DASH_EQ] = ACTIONS(319),
    [anon_sym_STAR_EQ] = ACTIONS(319),
    [anon_sym_SLASH_EQ] = ACTIONS(319),
    [anon_sym_AT_EQ] = ACTIONS(319),
    [anon_sym_SLASH_SLASH_EQ] = ACTIONS(319),
    [anon_sym_PERCENT_EQ] = ACTIONS(319),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(319),
    [anon_sym_GT_GT_EQ] = ACTIONS(319),
    [anon_sym_LT_LT_EQ] = ACTIONS(319),
    [anon_sym_AMP_EQ] = ACTIONS(319),
    [anon_sym_CARET_EQ] = ACTIONS(319),
    [anon_sym_PIPE_EQ] = ACTIONS(319),
    [sym_ellipsis] = ACTIONS(321),
    [sym_integer] = ACTIONS(323),
    [sym_float] = ACTIONS(321),
    [anon_sym_await] = ACTIONS(325),
    [sym_true] = ACTIONS(323),
    [sym_false] = ACTIONS(323),
    [sym_none] = ACTIONS(323),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(277),
    [sym_string_start] = ACTIONS(327),
  },
  [86] = {
    [sym_named_expression] = STATE(1758),
    [sym__named_expression_lhs] = STATE(2779),
    [sym_list_splat_pattern] = STATE(1433),
    [sym_as_pattern] = STATE(1758),
    [sym_expression] = STATE(1878),
    [sym_primary_expression] = STATE(1002),
    [sym_not_operator] = STATE(1758),
    [sym_boolean_operator] = STATE(1758),
    [sym_binary_operator] = STATE(1365),
    [sym_unary_operator] = STATE(1365),
    [sym_comparison_operator] = STATE(1758),
    [sym_lambda] = STATE(1758),
    [sym_attribute] = STATE(1365),
    [sym_subscript] = STATE(1365),
    [sym_call] = STATE(1365),
    [sym_list] = STATE(1365),
    [sym_set] = STATE(1365),
    [sym_tuple] = STATE(1365),
    [sym_dictionary] = STATE(1365),
    [sym_list_comprehension] = STATE(1365),
    [sym_dictionary_comprehension] = STATE(1365),
    [sym_set_comprehension] = STATE(1365),
    [sym_generator_expression] = STATE(1365),
    [sym_parenthesized_expression] = STATE(1365),
    [sym_conditional_expression] = STATE(1758),
    [sym_concatenated_string] = STATE(1365),
    [sym_string] = STATE(1004),
    [sym_await] = STATE(1365),
    [sym_identifier] = ACTIONS(406),
    [anon_sym_SEMI] = ACTIONS(277),
    [anon_sym_DOT] = ACTIONS(279),
    [anon_sym_LPAREN] = ACTIONS(408),
    [anon_sym_COMMA] = ACTIONS(284),
    [anon_sym_as] = ACTIONS(279),
    [anon_sym_STAR] = ACTIONS(410),
    [anon_sym_print] = ACTIONS(290),
    [anon_sym_GT_GT] = ACTIONS(279),
    [anon_sym_COLON_EQ] = ACTIONS(292),
    [anon_sym_if] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(302),
    [anon_sym_match] = ACTIONS(290),
    [anon_sym_async] = ACTIONS(290),
    [anon_sym_in] = ACTIONS(279),
    [anon_sym_STAR_STAR] = ACTIONS(279),
    [anon_sym_exec] = ACTIONS(290),
    [anon_sym_type] = ACTIONS(300),
    [anon_sym_EQ] = ACTIONS(302),
    [anon_sym_LBRACK] = ACTIONS(412),
    [anon_sym_AT] = ACTIONS(279),
    [anon_sym_DASH] = ACTIONS(414),
    [anon_sym_PIPE] = ACTIONS(279),
    [anon_sym_LBRACE] = ACTIONS(310),
    [anon_sym_PLUS] = ACTIONS(414),
    [anon_sym_not] = ACTIONS(416),
    [anon_sym_and] = ACTIONS(279),
    [anon_sym_or] = ACTIONS(279),
    [anon_sym_SLASH] = ACTIONS(279),
    [anon_sym_PERCENT] = ACTIONS(279),
    [anon_sym_SLASH_SLASH] = ACTIONS(279),
    [anon_sym_AMP] = ACTIONS(279),
    [anon_sym_CARET] = ACTIONS(279),
    [anon_sym_LT_LT] = ACTIONS(279),
    [anon_sym_TILDE] = ACTIONS(315),
    [anon_sym_LT] = ACTIONS(279),
    [anon_sym_LT_EQ] = ACTIONS(277),
    [anon_sym_EQ_EQ] = ACTIONS(277),
    [anon_sym_BANG_EQ] = ACTIONS(277),
    [anon_sym_GT_EQ] = ACTIONS(277),
    [anon_sym_GT] = ACTIONS(279),
    [anon_sym_LT_GT] = ACTIONS(277),
    [anon_sym_is] = ACTIONS(279),
    [anon_sym_lambda] = ACTIONS(317),
    [anon_sym_PLUS_EQ] = ACTIONS(319),
    [anon_sym_DASH_EQ] = ACTIONS(319),
    [anon_sym_STAR_EQ] = ACTIONS(319),
    [anon_sym_SLASH_EQ] = ACTIONS(319),
    [anon_sym_AT_EQ] = ACTIONS(319),
    [anon_sym_SLASH_SLASH_EQ] = ACTIONS(319),
    [anon_sym_PERCENT_EQ] = ACTIONS(319),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(319),
    [anon_sym_GT_GT_EQ] = ACTIONS(319),
    [anon_sym_LT_LT_EQ] = ACTIONS(319),
    [anon_sym_AMP_EQ] = ACTIONS(319),
    [anon_sym_CARET_EQ] = ACTIONS(319),
    [anon_sym_PIPE_EQ] = ACTIONS(319),
    [sym_ellipsis] = ACTIONS(321),
    [sym_integer] = ACTIONS(323),
    [sym_float] = ACTIONS(321),
    [anon_sym_await] = ACTIONS(325),
    [sym_true] = ACTIONS(323),
    [sym_false] = ACTIONS(323),
    [sym_none] = ACTIONS(323),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(277),
    [sym_string_start] = ACTIONS(327),
  },
  [87] = {
    [sym__simple_statements] = STATE(696),
    [sym_import_statement] = STATE(2365),
    [sym_future_import_statement] = STATE(2365),
    [sym_import_from_statement] = STATE(2365),
    [sym_print_statement] = STATE(2365),
    [sym_assert_statement] = STATE(2365),
    [sym_expression_statement] = STATE(2365),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2365),
    [sym_delete_statement] = STATE(2365),
    [sym_raise_statement] = STATE(2365),
    [sym_pass_statement] = STATE(2365),
    [sym_break_statement] = STATE(2365),
    [sym_continue_statement] = STATE(2365),
    [sym_global_statement] = STATE(2365),
    [sym_nonlocal_statement] = STATE(2365),
    [sym_exec_statement] = STATE(2365),
    [sym_type_alias_statement] = STATE(2365),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(420),
    [sym__indent] = ACTIONS(422),
    [sym_string_start] = ACTIONS(81),
  },
  [88] = {
    [sym__simple_statements] = STATE(794),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(424),
    [sym__indent] = ACTIONS(426),
    [sym_string_start] = ACTIONS(81),
  },
  [89] = {
    [sym__simple_statements] = STATE(659),
    [sym_import_statement] = STATE(2365),
    [sym_future_import_statement] = STATE(2365),
    [sym_import_from_statement] = STATE(2365),
    [sym_print_statement] = STATE(2365),
    [sym_assert_statement] = STATE(2365),
    [sym_expression_statement] = STATE(2365),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2365),
    [sym_delete_statement] = STATE(2365),
    [sym_raise_statement] = STATE(2365),
    [sym_pass_statement] = STATE(2365),
    [sym_break_statement] = STATE(2365),
    [sym_continue_statement] = STATE(2365),
    [sym_global_statement] = STATE(2365),
    [sym_nonlocal_statement] = STATE(2365),
    [sym_exec_statement] = STATE(2365),
    [sym_type_alias_statement] = STATE(2365),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(428),
    [sym__indent] = ACTIONS(430),
    [sym_string_start] = ACTIONS(81),
  },
  [90] = {
    [sym__simple_statements] = STATE(2528),
    [sym_import_statement] = STATE(2522),
    [sym_future_import_statement] = STATE(2522),
    [sym_import_from_statement] = STATE(2522),
    [sym_print_statement] = STATE(2522),
    [sym_assert_statement] = STATE(2522),
    [sym_expression_statement] = STATE(2522),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2522),
    [sym_delete_statement] = STATE(2522),
    [sym_raise_statement] = STATE(2522),
    [sym_pass_statement] = STATE(2522),
    [sym_break_statement] = STATE(2522),
    [sym_continue_statement] = STATE(2522),
    [sym_global_statement] = STATE(2522),
    [sym_nonlocal_statement] = STATE(2522),
    [sym_exec_statement] = STATE(2522),
    [sym_type_alias_statement] = STATE(2522),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(432),
    [sym__indent] = ACTIONS(434),
    [sym_string_start] = ACTIONS(81),
  },
  [91] = {
    [sym__simple_statements] = STATE(756),
    [sym_import_statement] = STATE(2289),
    [sym_future_import_statement] = STATE(2289),
    [sym_import_from_statement] = STATE(2289),
    [sym_print_statement] = STATE(2289),
    [sym_assert_statement] = STATE(2289),
    [sym_expression_statement] = STATE(2289),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2289),
    [sym_delete_statement] = STATE(2289),
    [sym_raise_statement] = STATE(2289),
    [sym_pass_statement] = STATE(2289),
    [sym_break_statement] = STATE(2289),
    [sym_continue_statement] = STATE(2289),
    [sym_global_statement] = STATE(2289),
    [sym_nonlocal_statement] = STATE(2289),
    [sym_exec_statement] = STATE(2289),
    [sym_type_alias_statement] = STATE(2289),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(436),
    [sym__indent] = ACTIONS(438),
    [sym_string_start] = ACTIONS(81),
  },
  [92] = {
    [sym__simple_statements] = STATE(710),
    [sym_import_statement] = STATE(2289),
    [sym_future_import_statement] = STATE(2289),
    [sym_import_from_statement] = STATE(2289),
    [sym_print_statement] = STATE(2289),
    [sym_assert_statement] = STATE(2289),
    [sym_expression_statement] = STATE(2289),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2289),
    [sym_delete_statement] = STATE(2289),
    [sym_raise_statement] = STATE(2289),
    [sym_pass_statement] = STATE(2289),
    [sym_break_statement] = STATE(2289),
    [sym_continue_statement] = STATE(2289),
    [sym_global_statement] = STATE(2289),
    [sym_nonlocal_statement] = STATE(2289),
    [sym_exec_statement] = STATE(2289),
    [sym_type_alias_statement] = STATE(2289),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(440),
    [sym__indent] = ACTIONS(442),
    [sym_string_start] = ACTIONS(81),
  },
  [93] = {
    [sym__simple_statements] = STATE(663),
    [sym_import_statement] = STATE(2425),
    [sym_future_import_statement] = STATE(2425),
    [sym_import_from_statement] = STATE(2425),
    [sym_print_statement] = STATE(2425),
    [sym_assert_statement] = STATE(2425),
    [sym_expression_statement] = STATE(2425),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2425),
    [sym_delete_statement] = STATE(2425),
    [sym_raise_statement] = STATE(2425),
    [sym_pass_statement] = STATE(2425),
    [sym_break_statement] = STATE(2425),
    [sym_continue_statement] = STATE(2425),
    [sym_global_statement] = STATE(2425),
    [sym_nonlocal_statement] = STATE(2425),
    [sym_exec_statement] = STATE(2425),
    [sym_type_alias_statement] = STATE(2425),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(444),
    [sym__indent] = ACTIONS(446),
    [sym_string_start] = ACTIONS(81),
  },
  [94] = {
    [sym__simple_statements] = STATE(713),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(448),
    [sym__indent] = ACTIONS(450),
    [sym_string_start] = ACTIONS(81),
  },
  [95] = {
    [sym__simple_statements] = STATE(722),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(452),
    [sym__indent] = ACTIONS(454),
    [sym_string_start] = ACTIONS(81),
  },
  [96] = {
    [sym__simple_statements] = STATE(846),
    [sym_import_statement] = STATE(2289),
    [sym_future_import_statement] = STATE(2289),
    [sym_import_from_statement] = STATE(2289),
    [sym_print_statement] = STATE(2289),
    [sym_assert_statement] = STATE(2289),
    [sym_expression_statement] = STATE(2289),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2289),
    [sym_delete_statement] = STATE(2289),
    [sym_raise_statement] = STATE(2289),
    [sym_pass_statement] = STATE(2289),
    [sym_break_statement] = STATE(2289),
    [sym_continue_statement] = STATE(2289),
    [sym_global_statement] = STATE(2289),
    [sym_nonlocal_statement] = STATE(2289),
    [sym_exec_statement] = STATE(2289),
    [sym_type_alias_statement] = STATE(2289),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(456),
    [sym__indent] = ACTIONS(458),
    [sym_string_start] = ACTIONS(81),
  },
  [97] = {
    [sym__simple_statements] = STATE(662),
    [sym_import_statement] = STATE(2477),
    [sym_future_import_statement] = STATE(2477),
    [sym_import_from_statement] = STATE(2477),
    [sym_print_statement] = STATE(2477),
    [sym_assert_statement] = STATE(2477),
    [sym_expression_statement] = STATE(2477),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2477),
    [sym_delete_statement] = STATE(2477),
    [sym_raise_statement] = STATE(2477),
    [sym_pass_statement] = STATE(2477),
    [sym_break_statement] = STATE(2477),
    [sym_continue_statement] = STATE(2477),
    [sym_global_statement] = STATE(2477),
    [sym_nonlocal_statement] = STATE(2477),
    [sym_exec_statement] = STATE(2477),
    [sym_type_alias_statement] = STATE(2477),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(460),
    [sym__indent] = ACTIONS(462),
    [sym_string_start] = ACTIONS(81),
  },
  [98] = {
    [sym__simple_statements] = STATE(778),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(464),
    [sym__indent] = ACTIONS(466),
    [sym_string_start] = ACTIONS(81),
  },
  [99] = {
    [sym__simple_statements] = STATE(830),
    [sym_import_statement] = STATE(2289),
    [sym_future_import_statement] = STATE(2289),
    [sym_import_from_statement] = STATE(2289),
    [sym_print_statement] = STATE(2289),
    [sym_assert_statement] = STATE(2289),
    [sym_expression_statement] = STATE(2289),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2289),
    [sym_delete_statement] = STATE(2289),
    [sym_raise_statement] = STATE(2289),
    [sym_pass_statement] = STATE(2289),
    [sym_break_statement] = STATE(2289),
    [sym_continue_statement] = STATE(2289),
    [sym_global_statement] = STATE(2289),
    [sym_nonlocal_statement] = STATE(2289),
    [sym_exec_statement] = STATE(2289),
    [sym_type_alias_statement] = STATE(2289),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(468),
    [sym__indent] = ACTIONS(470),
    [sym_string_start] = ACTIONS(81),
  },
  [100] = {
    [sym__simple_statements] = STATE(610),
    [sym_import_statement] = STATE(2289),
    [sym_future_import_statement] = STATE(2289),
    [sym_import_from_statement] = STATE(2289),
    [sym_print_statement] = STATE(2289),
    [sym_assert_statement] = STATE(2289),
    [sym_expression_statement] = STATE(2289),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2289),
    [sym_delete_statement] = STATE(2289),
    [sym_raise_statement] = STATE(2289),
    [sym_pass_statement] = STATE(2289),
    [sym_break_statement] = STATE(2289),
    [sym_continue_statement] = STATE(2289),
    [sym_global_statement] = STATE(2289),
    [sym_nonlocal_statement] = STATE(2289),
    [sym_exec_statement] = STATE(2289),
    [sym_type_alias_statement] = STATE(2289),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(472),
    [sym__indent] = ACTIONS(474),
    [sym_string_start] = ACTIONS(81),
  },
  [101] = {
    [sym__simple_statements] = STATE(776),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(476),
    [sym__indent] = ACTIONS(478),
    [sym_string_start] = ACTIONS(81),
  },
  [102] = {
    [sym__simple_statements] = STATE(735),
    [sym_import_statement] = STATE(2289),
    [sym_future_import_statement] = STATE(2289),
    [sym_import_from_statement] = STATE(2289),
    [sym_print_statement] = STATE(2289),
    [sym_assert_statement] = STATE(2289),
    [sym_expression_statement] = STATE(2289),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2289),
    [sym_delete_statement] = STATE(2289),
    [sym_raise_statement] = STATE(2289),
    [sym_pass_statement] = STATE(2289),
    [sym_break_statement] = STATE(2289),
    [sym_continue_statement] = STATE(2289),
    [sym_global_statement] = STATE(2289),
    [sym_nonlocal_statement] = STATE(2289),
    [sym_exec_statement] = STATE(2289),
    [sym_type_alias_statement] = STATE(2289),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(480),
    [sym__indent] = ACTIONS(482),
    [sym_string_start] = ACTIONS(81),
  },
  [103] = {
    [sym__simple_statements] = STATE(765),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(484),
    [sym__indent] = ACTIONS(486),
    [sym_string_start] = ACTIONS(81),
  },
  [104] = {
    [sym__simple_statements] = STATE(654),
    [sym_import_statement] = STATE(2477),
    [sym_future_import_statement] = STATE(2477),
    [sym_import_from_statement] = STATE(2477),
    [sym_print_statement] = STATE(2477),
    [sym_assert_statement] = STATE(2477),
    [sym_expression_statement] = STATE(2477),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2477),
    [sym_delete_statement] = STATE(2477),
    [sym_raise_statement] = STATE(2477),
    [sym_pass_statement] = STATE(2477),
    [sym_break_statement] = STATE(2477),
    [sym_continue_statement] = STATE(2477),
    [sym_global_statement] = STATE(2477),
    [sym_nonlocal_statement] = STATE(2477),
    [sym_exec_statement] = STATE(2477),
    [sym_type_alias_statement] = STATE(2477),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(488),
    [sym__indent] = ACTIONS(490),
    [sym_string_start] = ACTIONS(81),
  },
  [105] = {
    [sym__simple_statements] = STATE(719),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(492),
    [sym__indent] = ACTIONS(494),
    [sym_string_start] = ACTIONS(81),
  },
  [106] = {
    [sym__simple_statements] = STATE(759),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(496),
    [sym__indent] = ACTIONS(498),
    [sym_string_start] = ACTIONS(81),
  },
  [107] = {
    [sym__simple_statements] = STATE(1830),
    [sym_import_statement] = STATE(2287),
    [sym_future_import_statement] = STATE(2287),
    [sym_import_from_statement] = STATE(2287),
    [sym_print_statement] = STATE(2287),
    [sym_assert_statement] = STATE(2287),
    [sym_expression_statement] = STATE(2287),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2287),
    [sym_delete_statement] = STATE(2287),
    [sym_raise_statement] = STATE(2287),
    [sym_pass_statement] = STATE(2287),
    [sym_break_statement] = STATE(2287),
    [sym_continue_statement] = STATE(2287),
    [sym_global_statement] = STATE(2287),
    [sym_nonlocal_statement] = STATE(2287),
    [sym_exec_statement] = STATE(2287),
    [sym_type_alias_statement] = STATE(2287),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(500),
    [sym__indent] = ACTIONS(502),
    [sym_string_start] = ACTIONS(81),
  },
  [108] = {
    [sym__simple_statements] = STATE(751),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(504),
    [sym__indent] = ACTIONS(506),
    [sym_string_start] = ACTIONS(81),
  },
  [109] = {
    [sym__simple_statements] = STATE(760),
    [sym_import_statement] = STATE(2289),
    [sym_future_import_statement] = STATE(2289),
    [sym_import_from_statement] = STATE(2289),
    [sym_print_statement] = STATE(2289),
    [sym_assert_statement] = STATE(2289),
    [sym_expression_statement] = STATE(2289),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2289),
    [sym_delete_statement] = STATE(2289),
    [sym_raise_statement] = STATE(2289),
    [sym_pass_statement] = STATE(2289),
    [sym_break_statement] = STATE(2289),
    [sym_continue_statement] = STATE(2289),
    [sym_global_statement] = STATE(2289),
    [sym_nonlocal_statement] = STATE(2289),
    [sym_exec_statement] = STATE(2289),
    [sym_type_alias_statement] = STATE(2289),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(508),
    [sym__indent] = ACTIONS(510),
    [sym_string_start] = ACTIONS(81),
  },
  [110] = {
    [sym__simple_statements] = STATE(1841),
    [sym_import_statement] = STATE(2287),
    [sym_future_import_statement] = STATE(2287),
    [sym_import_from_statement] = STATE(2287),
    [sym_print_statement] = STATE(2287),
    [sym_assert_statement] = STATE(2287),
    [sym_expression_statement] = STATE(2287),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2287),
    [sym_delete_statement] = STATE(2287),
    [sym_raise_statement] = STATE(2287),
    [sym_pass_statement] = STATE(2287),
    [sym_break_statement] = STATE(2287),
    [sym_continue_statement] = STATE(2287),
    [sym_global_statement] = STATE(2287),
    [sym_nonlocal_statement] = STATE(2287),
    [sym_exec_statement] = STATE(2287),
    [sym_type_alias_statement] = STATE(2287),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(512),
    [sym__indent] = ACTIONS(514),
    [sym_string_start] = ACTIONS(81),
  },
  [111] = {
    [sym__simple_statements] = STATE(750),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(516),
    [sym__indent] = ACTIONS(518),
    [sym_string_start] = ACTIONS(81),
  },
  [112] = {
    [sym__simple_statements] = STATE(701),
    [sym_import_statement] = STATE(2289),
    [sym_future_import_statement] = STATE(2289),
    [sym_import_from_statement] = STATE(2289),
    [sym_print_statement] = STATE(2289),
    [sym_assert_statement] = STATE(2289),
    [sym_expression_statement] = STATE(2289),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2289),
    [sym_delete_statement] = STATE(2289),
    [sym_raise_statement] = STATE(2289),
    [sym_pass_statement] = STATE(2289),
    [sym_break_statement] = STATE(2289),
    [sym_continue_statement] = STATE(2289),
    [sym_global_statement] = STATE(2289),
    [sym_nonlocal_statement] = STATE(2289),
    [sym_exec_statement] = STATE(2289),
    [sym_type_alias_statement] = STATE(2289),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(520),
    [sym__indent] = ACTIONS(522),
    [sym_string_start] = ACTIONS(81),
  },
  [113] = {
    [sym__simple_statements] = STATE(748),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(524),
    [sym__indent] = ACTIONS(526),
    [sym_string_start] = ACTIONS(81),
  },
  [114] = {
    [sym__simple_statements] = STATE(711),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(528),
    [sym__indent] = ACTIONS(530),
    [sym_string_start] = ACTIONS(81),
  },
  [115] = {
    [sym__simple_statements] = STATE(2550),
    [sym_import_statement] = STATE(2522),
    [sym_future_import_statement] = STATE(2522),
    [sym_import_from_statement] = STATE(2522),
    [sym_print_statement] = STATE(2522),
    [sym_assert_statement] = STATE(2522),
    [sym_expression_statement] = STATE(2522),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2522),
    [sym_delete_statement] = STATE(2522),
    [sym_raise_statement] = STATE(2522),
    [sym_pass_statement] = STATE(2522),
    [sym_break_statement] = STATE(2522),
    [sym_continue_statement] = STATE(2522),
    [sym_global_statement] = STATE(2522),
    [sym_nonlocal_statement] = STATE(2522),
    [sym_exec_statement] = STATE(2522),
    [sym_type_alias_statement] = STATE(2522),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(532),
    [sym__indent] = ACTIONS(534),
    [sym_string_start] = ACTIONS(81),
  },
  [116] = {
    [sym__simple_statements] = STATE(2547),
    [sym_import_statement] = STATE(2522),
    [sym_future_import_statement] = STATE(2522),
    [sym_import_from_statement] = STATE(2522),
    [sym_print_statement] = STATE(2522),
    [sym_assert_statement] = STATE(2522),
    [sym_expression_statement] = STATE(2522),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2522),
    [sym_delete_statement] = STATE(2522),
    [sym_raise_statement] = STATE(2522),
    [sym_pass_statement] = STATE(2522),
    [sym_break_statement] = STATE(2522),
    [sym_continue_statement] = STATE(2522),
    [sym_global_statement] = STATE(2522),
    [sym_nonlocal_statement] = STATE(2522),
    [sym_exec_statement] = STATE(2522),
    [sym_type_alias_statement] = STATE(2522),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(536),
    [sym__indent] = ACTIONS(538),
    [sym_string_start] = ACTIONS(81),
  },
  [117] = {
    [sym__simple_statements] = STATE(737),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(540),
    [sym__indent] = ACTIONS(542),
    [sym_string_start] = ACTIONS(81),
  },
  [118] = {
    [sym__simple_statements] = STATE(675),
    [sym_import_statement] = STATE(2365),
    [sym_future_import_statement] = STATE(2365),
    [sym_import_from_statement] = STATE(2365),
    [sym_print_statement] = STATE(2365),
    [sym_assert_statement] = STATE(2365),
    [sym_expression_statement] = STATE(2365),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2365),
    [sym_delete_statement] = STATE(2365),
    [sym_raise_statement] = STATE(2365),
    [sym_pass_statement] = STATE(2365),
    [sym_break_statement] = STATE(2365),
    [sym_continue_statement] = STATE(2365),
    [sym_global_statement] = STATE(2365),
    [sym_nonlocal_statement] = STATE(2365),
    [sym_exec_statement] = STATE(2365),
    [sym_type_alias_statement] = STATE(2365),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(544),
    [sym__indent] = ACTIONS(546),
    [sym_string_start] = ACTIONS(81),
  },
  [119] = {
    [sym__simple_statements] = STATE(2593),
    [sym_import_statement] = STATE(2522),
    [sym_future_import_statement] = STATE(2522),
    [sym_import_from_statement] = STATE(2522),
    [sym_print_statement] = STATE(2522),
    [sym_assert_statement] = STATE(2522),
    [sym_expression_statement] = STATE(2522),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2522),
    [sym_delete_statement] = STATE(2522),
    [sym_raise_statement] = STATE(2522),
    [sym_pass_statement] = STATE(2522),
    [sym_break_statement] = STATE(2522),
    [sym_continue_statement] = STATE(2522),
    [sym_global_statement] = STATE(2522),
    [sym_nonlocal_statement] = STATE(2522),
    [sym_exec_statement] = STATE(2522),
    [sym_type_alias_statement] = STATE(2522),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(548),
    [sym__indent] = ACTIONS(550),
    [sym_string_start] = ACTIONS(81),
  },
  [120] = {
    [sym__simple_statements] = STATE(2598),
    [sym_import_statement] = STATE(2522),
    [sym_future_import_statement] = STATE(2522),
    [sym_import_from_statement] = STATE(2522),
    [sym_print_statement] = STATE(2522),
    [sym_assert_statement] = STATE(2522),
    [sym_expression_statement] = STATE(2522),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2522),
    [sym_delete_statement] = STATE(2522),
    [sym_raise_statement] = STATE(2522),
    [sym_pass_statement] = STATE(2522),
    [sym_break_statement] = STATE(2522),
    [sym_continue_statement] = STATE(2522),
    [sym_global_statement] = STATE(2522),
    [sym_nonlocal_statement] = STATE(2522),
    [sym_exec_statement] = STATE(2522),
    [sym_type_alias_statement] = STATE(2522),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(552),
    [sym__indent] = ACTIONS(554),
    [sym_string_start] = ACTIONS(81),
  },
  [121] = {
    [sym__simple_statements] = STATE(772),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(556),
    [sym__indent] = ACTIONS(558),
    [sym_string_start] = ACTIONS(81),
  },
  [122] = {
    [sym__simple_statements] = STATE(780),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(560),
    [sym__indent] = ACTIONS(562),
    [sym_string_start] = ACTIONS(81),
  },
  [123] = {
    [sym__simple_statements] = STATE(716),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(564),
    [sym__indent] = ACTIONS(566),
    [sym_string_start] = ACTIONS(81),
  },
  [124] = {
    [sym__simple_statements] = STATE(617),
    [sym_import_statement] = STATE(2303),
    [sym_future_import_statement] = STATE(2303),
    [sym_import_from_statement] = STATE(2303),
    [sym_print_statement] = STATE(2303),
    [sym_assert_statement] = STATE(2303),
    [sym_expression_statement] = STATE(2303),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2303),
    [sym_delete_statement] = STATE(2303),
    [sym_raise_statement] = STATE(2303),
    [sym_pass_statement] = STATE(2303),
    [sym_break_statement] = STATE(2303),
    [sym_continue_statement] = STATE(2303),
    [sym_global_statement] = STATE(2303),
    [sym_nonlocal_statement] = STATE(2303),
    [sym_exec_statement] = STATE(2303),
    [sym_type_alias_statement] = STATE(2303),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(568),
    [sym__indent] = ACTIONS(570),
    [sym_string_start] = ACTIONS(81),
  },
  [125] = {
    [sym__simple_statements] = STATE(843),
    [sym_import_statement] = STATE(2289),
    [sym_future_import_statement] = STATE(2289),
    [sym_import_from_statement] = STATE(2289),
    [sym_print_statement] = STATE(2289),
    [sym_assert_statement] = STATE(2289),
    [sym_expression_statement] = STATE(2289),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2289),
    [sym_delete_statement] = STATE(2289),
    [sym_raise_statement] = STATE(2289),
    [sym_pass_statement] = STATE(2289),
    [sym_break_statement] = STATE(2289),
    [sym_continue_statement] = STATE(2289),
    [sym_global_statement] = STATE(2289),
    [sym_nonlocal_statement] = STATE(2289),
    [sym_exec_statement] = STATE(2289),
    [sym_type_alias_statement] = STATE(2289),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(572),
    [sym__indent] = ACTIONS(574),
    [sym_string_start] = ACTIONS(81),
  },
  [126] = {
    [sym__simple_statements] = STATE(833),
    [sym_import_statement] = STATE(2289),
    [sym_future_import_statement] = STATE(2289),
    [sym_import_from_statement] = STATE(2289),
    [sym_print_statement] = STATE(2289),
    [sym_assert_statement] = STATE(2289),
    [sym_expression_statement] = STATE(2289),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2289),
    [sym_delete_statement] = STATE(2289),
    [sym_raise_statement] = STATE(2289),
    [sym_pass_statement] = STATE(2289),
    [sym_break_statement] = STATE(2289),
    [sym_continue_statement] = STATE(2289),
    [sym_global_statement] = STATE(2289),
    [sym_nonlocal_statement] = STATE(2289),
    [sym_exec_statement] = STATE(2289),
    [sym_type_alias_statement] = STATE(2289),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(576),
    [sym__indent] = ACTIONS(578),
    [sym_string_start] = ACTIONS(81),
  },
  [127] = {
    [sym__simple_statements] = STATE(2555),
    [sym_import_statement] = STATE(2522),
    [sym_future_import_statement] = STATE(2522),
    [sym_import_from_statement] = STATE(2522),
    [sym_print_statement] = STATE(2522),
    [sym_assert_statement] = STATE(2522),
    [sym_expression_statement] = STATE(2522),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2522),
    [sym_delete_statement] = STATE(2522),
    [sym_raise_statement] = STATE(2522),
    [sym_pass_statement] = STATE(2522),
    [sym_break_statement] = STATE(2522),
    [sym_continue_statement] = STATE(2522),
    [sym_global_statement] = STATE(2522),
    [sym_nonlocal_statement] = STATE(2522),
    [sym_exec_statement] = STATE(2522),
    [sym_type_alias_statement] = STATE(2522),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(580),
    [sym__indent] = ACTIONS(582),
    [sym_string_start] = ACTIONS(81),
  },
  [128] = {
    [sym__simple_statements] = STATE(705),
    [sym_import_statement] = STATE(2289),
    [sym_future_import_statement] = STATE(2289),
    [sym_import_from_statement] = STATE(2289),
    [sym_print_statement] = STATE(2289),
    [sym_assert_statement] = STATE(2289),
    [sym_expression_statement] = STATE(2289),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2289),
    [sym_delete_statement] = STATE(2289),
    [sym_raise_statement] = STATE(2289),
    [sym_pass_statement] = STATE(2289),
    [sym_break_statement] = STATE(2289),
    [sym_continue_statement] = STATE(2289),
    [sym_global_statement] = STATE(2289),
    [sym_nonlocal_statement] = STATE(2289),
    [sym_exec_statement] = STATE(2289),
    [sym_type_alias_statement] = STATE(2289),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(584),
    [sym__indent] = ACTIONS(586),
    [sym_string_start] = ACTIONS(81),
  },
  [129] = {
    [sym__simple_statements] = STATE(805),
    [sym_import_statement] = STATE(2289),
    [sym_future_import_statement] = STATE(2289),
    [sym_import_from_statement] = STATE(2289),
    [sym_print_statement] = STATE(2289),
    [sym_assert_statement] = STATE(2289),
    [sym_expression_statement] = STATE(2289),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2289),
    [sym_delete_statement] = STATE(2289),
    [sym_raise_statement] = STATE(2289),
    [sym_pass_statement] = STATE(2289),
    [sym_break_statement] = STATE(2289),
    [sym_continue_statement] = STATE(2289),
    [sym_global_statement] = STATE(2289),
    [sym_nonlocal_statement] = STATE(2289),
    [sym_exec_statement] = STATE(2289),
    [sym_type_alias_statement] = STATE(2289),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(588),
    [sym__indent] = ACTIONS(590),
    [sym_string_start] = ACTIONS(81),
  },
  [130] = {
    [sym__simple_statements] = STATE(717),
    [sym_import_statement] = STATE(2289),
    [sym_future_import_statement] = STATE(2289),
    [sym_import_from_statement] = STATE(2289),
    [sym_print_statement] = STATE(2289),
    [sym_assert_statement] = STATE(2289),
    [sym_expression_statement] = STATE(2289),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2289),
    [sym_delete_statement] = STATE(2289),
    [sym_raise_statement] = STATE(2289),
    [sym_pass_statement] = STATE(2289),
    [sym_break_statement] = STATE(2289),
    [sym_continue_statement] = STATE(2289),
    [sym_global_statement] = STATE(2289),
    [sym_nonlocal_statement] = STATE(2289),
    [sym_exec_statement] = STATE(2289),
    [sym_type_alias_statement] = STATE(2289),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(592),
    [sym__indent] = ACTIONS(594),
    [sym_string_start] = ACTIONS(81),
  },
  [131] = {
    [sym__simple_statements] = STATE(724),
    [sym_import_statement] = STATE(2289),
    [sym_future_import_statement] = STATE(2289),
    [sym_import_from_statement] = STATE(2289),
    [sym_print_statement] = STATE(2289),
    [sym_assert_statement] = STATE(2289),
    [sym_expression_statement] = STATE(2289),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2289),
    [sym_delete_statement] = STATE(2289),
    [sym_raise_statement] = STATE(2289),
    [sym_pass_statement] = STATE(2289),
    [sym_break_statement] = STATE(2289),
    [sym_continue_statement] = STATE(2289),
    [sym_global_statement] = STATE(2289),
    [sym_nonlocal_statement] = STATE(2289),
    [sym_exec_statement] = STATE(2289),
    [sym_type_alias_statement] = STATE(2289),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(596),
    [sym__indent] = ACTIONS(598),
    [sym_string_start] = ACTIONS(81),
  },
  [132] = {
    [sym__simple_statements] = STATE(816),
    [sym_import_statement] = STATE(2289),
    [sym_future_import_statement] = STATE(2289),
    [sym_import_from_statement] = STATE(2289),
    [sym_print_statement] = STATE(2289),
    [sym_assert_statement] = STATE(2289),
    [sym_expression_statement] = STATE(2289),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2289),
    [sym_delete_statement] = STATE(2289),
    [sym_raise_statement] = STATE(2289),
    [sym_pass_statement] = STATE(2289),
    [sym_break_statement] = STATE(2289),
    [sym_continue_statement] = STATE(2289),
    [sym_global_statement] = STATE(2289),
    [sym_nonlocal_statement] = STATE(2289),
    [sym_exec_statement] = STATE(2289),
    [sym_type_alias_statement] = STATE(2289),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(600),
    [sym__indent] = ACTIONS(602),
    [sym_string_start] = ACTIONS(81),
  },
  [133] = {
    [sym__simple_statements] = STATE(698),
    [sym_import_statement] = STATE(2462),
    [sym_future_import_statement] = STATE(2462),
    [sym_import_from_statement] = STATE(2462),
    [sym_print_statement] = STATE(2462),
    [sym_assert_statement] = STATE(2462),
    [sym_expression_statement] = STATE(2462),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2462),
    [sym_delete_statement] = STATE(2462),
    [sym_raise_statement] = STATE(2462),
    [sym_pass_statement] = STATE(2462),
    [sym_break_statement] = STATE(2462),
    [sym_continue_statement] = STATE(2462),
    [sym_global_statement] = STATE(2462),
    [sym_nonlocal_statement] = STATE(2462),
    [sym_exec_statement] = STATE(2462),
    [sym_type_alias_statement] = STATE(2462),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(604),
    [sym__indent] = ACTIONS(606),
    [sym_string_start] = ACTIONS(81),
  },
  [134] = {
    [sym__simple_statements] = STATE(838),
    [sym_import_statement] = STATE(2289),
    [sym_future_import_statement] = STATE(2289),
    [sym_import_from_statement] = STATE(2289),
    [sym_print_statement] = STATE(2289),
    [sym_assert_statement] = STATE(2289),
    [sym_expression_statement] = STATE(2289),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2289),
    [sym_delete_statement] = STATE(2289),
    [sym_raise_statement] = STATE(2289),
    [sym_pass_statement] = STATE(2289),
    [sym_break_statement] = STATE(2289),
    [sym_continue_statement] = STATE(2289),
    [sym_global_statement] = STATE(2289),
    [sym_nonlocal_statement] = STATE(2289),
    [sym_exec_statement] = STATE(2289),
    [sym_type_alias_statement] = STATE(2289),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(608),
    [sym__indent] = ACTIONS(610),
    [sym_string_start] = ACTIONS(81),
  },
  [135] = {
    [sym__simple_statements] = STATE(671),
    [sym_import_statement] = STATE(2477),
    [sym_future_import_statement] = STATE(2477),
    [sym_import_from_statement] = STATE(2477),
    [sym_print_statement] = STATE(2477),
    [sym_assert_statement] = STATE(2477),
    [sym_expression_statement] = STATE(2477),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2477),
    [sym_delete_statement] = STATE(2477),
    [sym_raise_statement] = STATE(2477),
    [sym_pass_statement] = STATE(2477),
    [sym_break_statement] = STATE(2477),
    [sym_continue_statement] = STATE(2477),
    [sym_global_statement] = STATE(2477),
    [sym_nonlocal_statement] = STATE(2477),
    [sym_exec_statement] = STATE(2477),
    [sym_type_alias_statement] = STATE(2477),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(612),
    [sym__indent] = ACTIONS(614),
    [sym_string_start] = ACTIONS(81),
  },
  [136] = {
    [sym__simple_statements] = STATE(834),
    [sym_import_statement] = STATE(2289),
    [sym_future_import_statement] = STATE(2289),
    [sym_import_from_statement] = STATE(2289),
    [sym_print_statement] = STATE(2289),
    [sym_assert_statement] = STATE(2289),
    [sym_expression_statement] = STATE(2289),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2289),
    [sym_delete_statement] = STATE(2289),
    [sym_raise_statement] = STATE(2289),
    [sym_pass_statement] = STATE(2289),
    [sym_break_statement] = STATE(2289),
    [sym_continue_statement] = STATE(2289),
    [sym_global_statement] = STATE(2289),
    [sym_nonlocal_statement] = STATE(2289),
    [sym_exec_statement] = STATE(2289),
    [sym_type_alias_statement] = STATE(2289),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(616),
    [sym__indent] = ACTIONS(618),
    [sym_string_start] = ACTIONS(81),
  },
  [137] = {
    [sym_import_statement] = STATE(2615),
    [sym_future_import_statement] = STATE(2615),
    [sym_import_from_statement] = STATE(2615),
    [sym_print_statement] = STATE(2615),
    [sym_assert_statement] = STATE(2615),
    [sym_expression_statement] = STATE(2615),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2615),
    [sym_delete_statement] = STATE(2615),
    [sym_raise_statement] = STATE(2615),
    [sym_pass_statement] = STATE(2615),
    [sym_break_statement] = STATE(2615),
    [sym_continue_statement] = STATE(2615),
    [sym_global_statement] = STATE(2615),
    [sym_nonlocal_statement] = STATE(2615),
    [sym_exec_statement] = STATE(2615),
    [sym_type_alias_statement] = STATE(2615),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(620),
    [sym_string_start] = ACTIONS(81),
  },
  [138] = {
    [sym_import_statement] = STATE(2615),
    [sym_future_import_statement] = STATE(2615),
    [sym_import_from_statement] = STATE(2615),
    [sym_print_statement] = STATE(2615),
    [sym_assert_statement] = STATE(2615),
    [sym_expression_statement] = STATE(2615),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2615),
    [sym_delete_statement] = STATE(2615),
    [sym_raise_statement] = STATE(2615),
    [sym_pass_statement] = STATE(2615),
    [sym_break_statement] = STATE(2615),
    [sym_continue_statement] = STATE(2615),
    [sym_global_statement] = STATE(2615),
    [sym_nonlocal_statement] = STATE(2615),
    [sym_exec_statement] = STATE(2615),
    [sym_type_alias_statement] = STATE(2615),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(622),
    [sym_string_start] = ACTIONS(81),
  },
  [139] = {
    [sym_import_statement] = STATE(2615),
    [sym_future_import_statement] = STATE(2615),
    [sym_import_from_statement] = STATE(2615),
    [sym_print_statement] = STATE(2615),
    [sym_assert_statement] = STATE(2615),
    [sym_expression_statement] = STATE(2615),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2615),
    [sym_delete_statement] = STATE(2615),
    [sym_raise_statement] = STATE(2615),
    [sym_pass_statement] = STATE(2615),
    [sym_break_statement] = STATE(2615),
    [sym_continue_statement] = STATE(2615),
    [sym_global_statement] = STATE(2615),
    [sym_nonlocal_statement] = STATE(2615),
    [sym_exec_statement] = STATE(2615),
    [sym_type_alias_statement] = STATE(2615),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(624),
    [sym_string_start] = ACTIONS(81),
  },
  [140] = {
    [sym_import_statement] = STATE(2615),
    [sym_future_import_statement] = STATE(2615),
    [sym_import_from_statement] = STATE(2615),
    [sym_print_statement] = STATE(2615),
    [sym_assert_statement] = STATE(2615),
    [sym_expression_statement] = STATE(2615),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2615),
    [sym_delete_statement] = STATE(2615),
    [sym_raise_statement] = STATE(2615),
    [sym_pass_statement] = STATE(2615),
    [sym_break_statement] = STATE(2615),
    [sym_continue_statement] = STATE(2615),
    [sym_global_statement] = STATE(2615),
    [sym_nonlocal_statement] = STATE(2615),
    [sym_exec_statement] = STATE(2615),
    [sym_type_alias_statement] = STATE(2615),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(626),
    [sym_string_start] = ACTIONS(81),
  },
  [141] = {
    [sym_import_statement] = STATE(2615),
    [sym_future_import_statement] = STATE(2615),
    [sym_import_from_statement] = STATE(2615),
    [sym_print_statement] = STATE(2615),
    [sym_assert_statement] = STATE(2615),
    [sym_expression_statement] = STATE(2615),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2615),
    [sym_delete_statement] = STATE(2615),
    [sym_raise_statement] = STATE(2615),
    [sym_pass_statement] = STATE(2615),
    [sym_break_statement] = STATE(2615),
    [sym_continue_statement] = STATE(2615),
    [sym_global_statement] = STATE(2615),
    [sym_nonlocal_statement] = STATE(2615),
    [sym_exec_statement] = STATE(2615),
    [sym_type_alias_statement] = STATE(2615),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(628),
    [sym_string_start] = ACTIONS(81),
  },
  [142] = {
    [sym_import_statement] = STATE(2615),
    [sym_future_import_statement] = STATE(2615),
    [sym_import_from_statement] = STATE(2615),
    [sym_print_statement] = STATE(2615),
    [sym_assert_statement] = STATE(2615),
    [sym_expression_statement] = STATE(2615),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2615),
    [sym_delete_statement] = STATE(2615),
    [sym_raise_statement] = STATE(2615),
    [sym_pass_statement] = STATE(2615),
    [sym_break_statement] = STATE(2615),
    [sym_continue_statement] = STATE(2615),
    [sym_global_statement] = STATE(2615),
    [sym_nonlocal_statement] = STATE(2615),
    [sym_exec_statement] = STATE(2615),
    [sym_type_alias_statement] = STATE(2615),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(630),
    [sym_string_start] = ACTIONS(81),
  },
  [143] = {
    [sym_import_statement] = STATE(2615),
    [sym_future_import_statement] = STATE(2615),
    [sym_import_from_statement] = STATE(2615),
    [sym_print_statement] = STATE(2615),
    [sym_assert_statement] = STATE(2615),
    [sym_expression_statement] = STATE(2615),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2615),
    [sym_delete_statement] = STATE(2615),
    [sym_raise_statement] = STATE(2615),
    [sym_pass_statement] = STATE(2615),
    [sym_break_statement] = STATE(2615),
    [sym_continue_statement] = STATE(2615),
    [sym_global_statement] = STATE(2615),
    [sym_nonlocal_statement] = STATE(2615),
    [sym_exec_statement] = STATE(2615),
    [sym_type_alias_statement] = STATE(2615),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(632),
    [sym_string_start] = ACTIONS(81),
  },
  [144] = {
    [sym_import_statement] = STATE(2615),
    [sym_future_import_statement] = STATE(2615),
    [sym_import_from_statement] = STATE(2615),
    [sym_print_statement] = STATE(2615),
    [sym_assert_statement] = STATE(2615),
    [sym_expression_statement] = STATE(2615),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2615),
    [sym_delete_statement] = STATE(2615),
    [sym_raise_statement] = STATE(2615),
    [sym_pass_statement] = STATE(2615),
    [sym_break_statement] = STATE(2615),
    [sym_continue_statement] = STATE(2615),
    [sym_global_statement] = STATE(2615),
    [sym_nonlocal_statement] = STATE(2615),
    [sym_exec_statement] = STATE(2615),
    [sym_type_alias_statement] = STATE(2615),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(634),
    [sym_string_start] = ACTIONS(81),
  },
  [145] = {
    [sym_import_statement] = STATE(2615),
    [sym_future_import_statement] = STATE(2615),
    [sym_import_from_statement] = STATE(2615),
    [sym_print_statement] = STATE(2615),
    [sym_assert_statement] = STATE(2615),
    [sym_expression_statement] = STATE(2615),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2615),
    [sym_delete_statement] = STATE(2615),
    [sym_raise_statement] = STATE(2615),
    [sym_pass_statement] = STATE(2615),
    [sym_break_statement] = STATE(2615),
    [sym_continue_statement] = STATE(2615),
    [sym_global_statement] = STATE(2615),
    [sym_nonlocal_statement] = STATE(2615),
    [sym_exec_statement] = STATE(2615),
    [sym_type_alias_statement] = STATE(2615),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(636),
    [sym_string_start] = ACTIONS(81),
  },
  [146] = {
    [sym_import_statement] = STATE(2615),
    [sym_future_import_statement] = STATE(2615),
    [sym_import_from_statement] = STATE(2615),
    [sym_print_statement] = STATE(2615),
    [sym_assert_statement] = STATE(2615),
    [sym_expression_statement] = STATE(2615),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2615),
    [sym_delete_statement] = STATE(2615),
    [sym_raise_statement] = STATE(2615),
    [sym_pass_statement] = STATE(2615),
    [sym_break_statement] = STATE(2615),
    [sym_continue_statement] = STATE(2615),
    [sym_global_statement] = STATE(2615),
    [sym_nonlocal_statement] = STATE(2615),
    [sym_exec_statement] = STATE(2615),
    [sym_type_alias_statement] = STATE(2615),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(638),
    [sym_string_start] = ACTIONS(81),
  },
  [147] = {
    [sym_import_statement] = STATE(2615),
    [sym_future_import_statement] = STATE(2615),
    [sym_import_from_statement] = STATE(2615),
    [sym_print_statement] = STATE(2615),
    [sym_assert_statement] = STATE(2615),
    [sym_expression_statement] = STATE(2615),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2615),
    [sym_delete_statement] = STATE(2615),
    [sym_raise_statement] = STATE(2615),
    [sym_pass_statement] = STATE(2615),
    [sym_break_statement] = STATE(2615),
    [sym_continue_statement] = STATE(2615),
    [sym_global_statement] = STATE(2615),
    [sym_nonlocal_statement] = STATE(2615),
    [sym_exec_statement] = STATE(2615),
    [sym_type_alias_statement] = STATE(2615),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(640),
    [sym_string_start] = ACTIONS(81),
  },
  [148] = {
    [sym_import_statement] = STATE(2615),
    [sym_future_import_statement] = STATE(2615),
    [sym_import_from_statement] = STATE(2615),
    [sym_print_statement] = STATE(2615),
    [sym_assert_statement] = STATE(2615),
    [sym_expression_statement] = STATE(2615),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2615),
    [sym_delete_statement] = STATE(2615),
    [sym_raise_statement] = STATE(2615),
    [sym_pass_statement] = STATE(2615),
    [sym_break_statement] = STATE(2615),
    [sym_continue_statement] = STATE(2615),
    [sym_global_statement] = STATE(2615),
    [sym_nonlocal_statement] = STATE(2615),
    [sym_exec_statement] = STATE(2615),
    [sym_type_alias_statement] = STATE(2615),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(642),
    [sym_string_start] = ACTIONS(81),
  },
  [149] = {
    [sym_import_statement] = STATE(2615),
    [sym_future_import_statement] = STATE(2615),
    [sym_import_from_statement] = STATE(2615),
    [sym_print_statement] = STATE(2615),
    [sym_assert_statement] = STATE(2615),
    [sym_expression_statement] = STATE(2615),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2615),
    [sym_delete_statement] = STATE(2615),
    [sym_raise_statement] = STATE(2615),
    [sym_pass_statement] = STATE(2615),
    [sym_break_statement] = STATE(2615),
    [sym_continue_statement] = STATE(2615),
    [sym_global_statement] = STATE(2615),
    [sym_nonlocal_statement] = STATE(2615),
    [sym_exec_statement] = STATE(2615),
    [sym_type_alias_statement] = STATE(2615),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(644),
    [sym_string_start] = ACTIONS(81),
  },
  [150] = {
    [sym_import_statement] = STATE(2615),
    [sym_future_import_statement] = STATE(2615),
    [sym_import_from_statement] = STATE(2615),
    [sym_print_statement] = STATE(2615),
    [sym_assert_statement] = STATE(2615),
    [sym_expression_statement] = STATE(2615),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2615),
    [sym_delete_statement] = STATE(2615),
    [sym_raise_statement] = STATE(2615),
    [sym_pass_statement] = STATE(2615),
    [sym_break_statement] = STATE(2615),
    [sym_continue_statement] = STATE(2615),
    [sym_global_statement] = STATE(2615),
    [sym_nonlocal_statement] = STATE(2615),
    [sym_exec_statement] = STATE(2615),
    [sym_type_alias_statement] = STATE(2615),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(646),
    [sym_string_start] = ACTIONS(81),
  },
  [151] = {
    [sym_import_statement] = STATE(2615),
    [sym_future_import_statement] = STATE(2615),
    [sym_import_from_statement] = STATE(2615),
    [sym_print_statement] = STATE(2615),
    [sym_assert_statement] = STATE(2615),
    [sym_expression_statement] = STATE(2615),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2615),
    [sym_delete_statement] = STATE(2615),
    [sym_raise_statement] = STATE(2615),
    [sym_pass_statement] = STATE(2615),
    [sym_break_statement] = STATE(2615),
    [sym_continue_statement] = STATE(2615),
    [sym_global_statement] = STATE(2615),
    [sym_nonlocal_statement] = STATE(2615),
    [sym_exec_statement] = STATE(2615),
    [sym_type_alias_statement] = STATE(2615),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(648),
    [sym_string_start] = ACTIONS(81),
  },
  [152] = {
    [sym_import_statement] = STATE(2615),
    [sym_future_import_statement] = STATE(2615),
    [sym_import_from_statement] = STATE(2615),
    [sym_print_statement] = STATE(2615),
    [sym_assert_statement] = STATE(2615),
    [sym_expression_statement] = STATE(2615),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2615),
    [sym_delete_statement] = STATE(2615),
    [sym_raise_statement] = STATE(2615),
    [sym_pass_statement] = STATE(2615),
    [sym_break_statement] = STATE(2615),
    [sym_continue_statement] = STATE(2615),
    [sym_global_statement] = STATE(2615),
    [sym_nonlocal_statement] = STATE(2615),
    [sym_exec_statement] = STATE(2615),
    [sym_type_alias_statement] = STATE(2615),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(650),
    [sym_string_start] = ACTIONS(81),
  },
  [153] = {
    [sym_import_statement] = STATE(2615),
    [sym_future_import_statement] = STATE(2615),
    [sym_import_from_statement] = STATE(2615),
    [sym_print_statement] = STATE(2615),
    [sym_assert_statement] = STATE(2615),
    [sym_expression_statement] = STATE(2615),
    [sym_named_expression] = STATE(1687),
    [sym__named_expression_lhs] = STATE(2782),
    [sym_return_statement] = STATE(2615),
    [sym_delete_statement] = STATE(2615),
    [sym_raise_statement] = STATE(2615),
    [sym_pass_statement] = STATE(2615),
    [sym_break_statement] = STATE(2615),
    [sym_continue_statement] = STATE(2615),
    [sym_global_statement] = STATE(2615),
    [sym_nonlocal_statement] = STATE(2615),
    [sym_exec_statement] = STATE(2615),
    [sym_type_alias_statement] = STATE(2615),
    [sym_pattern] = STATE(1671),
    [sym_tuple_pattern] = STATE(1668),
    [sym_list_pattern] = STATE(1668),
    [sym_list_splat_pattern] = STATE(635),
    [sym_as_pattern] = STATE(1687),
    [sym_expression] = STATE(1820),
    [sym_primary_expression] = STATE(1013),
    [sym_not_operator] = STATE(1687),
    [sym_boolean_operator] = STATE(1687),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_comparison_operator] = STATE(1687),
    [sym_lambda] = STATE(1687),
    [sym_assignment] = STATE(2559),
    [sym_augmented_assignment] = STATE(2559),
    [sym_pattern_list] = STATE(1679),
    [sym_yield] = STATE(2559),
    [sym_attribute] = STATE(637),
    [sym_subscript] = STATE(637),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_conditional_expression] = STATE(1687),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(9),
    [anon_sym_import] = ACTIONS(11),
    [anon_sym_from] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_STAR] = ACTIONS(17),
    [anon_sym_print] = ACTIONS(19),
    [anon_sym_assert] = ACTIONS(21),
    [anon_sym_return] = ACTIONS(23),
    [anon_sym_del] = ACTIONS(25),
    [anon_sym_raise] = ACTIONS(27),
    [anon_sym_pass] = ACTIONS(29),
    [anon_sym_break] = ACTIONS(31),
    [anon_sym_continue] = ACTIONS(33),
    [anon_sym_match] = ACTIONS(418),
    [anon_sym_async] = ACTIONS(418),
    [anon_sym_global] = ACTIONS(51),
    [anon_sym_nonlocal] = ACTIONS(53),
    [anon_sym_exec] = ACTIONS(55),
    [anon_sym_type] = ACTIONS(57),
    [anon_sym_LBRACK] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_lambda] = ACTIONS(71),
    [anon_sym_yield] = ACTIONS(73),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(79),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_string_start] = ACTIONS(81),
  },
  [154] = {
    [sym_list_splat_pattern] = STATE(1117),
    [sym_primary_expression] = STATE(995),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_attribute] = STATE(1057),
    [sym_subscript] = STATE(1057),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(77),
    [anon_sym_SEMI] = ACTIONS(277),
    [anon_sym_DOT] = ACTIONS(279),
    [anon_sym_LPAREN] = ACTIONS(652),
    [anon_sym_COMMA] = ACTIONS(284),
    [anon_sym_as] = ACTIONS(279),
    [anon_sym_STAR] = ACTIONS(654),
    [anon_sym_print] = ACTIONS(656),
    [anon_sym_GT_GT] = ACTIONS(279),
    [anon_sym_COLON_EQ] = ACTIONS(292),
    [anon_sym_if] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(302),
    [anon_sym_match] = ACTIONS(656),
    [anon_sym_async] = ACTIONS(656),
    [anon_sym_in] = ACTIONS(279),
    [anon_sym_STAR_STAR] = ACTIONS(279),
    [anon_sym_exec] = ACTIONS(656),
    [anon_sym_type] = ACTIONS(658),
    [anon_sym_EQ] = ACTIONS(302),
    [anon_sym_LBRACK] = ACTIONS(660),
    [anon_sym_AT] = ACTIONS(279),
    [anon_sym_DASH] = ACTIONS(662),
    [anon_sym_PIPE] = ACTIONS(279),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(662),
    [anon_sym_not] = ACTIONS(279),
    [anon_sym_and] = ACTIONS(279),
    [anon_sym_or] = ACTIONS(279),
    [anon_sym_SLASH] = ACTIONS(279),
    [anon_sym_PERCENT] = ACTIONS(279),
    [anon_sym_SLASH_SLASH] = ACTIONS(279),
    [anon_sym_AMP] = ACTIONS(279),
    [anon_sym_CARET] = ACTIONS(279),
    [anon_sym_LT_LT] = ACTIONS(279),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_LT] = ACTIONS(279),
    [anon_sym_LT_EQ] = ACTIONS(277),
    [anon_sym_EQ_EQ] = ACTIONS(277),
    [anon_sym_BANG_EQ] = ACTIONS(277),
    [anon_sym_GT_EQ] = ACTIONS(277),
    [anon_sym_GT] = ACTIONS(279),
    [anon_sym_LT_GT] = ACTIONS(277),
    [anon_sym_is] = ACTIONS(279),
    [anon_sym_PLUS_EQ] = ACTIONS(319),
    [anon_sym_DASH_EQ] = ACTIONS(319),
    [anon_sym_STAR_EQ] = ACTIONS(319),
    [anon_sym_SLASH_EQ] = ACTIONS(319),
    [anon_sym_AT_EQ] = ACTIONS(319),
    [anon_sym_SLASH_SLASH_EQ] = ACTIONS(319),
    [anon_sym_PERCENT_EQ] = ACTIONS(319),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(319),
    [anon_sym_GT_GT_EQ] = ACTIONS(319),
    [anon_sym_LT_LT_EQ] = ACTIONS(319),
    [anon_sym_AMP_EQ] = ACTIONS(319),
    [anon_sym_CARET_EQ] = ACTIONS(319),
    [anon_sym_PIPE_EQ] = ACTIONS(319),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(664),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(277),
    [sym_string_start] = ACTIONS(81),
  },
  [155] = {
    [sym_list_splat_pattern] = STATE(1117),
    [sym_primary_expression] = STATE(995),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_attribute] = STATE(1057),
    [sym_subscript] = STATE(1057),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(77),
    [anon_sym_SEMI] = ACTIONS(277),
    [anon_sym_DOT] = ACTIONS(279),
    [anon_sym_LPAREN] = ACTIONS(652),
    [anon_sym_COMMA] = ACTIONS(284),
    [anon_sym_as] = ACTIONS(279),
    [anon_sym_STAR] = ACTIONS(654),
    [anon_sym_print] = ACTIONS(656),
    [anon_sym_GT_GT] = ACTIONS(279),
    [anon_sym_COLON_EQ] = ACTIONS(292),
    [anon_sym_if] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(294),
    [anon_sym_match] = ACTIONS(656),
    [anon_sym_async] = ACTIONS(656),
    [anon_sym_in] = ACTIONS(279),
    [anon_sym_STAR_STAR] = ACTIONS(279),
    [anon_sym_exec] = ACTIONS(656),
    [anon_sym_type] = ACTIONS(658),
    [anon_sym_EQ] = ACTIONS(302),
    [anon_sym_LBRACK] = ACTIONS(660),
    [anon_sym_AT] = ACTIONS(279),
    [anon_sym_DASH] = ACTIONS(662),
    [anon_sym_PIPE] = ACTIONS(279),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(662),
    [anon_sym_not] = ACTIONS(279),
    [anon_sym_and] = ACTIONS(279),
    [anon_sym_or] = ACTIONS(279),
    [anon_sym_SLASH] = ACTIONS(279),
    [anon_sym_PERCENT] = ACTIONS(279),
    [anon_sym_SLASH_SLASH] = ACTIONS(279),
    [anon_sym_AMP] = ACTIONS(279),
    [anon_sym_CARET] = ACTIONS(279),
    [anon_sym_LT_LT] = ACTIONS(279),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_LT] = ACTIONS(279),
    [anon_sym_LT_EQ] = ACTIONS(277),
    [anon_sym_EQ_EQ] = ACTIONS(277),
    [anon_sym_BANG_EQ] = ACTIONS(277),
    [anon_sym_GT_EQ] = ACTIONS(277),
    [anon_sym_GT] = ACTIONS(279),
    [anon_sym_LT_GT] = ACTIONS(277),
    [anon_sym_is] = ACTIONS(279),
    [anon_sym_PLUS_EQ] = ACTIONS(319),
    [anon_sym_DASH_EQ] = ACTIONS(319),
    [anon_sym_STAR_EQ] = ACTIONS(319),
    [anon_sym_SLASH_EQ] = ACTIONS(319),
    [anon_sym_AT_EQ] = ACTIONS(319),
    [anon_sym_SLASH_SLASH_EQ] = ACTIONS(319),
    [anon_sym_PERCENT_EQ] = ACTIONS(319),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(319),
    [anon_sym_GT_GT_EQ] = ACTIONS(319),
    [anon_sym_LT_LT_EQ] = ACTIONS(319),
    [anon_sym_AMP_EQ] = ACTIONS(319),
    [anon_sym_CARET_EQ] = ACTIONS(319),
    [anon_sym_PIPE_EQ] = ACTIONS(319),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(664),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(277),
    [sym_string_start] = ACTIONS(81),
  },
  [156] = {
    [sym_list_splat_pattern] = STATE(1433),
    [sym_primary_expression] = STATE(1097),
    [sym_binary_operator] = STATE(1365),
    [sym_unary_operator] = STATE(1365),
    [sym_attribute] = STATE(1365),
    [sym_subscript] = STATE(1365),
    [sym_call] = STATE(1365),
    [sym_list] = STATE(1365),
    [sym_set] = STATE(1365),
    [sym_tuple] = STATE(1365),
    [sym_dictionary] = STATE(1365),
    [sym_list_comprehension] = STATE(1365),
    [sym_dictionary_comprehension] = STATE(1365),
    [sym_set_comprehension] = STATE(1365),
    [sym_generator_expression] = STATE(1365),
    [sym_parenthesized_expression] = STATE(1365),
    [sym_concatenated_string] = STATE(1365),
    [sym_string] = STATE(1004),
    [sym_await] = STATE(1365),
    [sym_identifier] = ACTIONS(323),
    [anon_sym_SEMI] = ACTIONS(666),
    [anon_sym_DOT] = ACTIONS(668),
    [anon_sym_LPAREN] = ACTIONS(408),
    [anon_sym_COMMA] = ACTIONS(666),
    [anon_sym_as] = ACTIONS(671),
    [anon_sym_STAR] = ACTIONS(410),
    [anon_sym_print] = ACTIONS(673),
    [anon_sym_GT_GT] = ACTIONS(668),
    [anon_sym_if] = ACTIONS(671),
    [anon_sym_COLON] = ACTIONS(666),
    [anon_sym_match] = ACTIONS(673),
    [anon_sym_async] = ACTIONS(673),
    [anon_sym_in] = ACTIONS(671),
    [anon_sym_STAR_STAR] = ACTIONS(668),
    [anon_sym_exec] = ACTIONS(673),
    [anon_sym_type] = ACTIONS(675),
    [anon_sym_EQ] = ACTIONS(671),
    [anon_sym_LBRACK] = ACTIONS(412),
    [anon_sym_AT] = ACTIONS(668),
    [anon_sym_DASH] = ACTIONS(414),
    [anon_sym_PIPE] = ACTIONS(668),
    [anon_sym_LBRACE] = ACTIONS(310),
    [anon_sym_PLUS] = ACTIONS(414),
    [anon_sym_not] = ACTIONS(671),
    [anon_sym_and] = ACTIONS(671),
    [anon_sym_or] = ACTIONS(671),
    [anon_sym_SLASH] = ACTIONS(668),
    [anon_sym_PERCENT] = ACTIONS(668),
    [anon_sym_SLASH_SLASH] = ACTIONS(668),
    [anon_sym_AMP] = ACTIONS(668),
    [anon_sym_CARET] = ACTIONS(668),
    [anon_sym_LT_LT] = ACTIONS(668),
    [anon_sym_TILDE] = ACTIONS(315),
    [anon_sym_LT] = ACTIONS(671),
    [anon_sym_LT_EQ] = ACTIONS(666),
    [anon_sym_EQ_EQ] = ACTIONS(666),
    [anon_sym_BANG_EQ] = ACTIONS(666),
    [anon_sym_GT_EQ] = ACTIONS(666),
    [anon_sym_GT] = ACTIONS(671),
    [anon_sym_LT_GT] = ACTIONS(666),
    [anon_sym_is] = ACTIONS(671),
    [anon_sym_PLUS_EQ] = ACTIONS(666),
    [anon_sym_DASH_EQ] = ACTIONS(666),
    [anon_sym_STAR_EQ] = ACTIONS(666),
    [anon_sym_SLASH_EQ] = ACTIONS(666),
    [anon_sym_AT_EQ] = ACTIONS(666),
    [anon_sym_SLASH_SLASH_EQ] = ACTIONS(666),
    [anon_sym_PERCENT_EQ] = ACTIONS(666),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(666),
    [anon_sym_GT_GT_EQ] = ACTIONS(666),
    [anon_sym_LT_LT_EQ] = ACTIONS(666),
    [anon_sym_AMP_EQ] = ACTIONS(666),
    [anon_sym_CARET_EQ] = ACTIONS(666),
    [anon_sym_PIPE_EQ] = ACTIONS(666),
    [sym_ellipsis] = ACTIONS(321),
    [sym_integer] = ACTIONS(323),
    [sym_float] = ACTIONS(321),
    [anon_sym_await] = ACTIONS(677),
    [sym_true] = ACTIONS(323),
    [sym_false] = ACTIONS(323),
    [sym_none] = ACTIONS(323),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(666),
    [sym_string_start] = ACTIONS(327),
  },
  [157] = {
    [sym_list_splat_pattern] = STATE(1117),
    [sym_primary_expression] = STATE(995),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_attribute] = STATE(1057),
    [sym_subscript] = STATE(1057),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(77),
    [anon_sym_SEMI] = ACTIONS(277),
    [anon_sym_DOT] = ACTIONS(279),
    [anon_sym_from] = ACTIONS(279),
    [anon_sym_LPAREN] = ACTIONS(652),
    [anon_sym_COMMA] = ACTIONS(277),
    [anon_sym_as] = ACTIONS(279),
    [anon_sym_STAR] = ACTIONS(654),
    [anon_sym_print] = ACTIONS(656),
    [anon_sym_GT_GT] = ACTIONS(277),
    [anon_sym_COLON_EQ] = ACTIONS(292),
    [anon_sym_if] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(279),
    [anon_sym_match] = ACTIONS(656),
    [anon_sym_async] = ACTIONS(656),
    [anon_sym_in] = ACTIONS(279),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_exec] = ACTIONS(656),
    [anon_sym_type] = ACTIONS(658),
    [anon_sym_EQ] = ACTIONS(279),
    [anon_sym_LBRACK] = ACTIONS(660),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_PIPE] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(279),
    [anon_sym_and] = ACTIONS(279),
    [anon_sym_or] = ACTIONS(279),
    [anon_sym_SLASH] = ACTIONS(279),
    [anon_sym_PERCENT] = ACTIONS(277),
    [anon_sym_SLASH_SLASH] = ACTIONS(277),
    [anon_sym_AMP] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [anon_sym_LT_LT] = ACTIONS(277),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_LT] = ACTIONS(279),
    [anon_sym_LT_EQ] = ACTIONS(277),
    [anon_sym_EQ_EQ] = ACTIONS(277),
    [anon_sym_BANG_EQ] = ACTIONS(277),
    [anon_sym_GT_EQ] = ACTIONS(277),
    [anon_sym_GT] = ACTIONS(279),
    [anon_sym_LT_GT] = ACTIONS(277),
    [anon_sym_is] = ACTIONS(279),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(664),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(277),
    [sym_string_start] = ACTIONS(81),
  },
  [158] = {
    [sym_list_splat_pattern] = STATE(1433),
    [sym_primary_expression] = STATE(1097),
    [sym_binary_operator] = STATE(1365),
    [sym_unary_operator] = STATE(1365),
    [sym_attribute] = STATE(1365),
    [sym_subscript] = STATE(1365),
    [sym_call] = STATE(1365),
    [sym_list] = STATE(1365),
    [sym_set] = STATE(1365),
    [sym_tuple] = STATE(1365),
    [sym_dictionary] = STATE(1365),
    [sym_list_comprehension] = STATE(1365),
    [sym_dictionary_comprehension] = STATE(1365),
    [sym_set_comprehension] = STATE(1365),
    [sym_generator_expression] = STATE(1365),
    [sym_parenthesized_expression] = STATE(1365),
    [sym_concatenated_string] = STATE(1365),
    [sym_string] = STATE(1004),
    [sym_await] = STATE(1365),
    [sym_identifier] = ACTIONS(323),
    [anon_sym_SEMI] = ACTIONS(666),
    [anon_sym_DOT] = ACTIONS(668),
    [anon_sym_from] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(408),
    [anon_sym_COMMA] = ACTIONS(666),
    [anon_sym_as] = ACTIONS(671),
    [anon_sym_STAR] = ACTIONS(410),
    [anon_sym_print] = ACTIONS(673),
    [anon_sym_GT_GT] = ACTIONS(679),
    [anon_sym_if] = ACTIONS(671),
    [anon_sym_COLON] = ACTIONS(666),
    [anon_sym_match] = ACTIONS(673),
    [anon_sym_async] = ACTIONS(673),
    [anon_sym_in] = ACTIONS(671),
    [anon_sym_STAR_STAR] = ACTIONS(679),
    [anon_sym_exec] = ACTIONS(673),
    [anon_sym_type] = ACTIONS(675),
    [anon_sym_EQ] = ACTIONS(671),
    [anon_sym_LBRACK] = ACTIONS(412),
    [anon_sym_AT] = ACTIONS(679),
    [anon_sym_DASH] = ACTIONS(315),
    [anon_sym_PIPE] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(310),
    [anon_sym_PLUS] = ACTIONS(315),
    [anon_sym_not] = ACTIONS(671),
    [anon_sym_and] = ACTIONS(671),
    [anon_sym_or] = ACTIONS(671),
    [anon_sym_SLASH] = ACTIONS(668),
    [anon_sym_PERCENT] = ACTIONS(679),
    [anon_sym_SLASH_SLASH] = ACTIONS(679),
    [anon_sym_AMP] = ACTIONS(679),
    [anon_sym_CARET] = ACTIONS(679),
    [anon_sym_LT_LT] = ACTIONS(679),
    [anon_sym_TILDE] = ACTIONS(315),
    [anon_sym_LT] = ACTIONS(671),
    [anon_sym_LT_EQ] = ACTIONS(666),
    [anon_sym_EQ_EQ] = ACTIONS(666),
    [anon_sym_BANG_EQ] = ACTIONS(666),
    [anon_sym_GT_EQ] = ACTIONS(666),
    [anon_sym_GT] = ACTIONS(671),
    [anon_sym_LT_GT] = ACTIONS(666),
    [anon_sym_is] = ACTIONS(671),
    [sym_ellipsis] = ACTIONS(321),
    [sym_integer] = ACTIONS(323),
    [sym_float] = ACTIONS(321),
    [anon_sym_await] = ACTIONS(677),
    [sym_true] = ACTIONS(323),
    [sym_false] = ACTIONS(323),
    [sym_none] = ACTIONS(323),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(666),
    [sym_string_start] = ACTIONS(327),
  },
  [159] = {
    [sym_list_splat_pattern] = STATE(1183),
    [sym_primary_expression] = STATE(1027),
    [sym_binary_operator] = STATE(1241),
    [sym_unary_operator] = STATE(1241),
    [sym_attribute] = STATE(1241),
    [sym_subscript] = STATE(1241),
    [sym_call] = STATE(1241),
    [sym_list] = STATE(1241),
    [sym_set] = STATE(1241),
    [sym_tuple] = STATE(1241),
    [sym_dictionary] = STATE(1241),
    [sym_list_comprehension] = STATE(1241),
    [sym_dictionary_comprehension] = STATE(1241),
    [sym_set_comprehension] = STATE(1241),
    [sym_generator_expression] = STATE(1241),
    [sym_parenthesized_expression] = STATE(1241),
    [sym_concatenated_string] = STATE(1241),
    [sym_string] = STATE(979),
    [sym_await] = STATE(1241),
    [sym_identifier] = ACTIONS(682),
    [anon_sym_DOT] = ACTIONS(279),
    [anon_sym_LPAREN] = ACTIONS(684),
    [anon_sym_COMMA] = ACTIONS(284),
    [anon_sym_as] = ACTIONS(279),
    [anon_sym_STAR] = ACTIONS(686),
    [anon_sym_print] = ACTIONS(688),
    [anon_sym_GT_GT] = ACTIONS(277),
    [anon_sym_COLON_EQ] = ACTIONS(292),
    [anon_sym_if] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(279),
    [anon_sym_match] = ACTIONS(688),
    [anon_sym_async] = ACTIONS(688),
    [anon_sym_in] = ACTIONS(279),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_exec] = ACTIONS(688),
    [anon_sym_type] = ACTIONS(690),
    [anon_sym_EQ] = ACTIONS(279),
    [anon_sym_LBRACK] = ACTIONS(692),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_DASH] = ACTIONS(694),
    [anon_sym_PIPE] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(696),
    [anon_sym_RBRACE] = ACTIONS(277),
    [anon_sym_PLUS] = ACTIONS(694),
    [anon_sym_not] = ACTIONS(279),
    [anon_sym_and] = ACTIONS(279),
    [anon_sym_or] = ACTIONS(279),
    [anon_sym_SLASH] = ACTIONS(279),
    [anon_sym_PERCENT] = ACTIONS(277),
    [anon_sym_SLASH_SLASH] = ACTIONS(277),
    [anon_sym_AMP] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [anon_sym_LT_LT] = ACTIONS(277),
    [anon_sym_TILDE] = ACTIONS(694),
    [anon_sym_LT] = ACTIONS(279),
    [anon_sym_LT_EQ] = ACTIONS(277),
    [anon_sym_EQ_EQ] = ACTIONS(277),
    [anon_sym_BANG_EQ] = ACTIONS(277),
    [anon_sym_GT_EQ] = ACTIONS(277),
    [anon_sym_GT] = ACTIONS(279),
    [anon_sym_LT_GT] = ACTIONS(277),
    [anon_sym_is] = ACTIONS(279),
    [sym_ellipsis] = ACTIONS(698),
    [sym_type_conversion] = ACTIONS(277),
    [sym_integer] = ACTIONS(682),
    [sym_float] = ACTIONS(698),
    [anon_sym_await] = ACTIONS(700),
    [sym_true] = ACTIONS(682),
    [sym_false] = ACTIONS(682),
    [sym_none] = ACTIONS(682),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_string_start] = ACTIONS(702),
  },
  [160] = {
    [sym_list_splat_pattern] = STATE(1183),
    [sym_primary_expression] = STATE(1027),
    [sym_binary_operator] = STATE(1241),
    [sym_unary_operator] = STATE(1241),
    [sym_attribute] = STATE(1241),
    [sym_subscript] = STATE(1241),
    [sym_call] = STATE(1241),
    [sym_list] = STATE(1241),
    [sym_set] = STATE(1241),
    [sym_tuple] = STATE(1241),
    [sym_dictionary] = STATE(1241),
    [sym_list_comprehension] = STATE(1241),
    [sym_dictionary_comprehension] = STATE(1241),
    [sym_set_comprehension] = STATE(1241),
    [sym_generator_expression] = STATE(1241),
    [sym_parenthesized_expression] = STATE(1241),
    [sym_concatenated_string] = STATE(1241),
    [sym_string] = STATE(979),
    [sym_await] = STATE(1241),
    [sym_identifier] = ACTIONS(682),
    [anon_sym_DOT] = ACTIONS(279),
    [anon_sym_LPAREN] = ACTIONS(684),
    [anon_sym_COMMA] = ACTIONS(277),
    [anon_sym_as] = ACTIONS(279),
    [anon_sym_STAR] = ACTIONS(686),
    [anon_sym_print] = ACTIONS(688),
    [anon_sym_GT_GT] = ACTIONS(277),
    [anon_sym_COLON_EQ] = ACTIONS(292),
    [anon_sym_if] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(279),
    [anon_sym_match] = ACTIONS(688),
    [anon_sym_async] = ACTIONS(688),
    [anon_sym_in] = ACTIONS(279),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_exec] = ACTIONS(688),
    [anon_sym_type] = ACTIONS(690),
    [anon_sym_EQ] = ACTIONS(279),
    [anon_sym_LBRACK] = ACTIONS(692),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_DASH] = ACTIONS(694),
    [anon_sym_PIPE] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(696),
    [anon_sym_RBRACE] = ACTIONS(277),
    [anon_sym_PLUS] = ACTIONS(694),
    [anon_sym_not] = ACTIONS(279),
    [anon_sym_and] = ACTIONS(279),
    [anon_sym_or] = ACTIONS(279),
    [anon_sym_SLASH] = ACTIONS(279),
    [anon_sym_PERCENT] = ACTIONS(277),
    [anon_sym_SLASH_SLASH] = ACTIONS(277),
    [anon_sym_AMP] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [anon_sym_LT_LT] = ACTIONS(277),
    [anon_sym_TILDE] = ACTIONS(694),
    [anon_sym_LT] = ACTIONS(279),
    [anon_sym_LT_EQ] = ACTIONS(277),
    [anon_sym_EQ_EQ] = ACTIONS(277),
    [anon_sym_BANG_EQ] = ACTIONS(277),
    [anon_sym_GT_EQ] = ACTIONS(277),
    [anon_sym_GT] = ACTIONS(279),
    [anon_sym_LT_GT] = ACTIONS(277),
    [anon_sym_is] = ACTIONS(279),
    [sym_ellipsis] = ACTIONS(698),
    [sym_type_conversion] = ACTIONS(277),
    [sym_integer] = ACTIONS(682),
    [sym_float] = ACTIONS(698),
    [anon_sym_await] = ACTIONS(700),
    [sym_true] = ACTIONS(682),
    [sym_false] = ACTIONS(682),
    [sym_none] = ACTIONS(682),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_string_start] = ACTIONS(702),
  },
  [161] = {
    [sym_list_splat_pattern] = STATE(1117),
    [sym_primary_expression] = STATE(995),
    [sym_binary_operator] = STATE(1057),
    [sym_unary_operator] = STATE(1057),
    [sym_attribute] = STATE(1057),
    [sym_subscript] = STATE(1057),
    [sym_call] = STATE(1057),
    [sym_list] = STATE(1057),
    [sym_set] = STATE(1057),
    [sym_tuple] = STATE(1057),
    [sym_dictionary] = STATE(1057),
    [sym_list_comprehension] = STATE(1057),
    [sym_dictionary_comprehension] = STATE(1057),
    [sym_set_comprehension] = STATE(1057),
    [sym_generator_expression] = STATE(1057),
    [sym_parenthesized_expression] = STATE(1057),
    [sym_concatenated_string] = STATE(1057),
    [sym_string] = STATE(975),
    [sym_await] = STATE(1057),
    [sym_identifier] = ACTIONS(77),
    [anon_sym_SEMI] = ACTIONS(277),
    [anon_sym_DOT] = ACTIONS(279),
    [anon_sym_from] = ACTIONS(279),
    [anon_sym_LPAREN] = ACTIONS(652),
    [anon_sym_COMMA] = ACTIONS(277),
    [anon_sym_as] = ACTIONS(279),
    [anon_sym_STAR] = ACTIONS(654),
    [anon_sym_print] = ACTIONS(656),
    [anon_sym_GT_GT] = ACTIONS(277),
    [anon_sym_if] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(277),
    [anon_sym_match] = ACTIONS(656),
    [anon_sym_async] = ACTIONS(656),
    [anon_sym_in] = ACTIONS(279),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_exec] = ACTIONS(656),
    [anon_sym_type] = ACTIONS(658),
    [anon_sym_EQ] = ACTIONS(279),
    [anon_sym_LBRACK] = ACTIONS(660),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_PIPE] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_not] = ACTIONS(279),
    [anon_sym_and] = ACTIONS(279),
    [anon_sym_or] = ACTIONS(279),
    [anon_sym_SLASH] = ACTIONS(279),
    [anon_sym_PERCENT] = ACTIONS(277),
    [anon_sym_SLASH_SLASH] = ACTIONS(277),
    [anon_sym_AMP] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [anon_sym_LT_LT] = ACTIONS(277),
    [anon_sym_TILDE] = ACTIONS(65),
    [anon_sym_LT] = ACTIONS(279),
    [anon_sym_LT_EQ] = ACTIONS(277),
    [anon_sym_EQ_EQ] = ACTIONS(277),
    [anon_sym_BANG_EQ] = ACTIONS(277),
    [anon_sym_GT_EQ] = ACTIONS(277),
    [anon_sym_GT] = ACTIONS(279),
    [anon_sym_LT_GT] = ACTIONS(277),
    [anon_sym_is] = ACTIONS(279),
    [sym_ellipsis] = ACTIONS(75),
    [sym_integer] = ACTIONS(77),
    [sym_float] = ACTIONS(75),
    [anon_sym_await] = ACTIONS(664),
    [sym_true] = ACTIONS(77),
    [sym_false] = ACTIONS(77),
    [sym_none] = ACTIONS(77),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(277),
    [sym_string_start] = ACTIONS(81),
  },
  [162] = {
    [sym_list_splat_pattern] = STATE(1433),
    [sym_primary_expression] = STATE(1097),
    [sym_binary_operator] = STATE(1365),
    [sym_unary_operator] = STATE(1365),
    [sym_attribute] = STATE(1365),
    [sym_subscript] = STATE(1365),
    [sym_call] = STATE(1365),
    [sym_list] = STATE(1365),
    [sym_set] = STATE(1365),
    [sym_tuple] = STATE(1365),
    [sym_dictionary] = STATE(1365),
    [sym_list_comprehension] = STATE(1365),
    [sym_dictionary_comprehension] = STATE(1365),
    [sym_set_comprehension] = STATE(1365),
    [sym_generator_expression] = STATE(1365),
    [sym_parenthesized_expression] = STATE(1365),
    [sym_concatenated_string] = STATE(1365),
    [sym_string] = STATE(1004),
    [sym_await] = STATE(1365),
    [sym_identifier] = ACTIONS(323),
    [anon_sym_DOT] = ACTIONS(668),
    [anon_sym_LPAREN] = ACTIONS(408),
    [anon_sym_COMMA] = ACTIONS(666),
    [anon_sym_as] = ACTIONS(671),
    [anon_sym_STAR] = ACTIONS(410),
    [anon_sym_print] = ACTIONS(673),
    [anon_sym_GT_GT] = ACTIONS(679),
    [anon_sym_if] = ACTIONS(671),
    [anon_sym_COLON] = ACTIONS(666),
    [anon_sym_match] = ACTIONS(673),
    [anon_sym_async] = ACTIONS(673),
    [anon_sym_for] = ACTIONS(671),
    [anon_sym_in] = ACTIONS(671),
    [anon_sym_STAR_STAR] = ACTIONS(679),
    [anon_sym_exec] = ACTIONS(673),
    [anon_sym_type] = ACTIONS(675),
    [anon_sym_EQ] = ACTIONS(671),
    [anon_sym_LBRACK] = ACTIONS(412),
    [anon_sym_AT] = ACTIONS(679),
    [anon_sym_DASH] = ACTIONS(315),
    [anon_sym_PIPE] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(310),
    [anon_sym_RBRACE] = ACTIONS(666),
    [anon_sym_PLUS] = ACTIONS(315),
    [anon_sym_not] = ACTIONS(671),
    [anon_sym_and] = ACTIONS(671),
    [anon_sym_or] = ACTIONS(671),
    [anon_sym_SLASH] = ACTIONS(668),
    [anon_sym_PERCENT] = ACTIONS(679),
    [anon_sym_SLASH_SLASH] = ACTIONS(679),
    [anon_sym_AMP] = ACTIONS(679),
    [anon_sym_CARET] = ACTIONS(679),
    [anon_sym_LT_LT] = ACTIONS(679),
    [anon_sym_TILDE] = ACTIONS(315),
    [anon_sym_LT] = ACTIONS(671),
    [anon_sym_LT_EQ] = ACTIONS(666),
    [anon_sym_EQ_EQ] = ACTIONS(666),
    [anon_sym_BANG_EQ] = ACTIONS(666),
    [anon_sym_GT_EQ] = ACTIONS(666),
    [anon_sym_GT] = ACTIONS(671),
    [anon_sym_LT_GT] = ACTIONS(666),
    [anon_sym_is] = ACTIONS(671),
    [sym_ellipsis] = ACTIONS(321),
    [sym_type_conversion] = ACTIONS(666),
    [sym_integer] = ACTIONS(323),
    [sym_float] = ACTIONS(321),
    [anon_sym_await] = ACTIONS(677),
    [sym_true] = ACTIONS(323),
    [sym_false] = ACTIONS(323),
    [sym_none] = ACTIONS(323),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_string_start] = ACTIONS(327),
  },
  [163] = {
    [sym_list_splat_pattern] = STATE(1183),
    [sym_primary_expression] = STATE(1027),
    [sym_binary_operator] = STATE(1241),
    [sym_unary_operator] = STATE(1241),
    [sym_attribute] = STATE(1241),
    [sym_subscript] = STATE(1241),
    [sym_call] = STATE(1241),
    [sym_list] = STATE(1241),
    [sym_set] = STATE(1241),
    [sym_tuple] = STATE(1241),
    [sym_dictionary] = STATE(1241),
    [sym_list_comprehension] = STATE(1241),
    [sym_dictionary_comprehension] = STATE(1241),
    [sym_set_comprehension] = STATE(1241),
    [sym_generator_expression] = STATE(1241),
    [sym_parenthesized_expression] = STATE(1241),
    [sym_concatenated_string] = STATE(1241),
    [sym_string] = STATE(979),
    [sym_await] = STATE(1241),
    [sym_identifier] = ACTIONS(682),
    [anon_sym_DOT] = ACTIONS(668),
    [anon_sym_LPAREN] = ACTIONS(684),
    [anon_sym_COMMA] = ACTIONS(679),
    [anon_sym_as] = ACTIONS(668),
    [anon_sym_STAR] = ACTIONS(686),
    [anon_sym_print] = ACTIONS(688),
    [anon_sym_GT_GT] = ACTIONS(679),
    [anon_sym_COLON_EQ] = ACTIONS(292),
    [anon_sym_if] = ACTIONS(668),
    [anon_sym_COLON] = ACTIONS(671),
    [anon_sym_match] = ACTIONS(688),
    [anon_sym_async] = ACTIONS(688),
    [anon_sym_for] = ACTIONS(671),
    [anon_sym_in] = ACTIONS(668),
    [anon_sym_STAR_STAR] = ACTIONS(679),
    [anon_sym_exec] = ACTIONS(688),
    [anon_sym_type] = ACTIONS(690),
    [anon_sym_LBRACK] = ACTIONS(692),
    [anon_sym_AT] = ACTIONS(679),
    [anon_sym_DASH] = ACTIONS(694),
    [anon_sym_PIPE] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(696),
    [anon_sym_RBRACE] = ACTIONS(679),
    [anon_sym_PLUS] = ACTIONS(694),
    [anon_sym_not] = ACTIONS(668),
    [anon_sym_and] = ACTIONS(668),
    [anon_sym_or] = ACTIONS(668),
    [anon_sym_SLASH] = ACTIONS(668),
    [anon_sym_PERCENT] = ACTIONS(679),
    [anon_sym_SLASH_SLASH] = ACTIONS(679),
    [anon_sym_AMP] = ACTIONS(679),
    [anon_sym_CARET] = ACTIONS(679),
    [anon_sym_LT_LT] = ACTIONS(679),
    [anon_sym_TILDE] = ACTIONS(694),
    [anon_sym_LT] = ACTIONS(668),
    [anon_sym_LT_EQ] = ACTIONS(679),
    [anon_sym_EQ_EQ] = ACTIONS(679),
    [anon_sym_BANG_EQ] = ACTIONS(679),
    [anon_sym_GT_EQ] = ACTIONS(679),
    [anon_sym_GT] = ACTIONS(668),
    [anon_sym_LT_GT] = ACTIONS(679),
    [anon_sym_is] = ACTIONS(668),
    [sym_ellipsis] = ACTIONS(698),
    [sym_integer] = ACTIONS(682),
    [sym_float] = ACTIONS(698),
    [anon_sym_await] = ACTIONS(700),
    [sym_true] = ACTIONS(682),
    [sym_false] = ACTIONS(682),
    [sym_none] = ACTIONS(682),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_string_start] = ACTIONS(702),
  },
  [164] = {
    [sym_list_splat_pattern] = STATE(1433),
    [sym_primary_expression] = STATE(1097),
    [sym_binary_operator] = STATE(1365),
    [sym_unary_operator] = STATE(1365),
    [sym_attribute] = STATE(1365),
    [sym_subscript] = STATE(1365),
    [sym_call] = STATE(1365),
    [sym_list] = STATE(1365),
    [sym_set] = STATE(1365),
    [sym_tuple] = STATE(1365),
    [sym_dictionary] = STATE(1365),
    [sym_list_comprehension] = STATE(1365),
    [sym_dictionary_comprehension] = STATE(1365),
    [sym_set_comprehension] = STATE(1365),
    [sym_generator_expression] = STATE(1365),
    [sym_parenthesized_expression] = STATE(1365),
    [sym_concatenated_string] = STATE(1365),
    [sym_string] = STATE(1004),
    [sym_await] = STATE(1365),
    [sym_identifier] = ACTIONS(323),
    [anon_sym_DOT] = ACTIONS(668),
    [anon_sym_LPAREN] = ACTIONS(408),
    [anon_sym_RPAREN] = ACTIONS(666),
    [anon_sym_COMMA] = ACTIONS(666),
    [anon_sym_as] = ACTIONS(671),
    [anon_sym_STAR] = ACTIONS(410),
    [anon_sym_print] = ACTIONS(673),
    [anon_sym_GT_GT] = ACTIONS(679),
    [anon_sym_if] = ACTIONS(671),
    [anon_sym_COLON] = ACTIONS(666),
    [anon_sym_match] = ACTIONS(673),
    [anon_sym_async] = ACTIONS(673),
    [anon_sym_for] = ACTIONS(671),
    [anon_sym_in] = ACTIONS(671),
    [anon_sym_STAR_STAR] = ACTIONS(679),
    [anon_sym_exec] = ACTIONS(673),
    [anon_sym_type] = ACTIONS(675),
    [anon_sym_EQ] = ACTIONS(671),
    [anon_sym_LBRACK] = ACTIONS(412),
    [anon_sym_AT] = ACTIONS(679),
    [anon_sym_DASH] = ACTIONS(315),
    [anon_sym_PIPE] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(310),
    [anon_sym_PLUS] = ACTIONS(315),
    [anon_sym_not] = ACTIONS(671),
    [anon_sym_and] = ACTIONS(671),
    [anon_sym_or] = ACTIONS(671),
    [anon_sym_SLASH] = ACTIONS(668),
    [anon_sym_PERCENT] = ACTIONS(679),
    [anon_sym_SLASH_SLASH] = ACTIONS(679),
    [anon_sym_AMP] = ACTIONS(679),
    [anon_sym_CARET] = ACTIONS(679),
    [anon_sym_LT_LT] = ACTIONS(679),
    [anon_sym_TILDE] = ACTIONS(315),
    [anon_sym_LT] = ACTIONS(671),
    [anon_sym_LT_EQ] = ACTIONS(666),
    [anon_sym_EQ_EQ] = ACTIONS(666),
    [anon_sym_BANG_EQ] = ACTIONS(666),
    [anon_sym_GT_EQ] = ACTIONS(666),
    [anon_sym_GT] = ACTIONS(671),
    [anon_sym_LT_GT] = ACTIONS(666),
    [anon_sym_is] = ACTIONS(671),
    [sym_ellipsis] = ACTIONS(321),
    [sym_integer] = ACTIONS(323),
    [sym_float] = ACTIONS(321),
    [anon_sym_await] = ACTIONS(677),
    [sym_true] = ACTIONS(323),
    [sym_false] = ACTIONS(323),
    [sym_none] = ACTIONS(323),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_string_start] = ACTIONS(327),
  },
  [165] = {
    [sym_list_splat_pattern] = STATE(1218),
    [sym_primary_expression] = STATE(1031),
    [sym_binary_operator] = STATE(1169),
    [sym_unary_operator] = STATE(1169),
    [sym_attribute] = STATE(1169),
    [sym_subscript] = STATE(1169),
    [sym_call] = STATE(1169),
    [sym_list] = STATE(1169),
    [sym_set] = STATE(1169),
    [sym_tuple] = STATE(1169),
    [sym_dictionary] = STATE(1169),
    [sym_list_comprehension] = STATE(1169),
    [sym_dictionary_comprehension] = STATE(1169),
    [sym_set_comprehension] = STATE(1169),
    [sym_generator_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1169),
    [sym_concatenated_string] = STATE(1169),
    [sym_string] = STATE(993),
    [sym_await] = STATE(1169),
    [sym_identifier] = ACTIONS(704),
    [anon_sym_DOT] = ACTIONS(279),
    [anon_sym_LPAREN] = ACTIONS(706),
    [anon_sym_COMMA] = ACTIONS(277),
    [anon_sym_as] = ACTIONS(279),
    [anon_sym_STAR] = ACTIONS(708),
    [anon_sym_print] = ACTIONS(710),
    [anon_sym_GT_GT] = ACTIONS(277),
    [anon_sym_COLON_EQ] = ACTIONS(292),
    [anon_sym_if] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(279),
    [anon_sym_match] = ACTIONS(710),
    [anon_sym_async] = ACTIONS(710),
    [anon_sym_for] = ACTIONS(279),
    [anon_sym_in] = ACTIONS(279),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_exec] = ACTIONS(710),
    [anon_sym_type] = ACTIONS(712),
    [anon_sym_LBRACK] = ACTIONS(714),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_DASH] = ACTIONS(716),
    [anon_sym_PIPE] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(718),
    [anon_sym_RBRACE] = ACTIONS(277),
    [anon_sym_PLUS] = ACTIONS(716),
    [anon_sym_not] = ACTIONS(279),
    [anon_sym_and] = ACTIONS(279),
    [anon_sym_or] = ACTIONS(279),
    [anon_sym_SLASH] = ACTIONS(279),
    [anon_sym_PERCENT] = ACTIONS(277),
    [anon_sym_SLASH_SLASH] = ACTIONS(277),
    [anon_sym_AMP] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [anon_sym_LT_LT] = ACTIONS(277),
    [anon_sym_TILDE] = ACTIONS(716),
    [anon_sym_LT] = ACTIONS(279),
    [anon_sym_LT_EQ] = ACTIONS(277),
    [anon_sym_EQ_EQ] = ACTIONS(277),
    [anon_sym_BANG_EQ] = ACTIONS(277),
    [anon_sym_GT_EQ] = ACTIONS(277),
    [anon_sym_GT] = ACTIONS(279),
    [anon_sym_LT_GT] = ACTIONS(277),
    [anon_sym_is] = ACTIONS(279),
    [sym_ellipsis] = ACTIONS(720),
    [sym_integer] = ACTIONS(704),
    [sym_float] = ACTIONS(720),
    [anon_sym_await] = ACTIONS(722),
    [sym_true] = ACTIONS(704),
    [sym_false] = ACTIONS(704),
    [sym_none] = ACTIONS(704),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_string_start] = ACTIONS(724),
  },
  [166] = {
    [sym_list_splat_pattern] = STATE(1290),
    [sym_primary_expression] = STATE(1157),
    [sym_binary_operator] = STATE(1337),
    [sym_unary_operator] = STATE(1337),
    [sym_attribute] = STATE(1337),
    [sym_subscript] = STATE(1337),
    [sym_call] = STATE(1337),
    [sym_list] = STATE(1337),
    [sym_set] = STATE(1337),
    [sym_tuple] = STATE(1337),
    [sym_dictionary] = STATE(1337),
    [sym_list_comprehension] = STATE(1337),
    [sym_dictionary_comprehension] = STATE(1337),
    [sym_set_comprehension] = STATE(1337),
    [sym_generator_expression] = STATE(1337),
    [sym_parenthesized_expression] = STATE(1337),
    [sym_concatenated_string] = STATE(1337),
    [sym_string] = STATE(1030),
    [sym_await] = STATE(1337),
    [sym_identifier] = ACTIONS(726),
    [anon_sym_DOT] = ACTIONS(279),
    [anon_sym_LPAREN] = ACTIONS(728),
    [anon_sym_RPAREN] = ACTIONS(277),
    [anon_sym_COMMA] = ACTIONS(277),
    [anon_sym_as] = ACTIONS(279),
    [anon_sym_STAR] = ACTIONS(730),
    [anon_sym_print] = ACTIONS(732),
    [anon_sym_GT_GT] = ACTIONS(277),
    [anon_sym_COLON_EQ] = ACTIONS(292),
    [anon_sym_if] = ACTIONS(279),
    [anon_sym_match] = ACTIONS(732),
    [anon_sym_async] = ACTIONS(732),
    [anon_sym_for] = ACTIONS(279),
    [anon_sym_in] = ACTIONS(279),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_exec] = ACTIONS(732),
    [anon_sym_type] = ACTIONS(734),
    [anon_sym_EQ] = ACTIONS(736),
    [anon_sym_LBRACK] = ACTIONS(738),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_DASH] = ACTIONS(740),
    [anon_sym_PIPE] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(742),
    [anon_sym_PLUS] = ACTIONS(740),
    [anon_sym_not] = ACTIONS(279),
    [anon_sym_and] = ACTIONS(279),
    [anon_sym_or] = ACTIONS(279),
    [anon_sym_SLASH] = ACTIONS(279),
    [anon_sym_PERCENT] = ACTIONS(277),
    [anon_sym_SLASH_SLASH] = ACTIONS(277),
    [anon_sym_AMP] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [anon_sym_LT_LT] = ACTIONS(277),
    [anon_sym_TILDE] = ACTIONS(740),
    [anon_sym_LT] = ACTIONS(279),
    [anon_sym_LT_EQ] = ACTIONS(277),
    [anon_sym_EQ_EQ] = ACTIONS(277),
    [anon_sym_BANG_EQ] = ACTIONS(277),
    [anon_sym_GT_EQ] = ACTIONS(277),
    [anon_sym_GT] = ACTIONS(279),
    [anon_sym_LT_GT] = ACTIONS(277),
    [anon_sym_is] = ACTIONS(279),
    [sym_ellipsis] = ACTIONS(744),
    [sym_integer] = ACTIONS(726),
    [sym_float] = ACTIONS(744),
    [anon_sym_await] = ACTIONS(746),
    [sym_true] = ACTIONS(726),
    [sym_false] = ACTIONS(726),
    [sym_none] = ACTIONS(726),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_string_start] = ACTIONS(748),
  },
  [167] = {
    [sym_list_splat_pattern] = STATE(1433),
    [sym_primary_expression] = STATE(1097),
    [sym_binary_operator] = STATE(1365),
    [sym_unary_operator] = STATE(1365),
    [sym_attribute] = STATE(1365),
    [sym_subscript] = STATE(1365),
    [sym_call] = STATE(1365),
    [sym_list] = STATE(1365),
    [sym_set] = STATE(1365),
    [sym_tuple] = STATE(1365),
    [sym_dictionary] = STATE(1365),
    [sym_list_comprehension] = STATE(1365),
    [sym_dictionary_comprehension] = STATE(1365),
    [sym_set_comprehension] = STATE(1365),
    [sym_generator_expression] = STATE(1365),
    [sym_parenthesized_expression] = STATE(1365),
    [sym_concatenated_string] = STATE(1365),
    [sym_string] = STATE(1004),
    [sym_await] = STATE(1365),
    [sym_identifier] = ACTIONS(323),
    [anon_sym_DOT] = ACTIONS(279),
    [anon_sym_LPAREN] = ACTIONS(408),
    [anon_sym_COMMA] = ACTIONS(277),
    [anon_sym_as] = ACTIONS(279),
    [anon_sym_STAR] = ACTIONS(410),
    [anon_sym_print] = ACTIONS(673),
    [anon_sym_GT_GT] = ACTIONS(277),
    [anon_sym_COLON_EQ] = ACTIONS(292),
    [anon_sym_if] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(279),
    [anon_sym_else] = ACTIONS(279),
    [anon_sym_match] = ACTIONS(673),
    [anon_sym_async] = ACTIONS(673),
    [anon_sym_in] = ACTIONS(279),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_exec] = ACTIONS(673),
    [anon_sym_type] = ACTIONS(675),
    [anon_sym_EQ] = ACTIONS(279),
    [anon_sym_LBRACK] = ACTIONS(412),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_DASH] = ACTIONS(315),
    [anon_sym_PIPE] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(310),
    [anon_sym_PLUS] = ACTIONS(315),
    [anon_sym_not] = ACTIONS(279),
    [anon_sym_and] = ACTIONS(279),
    [anon_sym_or] = ACTIONS(279),
    [anon_sym_SLASH] = ACTIONS(279),
    [anon_sym_PERCENT] = ACTIONS(277),
    [anon_sym_SLASH_SLASH] = ACTIONS(277),
    [anon_sym_AMP] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [anon_sym_LT_LT] = ACTIONS(277),
    [anon_sym_TILDE] = ACTIONS(315),
    [anon_sym_LT] = ACTIONS(279),
    [anon_sym_LT_EQ] = ACTIONS(277),
    [anon_sym_EQ_EQ] = ACTIONS(277),
    [anon_sym_BANG_EQ] = ACTIONS(277),
    [anon_sym_GT_EQ] = ACTIONS(277),
    [anon_sym_GT] = ACTIONS(279),
    [anon_sym_LT_GT] = ACTIONS(277),
    [anon_sym_is] = ACTIONS(279),
    [sym_ellipsis] = ACTIONS(321),
    [sym_integer] = ACTIONS(323),
    [sym_float] = ACTIONS(321),
    [anon_sym_await] = ACTIONS(677),
    [sym_true] = ACTIONS(323),
    [sym_false] = ACTIONS(323),
    [sym_none] = ACTIONS(323),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_string_start] = ACTIONS(327),
  },
  [168] = {
    [sym_list_splat_pattern] = STATE(1183),
    [sym_primary_expression] = STATE(1027),
    [sym_binary_operator] = STATE(1241),
    [sym_unary_operator] = STATE(1241),
    [sym_attribute] = STATE(1241),
    [sym_subscript] = STATE(1241),
    [sym_call] = STATE(1241),
    [sym_list] = STATE(1241),
    [sym_set] = STATE(1241),
    [sym_tuple] = STATE(1241),
    [sym_dictionary] = STATE(1241),
    [sym_list_comprehension] = STATE(1241),
    [sym_dictionary_comprehension] = STATE(1241),
    [sym_set_comprehension] = STATE(1241),
    [sym_generator_expression] = STATE(1241),
    [sym_parenthesized_expression] = STATE(1241),
    [sym_concatenated_string] = STATE(1241),
    [sym_string] = STATE(979),
    [sym_await] = STATE(1241),
    [sym_identifier] = ACTIONS(682),
    [anon_sym_DOT] = ACTIONS(279),
    [anon_sym_LPAREN] = ACTIONS(684),
    [anon_sym_COMMA] = ACTIONS(277),
    [anon_sym_as] = ACTIONS(279),
    [anon_sym_STAR] = ACTIONS(686),
    [anon_sym_print] = ACTIONS(688),
    [anon_sym_GT_GT] = ACTIONS(277),
    [anon_sym_if] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(277),
    [anon_sym_match] = ACTIONS(688),
    [anon_sym_async] = ACTIONS(688),
    [anon_sym_in] = ACTIONS(279),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_exec] = ACTIONS(688),
    [anon_sym_type] = ACTIONS(690),
    [anon_sym_EQ] = ACTIONS(279),
    [anon_sym_LBRACK] = ACTIONS(692),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_DASH] = ACTIONS(694),
    [anon_sym_PIPE] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(696),
    [anon_sym_RBRACE] = ACTIONS(277),
    [anon_sym_PLUS] = ACTIONS(694),
    [anon_sym_not] = ACTIONS(279),
    [anon_sym_and] = ACTIONS(279),
    [anon_sym_or] = ACTIONS(279),
    [anon_sym_SLASH] = ACTIONS(279),
    [anon_sym_PERCENT] = ACTIONS(277),
    [anon_sym_SLASH_SLASH] = ACTIONS(277),
    [anon_sym_AMP] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [anon_sym_LT_LT] = ACTIONS(277),
    [anon_sym_TILDE] = ACTIONS(694),
    [anon_sym_LT] = ACTIONS(279),
    [anon_sym_LT_EQ] = ACTIONS(277),
    [anon_sym_EQ_EQ] = ACTIONS(277),
    [anon_sym_BANG_EQ] = ACTIONS(277),
    [anon_sym_GT_EQ] = ACTIONS(277),
    [anon_sym_GT] = ACTIONS(279),
    [anon_sym_LT_GT] = ACTIONS(277),
    [anon_sym_is] = ACTIONS(279),
    [sym_ellipsis] = ACTIONS(698),
    [sym_type_conversion] = ACTIONS(277),
    [sym_integer] = ACTIONS(682),
    [sym_float] = ACTIONS(698),
    [anon_sym_await] = ACTIONS(700),
    [sym_true] = ACTIONS(682),
    [sym_false] = ACTIONS(682),
    [sym_none] = ACTIONS(682),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_string_start] = ACTIONS(702),
  },
  [169] = {
    [sym_list_splat_pattern] = STATE(1432),
    [sym_primary_expression] = STATE(1090),
    [sym_binary_operator] = STATE(1306),
    [sym_unary_operator] = STATE(1306),
    [sym_attribute] = STATE(1306),
    [sym_subscript] = STATE(1306),
    [sym_call] = STATE(1306),
    [sym_list] = STATE(1306),
    [sym_set] = STATE(1306),
    [sym_tuple] = STATE(1306),
    [sym_dictionary] = STATE(1306),
    [sym_list_comprehension] = STATE(1306),
    [sym_dictionary_comprehension] = STATE(1306),
    [sym_set_comprehension] = STATE(1306),
    [sym_generator_expression] = STATE(1306),
    [sym_parenthesized_expression] = STATE(1306),
    [sym_concatenated_string] = STATE(1306),
    [sym_string] = STATE(1032),
    [sym_await] = STATE(1306),
    [sym_identifier] = ACTIONS(750),
    [anon_sym_DOT] = ACTIONS(279),
    [anon_sym_LPAREN] = ACTIONS(752),
    [anon_sym_RPAREN] = ACTIONS(277),
    [anon_sym_COMMA] = ACTIONS(277),
    [anon_sym_as] = ACTIONS(279),
    [anon_sym_STAR] = ACTIONS(754),
    [anon_sym_print] = ACTIONS(756),
    [anon_sym_GT_GT] = ACTIONS(277),
    [anon_sym_COLON_EQ] = ACTIONS(292),
    [anon_sym_if] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(279),
    [anon_sym_match] = ACTIONS(756),
    [anon_sym_async] = ACTIONS(756),
    [anon_sym_in] = ACTIONS(279),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_exec] = ACTIONS(756),
    [anon_sym_type] = ACTIONS(758),
    [anon_sym_EQ] = ACTIONS(279),
    [anon_sym_LBRACK] = ACTIONS(760),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_DASH] = ACTIONS(762),
    [anon_sym_PIPE] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(764),
    [anon_sym_PLUS] = ACTIONS(762),
    [anon_sym_not] = ACTIONS(279),
    [anon_sym_and] = ACTIONS(279),
    [anon_sym_or] = ACTIONS(279),
    [anon_sym_SLASH] = ACTIONS(279),
    [anon_sym_PERCENT] = ACTIONS(277),
    [anon_sym_SLASH_SLASH] = ACTIONS(277),
    [anon_sym_AMP] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [anon_sym_LT_LT] = ACTIONS(277),
    [anon_sym_TILDE] = ACTIONS(762),
    [anon_sym_LT] = ACTIONS(279),
    [anon_sym_LT_EQ] = ACTIONS(277),
    [anon_sym_EQ_EQ] = ACTIONS(277),
    [anon_sym_BANG_EQ] = ACTIONS(277),
    [anon_sym_GT_EQ] = ACTIONS(277),
    [anon_sym_GT] = ACTIONS(279),
    [anon_sym_LT_GT] = ACTIONS(277),
    [anon_sym_is] = ACTIONS(279),
    [sym_ellipsis] = ACTIONS(766),
    [sym_integer] = ACTIONS(750),
    [sym_float] = ACTIONS(766),
    [anon_sym_await] = ACTIONS(768),
    [sym_true] = ACTIONS(750),
    [sym_false] = ACTIONS(750),
    [sym_none] = ACTIONS(750),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_string_start] = ACTIONS(770),
  },
  [170] = {
    [sym_list_splat_pattern] = STATE(1470),
    [sym_primary_expression] = STATE(1189),
    [sym_binary_operator] = STATE(1450),
    [sym_unary_operator] = STATE(1450),
    [sym_attribute] = STATE(1450),
    [sym_subscript] = STATE(1450),
    [sym_call] = STATE(1450),
    [sym_list] = STATE(1450),
    [sym_set] = STATE(1450),
    [sym_tuple] = STATE(1450),
    [sym_dictionary] = STATE(1450),
    [sym_list_comprehension] = STATE(1450),
    [sym_dictionary_comprehension] = STATE(1450),
    [sym_set_comprehension] = STATE(1450),
    [sym_generator_expression] = STATE(1450),
    [sym_parenthesized_expression] = STATE(1450),
    [sym_concatenated_string] = STATE(1450),
    [sym_string] = STATE(1150),
    [sym_await] = STATE(1450),
    [sym_identifier] = ACTIONS(772),
    [anon_sym_DOT] = ACTIONS(668),
    [anon_sym_LPAREN] = ACTIONS(774),
    [anon_sym_COMMA] = ACTIONS(679),
    [anon_sym_as] = ACTIONS(668),
    [anon_sym_STAR] = ACTIONS(776),
    [anon_sym_print] = ACTIONS(778),
    [anon_sym_GT_GT] = ACTIONS(679),
    [anon_sym_COLON_EQ] = ACTIONS(292),
    [anon_sym_if] = ACTIONS(668),
    [anon_sym_match] = ACTIONS(778),
    [anon_sym_async] = ACTIONS(778),
    [anon_sym_for] = ACTIONS(671),
    [anon_sym_in] = ACTIONS(668),
    [anon_sym_STAR_STAR] = ACTIONS(679),
    [anon_sym_exec] = ACTIONS(778),
    [anon_sym_type] = ACTIONS(780),
    [anon_sym_LBRACK] = ACTIONS(782),
    [anon_sym_RBRACK] = ACTIONS(679),
    [anon_sym_AT] = ACTIONS(679),
    [anon_sym_DASH] = ACTIONS(784),
    [anon_sym_PIPE] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(786),
    [anon_sym_PLUS] = ACTIONS(784),
    [anon_sym_not] = ACTIONS(668),
    [anon_sym_and] = ACTIONS(668),
    [anon_sym_or] = ACTIONS(668),
    [anon_sym_SLASH] = ACTIONS(668),
    [anon_sym_PERCENT] = ACTIONS(679),
    [anon_sym_SLASH_SLASH] = ACTIONS(679),
    [anon_sym_AMP] = ACTIONS(679),
    [anon_sym_CARET] = ACTIONS(679),
    [anon_sym_LT_LT] = ACTIONS(679),
    [anon_sym_TILDE] = ACTIONS(784),
    [anon_sym_LT] = ACTIONS(668),
    [anon_sym_LT_EQ] = ACTIONS(679),
    [anon_sym_EQ_EQ] = ACTIONS(679),
    [anon_sym_BANG_EQ] = ACTIONS(679),
    [anon_sym_GT_EQ] = ACTIONS(679),
    [anon_sym_GT] = ACTIONS(668),
    [anon_sym_LT_GT] = ACTIONS(679),
    [anon_sym_is] = ACTIONS(668),
    [sym_ellipsis] = ACTIONS(788),
    [sym_integer] = ACTIONS(772),
    [sym_float] = ACTIONS(788),
    [anon_sym_await] = ACTIONS(790),
    [sym_true] = ACTIONS(772),
    [sym_false] = ACTIONS(772),
    [sym_none] = ACTIONS(772),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_string_start] = ACTIONS(792),
  },
  [171] = {
    [sym_list_splat_pattern] = STATE(1432),
    [sym_primary_expression] = STATE(1090),
    [sym_binary_operator] = STATE(1306),
    [sym_unary_operator] = STATE(1306),
    [sym_attribute] = STATE(1306),
    [sym_subscript] = STATE(1306),
    [sym_call] = STATE(1306),
    [sym_list] = STATE(1306),
    [sym_set] = STATE(1306),
    [sym_tuple] = STATE(1306),
    [sym_dictionary] = STATE(1306),
    [sym_list_comprehension] = STATE(1306),
    [sym_dictionary_comprehension] = STATE(1306),
    [sym_set_comprehension] = STATE(1306),
    [sym_generator_expression] = STATE(1306),
    [sym_parenthesized_expression] = STATE(1306),
    [sym_concatenated_string] = STATE(1306),
    [sym_string] = STATE(1032),
    [sym_await] = STATE(1306),
    [sym_identifier] = ACTIONS(750),
    [anon_sym_DOT] = ACTIONS(668),
    [anon_sym_LPAREN] = ACTIONS(752),
    [anon_sym_RPAREN] = ACTIONS(679),
    [anon_sym_COMMA] = ACTIONS(679),
    [anon_sym_as] = ACTIONS(668),
    [anon_sym_STAR] = ACTIONS(754),
    [anon_sym_print] = ACTIONS(756),
    [anon_sym_GT_GT] = ACTIONS(679),
    [anon_sym_COLON_EQ] = ACTIONS(292),
    [anon_sym_if] = ACTIONS(668),
    [anon_sym_match] = ACTIONS(756),
    [anon_sym_async] = ACTIONS(756),
    [anon_sym_for] = ACTIONS(671),
    [anon_sym_in] = ACTIONS(668),
    [anon_sym_STAR_STAR] = ACTIONS(679),
    [anon_sym_exec] = ACTIONS(756),
    [anon_sym_type] = ACTIONS(758),
    [anon_sym_LBRACK] = ACTIONS(760),
    [anon_sym_AT] = ACTIONS(679),
    [anon_sym_DASH] = ACTIONS(762),
    [anon_sym_PIPE] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(764),
    [anon_sym_PLUS] = ACTIONS(762),
    [anon_sym_not] = ACTIONS(668),
    [anon_sym_and] = ACTIONS(668),
    [anon_sym_or] = ACTIONS(668),
    [anon_sym_SLASH] = ACTIONS(668),
    [anon_sym_PERCENT] = ACTIONS(679),
    [anon_sym_SLASH_SLASH] = ACTIONS(679),
    [anon_sym_AMP] = ACTIONS(679),
    [anon_sym_CARET] = ACTIONS(679),
    [anon_sym_LT_LT] = ACTIONS(679),
    [anon_sym_TILDE] = ACTIONS(762),
    [anon_sym_LT] = ACTIONS(668),
    [anon_sym_LT_EQ] = ACTIONS(679),
    [anon_sym_EQ_EQ] = ACTIONS(679),
    [anon_sym_BANG_EQ] = ACTIONS(679),
    [anon_sym_GT_EQ] = ACTIONS(679),
    [anon_sym_GT] = ACTIONS(668),
    [anon_sym_LT_GT] = ACTIONS(679),
    [anon_sym_is] = ACTIONS(668),
    [sym_ellipsis] = ACTIONS(766),
    [sym_integer] = ACTIONS(750),
    [sym_float] = ACTIONS(766),
    [anon_sym_await] = ACTIONS(768),
    [sym_true] = ACTIONS(750),
    [sym_false] = ACTIONS(750),
    [sym_none] = ACTIONS(750),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_string_start] = ACTIONS(770),
  },
  [172] = {
    [sym_list_splat_pattern] = STATE(1367),
    [sym_primary_expression] = STATE(1101),
    [sym_binary_operator] = STATE(1414),
    [sym_unary_operator] = STATE(1414),
    [sym_attribute] = STATE(1414),
    [sym_subscript] = STATE(1414),
    [sym_call] = STATE(1414),
    [sym_list] = STATE(1414),
    [sym_set] = STATE(1414),
    [sym_tuple] = STATE(1414),
    [sym_dictionary] = STATE(1414),
    [sym_list_comprehension] = STATE(1414),
    [sym_dictionary_comprehension] = STATE(1414),
    [sym_set_comprehension] = STATE(1414),
    [sym_generator_expression] = STATE(1414),
    [sym_parenthesized_expression] = STATE(1414),
    [sym_concatenated_string] = STATE(1414),
    [sym_string] = STATE(1017),
    [sym_await] = STATE(1414),
    [sym_identifier] = ACTIONS(794),
    [anon_sym_DOT] = ACTIONS(279),
    [anon_sym_LPAREN] = ACTIONS(796),
    [anon_sym_COMMA] = ACTIONS(284),
    [anon_sym_as] = ACTIONS(279),
    [anon_sym_STAR] = ACTIONS(798),
    [anon_sym_print] = ACTIONS(800),
    [anon_sym_GT_GT] = ACTIONS(277),
    [anon_sym_COLON_EQ] = ACTIONS(292),
    [anon_sym_if] = ACTIONS(279),
    [anon_sym_match] = ACTIONS(800),
    [anon_sym_async] = ACTIONS(800),
    [anon_sym_for] = ACTIONS(279),
    [anon_sym_in] = ACTIONS(279),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_exec] = ACTIONS(800),
    [anon_sym_type] = ACTIONS(802),
    [anon_sym_LBRACK] = ACTIONS(804),
    [anon_sym_RBRACK] = ACTIONS(284),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_DASH] = ACTIONS(806),
    [anon_sym_PIPE] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_PLUS] = ACTIONS(806),
    [anon_sym_not] = ACTIONS(279),
    [anon_sym_and] = ACTIONS(279),
    [anon_sym_or] = ACTIONS(279),
    [anon_sym_SLASH] = ACTIONS(279),
    [anon_sym_PERCENT] = ACTIONS(277),
    [anon_sym_SLASH_SLASH] = ACTIONS(277),
    [anon_sym_AMP] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [anon_sym_LT_LT] = ACTIONS(277),
    [anon_sym_TILDE] = ACTIONS(806),
    [anon_sym_LT] = ACTIONS(279),
    [anon_sym_LT_EQ] = ACTIONS(277),
    [anon_sym_EQ_EQ] = ACTIONS(277),
    [anon_sym_BANG_EQ] = ACTIONS(277),
    [anon_sym_GT_EQ] = ACTIONS(277),
    [anon_sym_GT] = ACTIONS(279),
    [anon_sym_LT_GT] = ACTIONS(277),
    [anon_sym_is] = ACTIONS(279),
    [sym_ellipsis] = ACTIONS(810),
    [sym_integer] = ACTIONS(794),
    [sym_float] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(812),
    [sym_true] = ACTIONS(794),
    [sym_false] = ACTIONS(794),
    [sym_none] = ACTIONS(794),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_string_start] = ACTIONS(814),
  },
  [173] = {
    [sym_list_splat_pattern] = STATE(1470),
    [sym_primary_expression] = STATE(1189),
    [sym_binary_operator] = STATE(1450),
    [sym_unary_operator] = STATE(1450),
    [sym_attribute] = STATE(1450),
    [sym_subscript] = STATE(1450),
    [sym_call] = STATE(1450),
    [sym_list] = STATE(1450),
    [sym_set] = STATE(1450),
    [sym_tuple] = STATE(1450),
    [sym_dictionary] = STATE(1450),
    [sym_list_comprehension] = STATE(1450),
    [sym_dictionary_comprehension] = STATE(1450),
    [sym_set_comprehension] = STATE(1450),
    [sym_generator_expression] = STATE(1450),
    [sym_parenthesized_expression] = STATE(1450),
    [sym_concatenated_string] = STATE(1450),
    [sym_string] = STATE(1150),
    [sym_await] = STATE(1450),
    [sym_identifier] = ACTIONS(772),
    [anon_sym_DOT] = ACTIONS(279),
    [anon_sym_LPAREN] = ACTIONS(774),
    [anon_sym_COMMA] = ACTIONS(277),
    [anon_sym_as] = ACTIONS(279),
    [anon_sym_STAR] = ACTIONS(776),
    [anon_sym_print] = ACTIONS(778),
    [anon_sym_GT_GT] = ACTIONS(277),
    [anon_sym_COLON_EQ] = ACTIONS(292),
    [anon_sym_if] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(279),
    [anon_sym_match] = ACTIONS(778),
    [anon_sym_async] = ACTIONS(778),
    [anon_sym_in] = ACTIONS(279),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_exec] = ACTIONS(778),
    [anon_sym_type] = ACTIONS(780),
    [anon_sym_LBRACK] = ACTIONS(782),
    [anon_sym_RBRACK] = ACTIONS(277),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_DASH] = ACTIONS(784),
    [anon_sym_PIPE] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(786),
    [anon_sym_PLUS] = ACTIONS(784),
    [anon_sym_not] = ACTIONS(279),
    [anon_sym_and] = ACTIONS(279),
    [anon_sym_or] = ACTIONS(279),
    [anon_sym_SLASH] = ACTIONS(279),
    [anon_sym_PERCENT] = ACTIONS(277),
    [anon_sym_SLASH_SLASH] = ACTIONS(277),
    [anon_sym_AMP] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [anon_sym_LT_LT] = ACTIONS(277),
    [anon_sym_TILDE] = ACTIONS(784),
    [anon_sym_LT] = ACTIONS(279),
    [anon_sym_LT_EQ] = ACTIONS(277),
    [anon_sym_EQ_EQ] = ACTIONS(277),
    [anon_sym_BANG_EQ] = ACTIONS(277),
    [anon_sym_GT_EQ] = ACTIONS(277),
    [anon_sym_GT] = ACTIONS(279),
    [anon_sym_LT_GT] = ACTIONS(277),
    [anon_sym_is] = ACTIONS(279),
    [sym_ellipsis] = ACTIONS(788),
    [sym_integer] = ACTIONS(772),
    [sym_float] = ACTIONS(788),
    [anon_sym_await] = ACTIONS(790),
    [sym_true] = ACTIONS(772),
    [sym_false] = ACTIONS(772),
    [sym_none] = ACTIONS(772),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_string_start] = ACTIONS(792),
  },
  [174] = {
    [sym_list_splat_pattern] = STATE(1290),
    [sym_primary_expression] = STATE(1157),
    [sym_binary_operator] = STATE(1337),
    [sym_unary_operator] = STATE(1337),
    [sym_attribute] = STATE(1337),
    [sym_subscript] = STATE(1337),
    [sym_call] = STATE(1337),
    [sym_list] = STATE(1337),
    [sym_set] = STATE(1337),
    [sym_tuple] = STATE(1337),
    [sym_dictionary] = STATE(1337),
    [sym_list_comprehension] = STATE(1337),
    [sym_dictionary_comprehension] = STATE(1337),
    [sym_set_comprehension] = STATE(1337),
    [sym_generator_expression] = STATE(1337),
    [sym_parenthesized_expression] = STATE(1337),
    [sym_concatenated_string] = STATE(1337),
    [sym_string] = STATE(1030),
    [sym_await] = STATE(1337),
    [sym_identifier] = ACTIONS(726),
    [anon_sym_DOT] = ACTIONS(279),
    [anon_sym_LPAREN] = ACTIONS(728),
    [anon_sym_RPAREN] = ACTIONS(277),
    [anon_sym_COMMA] = ACTIONS(277),
    [anon_sym_as] = ACTIONS(279),
    [anon_sym_STAR] = ACTIONS(730),
    [anon_sym_print] = ACTIONS(732),
    [anon_sym_GT_GT] = ACTIONS(277),
    [anon_sym_COLON_EQ] = ACTIONS(292),
    [anon_sym_if] = ACTIONS(279),
    [anon_sym_match] = ACTIONS(732),
    [anon_sym_async] = ACTIONS(732),
    [anon_sym_for] = ACTIONS(279),
    [anon_sym_in] = ACTIONS(279),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_exec] = ACTIONS(732),
    [anon_sym_type] = ACTIONS(734),
    [anon_sym_LBRACK] = ACTIONS(738),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_DASH] = ACTIONS(740),
    [anon_sym_PIPE] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(742),
    [anon_sym_PLUS] = ACTIONS(740),
    [anon_sym_not] = ACTIONS(279),
    [anon_sym_and] = ACTIONS(279),
    [anon_sym_or] = ACTIONS(279),
    [anon_sym_SLASH] = ACTIONS(279),
    [anon_sym_PERCENT] = ACTIONS(277),
    [anon_sym_SLASH_SLASH] = ACTIONS(277),
    [anon_sym_AMP] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [anon_sym_LT_LT] = ACTIONS(277),
    [anon_sym_TILDE] = ACTIONS(740),
    [anon_sym_LT] = ACTIONS(279),
    [anon_sym_LT_EQ] = ACTIONS(277),
    [anon_sym_EQ_EQ] = ACTIONS(277),
    [anon_sym_BANG_EQ] = ACTIONS(277),
    [anon_sym_GT_EQ] = ACTIONS(277),
    [anon_sym_GT] = ACTIONS(279),
    [anon_sym_LT_GT] = ACTIONS(277),
    [anon_sym_is] = ACTIONS(279),
    [sym_ellipsis] = ACTIONS(744),
    [sym_integer] = ACTIONS(726),
    [sym_float] = ACTIONS(744),
    [anon_sym_await] = ACTIONS(746),
    [sym_true] = ACTIONS(726),
    [sym_false] = ACTIONS(726),
    [sym_none] = ACTIONS(726),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_string_start] = ACTIONS(748),
  },
  [175] = {
    [sym_list_splat_pattern] = STATE(1432),
    [sym_primary_expression] = STATE(1090),
    [sym_binary_operator] = STATE(1306),
    [sym_unary_operator] = STATE(1306),
    [sym_attribute] = STATE(1306),
    [sym_subscript] = STATE(1306),
    [sym_call] = STATE(1306),
    [sym_list] = STATE(1306),
    [sym_set] = STATE(1306),
    [sym_tuple] = STATE(1306),
    [sym_dictionary] = STATE(1306),
    [sym_list_comprehension] = STATE(1306),
    [sym_dictionary_comprehension] = STATE(1306),
    [sym_set_comprehension] = STATE(1306),
    [sym_generator_expression] = STATE(1306),
    [sym_parenthesized_expression] = STATE(1306),
    [sym_concatenated_string] = STATE(1306),
    [sym_string] = STATE(1032),
    [sym_await] = STATE(1306),
    [sym_identifier] = ACTIONS(750),
    [anon_sym_DOT] = ACTIONS(279),
    [anon_sym_LPAREN] = ACTIONS(752),
    [anon_sym_RPAREN] = ACTIONS(277),
    [anon_sym_COMMA] = ACTIONS(277),
    [anon_sym_as] = ACTIONS(279),
    [anon_sym_STAR] = ACTIONS(754),
    [anon_sym_print] = ACTIONS(756),
    [anon_sym_GT_GT] = ACTIONS(277),
    [anon_sym_if] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(277),
    [anon_sym_match] = ACTIONS(756),
    [anon_sym_async] = ACTIONS(756),
    [anon_sym_in] = ACTIONS(279),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_exec] = ACTIONS(756),
    [anon_sym_type] = ACTIONS(758),
    [anon_sym_EQ] = ACTIONS(279),
    [anon_sym_LBRACK] = ACTIONS(760),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_DASH] = ACTIONS(762),
    [anon_sym_PIPE] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(764),
    [anon_sym_PLUS] = ACTIONS(762),
    [anon_sym_not] = ACTIONS(279),
    [anon_sym_and] = ACTIONS(279),
    [anon_sym_or] = ACTIONS(279),
    [anon_sym_SLASH] = ACTIONS(279),
    [anon_sym_PERCENT] = ACTIONS(277),
    [anon_sym_SLASH_SLASH] = ACTIONS(277),
    [anon_sym_AMP] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [anon_sym_LT_LT] = ACTIONS(277),
    [anon_sym_TILDE] = ACTIONS(762),
    [anon_sym_LT] = ACTIONS(279),
    [anon_sym_LT_EQ] = ACTIONS(277),
    [anon_sym_EQ_EQ] = ACTIONS(277),
    [anon_sym_BANG_EQ] = ACTIONS(277),
    [anon_sym_GT_EQ] = ACTIONS(277),
    [anon_sym_GT] = ACTIONS(279),
    [anon_sym_LT_GT] = ACTIONS(277),
    [anon_sym_is] = ACTIONS(279),
    [sym_ellipsis] = ACTIONS(766),
    [sym_integer] = ACTIONS(750),
    [sym_float] = ACTIONS(766),
    [anon_sym_await] = ACTIONS(768),
    [sym_true] = ACTIONS(750),
    [sym_false] = ACTIONS(750),
    [sym_none] = ACTIONS(750),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_string_start] = ACTIONS(770),
  },
  [176] = {
    [sym_list_splat_pattern] = STATE(1433),
    [sym_primary_expression] = STATE(1097),
    [sym_binary_operator] = STATE(1365),
    [sym_unary_operator] = STATE(1365),
    [sym_attribute] = STATE(1365),
    [sym_subscript] = STATE(1365),
    [sym_call] = STATE(1365),
    [sym_list] = STATE(1365),
    [sym_set] = STATE(1365),
    [sym_tuple] = STATE(1365),
    [sym_dictionary] = STATE(1365),
    [sym_list_comprehension] = STATE(1365),
    [sym_dictionary_comprehension] = STATE(1365),
    [sym_set_comprehension] = STATE(1365),
    [sym_generator_expression] = STATE(1365),
    [sym_parenthesized_expression] = STATE(1365),
    [sym_concatenated_string] = STATE(1365),
    [sym_string] = STATE(1004),
    [sym_await] = STATE(1365),
    [sym_identifier] = ACTIONS(323),
    [anon_sym_SEMI] = ACTIONS(319),
    [anon_sym_DOT] = ACTIONS(279),
    [anon_sym_LPAREN] = ACTIONS(408),
    [anon_sym_COMMA] = ACTIONS(319),
    [anon_sym_STAR] = ACTIONS(410),
    [anon_sym_print] = ACTIONS(673),
    [anon_sym_GT_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(319),
    [anon_sym_match] = ACTIONS(673),
    [anon_sym_async] = ACTIONS(673),
    [anon_sym_STAR_STAR] = ACTIONS(279),
    [anon_sym_exec] = ACTIONS(673),
    [anon_sym_type] = ACTIONS(675),
    [anon_sym_EQ] = ACTIONS(319),
    [anon_sym_LBRACK] = ACTIONS(412),
    [anon_sym_AT] = ACTIONS(279),
    [anon_sym_DASH] = ACTIONS(414),
    [anon_sym_PIPE] = ACTIONS(279),
    [anon_sym_LBRACE] = ACTIONS(310),
    [anon_sym_PLUS] = ACTIONS(414),
    [anon_sym_SLASH] = ACTIONS(279),
    [anon_sym_PERCENT] = ACTIONS(279),
    [anon_sym_SLASH_SLASH] = ACTIONS(279),
    [anon_sym_AMP] = ACTIONS(279),
    [anon_sym_CARET] = ACTIONS(279),
    [anon_sym_LT_LT] = ACTIONS(279),
    [anon_sym_TILDE] = ACTIONS(315),
    [anon_sym_PLUS_EQ] = ACTIONS(319),
    [anon_sym_DASH_EQ] = ACTIONS(319),
    [anon_sym_STAR_EQ] = ACTIONS(319),
    [anon_sym_SLASH_EQ] = ACTIONS(319),
    [anon_sym_AT_EQ] = ACTIONS(319),
    [anon_sym_SLASH_SLASH_EQ] = ACTIONS(319),
    [anon_sym_PERCENT_EQ] = ACTIONS(319),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(319),
    [anon_sym_GT_GT_EQ] = ACTIONS(319),
    [anon_sym_LT_LT_EQ] = ACTIONS(319),
    [anon_sym_AMP_EQ] = ACTIONS(319),
    [anon_sym_CARET_EQ] = ACTIONS(319),
    [anon_sym_PIPE_EQ] = ACTIONS(319),
    [sym_ellipsis] = ACTIONS(321),
    [sym_integer] = ACTIONS(323),
    [sym_float] = ACTIONS(321),
    [anon_sym_await] = ACTIONS(677),
    [sym_true] = ACTIONS(323),
    [sym_false] = ACTIONS(323),
    [sym_none] = ACTIONS(323),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym__newline] = ACTIONS(319),
    [sym_string_start] = ACTIONS(327),
  },
  [177] = {
    [sym_list_splat_pattern] = STATE(1433),
    [sym_primary_expression] = STATE(1097),
    [sym_binary_operator] = STATE(1365),
    [sym_unary_operator] = STATE(1365),
    [sym_attribute] = STATE(1365),
    [sym_subscript] = STATE(1365),
    [sym_call] = STATE(1365),
    [sym_list] = STATE(1365),
    [sym_set] = STATE(1365),
    [sym_tuple] = STATE(1365),
    [sym_dictionary] = STATE(1365),
    [sym_list_comprehension] = STATE(1365),
    [sym_dictionary_comprehension] = STATE(1365),
    [sym_set_comprehension] = STATE(1365),
    [sym_generator_expression] = STATE(1365),
    [sym_parenthesized_expression] = STATE(1365),
    [sym_concatenated_string] = STATE(1365),
    [sym_string] = STATE(1004),
    [sym_await] = STATE(1365),
    [sym_identifier] = ACTIONS(323),
    [anon_sym_DOT] = ACTIONS(279),
    [anon_sym_LPAREN] = ACTIONS(408),
    [anon_sym_COMMA] = ACTIONS(277),
    [anon_sym_as] = ACTIONS(279),
    [anon_sym_STAR] = ACTIONS(410),
    [anon_sym_print] = ACTIONS(673),
    [anon_sym_GT_GT] = ACTIONS(277),
    [anon_sym_if] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(277),
    [anon_sym_else] = ACTIONS(279),
    [anon_sym_match] = ACTIONS(673),
    [anon_sym_async] = ACTIONS(673),
    [anon_sym_in] = ACTIONS(279),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_exec] = ACTIONS(673),
    [anon_sym_type] = ACTIONS(675),
    [anon_sym_EQ] = ACTIONS(279),
    [anon_sym_LBRACK] = ACTIONS(412),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_DASH] = ACTIONS(315),
    [anon_sym_PIPE] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(310),
    [anon_sym_PLUS] = ACTIONS(315),
    [anon_sym_not] = ACTIONS(279),
    [anon_sym_and] = ACTIONS(279),
    [anon_sym_or] = ACTIONS(279),
    [anon_sym_SLASH] = ACTIONS(279),
    [anon_sym_PERCENT] = ACTIONS(277),
    [anon_sym_SLASH_SLASH] = ACTIONS(277),
    [anon_sym_AMP] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [anon_sym_LT_LT] = ACTIONS(277),
    [anon_sym_TILDE] = ACTIONS(315),
    [anon_sym_LT] = ACTIONS(279),
    [anon_sym_LT_EQ] = ACTIONS(277),
    [anon_sym_EQ_EQ] = ACTIONS(277),
    [anon_sym_BANG_EQ] = ACTIONS(277),
    [anon_sym_GT_EQ] = ACTIONS(277),
    [anon_sym_GT] = ACTIONS(279),
    [anon_sym_LT_GT] = ACTIONS(277),
    [anon_sym_is] = ACTIONS(279),
    [sym_ellipsis] = ACTIONS(321),
    [sym_integer] = ACTIONS(323),
    [sym_float] = ACTIONS(321),
    [anon_sym_await] = ACTIONS(677),
    [sym_true] = ACTIONS(323),
    [sym_false] = ACTIONS(323),
    [sym_none] = ACTIONS(323),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_string_start] = ACTIONS(327),
  },
  [178] = {
    [sym_list_splat_pattern] = STATE(1218),
    [sym_primary_expression] = STATE(1031),
    [sym_binary_operator] = STATE(1169),
    [sym_unary_operator] = STATE(1169),
    [sym_attribute] = STATE(1169),
    [sym_subscript] = STATE(1169),
    [sym_call] = STATE(1169),
    [sym_list] = STATE(1169),
    [sym_set] = STATE(1169),
    [sym_tuple] = STATE(1169),
    [sym_dictionary] = STATE(1169),
    [sym_list_comprehension] = STATE(1169),
    [sym_dictionary_comprehension] = STATE(1169),
    [sym_set_comprehension] = STATE(1169),
    [sym_generator_expression] = STATE(1169),
    [sym_parenthesized_expression] = STATE(1169),
    [sym_concatenated_string] = STATE(1169),
    [sym_string] = STATE(993),
    [sym_await] = STATE(1169),
    [sym_identifier] = ACTIONS(704),
    [anon_sym_DOT] = ACTIONS(279),
    [anon_sym_LPAREN] = ACTIONS(706),
    [anon_sym_COMMA] = ACTIONS(277),
    [anon_sym_as] = ACTIONS(279),
    [anon_sym_STAR] = ACTIONS(708),
    [anon_sym_print] = ACTIONS(710),
    [anon_sym_GT_GT] = ACTIONS(277),
    [anon_sym_if] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(277),
    [anon_sym_match] = ACTIONS(710),
    [anon_sym_async] = ACTIONS(710),
    [anon_sym_for] = ACTIONS(279),
    [anon_sym_in] = ACTIONS(279),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_exec] = ACTIONS(710),
    [anon_sym_type] = ACTIONS(712),
    [anon_sym_LBRACK] = ACTIONS(714),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_DASH] = ACTIONS(716),
    [anon_sym_PIPE] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(718),
    [anon_sym_RBRACE] = ACTIONS(277),
    [anon_sym_PLUS] = ACTIONS(716),
    [anon_sym_not] = ACTIONS(279),
    [anon_sym_and] = ACTIONS(279),
    [anon_sym_or] = ACTIONS(279),
    [anon_sym_SLASH] = ACTIONS(279),
    [anon_sym_PERCENT] = ACTIONS(277),
    [anon_sym_SLASH_SLASH] = ACTIONS(277),
    [anon_sym_AMP] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [anon_sym_LT_LT] = ACTIONS(277),
    [anon_sym_TILDE] = ACTIONS(716),
    [anon_sym_LT] = ACTIONS(279),
    [anon_sym_LT_EQ] = ACTIONS(277),
    [anon_sym_EQ_EQ] = ACTIONS(277),
    [anon_sym_BANG_EQ] = ACTIONS(277),
    [anon_sym_GT_EQ] = ACTIONS(277),
    [anon_sym_GT] = ACTIONS(279),
    [anon_sym_LT_GT] = ACTIONS(277),
    [anon_sym_is] = ACTIONS(279),
    [sym_ellipsis] = ACTIONS(720),
    [sym_integer] = ACTIONS(704),
    [sym_float] = ACTIONS(720),
    [anon_sym_await] = ACTIONS(722),
    [sym_true] = ACTIONS(704),
    [sym_false] = ACTIONS(704),
    [sym_none] = ACTIONS(704),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_string_start] = ACTIONS(724),
  },
  [179] = {
    [sym_list_splat_pattern] = STATE(1367),
    [sym_primary_expression] = STATE(1101),
    [sym_binary_operator] = STATE(1414),
    [sym_unary_operator] = STATE(1414),
    [sym_attribute] = STATE(1414),
    [sym_subscript] = STATE(1414),
    [sym_call] = STATE(1414),
    [sym_list] = STATE(1414),
    [sym_set] = STATE(1414),
    [sym_tuple] = STATE(1414),
    [sym_dictionary] = STATE(1414),
    [sym_list_comprehension] = STATE(1414),
    [sym_dictionary_comprehension] = STATE(1414),
    [sym_set_comprehension] = STATE(1414),
    [sym_generator_expression] = STATE(1414),
    [sym_parenthesized_expression] = STATE(1414),
    [sym_concatenated_string] = STATE(1414),
    [sym_string] = STATE(1017),
    [sym_await] = STATE(1414),
    [sym_identifier] = ACTIONS(794),
    [anon_sym_DOT] = ACTIONS(279),
    [anon_sym_LPAREN] = ACTIONS(796),
    [anon_sym_COMMA] = ACTIONS(277),
    [anon_sym_as] = ACTIONS(279),
    [anon_sym_STAR] = ACTIONS(798),
    [anon_sym_print] = ACTIONS(800),
    [anon_sym_GT_GT] = ACTIONS(277),
    [anon_sym_COLON_EQ] = ACTIONS(292),
    [anon_sym_if] = ACTIONS(279),
    [anon_sym_match] = ACTIONS(800),
    [anon_sym_async] = ACTIONS(800),
    [anon_sym_for] = ACTIONS(279),
    [anon_sym_in] = ACTIONS(279),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_exec] = ACTIONS(800),
    [anon_sym_type] = ACTIONS(802),
    [anon_sym_LBRACK] = ACTIONS(804),
    [anon_sym_RBRACK] = ACTIONS(277),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_DASH] = ACTIONS(806),
    [anon_sym_PIPE] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_PLUS] = ACTIONS(806),
    [anon_sym_not] = ACTIONS(279),
    [anon_sym_and] = ACTIONS(279),
    [anon_sym_or] = ACTIONS(279),
    [anon_sym_SLASH] = ACTIONS(279),
    [anon_sym_PERCENT] = ACTIONS(277),
    [anon_sym_SLASH_SLASH] = ACTIONS(277),
    [anon_sym_AMP] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [anon_sym_LT_LT] = ACTIONS(277),
    [anon_sym_TILDE] = ACTIONS(806),
    [anon_sym_LT] = ACTIONS(279),
    [anon_sym_LT_EQ] = ACTIONS(277),
    [anon_sym_EQ_EQ] = ACTIONS(277),
    [anon_sym_BANG_EQ] = ACTIONS(277),
    [anon_sym_GT_EQ] = ACTIONS(277),
    [anon_sym_GT] = ACTIONS(279),
    [anon_sym_LT_GT] = ACTIONS(277),
    [anon_sym_is] = ACTIONS(279),
    [sym_ellipsis] = ACTIONS(810),
    [sym_integer] = ACTIONS(794),
    [sym_float] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(812),
    [sym_true] = ACTIONS(794),
    [sym_false] = ACTIONS(794),
    [sym_none] = ACTIONS(794),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_string_start] = ACTIONS(814),
  },
  [180] = {
    [sym_list_splat_pattern] = STATE(1433),
    [sym_primary_expression] = STATE(1097),
    [sym_binary_operator] = STATE(1365),
    [sym_unary_operator] = STATE(1365),
    [sym_attribute] = STATE(1365),
    [sym_subscript] = STATE(1365),
    [sym_call] = STATE(1365),
    [sym_list] = STATE(1365),
    [sym_set] = STATE(1365),
    [sym_tuple] = STATE(1365),
    [sym_dictionary] = STATE(1365),
    [sym_list_comprehension] = STATE(1365),
    [sym_dictionary_comprehension] = STATE(1365),
    [sym_set_comprehension] = STATE(1365),
    [sym_generator_expression] = STATE(1365),
    [sym_parenthesized_expression] = STATE(1365),
    [sym_concatenated_string] = STATE(1365),
    [sym_string] = STATE(1004),
    [sym_await] = STATE(1365),
    [sym_identifier] = ACTIONS(323),
    [anon_sym_DOT] = ACTIONS(668),
    [anon_sym_LPAREN] = ACTIONS(408),
    [anon_sym_COMMA] = ACTIONS(666),
    [anon_sym_as] = ACTIONS(671),
    [anon_sym_STAR] = ACTIONS(410),
    [anon_sym_print] = ACTIONS(673),
    [anon_sym_GT_GT] = ACTIONS(679),
    [anon_sym_if] = ACTIONS(671),
    [anon_sym_COLON] = ACTIONS(666),
    [anon_sym_match] = ACTIONS(673),
    [anon_sym_async] = ACTIONS(673),
    [anon_sym_for] = ACTIONS(671),
    [anon_sym_in] = ACTIONS(671),
    [anon_sym_STAR_STAR] = ACTIONS(679),
    [anon_sym_exec] = ACTIONS(673),
    [anon_sym_type] = ACTIONS(675),
    [anon_sym_LBRACK] = ACTIONS(412),
    [anon_sym_RBRACK] = ACTIONS(666),
    [anon_sym_AT] = ACTIONS(679),
    [anon_sym_DASH] = ACTIONS(315),
    [anon_sym_PIPE] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(310),
    [anon_sym_PLUS] = ACTIONS(315),
    [anon_sym_not] = ACTIONS(671),
    [anon_sym_and] = ACTIONS(671),
    [anon_sym_or] = ACTIONS(671),
    [anon_sym_SLASH] = ACTIONS(668),
    [anon_sym_PERCENT] = ACTIONS(679),
    [anon_sym_SLASH_SLASH] = ACTIONS(679),
    [anon_sym_AMP] = ACTIONS(679),
    [anon_sym_CARET] = ACTIONS(679),
    [anon_sym_LT_LT] = ACTIONS(679),
    [anon_sym_TILDE] = ACTIONS(315),
    [anon_sym_LT] = ACTIONS(671),
    [anon_sym_LT_EQ] = ACTIONS(666),
    [anon_sym_EQ_EQ] = ACTIONS(666),
    [anon_sym_BANG_EQ] = ACTIONS(666),
    [anon_sym_GT_EQ] = ACTIONS(666),
    [anon_sym_GT] = ACTIONS(671),
    [anon_sym_LT_GT] = ACTIONS(666),
    [anon_sym_is] = ACTIONS(671),
    [sym_ellipsis] = ACTIONS(321),
    [sym_integer] = ACTIONS(323),
    [sym_float] = ACTIONS(321),
    [anon_sym_await] = ACTIONS(677),
    [sym_true] = ACTIONS(323),
    [sym_false] = ACTIONS(323),
    [sym_none] = ACTIONS(323),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_string_start] = ACTIONS(327),
  },
  [181] = {
    [sym_list_splat_pattern] = STATE(1433),
    [sym_primary_expression] = STATE(1097),
    [sym_binary_operator] = STATE(1365),
    [sym_unary_operator] = STATE(1365),
    [sym_attribute] = STATE(1365),
    [sym_subscript] = STATE(1365),
    [sym_call] = STATE(1365),
    [sym_list] = STATE(1365),
    [sym_set] = STATE(1365),
    [sym_tuple] = STATE(1365),
    [sym_dictionary] = STATE(1365),
    [sym_list_comprehension] = STATE(1365),
    [sym_dictionary_comprehension] = STATE(1365),
    [sym_set_comprehension] = STATE(1365),
    [sym_generator_expression] = STATE(1365),
    [sym_parenthesized_expression] = STATE(1365),
    [sym_concatenated_string] = STATE(1365),
    [sym_string] = STATE(1004),
    [sym_await] = STATE(1365),
    [sym_identifier] = ACTIONS(323),
    [anon_sym_DOT] = ACTIONS(668),
    [anon_sym_LPAREN] = ACTIONS(408),
    [anon_sym_COMMA] = ACTIONS(666),
    [anon_sym_as] = ACTIONS(671),
    [anon_sym_STAR] = ACTIONS(410),
    [anon_sym_print] = ACTIONS(673),
    [anon_sym_GT_GT] = ACTIONS(679),
    [anon_sym_if] = ACTIONS(671),
    [anon_sym_COLON] = ACTIONS(666),
    [anon_sym_else] = ACTIONS(671),
    [anon_sym_match] = ACTIONS(673),
    [anon_sym_async] = ACTIONS(673),
    [anon_sym_in] = ACTIONS(671),
    [anon_sym_STAR_STAR] = ACTIONS(679),
    [anon_sym_exec] = ACTIONS(673),
    [anon_sym_type] = ACTIONS(675),
    [anon_sym_EQ] = ACTIONS(671),
    [anon_sym_LBRACK] = ACTIONS(412),
    [anon_sym_AT] = ACTIONS(679),
    [anon_sym_DASH] = ACTIONS(315),
    [anon_sym_PIPE] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(310),
    [anon_sym_PLUS] = ACTIONS(315),
    [anon_sym_not] = ACTIONS(671),
    [anon_sym_and] = ACTIONS(671),
    [anon_sym_or] = ACTIONS(671),
    [anon_sym_SLASH] = ACTIONS(668),
    [anon_sym_PERCENT] = ACTIONS(679),
    [anon_sym_SLASH_SLASH] = ACTIONS(679),
    [anon_sym_AMP] = ACTIONS(679),
    [anon_sym_CARET] = ACTIONS(679),
    [anon_sym_LT_LT] = ACTIONS(679),
    [anon_sym_TILDE] = ACTIONS(315),
    [anon_sym_LT] = ACTIONS(671),
    [anon_sym_LT_EQ] = ACTIONS(666),
    [anon_sym_EQ_EQ] = ACTIONS(666),
    [anon_sym_BANG_EQ] = ACTIONS(666),
    [anon_sym_GT_EQ] = ACTIONS(666),
    [anon_sym_GT] = ACTIONS(671),
    [anon_sym_LT_GT] = ACTIONS(666),
    [anon_sym_is] = ACTIONS(671),
    [sym_ellipsis] = ACTIONS(321),
    [sym_integer] = ACTIONS(323),
    [sym_float] = ACTIONS(321),
    [anon_sym_await] = ACTIONS(677),
    [sym_true] = ACTIONS(323),
    [sym_false] = ACTIONS(323),
    [sym_none] = ACTIONS(323),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_string_start] = ACTIONS(327),
  },
  [182] = {
    [sym_list_splat_pattern] = STATE(1290),
    [sym_primary_expression] = STATE(1157),
    [sym_binary_operator] = STATE(1337),
    [sym_unary_operator] = STATE(1337),
    [sym_attribute] = STATE(1337),
    [sym_subscript] = STATE(1337),
    [sym_call] = STATE(1337),
    [sym_list] = STATE(1337),
    [sym_set] = STATE(1337),
    [sym_tuple] = STATE(1337),
    [sym_dictionary] = STATE(1337),
    [sym_list_comprehension] = STATE(1337),
    [sym_dictionary_comprehension] = STATE(1337),
    [sym_set_comprehension] = STATE(1337),
    [sym_generator_expression] = STATE(1337),
    [sym_parenthesized_expression] = STATE(1337),
    [sym_concatenated_string] = STATE(1337),
    [sym_string] = STATE(1030),
    [sym_await] = STATE(1337),
    [sym_identifier] = ACTIONS(726),
    [anon_sym_DOT] = ACTIONS(279),
    [anon_sym_LPAREN] = ACTIONS(728),
    [anon_sym_RPAREN] = ACTIONS(284),
    [anon_sym_COMMA] = ACTIONS(284),
    [anon_sym_as] = ACTIONS(279),
    [anon_sym_STAR] = ACTIONS(730),
    [anon_sym_print] = ACTIONS(732),
    [anon_sym_GT_GT] = ACTIONS(277),
    [anon_sym_COLON_EQ] = ACTIONS(292),
    [anon_sym_if] = ACTIONS(279),
    [anon_sym_match] = ACTIONS(732),
    [anon_sym_async] = ACTIONS(732),
    [anon_sym_for] = ACTIONS(279),
    [anon_sym_in] = ACTIONS(279),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_exec] = ACTIONS(732),
    [anon_sym_type] = ACTIONS(734),
    [anon_sym_LBRACK] = ACTIONS(738),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_DASH] = ACTIONS(740),
    [anon_sym_PIPE] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(742),
    [anon_sym_PLUS] = ACTIONS(740),
    [anon_sym_not] = ACTIONS(279),
    [anon_sym_and] = ACTIONS(279),
    [anon_sym_or] = ACTIONS(279),
    [anon_sym_SLASH] = ACTIONS(279),
    [anon_sym_PERCENT] = ACTIONS(277),
    [anon_sym_SLASH_SLASH] = ACTIONS(277),
    [anon_sym_AMP] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [anon_sym_LT_LT] = ACTIONS(277),
    [anon_sym_TILDE] = ACTIONS(740),
    [anon_sym_LT] = ACTIONS(279),
    [anon_sym_LT_EQ] = ACTIONS(277),
    [anon_sym_EQ_EQ] = ACTIONS(277),
    [anon_sym_BANG_EQ] = ACTIONS(277),
    [anon_sym_GT_EQ] = ACTIONS(277),
    [anon_sym_GT] = ACTIONS(279),
    [anon_sym_LT_GT] = ACTIONS(277),
    [anon_sym_is] = ACTIONS(279),
    [sym_ellipsis] = ACTIONS(744),
    [sym_integer] = ACTIONS(726),
    [sym_float] = ACTIONS(744),
    [anon_sym_await] = ACTIONS(746),
    [sym_true] = ACTIONS(726),
    [sym_false] = ACTIONS(726),
    [sym_none] = ACTIONS(726),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_string_start] = ACTIONS(748),
  },
  [183] = {
    [sym_list_splat_pattern] = STATE(1432),
    [sym_primary_expression] = STATE(1090),
    [sym_binary_operator] = STATE(1306),
    [sym_unary_operator] = STATE(1306),
    [sym_attribute] = STATE(1306),
    [sym_subscript] = STATE(1306),
    [sym_call] = STATE(1306),
    [sym_list] = STATE(1306),
    [sym_set] = STATE(1306),
    [sym_tuple] = STATE(1306),
    [sym_dictionary] = STATE(1306),
    [sym_list_comprehension] = STATE(1306),
    [sym_dictionary_comprehension] = STATE(1306),
    [sym_set_comprehension] = STATE(1306),
    [sym_generator_expression] = STATE(1306),
    [sym_parenthesized_expression] = STATE(1306),
    [sym_concatenated_string] = STATE(1306),
    [sym_string] = STATE(1032),
    [sym_await] = STATE(1306),
    [sym_identifier] = ACTIONS(750),
    [anon_sym_DOT] = ACTIONS(279),
    [anon_sym_LPAREN] = ACTIONS(752),
    [anon_sym_RPAREN] = ACTIONS(277),
    [anon_sym_COMMA] = ACTIONS(277),
    [anon_sym_as] = ACTIONS(279),
    [anon_sym_STAR] = ACTIONS(754),
    [anon_sym_print] = ACTIONS(756),
    [anon_sym_GT_GT] = ACTIONS(277),
    [anon_sym_COLON_EQ] = ACTIONS(292),
    [anon_sym_if] = ACTIONS(279),
    [anon_sym_match] = ACTIONS(756),
    [anon_sym_async] = ACTIONS(756),
    [anon_sym_in] = ACTIONS(279),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_exec] = ACTIONS(756),
    [anon_sym_type] = ACTIONS(758),
    [anon_sym_EQ] = ACTIONS(736),
    [anon_sym_LBRACK] = ACTIONS(760),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_DASH] = ACTIONS(762),
    [anon_sym_PIPE] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(764),
    [anon_sym_PLUS] = ACTIONS(762),
    [anon_sym_not] = ACTIONS(279),
    [anon_sym_and] = ACTIONS(279),
    [anon_sym_or] = ACTIONS(279),
    [anon_sym_SLASH] = ACTIONS(279),
    [anon_sym_PERCENT] = ACTIONS(277),
    [anon_sym_SLASH_SLASH] = ACTIONS(277),
    [anon_sym_AMP] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [anon_sym_LT_LT] = ACTIONS(277),
    [anon_sym_TILDE] = ACTIONS(762),
    [anon_sym_LT] = ACTIONS(279),
    [anon_sym_LT_EQ] = ACTIONS(277),
    [anon_sym_EQ_EQ] = ACTIONS(277),
    [anon_sym_BANG_EQ] = ACTIONS(277),
    [anon_sym_GT_EQ] = ACTIONS(277),
    [anon_sym_GT] = ACTIONS(279),
    [anon_sym_LT_GT] = ACTIONS(277),
    [anon_sym_is] = ACTIONS(279),
    [sym_ellipsis] = ACTIONS(766),
    [sym_integer] = ACTIONS(750),
    [sym_float] = ACTIONS(766),
    [anon_sym_await] = ACTIONS(768),
    [sym_true] = ACTIONS(750),
    [sym_false] = ACTIONS(750),
    [sym_none] = ACTIONS(750),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_string_start] = ACTIONS(770),
  },
  [184] = {
    [sym_list_splat_pattern] = STATE(1470),
    [sym_primary_expression] = STATE(1189),
    [sym_binary_operator] = STATE(1450),
    [sym_unary_operator] = STATE(1450),
    [sym_attribute] = STATE(1450),
    [sym_subscript] = STATE(1450),
    [sym_call] = STATE(1450),
    [sym_list] = STATE(1450),
    [sym_set] = STATE(1450),
    [sym_tuple] = STATE(1450),
    [sym_dictionary] = STATE(1450),
    [sym_list_comprehension] = STATE(1450),
    [sym_dictionary_comprehension] = STATE(1450),
    [sym_set_comprehension] = STATE(1450),
    [sym_generator_expression] = STATE(1450),
    [sym_parenthesized_expression] = STATE(1450),
    [sym_concatenated_string] = STATE(1450),
    [sym_string] = STATE(1150),
    [sym_await] = STATE(1450),
    [sym_identifier] = ACTIONS(772),
    [anon_sym_DOT] = ACTIONS(279),
    [anon_sym_LPAREN] = ACTIONS(774),
    [anon_sym_COMMA] = ACTIONS(277),
    [anon_sym_as] = ACTIONS(279),
    [anon_sym_STAR] = ACTIONS(776),
    [anon_sym_print] = ACTIONS(778),
    [anon_sym_GT_GT] = ACTIONS(277),
    [anon_sym_if] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(277),
    [anon_sym_match] = ACTIONS(778),
    [anon_sym_async] = ACTIONS(778),
    [anon_sym_in] = ACTIONS(279),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_exec] = ACTIONS(778),
    [anon_sym_type] = ACTIONS(780),
    [anon_sym_LBRACK] = ACTIONS(782),
    [anon_sym_RBRACK] = ACTIONS(277),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_DASH] = ACTIONS(784),
    [anon_sym_PIPE] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(786),
    [anon_sym_PLUS] = ACTIONS(784),
    [anon_sym_not] = ACTIONS(279),
    [anon_sym_and] = ACTIONS(279),
    [anon_sym_or] = ACTIONS(279),
    [anon_sym_SLASH] = ACTIONS(279),
    [anon_sym_PERCENT] = ACTIONS(277),
    [anon_sym_SLASH_SLASH] = ACTIONS(277),
    [anon_sym_AMP] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [anon_sym_LT_LT] = ACTIONS(277),
    [anon_sym_TILDE] = ACTIONS(784),
    [anon_sym_LT] = ACTIONS(279),
    [anon_sym_LT_EQ] = ACTIONS(277),
    [anon_sym_EQ_EQ] = ACTIONS(277),
    [anon_sym_BANG_EQ] = ACTIONS(277),
    [anon_sym_GT_EQ] = ACTIONS(277),
    [anon_sym_GT] = ACTIONS(279),
    [anon_sym_LT_GT] = ACTIONS(277),
    [anon_sym_is] = ACTIONS(279),
    [sym_ellipsis] = ACTIONS(788),
    [sym_integer] = ACTIONS(772),
    [sym_float] = ACTIONS(788),
    [anon_sym_await] = ACTIONS(790),
    [sym_true] = ACTIONS(772),
    [sym_false] = ACTIONS(772),
    [sym_none] = ACTIONS(772),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_string_start] = ACTIONS(792),
  },
  [185] = {
    [sym_list_splat_pattern] = STATE(1290),
    [sym_primary_expression] = STATE(1157),
    [sym_binary_operator] = STATE(1337),
    [sym_unary_operator] = STATE(1337),
    [sym_attribute] = STATE(1337),
    [sym_subscript] = STATE(1337),
    [sym_call] = STATE(1337),
    [sym_list] = STATE(1337),
    [sym_set] = STATE(1337),
    [sym_tuple] = STATE(1337),
    [sym_dictionary] = STATE(1337),
    [sym_list_comprehension] = STATE(1337),
    [sym_dictionary_comprehension] = STATE(1337),
    [sym_set_comprehension] = STATE(1337),
    [sym_generator_expression] = STATE(1337),
    [sym_parenthesized_expression] = STATE(1337),
    [sym_concatenated_string] = STATE(1337),
    [sym_string] = STATE(1030),
    [sym_await] = STATE(1337),
    [sym_identifier] = ACTIONS(726),
    [anon_sym_DOT] = ACTIONS(279),
    [anon_sym_LPAREN] = ACTIONS(728),
    [anon_sym_RPAREN] = ACTIONS(277),
    [anon_sym_COMMA] = ACTIONS(277),
    [anon_sym_as] = ACTIONS(279),
    [anon_sym_STAR] = ACTIONS(730),
    [anon_sym_print] = ACTIONS(732),
    [anon_sym_GT_GT] = ACTIONS(277),
    [anon_sym_if] = ACTIONS(279),
    [anon_sym_match] = ACTIONS(732),
    [anon_sym_async] = ACTIONS(732),
    [anon_sym_for] = ACTIONS(279),
    [anon_sym_in] = ACTIONS(279),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_exec] = ACTIONS(732),
    [anon_sym_type] = ACTIONS(734),
    [anon_sym_LBRACK] = ACTIONS(738),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_DASH] = ACTIONS(740),
    [anon_sym_PIPE] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(742),
    [anon_sym_PLUS] = ACTIONS(740),
    [anon_sym_not] = ACTIONS(279),
    [anon_sym_and] = ACTIONS(279),
    [anon_sym_or] = ACTIONS(279),
    [anon_sym_SLASH] = ACTIONS(279),
    [anon_sym_PERCENT] = ACTIONS(277),
    [anon_sym_SLASH_SLASH] = ACTIONS(277),
    [anon_sym_AMP] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [anon_sym_LT_LT] = ACTIONS(277),
    [anon_sym_TILDE] = ACTIONS(740),
    [anon_sym_LT] = ACTIONS(279),
    [anon_sym_LT_EQ] = ACTIONS(277),
    [anon_sym_EQ_EQ] = ACTIONS(277),
    [anon_sym_BANG_EQ] = ACTIONS(277),
    [anon_sym_GT_EQ] = ACTIONS(277),
    [anon_sym_GT] = ACTIONS(279),
    [anon_sym_LT_GT] = ACTIONS(277),
    [anon_sym_is] = ACTIONS(279),
    [sym_ellipsis] = ACTIONS(744),
    [sym_integer] = ACTIONS(726),
    [sym_float] = ACTIONS(744),
    [anon_sym_await] = ACTIONS(746),
    [sym_true] = ACTIONS(726),
    [sym_false] = ACTIONS(726),
    [sym_none] = ACTIONS(726),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_string_start] = ACTIONS(748),
  },
  [186] = {
    [sym_list_splat_pattern] = STATE(1367),
    [sym_primary_expression] = STATE(1101),
    [sym_binary_operator] = STATE(1414),
    [sym_unary_operator] = STATE(1414),
    [sym_attribute] = STATE(1414),
    [sym_subscript] = STATE(1414),
    [sym_call] = STATE(1414),
    [sym_list] = STATE(1414),
    [sym_set] = STATE(1414),
    [sym_tuple] = STATE(1414),
    [sym_dictionary] = STATE(1414),
    [sym_list_comprehension] = STATE(1414),
    [sym_dictionary_comprehension] = STATE(1414),
    [sym_set_comprehension] = STATE(1414),
    [sym_generator_expression] = STATE(1414),
    [sym_parenthesized_expression] = STATE(1414),
    [sym_concatenated_string] = STATE(1414),
    [sym_string] = STATE(1017),
    [sym_await] = STATE(1414),
    [sym_identifier] = ACTIONS(794),
    [anon_sym_DOT] = ACTIONS(279),
    [anon_sym_LPAREN] = ACTIONS(796),
    [anon_sym_COMMA] = ACTIONS(277),
    [anon_sym_as] = ACTIONS(279),
    [anon_sym_STAR] = ACTIONS(798),
    [anon_sym_print] = ACTIONS(800),
    [anon_sym_GT_GT] = ACTIONS(277),
    [anon_sym_if] = ACTIONS(279),
    [anon_sym_match] = ACTIONS(800),
    [anon_sym_async] = ACTIONS(800),
    [anon_sym_for] = ACTIONS(279),
    [anon_sym_in] = ACTIONS(279),
    [anon_sym_STAR_STAR] = ACTIONS(277),
    [anon_sym_exec] = ACTIONS(800),
    [anon_sym_type] = ACTIONS(802),
    [anon_sym_LBRACK] = ACTIONS(804),
    [anon_sym_RBRACK] = ACTIONS(277),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_DASH] = ACTIONS(806),
    [anon_sym_PIPE] = ACTIONS(277),
    [anon_sym_LBRACE] = ACTIONS(808),
    [anon_sym_PLUS] = ACTIONS(806),
    [anon_sym_not] = ACTIONS(279),
    [anon_sym_and] = ACTIONS(279),
    [anon_sym_or] = ACTIONS(279),
    [anon_sym_SLASH] = ACTIONS(279),
    [anon_sym_PERCENT] = ACTIONS(277),
    [anon_sym_SLASH_SLASH] = ACTIONS(277),
    [anon_sym_AMP] = ACTIONS(277),
    [anon_sym_CARET] = ACTIONS(277),
    [anon_sym_LT_LT] = ACTIONS(277),
    [anon_sym_TILDE] = ACTIONS(806),
    [anon_sym_LT] = ACTIONS(279),
    [anon_sym_LT_EQ] = ACTIONS(277),
    [anon_sym_EQ_EQ] = ACTIONS(277),
    [anon_sym_BANG_EQ] = ACTIONS(277),
    [anon_sym_GT_EQ] = ACTIONS(277),
    [anon_sym_GT] = ACTIONS(279),
    [anon_sym_LT_GT] = ACTIONS(277),
    [anon_sym_is] = ACTIONS(279),
    [sym_ellipsis] = ACTIONS(810),
    [sym_integer] = ACTIONS(794),
    [sym_float] = ACTIONS(810),
    [anon_sym_await] = ACTIONS(812),
    [sym_true] = ACTIONS(794),
    [sym_false] = ACTIONS(794),
    [sym_none] = ACTIONS(794),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_string_start] = ACTIONS(814),
  },
  [187] = {
    [sym_list_splat_pattern] = STATE(1433),
    [sym_primary_expression] = STATE(1097),
    [sym_binary_operator] = STATE(1365),
    [sym_unary_operator] = STATE(1365),
    [sym_attribute] = STATE(1365),
    [sym_subscript] = STATE(1365),
    [sym_call] = STATE(1365),
    [sym_list] = STATE(1365),
    [sym_set] = STATE(1365),
    [sym_tuple] = STATE(1365),
    [sym_dictionary] = STATE(1365),
    [sym_list_comprehension] = STATE(1365),
    [sym_dictionary_comprehension] = STATE(1365),
    [sym_set_comprehension] = STATE(1365),
    [sym_generator_expression] = STATE(1365),
    [sym_parenthesized_expression] = STATE(1365),
    [sym_concatenated_string] = STATE(1365),
    [sym_string] = STATE(1004),
    [sym_await] = STATE(1365),
    [sym_identifier] = ACTIONS(323),
    [anon_sym_DOT] = ACTIONS(279),
    [anon_sym_LPAREN] = ACTIONS(408),
    [anon_sym_COMMA] = ACTIONS(319),
    [anon_sym_STAR] = ACTIONS(410),
    [anon_sym_print] = ACTIONS(673),
    [anon_sym_GT_GT] = ACTIONS(279),
    [anon_sym_COLON] = ACTIONS(319),
    [anon_sym_match] = ACTIONS(673),
    [anon_sym_async] = ACTIONS(673),
    [anon_sym_STAR_STAR] = ACTIONS(279),
    [anon_sym_exec] = ACTIONS(673),
    [anon_sym_type] = ACTIONS(675),
    [anon_sym_EQ] = ACTIONS(319),
    [anon_sym_LBRACK] = ACTIONS(412),
    [anon_sym_AT] = ACTIONS(279),
    [anon_sym_DASH] = ACTIONS(414),
    [anon_sym_PIPE] = ACTIONS(279),
    [anon_sym_LBRACE] = ACTIONS(310),
    [anon_sym_PLUS] = ACTIONS(414),
    [anon_sym_SLASH] = ACTIONS(279),
    [anon_sym_PERCENT] = ACTIONS(279),
    [anon_sym_SLASH_SLASH] = ACTIONS(279),
    [anon_sym_AMP] = ACTIONS(279),
    [anon_sym_CARET] = ACTIONS(279),
    [anon_sym_LT_LT] = ACTIONS(279),
    [anon_sym_TILDE] = ACTIONS(315),
    [anon_sym_PLUS_EQ] = ACTIONS(319),
    [anon_sym_DASH_EQ] = ACTIONS(319),
    [anon_sym_STAR_EQ] = ACTIONS(319),
    [anon_sym_SLASH_EQ] = ACTIONS(319),
    [anon_sym_AT_EQ] = ACTIONS(319),
    [anon_sym_SLASH_SLASH_EQ] = ACTIONS(319),
    [anon_sym_PERCENT_EQ] = ACTIONS(319),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(319),
    [anon_sym_GT_GT_EQ] = ACTIONS(319),
    [anon_sym_LT_LT_EQ] = ACTIONS(319),
    [anon_sym_AMP_EQ] = ACTIONS(319),
    [anon_sym_CARET_EQ] = ACTIONS(319),
    [anon_sym_PIPE_EQ] = ACTIONS(319),
    [sym_ellipsis] = ACTIONS(321),
    [sym_integer] = ACTIONS(323),
    [sym_float] = ACTIONS(321),
    [anon_sym_await] = ACTIONS(677),
    [sym_true] = ACTIONS(323),
    [sym_false] = ACTIONS(323),
    [sym_none] = ACTIONS(323),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_string_start] = ACTIONS(327),
  },
  [188] = {
    [sym_list_splat_pattern] = STATE(1433),
    [sym_primary_expression] = STATE(1097),
    [sym_binary_operator] = STATE(1365),
    [sym_unary_operator] = STATE(1365),
    [sym_attribute] = STATE(1365),
    [sym_subscript] = STATE(1365),
    [sym_call] = STATE(1365),
    [sym_list] = STATE(1365),
    [sym_set] = STATE(1365),
    [sym_tuple] = STATE(1365),
    [sym_dictionary] = STATE(1365),
    [sym_list_comprehension] = STATE(1365),
    [sym_dictionary_comprehension] = STATE(1365),
    [sym_set_comprehension] = STATE(1365),
    [sym_generator_expression] = STATE(1365),
    [sym_parenthesized_expression] = STATE(1365),
    [sym_concatenated_string] = STATE(1365),
    [sym_string] = STATE(1004),
    [sym_await] = STATE(1365),
    [sym_identifier] = ACTIONS(323),
    [anon_sym_DOT] = ACTIONS(668),
    [anon_sym_LPAREN] = ACTIONS(408),
    [anon_sym_COMMA] = ACTIONS(666),
    [anon_sym_STAR] = ACTIONS(410),
    [anon_sym_print] = ACTIONS(673),
    [anon_sym_GT_GT] = ACTIONS(668),
    [anon_sym_COLON] = ACTIONS(666),
    [anon_sym_match] = ACTIONS(673),
    [anon_sym_async] = ACTIONS(673),
    [anon_sym_STAR_STAR] = ACTIONS(668),
    [anon_sym_exec] = ACTIONS(673),
    [anon_sym_type] = ACTIONS(675),
    [anon_sym_EQ] = ACTIONS(666),
    [anon_sym_LBRACK] = ACTIONS(412),
    [anon_sym_AT] = ACTIONS(668),
    [anon_sym_DASH] = ACTIONS(414),
    [anon_sym_PIPE] = ACTIONS(668),
    [anon_sym_LBRACE] = ACTIONS(310),
    [anon_sym_PLUS] = ACTIONS(414),
    [anon_sym_SLASH] = ACTIONS(668),
    [anon_sym_PERCENT] = ACTIONS(668),
    [anon_sym_SLASH_SLASH] = ACTIONS(668),
    [anon_sym_AMP] = ACTIONS(668),
    [anon_sym_CARET] = ACTIONS(668),
    [anon_sym_LT_LT] = ACTIONS(668),
    [anon_sym_TILDE] = ACTIONS(315),
    [anon_sym_PLUS_EQ] = ACTIONS(666),
    [anon_sym_DASH_EQ] = ACTIONS(666),
    [anon_sym_STAR_EQ] = ACTIONS(666),
    [anon_sym_SLASH_EQ] = ACTIONS(666),
    [anon_sym_AT_EQ] = ACTIONS(666),
    [anon_sym_SLASH_SLASH_EQ] = ACTIONS(666),
    [anon_sym_PERCENT_EQ] = ACTIONS(666),
    [anon_sym_STAR_STAR_EQ] = ACTIONS(666),
    [anon_sym_GT_GT_EQ] = ACTIONS(666),
    [anon_sym_LT_LT_EQ] = ACTIONS(666),
    [anon_sym_AMP_EQ] = ACTIONS(666),
    [anon_sym_CARET_EQ] = ACTIONS(666),
    [anon_sym_PIPE_EQ] = ACTIONS(666),
    [sym_ellipsis] = ACTIONS(321),
    [sym_integer] = ACTIONS(323),
    [sym_float] = ACTIONS(321),
    [anon_sym_await] = ACTIONS(677),
    [sym_true] = ACTIONS(323),
    [sym_false] = ACTIONS(323),
    [sym_none] = ACTIONS(323),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_string_start] = ACTIONS(327),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 30,
    ACTIONS(808), 1,
      anon_sym_LBRACE,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(816), 1,
      sym_identifier,
    ACTIONS(818), 1,
      anon_sym_LPAREN,
    ACTIONS(820), 1,
      anon_sym_STAR,
    ACTIONS(824), 1,
      anon_sym_type,
    ACTIONS(826), 1,
      anon_sym_LBRACK,
    ACTIONS(828), 1,
      anon_sym_RBRACK,
    ACTIONS(830), 1,
      anon_sym_not,
    ACTIONS(832), 1,
      anon_sym_lambda,
    ACTIONS(834), 1,
      anon_sym_yield,
    ACTIONS(836), 1,
      anon_sym_await,
    STATE(1016), 1,
      sym_primary_expression,
    STATE(1017), 1,
      sym_string,
    STATE(1419), 1,
      sym_list_splat_pattern,
    STATE(1725), 1,
      sym_expression,
    STATE(2410), 1,
      sym_pattern,
    STATE(2702), 1,
      sym__named_expression_lhs,
    STATE(2741), 1,
      sym__patterns,
    STATE(2817), 1,
      sym__collection_elements,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      sym_ellipsis,
      sym_float,
    STATE(1421), 2,
      sym_attribute,
      sym_subscript,
    STATE(2600), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(806), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2399), 3,
      sym_list_splat,
      sym_parenthesized_list_splat,
      sym_yield,
    ACTIONS(794), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(822), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1809), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1414), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [124] = 32,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(838), 1,
      sym_identifier,
    ACTIONS(840), 1,
      anon_sym_LPAREN,
    ACTIONS(842), 1,
      anon_sym_RPAREN,
    ACTIONS(844), 1,
      anon_sym_STAR,
    ACTIONS(848), 1,
      anon_sym_type,
    ACTIONS(850), 1,
      anon_sym_LBRACK,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(854), 1,
      anon_sym_lambda,
    ACTIONS(856), 1,
      anon_sym_yield,
    ACTIONS(858), 1,
      anon_sym_await,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1341), 1,
      sym_list_splat_pattern,
    STATE(1722), 1,
      sym_expression,
    STATE(2317), 1,
      sym_yield,
    STATE(2328), 1,
      sym_parenthesized_list_splat,
    STATE(2336), 1,
      sym_list_splat,
    STATE(2384), 1,
      sym_pattern,
    STATE(2763), 1,
      sym__collection_elements,
    STATE(2769), 1,
      sym__patterns,
    STATE(2803), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    STATE(1342), 2,
      sym_attribute,
      sym_subscript,
    STATE(2574), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(846), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [252] = 31,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(838), 1,
      sym_identifier,
    ACTIONS(840), 1,
      anon_sym_LPAREN,
    ACTIONS(844), 1,
      anon_sym_STAR,
    ACTIONS(848), 1,
      anon_sym_type,
    ACTIONS(850), 1,
      anon_sym_LBRACK,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(854), 1,
      anon_sym_lambda,
    ACTIONS(856), 1,
      anon_sym_yield,
    ACTIONS(858), 1,
      anon_sym_await,
    ACTIONS(860), 1,
      anon_sym_RPAREN,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1341), 1,
      sym_list_splat_pattern,
    STATE(1707), 1,
      sym_expression,
    STATE(2384), 1,
      sym_pattern,
    STATE(2390), 1,
      sym_yield,
    STATE(2677), 1,
      sym__collection_elements,
    STATE(2689), 1,
      sym__patterns,
    STATE(2803), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    STATE(1342), 2,
      sym_attribute,
      sym_subscript,
    STATE(2269), 2,
      sym_list_splat,
      sym_parenthesized_list_splat,
    STATE(2574), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(846), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [378] = 28,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(15), 1,
      anon_sym_LPAREN,
    ACTIONS(17), 1,
      anon_sym_STAR,
    ACTIONS(61), 1,
      anon_sym_LBRACK,
    ACTIONS(67), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_not,
    ACTIONS(71), 1,
      anon_sym_lambda,
    ACTIONS(73), 1,
      anon_sym_yield,
    ACTIONS(79), 1,
      anon_sym_await,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(862), 1,
      anon_sym_type,
    STATE(635), 1,
      sym_list_splat_pattern,
    STATE(975), 1,
      sym_string,
    STATE(1013), 1,
      sym_primary_expression,
    STATE(1666), 1,
      sym_pattern_list,
    STATE(1670), 1,
      sym_pattern,
    STATE(1858), 1,
      sym_expression,
    STATE(2782), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(75), 2,
      sym_ellipsis,
      sym_float,
    STATE(637), 2,
      sym_attribute,
      sym_subscript,
    STATE(1668), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(65), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(77), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(418), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(2529), 5,
      sym_expression_list,
      sym_assignment,
      sym_augmented_assignment,
      sym__right_hand_side,
      sym_yield,
    STATE(1687), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1057), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [498] = 31,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(838), 1,
      sym_identifier,
    ACTIONS(840), 1,
      anon_sym_LPAREN,
    ACTIONS(844), 1,
      anon_sym_STAR,
    ACTIONS(848), 1,
      anon_sym_type,
    ACTIONS(850), 1,
      anon_sym_LBRACK,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(854), 1,
      anon_sym_lambda,
    ACTIONS(856), 1,
      anon_sym_yield,
    ACTIONS(858), 1,
      anon_sym_await,
    ACTIONS(864), 1,
      anon_sym_RPAREN,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1341), 1,
      sym_list_splat_pattern,
    STATE(1719), 1,
      sym_expression,
    STATE(2379), 1,
      sym_yield,
    STATE(2384), 1,
      sym_pattern,
    STATE(2700), 1,
      sym__patterns,
    STATE(2803), 1,
      sym__named_expression_lhs,
    STATE(2826), 1,
      sym__collection_elements,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    STATE(1342), 2,
      sym_attribute,
      sym_subscript,
    STATE(2269), 2,
      sym_list_splat,
      sym_parenthesized_list_splat,
    STATE(2574), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(846), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [624] = 30,
    ACTIONS(808), 1,
      anon_sym_LBRACE,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(816), 1,
      sym_identifier,
    ACTIONS(818), 1,
      anon_sym_LPAREN,
    ACTIONS(820), 1,
      anon_sym_STAR,
    ACTIONS(824), 1,
      anon_sym_type,
    ACTIONS(826), 1,
      anon_sym_LBRACK,
    ACTIONS(830), 1,
      anon_sym_not,
    ACTIONS(832), 1,
      anon_sym_lambda,
    ACTIONS(834), 1,
      anon_sym_yield,
    ACTIONS(836), 1,
      anon_sym_await,
    ACTIONS(866), 1,
      anon_sym_RBRACK,
    STATE(1016), 1,
      sym_primary_expression,
    STATE(1017), 1,
      sym_string,
    STATE(1419), 1,
      sym_list_splat_pattern,
    STATE(1725), 1,
      sym_expression,
    STATE(2410), 1,
      sym_pattern,
    STATE(2702), 1,
      sym__named_expression_lhs,
    STATE(2762), 1,
      sym__patterns,
    STATE(2817), 1,
      sym__collection_elements,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      sym_ellipsis,
      sym_float,
    STATE(1421), 2,
      sym_attribute,
      sym_subscript,
    STATE(2600), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(806), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2399), 3,
      sym_list_splat,
      sym_parenthesized_list_splat,
      sym_yield,
    ACTIONS(794), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(822), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1809), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1414), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [748] = 30,
    ACTIONS(714), 1,
      anon_sym_LBRACK,
    ACTIONS(718), 1,
      anon_sym_LBRACE,
    ACTIONS(724), 1,
      sym_string_start,
    ACTIONS(868), 1,
      sym_identifier,
    ACTIONS(870), 1,
      anon_sym_LPAREN,
    ACTIONS(872), 1,
      anon_sym_COMMA,
    ACTIONS(874), 1,
      anon_sym_STAR,
    ACTIONS(878), 1,
      anon_sym_STAR_STAR,
    ACTIONS(880), 1,
      anon_sym_type,
    ACTIONS(882), 1,
      anon_sym_RBRACE,
    ACTIONS(884), 1,
      anon_sym_not,
    ACTIONS(886), 1,
      anon_sym_lambda,
    ACTIONS(888), 1,
      anon_sym_yield,
    ACTIONS(890), 1,
      anon_sym_await,
    STATE(993), 1,
      sym_string,
    STATE(994), 1,
      sym_primary_expression,
    STATE(1218), 1,
      sym_list_splat_pattern,
    STATE(1695), 1,
      sym_expression,
    STATE(1876), 1,
      sym_pair,
    STATE(2470), 1,
      sym_dictionary_splat,
    STATE(2685), 1,
      sym__named_expression_lhs,
    STATE(2719), 1,
      sym__collection_elements,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(720), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(716), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2364), 3,
      sym_list_splat,
      sym_parenthesized_list_splat,
      sym_yield,
    ACTIONS(704), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(876), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1768), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1169), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [872] = 30,
    ACTIONS(808), 1,
      anon_sym_LBRACE,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(816), 1,
      sym_identifier,
    ACTIONS(818), 1,
      anon_sym_LPAREN,
    ACTIONS(820), 1,
      anon_sym_STAR,
    ACTIONS(824), 1,
      anon_sym_type,
    ACTIONS(826), 1,
      anon_sym_LBRACK,
    ACTIONS(830), 1,
      anon_sym_not,
    ACTIONS(832), 1,
      anon_sym_lambda,
    ACTIONS(834), 1,
      anon_sym_yield,
    ACTIONS(836), 1,
      anon_sym_await,
    ACTIONS(892), 1,
      anon_sym_RBRACK,
    STATE(1016), 1,
      sym_primary_expression,
    STATE(1017), 1,
      sym_string,
    STATE(1419), 1,
      sym_list_splat_pattern,
    STATE(1701), 1,
      sym_expression,
    STATE(2410), 1,
      sym_pattern,
    STATE(2702), 1,
      sym__named_expression_lhs,
    STATE(2762), 1,
      sym__patterns,
    STATE(2767), 1,
      sym__collection_elements,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      sym_ellipsis,
      sym_float,
    STATE(1421), 2,
      sym_attribute,
      sym_subscript,
    STATE(2600), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(806), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2399), 3,
      sym_list_splat,
      sym_parenthesized_list_splat,
      sym_yield,
    ACTIONS(794), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(822), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1809), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1414), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [996] = 30,
    ACTIONS(714), 1,
      anon_sym_LBRACK,
    ACTIONS(718), 1,
      anon_sym_LBRACE,
    ACTIONS(724), 1,
      sym_string_start,
    ACTIONS(868), 1,
      sym_identifier,
    ACTIONS(870), 1,
      anon_sym_LPAREN,
    ACTIONS(874), 1,
      anon_sym_STAR,
    ACTIONS(878), 1,
      anon_sym_STAR_STAR,
    ACTIONS(880), 1,
      anon_sym_type,
    ACTIONS(884), 1,
      anon_sym_not,
    ACTIONS(886), 1,
      anon_sym_lambda,
    ACTIONS(888), 1,
      anon_sym_yield,
    ACTIONS(890), 1,
      anon_sym_await,
    ACTIONS(894), 1,
      anon_sym_COMMA,
    ACTIONS(896), 1,
      anon_sym_RBRACE,
    STATE(993), 1,
      sym_string,
    STATE(994), 1,
      sym_primary_expression,
    STATE(1218), 1,
      sym_list_splat_pattern,
    STATE(1694), 1,
      sym_expression,
    STATE(1862), 1,
      sym_pair,
    STATE(2518), 1,
      sym_dictionary_splat,
    STATE(2685), 1,
      sym__named_expression_lhs,
    STATE(2755), 1,
      sym__collection_elements,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(720), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(716), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2364), 3,
      sym_list_splat,
      sym_parenthesized_list_splat,
      sym_yield,
    ACTIONS(704), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(876), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1768), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1169), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [1120] = 30,
    ACTIONS(714), 1,
      anon_sym_LBRACK,
    ACTIONS(718), 1,
      anon_sym_LBRACE,
    ACTIONS(724), 1,
      sym_string_start,
    ACTIONS(868), 1,
      sym_identifier,
    ACTIONS(870), 1,
      anon_sym_LPAREN,
    ACTIONS(874), 1,
      anon_sym_STAR,
    ACTIONS(878), 1,
      anon_sym_STAR_STAR,
    ACTIONS(880), 1,
      anon_sym_type,
    ACTIONS(884), 1,
      anon_sym_not,
    ACTIONS(886), 1,
      anon_sym_lambda,
    ACTIONS(888), 1,
      anon_sym_yield,
    ACTIONS(890), 1,
      anon_sym_await,
    ACTIONS(898), 1,
      anon_sym_COMMA,
    ACTIONS(900), 1,
      anon_sym_RBRACE,
    STATE(993), 1,
      sym_string,
    STATE(994), 1,
      sym_primary_expression,
    STATE(1218), 1,
      sym_list_splat_pattern,
    STATE(1700), 1,
      sym_expression,
    STATE(1905), 1,
      sym_pair,
    STATE(2517), 1,
      sym_dictionary_splat,
    STATE(2685), 1,
      sym__named_expression_lhs,
    STATE(2814), 1,
      sym__collection_elements,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(720), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(716), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2364), 3,
      sym_list_splat,
      sym_parenthesized_list_splat,
      sym_yield,
    ACTIONS(704), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(876), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1768), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1169), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [1244] = 30,
    ACTIONS(808), 1,
      anon_sym_LBRACE,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(816), 1,
      sym_identifier,
    ACTIONS(818), 1,
      anon_sym_LPAREN,
    ACTIONS(820), 1,
      anon_sym_STAR,
    ACTIONS(824), 1,
      anon_sym_type,
    ACTIONS(826), 1,
      anon_sym_LBRACK,
    ACTIONS(830), 1,
      anon_sym_not,
    ACTIONS(832), 1,
      anon_sym_lambda,
    ACTIONS(834), 1,
      anon_sym_yield,
    ACTIONS(836), 1,
      anon_sym_await,
    ACTIONS(902), 1,
      anon_sym_RBRACK,
    STATE(1016), 1,
      sym_primary_expression,
    STATE(1017), 1,
      sym_string,
    STATE(1419), 1,
      sym_list_splat_pattern,
    STATE(1701), 1,
      sym_expression,
    STATE(2410), 1,
      sym_pattern,
    STATE(2702), 1,
      sym__named_expression_lhs,
    STATE(2762), 1,
      sym__patterns,
    STATE(2767), 1,
      sym__collection_elements,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      sym_ellipsis,
      sym_float,
    STATE(1421), 2,
      sym_attribute,
      sym_subscript,
    STATE(2600), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(806), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2399), 3,
      sym_list_splat,
      sym_parenthesized_list_splat,
      sym_yield,
    ACTIONS(794), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(822), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1809), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1414), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [1368] = 30,
    ACTIONS(714), 1,
      anon_sym_LBRACK,
    ACTIONS(718), 1,
      anon_sym_LBRACE,
    ACTIONS(724), 1,
      sym_string_start,
    ACTIONS(868), 1,
      sym_identifier,
    ACTIONS(870), 1,
      anon_sym_LPAREN,
    ACTIONS(874), 1,
      anon_sym_STAR,
    ACTIONS(878), 1,
      anon_sym_STAR_STAR,
    ACTIONS(880), 1,
      anon_sym_type,
    ACTIONS(884), 1,
      anon_sym_not,
    ACTIONS(886), 1,
      anon_sym_lambda,
    ACTIONS(888), 1,
      anon_sym_yield,
    ACTIONS(890), 1,
      anon_sym_await,
    ACTIONS(904), 1,
      anon_sym_COMMA,
    ACTIONS(906), 1,
      anon_sym_RBRACE,
    STATE(993), 1,
      sym_string,
    STATE(994), 1,
      sym_primary_expression,
    STATE(1218), 1,
      sym_list_splat_pattern,
    STATE(1684), 1,
      sym_expression,
    STATE(1892), 1,
      sym_pair,
    STATE(2476), 1,
      sym_dictionary_splat,
    STATE(2685), 1,
      sym__named_expression_lhs,
    STATE(2743), 1,
      sym__collection_elements,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(720), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(716), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2364), 3,
      sym_list_splat,
      sym_parenthesized_list_splat,
      sym_yield,
    ACTIONS(704), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(876), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1768), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1169), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [1492] = 32,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(838), 1,
      sym_identifier,
    ACTIONS(840), 1,
      anon_sym_LPAREN,
    ACTIONS(844), 1,
      anon_sym_STAR,
    ACTIONS(848), 1,
      anon_sym_type,
    ACTIONS(850), 1,
      anon_sym_LBRACK,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(854), 1,
      anon_sym_lambda,
    ACTIONS(856), 1,
      anon_sym_yield,
    ACTIONS(858), 1,
      anon_sym_await,
    ACTIONS(908), 1,
      anon_sym_RPAREN,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1341), 1,
      sym_list_splat_pattern,
    STATE(1712), 1,
      sym_expression,
    STATE(2371), 1,
      sym_yield,
    STATE(2384), 1,
      sym_pattern,
    STATE(2397), 1,
      sym_list_splat,
    STATE(2400), 1,
      sym_parenthesized_list_splat,
    STATE(2698), 1,
      sym__collection_elements,
    STATE(2781), 1,
      sym__patterns,
    STATE(2803), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    STATE(1342), 2,
      sym_attribute,
      sym_subscript,
    STATE(2574), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(846), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [1620] = 30,
    ACTIONS(808), 1,
      anon_sym_LBRACE,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(816), 1,
      sym_identifier,
    ACTIONS(818), 1,
      anon_sym_LPAREN,
    ACTIONS(820), 1,
      anon_sym_STAR,
    ACTIONS(824), 1,
      anon_sym_type,
    ACTIONS(826), 1,
      anon_sym_LBRACK,
    ACTIONS(830), 1,
      anon_sym_not,
    ACTIONS(832), 1,
      anon_sym_lambda,
    ACTIONS(834), 1,
      anon_sym_yield,
    ACTIONS(836), 1,
      anon_sym_await,
    ACTIONS(910), 1,
      anon_sym_RBRACK,
    STATE(1016), 1,
      sym_primary_expression,
    STATE(1017), 1,
      sym_string,
    STATE(1419), 1,
      sym_list_splat_pattern,
    STATE(1725), 1,
      sym_expression,
    STATE(2410), 1,
      sym_pattern,
    STATE(2702), 1,
      sym__named_expression_lhs,
    STATE(2740), 1,
      sym__patterns,
    STATE(2817), 1,
      sym__collection_elements,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      sym_ellipsis,
      sym_float,
    STATE(1421), 2,
      sym_attribute,
      sym_subscript,
    STATE(2600), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(806), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2399), 3,
      sym_list_splat,
      sym_parenthesized_list_splat,
      sym_yield,
    ACTIONS(794), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(822), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1809), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1414), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [1744] = 30,
    ACTIONS(808), 1,
      anon_sym_LBRACE,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(816), 1,
      sym_identifier,
    ACTIONS(818), 1,
      anon_sym_LPAREN,
    ACTIONS(820), 1,
      anon_sym_STAR,
    ACTIONS(824), 1,
      anon_sym_type,
    ACTIONS(826), 1,
      anon_sym_LBRACK,
    ACTIONS(830), 1,
      anon_sym_not,
    ACTIONS(832), 1,
      anon_sym_lambda,
    ACTIONS(834), 1,
      anon_sym_yield,
    ACTIONS(836), 1,
      anon_sym_await,
    ACTIONS(912), 1,
      anon_sym_RBRACK,
    STATE(1016), 1,
      sym_primary_expression,
    STATE(1017), 1,
      sym_string,
    STATE(1419), 1,
      sym_list_splat_pattern,
    STATE(1702), 1,
      sym_expression,
    STATE(2410), 1,
      sym_pattern,
    STATE(2702), 1,
      sym__named_expression_lhs,
    STATE(2762), 1,
      sym__patterns,
    STATE(2829), 1,
      sym__collection_elements,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      sym_ellipsis,
      sym_float,
    STATE(1421), 2,
      sym_attribute,
      sym_subscript,
    STATE(2600), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(806), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2399), 3,
      sym_list_splat,
      sym_parenthesized_list_splat,
      sym_yield,
    ACTIONS(794), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(822), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1809), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1414), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [1868] = 30,
    ACTIONS(714), 1,
      anon_sym_LBRACK,
    ACTIONS(718), 1,
      anon_sym_LBRACE,
    ACTIONS(724), 1,
      sym_string_start,
    ACTIONS(868), 1,
      sym_identifier,
    ACTIONS(870), 1,
      anon_sym_LPAREN,
    ACTIONS(874), 1,
      anon_sym_STAR,
    ACTIONS(878), 1,
      anon_sym_STAR_STAR,
    ACTIONS(880), 1,
      anon_sym_type,
    ACTIONS(884), 1,
      anon_sym_not,
    ACTIONS(886), 1,
      anon_sym_lambda,
    ACTIONS(888), 1,
      anon_sym_yield,
    ACTIONS(890), 1,
      anon_sym_await,
    ACTIONS(914), 1,
      anon_sym_COMMA,
    ACTIONS(916), 1,
      anon_sym_RBRACE,
    STATE(993), 1,
      sym_string,
    STATE(994), 1,
      sym_primary_expression,
    STATE(1218), 1,
      sym_list_splat_pattern,
    STATE(1698), 1,
      sym_expression,
    STATE(1890), 1,
      sym_pair,
    STATE(2359), 1,
      sym_dictionary_splat,
    STATE(2685), 1,
      sym__named_expression_lhs,
    STATE(2705), 1,
      sym__collection_elements,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(720), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(716), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2364), 3,
      sym_list_splat,
      sym_parenthesized_list_splat,
      sym_yield,
    ACTIONS(704), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(876), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1768), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1169), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [1992] = 30,
    ACTIONS(714), 1,
      anon_sym_LBRACK,
    ACTIONS(718), 1,
      anon_sym_LBRACE,
    ACTIONS(724), 1,
      sym_string_start,
    ACTIONS(868), 1,
      sym_identifier,
    ACTIONS(870), 1,
      anon_sym_LPAREN,
    ACTIONS(874), 1,
      anon_sym_STAR,
    ACTIONS(878), 1,
      anon_sym_STAR_STAR,
    ACTIONS(880), 1,
      anon_sym_type,
    ACTIONS(884), 1,
      anon_sym_not,
    ACTIONS(886), 1,
      anon_sym_lambda,
    ACTIONS(888), 1,
      anon_sym_yield,
    ACTIONS(890), 1,
      anon_sym_await,
    ACTIONS(918), 1,
      anon_sym_COMMA,
    ACTIONS(920), 1,
      anon_sym_RBRACE,
    STATE(993), 1,
      sym_string,
    STATE(994), 1,
      sym_primary_expression,
    STATE(1218), 1,
      sym_list_splat_pattern,
    STATE(1691), 1,
      sym_expression,
    STATE(1909), 1,
      sym_pair,
    STATE(2381), 1,
      sym_dictionary_splat,
    STATE(2685), 1,
      sym__named_expression_lhs,
    STATE(2687), 1,
      sym__collection_elements,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(720), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(716), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2364), 3,
      sym_list_splat,
      sym_parenthesized_list_splat,
      sym_yield,
    ACTIONS(704), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(876), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1768), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1169), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [2116] = 30,
    ACTIONS(808), 1,
      anon_sym_LBRACE,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(816), 1,
      sym_identifier,
    ACTIONS(818), 1,
      anon_sym_LPAREN,
    ACTIONS(820), 1,
      anon_sym_STAR,
    ACTIONS(824), 1,
      anon_sym_type,
    ACTIONS(826), 1,
      anon_sym_LBRACK,
    ACTIONS(830), 1,
      anon_sym_not,
    ACTIONS(832), 1,
      anon_sym_lambda,
    ACTIONS(834), 1,
      anon_sym_yield,
    ACTIONS(836), 1,
      anon_sym_await,
    ACTIONS(922), 1,
      anon_sym_RBRACK,
    STATE(1016), 1,
      sym_primary_expression,
    STATE(1017), 1,
      sym_string,
    STATE(1419), 1,
      sym_list_splat_pattern,
    STATE(1723), 1,
      sym_expression,
    STATE(2410), 1,
      sym_pattern,
    STATE(2691), 1,
      sym__collection_elements,
    STATE(2702), 1,
      sym__named_expression_lhs,
    STATE(2818), 1,
      sym__patterns,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      sym_ellipsis,
      sym_float,
    STATE(1421), 2,
      sym_attribute,
      sym_subscript,
    STATE(2600), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(806), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2399), 3,
      sym_list_splat,
      sym_parenthesized_list_splat,
      sym_yield,
    ACTIONS(794), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(822), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1809), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1414), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [2240] = 31,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(838), 1,
      sym_identifier,
    ACTIONS(840), 1,
      anon_sym_LPAREN,
    ACTIONS(844), 1,
      anon_sym_STAR,
    ACTIONS(848), 1,
      anon_sym_type,
    ACTIONS(850), 1,
      anon_sym_LBRACK,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(854), 1,
      anon_sym_lambda,
    ACTIONS(856), 1,
      anon_sym_yield,
    ACTIONS(858), 1,
      anon_sym_await,
    ACTIONS(924), 1,
      anon_sym_RPAREN,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1341), 1,
      sym_list_splat_pattern,
    STATE(1719), 1,
      sym_expression,
    STATE(2379), 1,
      sym_yield,
    STATE(2384), 1,
      sym_pattern,
    STATE(2769), 1,
      sym__patterns,
    STATE(2803), 1,
      sym__named_expression_lhs,
    STATE(2826), 1,
      sym__collection_elements,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    STATE(1342), 2,
      sym_attribute,
      sym_subscript,
    STATE(2269), 2,
      sym_list_splat,
      sym_parenthesized_list_splat,
    STATE(2574), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(846), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [2366] = 31,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(838), 1,
      sym_identifier,
    ACTIONS(840), 1,
      anon_sym_LPAREN,
    ACTIONS(844), 1,
      anon_sym_STAR,
    ACTIONS(848), 1,
      anon_sym_type,
    ACTIONS(850), 1,
      anon_sym_LBRACK,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(854), 1,
      anon_sym_lambda,
    ACTIONS(856), 1,
      anon_sym_yield,
    ACTIONS(858), 1,
      anon_sym_await,
    ACTIONS(926), 1,
      anon_sym_RPAREN,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1341), 1,
      sym_list_splat_pattern,
    STATE(1713), 1,
      sym_expression,
    STATE(2384), 1,
      sym_pattern,
    STATE(2527), 1,
      sym_yield,
    STATE(2689), 1,
      sym__patterns,
    STATE(2754), 1,
      sym__collection_elements,
    STATE(2803), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    STATE(1342), 2,
      sym_attribute,
      sym_subscript,
    STATE(2269), 2,
      sym_list_splat,
      sym_parenthesized_list_splat,
    STATE(2574), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(846), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [2492] = 30,
    ACTIONS(808), 1,
      anon_sym_LBRACE,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(816), 1,
      sym_identifier,
    ACTIONS(818), 1,
      anon_sym_LPAREN,
    ACTIONS(820), 1,
      anon_sym_STAR,
    ACTIONS(824), 1,
      anon_sym_type,
    ACTIONS(826), 1,
      anon_sym_LBRACK,
    ACTIONS(830), 1,
      anon_sym_not,
    ACTIONS(832), 1,
      anon_sym_lambda,
    ACTIONS(834), 1,
      anon_sym_yield,
    ACTIONS(836), 1,
      anon_sym_await,
    ACTIONS(928), 1,
      anon_sym_RBRACK,
    STATE(1016), 1,
      sym_primary_expression,
    STATE(1017), 1,
      sym_string,
    STATE(1419), 1,
      sym_list_splat_pattern,
    STATE(1703), 1,
      sym_expression,
    STATE(2410), 1,
      sym_pattern,
    STATE(2702), 1,
      sym__named_expression_lhs,
    STATE(2738), 1,
      sym__collection_elements,
    STATE(2741), 1,
      sym__patterns,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      sym_ellipsis,
      sym_float,
    STATE(1421), 2,
      sym_attribute,
      sym_subscript,
    STATE(2600), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(806), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2399), 3,
      sym_list_splat,
      sym_parenthesized_list_splat,
      sym_yield,
    ACTIONS(794), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(822), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1809), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1414), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [2616] = 31,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(838), 1,
      sym_identifier,
    ACTIONS(840), 1,
      anon_sym_LPAREN,
    ACTIONS(844), 1,
      anon_sym_STAR,
    ACTIONS(848), 1,
      anon_sym_type,
    ACTIONS(850), 1,
      anon_sym_LBRACK,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(854), 1,
      anon_sym_lambda,
    ACTIONS(856), 1,
      anon_sym_yield,
    ACTIONS(858), 1,
      anon_sym_await,
    ACTIONS(930), 1,
      anon_sym_RPAREN,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1341), 1,
      sym_list_splat_pattern,
    STATE(1719), 1,
      sym_expression,
    STATE(2379), 1,
      sym_yield,
    STATE(2384), 1,
      sym_pattern,
    STATE(2689), 1,
      sym__patterns,
    STATE(2803), 1,
      sym__named_expression_lhs,
    STATE(2826), 1,
      sym__collection_elements,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    STATE(1342), 2,
      sym_attribute,
      sym_subscript,
    STATE(2269), 2,
      sym_list_splat,
      sym_parenthesized_list_splat,
    STATE(2574), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(846), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [2742] = 30,
    ACTIONS(808), 1,
      anon_sym_LBRACE,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(816), 1,
      sym_identifier,
    ACTIONS(818), 1,
      anon_sym_LPAREN,
    ACTIONS(820), 1,
      anon_sym_STAR,
    ACTIONS(824), 1,
      anon_sym_type,
    ACTIONS(826), 1,
      anon_sym_LBRACK,
    ACTIONS(830), 1,
      anon_sym_not,
    ACTIONS(832), 1,
      anon_sym_lambda,
    ACTIONS(834), 1,
      anon_sym_yield,
    ACTIONS(836), 1,
      anon_sym_await,
    ACTIONS(932), 1,
      anon_sym_RBRACK,
    STATE(1016), 1,
      sym_primary_expression,
    STATE(1017), 1,
      sym_string,
    STATE(1419), 1,
      sym_list_splat_pattern,
    STATE(1725), 1,
      sym_expression,
    STATE(2410), 1,
      sym_pattern,
    STATE(2702), 1,
      sym__named_expression_lhs,
    STATE(2762), 1,
      sym__patterns,
    STATE(2817), 1,
      sym__collection_elements,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      sym_ellipsis,
      sym_float,
    STATE(1421), 2,
      sym_attribute,
      sym_subscript,
    STATE(2600), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(806), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2399), 3,
      sym_list_splat,
      sym_parenthesized_list_splat,
      sym_yield,
    ACTIONS(794), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(822), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1809), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1414), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [2866] = 30,
    ACTIONS(714), 1,
      anon_sym_LBRACK,
    ACTIONS(718), 1,
      anon_sym_LBRACE,
    ACTIONS(724), 1,
      sym_string_start,
    ACTIONS(868), 1,
      sym_identifier,
    ACTIONS(870), 1,
      anon_sym_LPAREN,
    ACTIONS(874), 1,
      anon_sym_STAR,
    ACTIONS(878), 1,
      anon_sym_STAR_STAR,
    ACTIONS(880), 1,
      anon_sym_type,
    ACTIONS(884), 1,
      anon_sym_not,
    ACTIONS(886), 1,
      anon_sym_lambda,
    ACTIONS(888), 1,
      anon_sym_yield,
    ACTIONS(890), 1,
      anon_sym_await,
    ACTIONS(934), 1,
      anon_sym_COMMA,
    ACTIONS(936), 1,
      anon_sym_RBRACE,
    STATE(993), 1,
      sym_string,
    STATE(994), 1,
      sym_primary_expression,
    STATE(1218), 1,
      sym_list_splat_pattern,
    STATE(1686), 1,
      sym_expression,
    STATE(1896), 1,
      sym_pair,
    STATE(2276), 1,
      sym_dictionary_splat,
    STATE(2685), 1,
      sym__named_expression_lhs,
    STATE(2813), 1,
      sym__collection_elements,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(720), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(716), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2364), 3,
      sym_list_splat,
      sym_parenthesized_list_splat,
      sym_yield,
    ACTIONS(704), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(876), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1768), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1169), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [2990] = 31,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(838), 1,
      sym_identifier,
    ACTIONS(840), 1,
      anon_sym_LPAREN,
    ACTIONS(844), 1,
      anon_sym_STAR,
    ACTIONS(848), 1,
      anon_sym_type,
    ACTIONS(850), 1,
      anon_sym_LBRACK,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(854), 1,
      anon_sym_lambda,
    ACTIONS(856), 1,
      anon_sym_yield,
    ACTIONS(858), 1,
      anon_sym_await,
    ACTIONS(938), 1,
      anon_sym_RPAREN,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1341), 1,
      sym_list_splat_pattern,
    STATE(1719), 1,
      sym_expression,
    STATE(2379), 1,
      sym_yield,
    STATE(2384), 1,
      sym_pattern,
    STATE(2689), 1,
      sym__patterns,
    STATE(2803), 1,
      sym__named_expression_lhs,
    STATE(2826), 1,
      sym__collection_elements,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    STATE(1342), 2,
      sym_attribute,
      sym_subscript,
    STATE(2269), 2,
      sym_list_splat,
      sym_parenthesized_list_splat,
    STATE(2574), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(846), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [3116] = 30,
    ACTIONS(808), 1,
      anon_sym_LBRACE,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(816), 1,
      sym_identifier,
    ACTIONS(818), 1,
      anon_sym_LPAREN,
    ACTIONS(820), 1,
      anon_sym_STAR,
    ACTIONS(824), 1,
      anon_sym_type,
    ACTIONS(826), 1,
      anon_sym_LBRACK,
    ACTIONS(830), 1,
      anon_sym_not,
    ACTIONS(832), 1,
      anon_sym_lambda,
    ACTIONS(834), 1,
      anon_sym_yield,
    ACTIONS(836), 1,
      anon_sym_await,
    ACTIONS(940), 1,
      anon_sym_RBRACK,
    STATE(1016), 1,
      sym_primary_expression,
    STATE(1017), 1,
      sym_string,
    STATE(1419), 1,
      sym_list_splat_pattern,
    STATE(1725), 1,
      sym_expression,
    STATE(2410), 1,
      sym_pattern,
    STATE(2695), 1,
      sym__patterns,
    STATE(2702), 1,
      sym__named_expression_lhs,
    STATE(2817), 1,
      sym__collection_elements,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      sym_ellipsis,
      sym_float,
    STATE(1421), 2,
      sym_attribute,
      sym_subscript,
    STATE(2600), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(806), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2399), 3,
      sym_list_splat,
      sym_parenthesized_list_splat,
      sym_yield,
    ACTIONS(794), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(822), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1809), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1414), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [3240] = 31,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(838), 1,
      sym_identifier,
    ACTIONS(840), 1,
      anon_sym_LPAREN,
    ACTIONS(844), 1,
      anon_sym_STAR,
    ACTIONS(848), 1,
      anon_sym_type,
    ACTIONS(850), 1,
      anon_sym_LBRACK,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(854), 1,
      anon_sym_lambda,
    ACTIONS(856), 1,
      anon_sym_yield,
    ACTIONS(858), 1,
      anon_sym_await,
    ACTIONS(942), 1,
      anon_sym_RPAREN,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1341), 1,
      sym_list_splat_pattern,
    STATE(1707), 1,
      sym_expression,
    STATE(2384), 1,
      sym_pattern,
    STATE(2390), 1,
      sym_yield,
    STATE(2677), 1,
      sym__collection_elements,
    STATE(2689), 1,
      sym__patterns,
    STATE(2803), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    STATE(1342), 2,
      sym_attribute,
      sym_subscript,
    STATE(2269), 2,
      sym_list_splat,
      sym_parenthesized_list_splat,
    STATE(2574), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(846), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [3366] = 28,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(15), 1,
      anon_sym_LPAREN,
    ACTIONS(17), 1,
      anon_sym_STAR,
    ACTIONS(61), 1,
      anon_sym_LBRACK,
    ACTIONS(67), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_not,
    ACTIONS(71), 1,
      anon_sym_lambda,
    ACTIONS(73), 1,
      anon_sym_yield,
    ACTIONS(79), 1,
      anon_sym_await,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(862), 1,
      anon_sym_type,
    STATE(635), 1,
      sym_list_splat_pattern,
    STATE(975), 1,
      sym_string,
    STATE(1013), 1,
      sym_primary_expression,
    STATE(1666), 1,
      sym_pattern_list,
    STATE(1670), 1,
      sym_pattern,
    STATE(1858), 1,
      sym_expression,
    STATE(2782), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(75), 2,
      sym_ellipsis,
      sym_float,
    STATE(637), 2,
      sym_attribute,
      sym_subscript,
    STATE(1668), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(65), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(77), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(418), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(2607), 5,
      sym_expression_list,
      sym_assignment,
      sym_augmented_assignment,
      sym__right_hand_side,
      sym_yield,
    STATE(1687), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1057), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [3486] = 31,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(838), 1,
      sym_identifier,
    ACTIONS(840), 1,
      anon_sym_LPAREN,
    ACTIONS(844), 1,
      anon_sym_STAR,
    ACTIONS(848), 1,
      anon_sym_type,
    ACTIONS(850), 1,
      anon_sym_LBRACK,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(854), 1,
      anon_sym_lambda,
    ACTIONS(856), 1,
      anon_sym_yield,
    ACTIONS(858), 1,
      anon_sym_await,
    ACTIONS(944), 1,
      anon_sym_RPAREN,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1341), 1,
      sym_list_splat_pattern,
    STATE(1719), 1,
      sym_expression,
    STATE(2379), 1,
      sym_yield,
    STATE(2384), 1,
      sym_pattern,
    STATE(2781), 1,
      sym__patterns,
    STATE(2803), 1,
      sym__named_expression_lhs,
    STATE(2826), 1,
      sym__collection_elements,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    STATE(1342), 2,
      sym_attribute,
      sym_subscript,
    STATE(2269), 2,
      sym_list_splat,
      sym_parenthesized_list_splat,
    STATE(2574), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(846), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [3612] = 30,
    ACTIONS(714), 1,
      anon_sym_LBRACK,
    ACTIONS(718), 1,
      anon_sym_LBRACE,
    ACTIONS(724), 1,
      sym_string_start,
    ACTIONS(868), 1,
      sym_identifier,
    ACTIONS(870), 1,
      anon_sym_LPAREN,
    ACTIONS(874), 1,
      anon_sym_STAR,
    ACTIONS(878), 1,
      anon_sym_STAR_STAR,
    ACTIONS(880), 1,
      anon_sym_type,
    ACTIONS(884), 1,
      anon_sym_not,
    ACTIONS(886), 1,
      anon_sym_lambda,
    ACTIONS(888), 1,
      anon_sym_yield,
    ACTIONS(890), 1,
      anon_sym_await,
    ACTIONS(946), 1,
      anon_sym_COMMA,
    ACTIONS(948), 1,
      anon_sym_RBRACE,
    STATE(993), 1,
      sym_string,
    STATE(994), 1,
      sym_primary_expression,
    STATE(1218), 1,
      sym_list_splat_pattern,
    STATE(1690), 1,
      sym_expression,
    STATE(1886), 1,
      sym_pair,
    STATE(2423), 1,
      sym_dictionary_splat,
    STATE(2644), 1,
      sym__collection_elements,
    STATE(2685), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(720), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(716), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2364), 3,
      sym_list_splat,
      sym_parenthesized_list_splat,
      sym_yield,
    ACTIONS(704), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(876), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1768), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1169), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [3736] = 30,
    ACTIONS(808), 1,
      anon_sym_LBRACE,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(816), 1,
      sym_identifier,
    ACTIONS(818), 1,
      anon_sym_LPAREN,
    ACTIONS(820), 1,
      anon_sym_STAR,
    ACTIONS(824), 1,
      anon_sym_type,
    ACTIONS(826), 1,
      anon_sym_LBRACK,
    ACTIONS(830), 1,
      anon_sym_not,
    ACTIONS(832), 1,
      anon_sym_lambda,
    ACTIONS(834), 1,
      anon_sym_yield,
    ACTIONS(836), 1,
      anon_sym_await,
    ACTIONS(950), 1,
      anon_sym_RBRACK,
    STATE(1016), 1,
      sym_primary_expression,
    STATE(1017), 1,
      sym_string,
    STATE(1419), 1,
      sym_list_splat_pattern,
    STATE(1725), 1,
      sym_expression,
    STATE(2410), 1,
      sym_pattern,
    STATE(2702), 1,
      sym__named_expression_lhs,
    STATE(2817), 1,
      sym__collection_elements,
    STATE(2818), 1,
      sym__patterns,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      sym_ellipsis,
      sym_float,
    STATE(1421), 2,
      sym_attribute,
      sym_subscript,
    STATE(2600), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(806), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2399), 3,
      sym_list_splat,
      sym_parenthesized_list_splat,
      sym_yield,
    ACTIONS(794), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(822), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1809), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1414), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [3860] = 31,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(838), 1,
      sym_identifier,
    ACTIONS(840), 1,
      anon_sym_LPAREN,
    ACTIONS(844), 1,
      anon_sym_STAR,
    ACTIONS(848), 1,
      anon_sym_type,
    ACTIONS(850), 1,
      anon_sym_LBRACK,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(854), 1,
      anon_sym_lambda,
    ACTIONS(856), 1,
      anon_sym_yield,
    ACTIONS(858), 1,
      anon_sym_await,
    ACTIONS(952), 1,
      anon_sym_RPAREN,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1341), 1,
      sym_list_splat_pattern,
    STATE(1719), 1,
      sym_expression,
    STATE(2379), 1,
      sym_yield,
    STATE(2384), 1,
      sym_pattern,
    STATE(2707), 1,
      sym__patterns,
    STATE(2803), 1,
      sym__named_expression_lhs,
    STATE(2826), 1,
      sym__collection_elements,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    STATE(1342), 2,
      sym_attribute,
      sym_subscript,
    STATE(2269), 2,
      sym_list_splat,
      sym_parenthesized_list_splat,
    STATE(2574), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(846), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [3986] = 28,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(15), 1,
      anon_sym_LPAREN,
    ACTIONS(17), 1,
      anon_sym_STAR,
    ACTIONS(61), 1,
      anon_sym_LBRACK,
    ACTIONS(67), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_not,
    ACTIONS(71), 1,
      anon_sym_lambda,
    ACTIONS(73), 1,
      anon_sym_yield,
    ACTIONS(79), 1,
      anon_sym_await,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(862), 1,
      anon_sym_type,
    STATE(635), 1,
      sym_list_splat_pattern,
    STATE(975), 1,
      sym_string,
    STATE(1013), 1,
      sym_primary_expression,
    STATE(1666), 1,
      sym_pattern_list,
    STATE(1670), 1,
      sym_pattern,
    STATE(1858), 1,
      sym_expression,
    STATE(2782), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(75), 2,
      sym_ellipsis,
      sym_float,
    STATE(637), 2,
      sym_attribute,
      sym_subscript,
    STATE(1668), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(65), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(77), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(418), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(2609), 5,
      sym_expression_list,
      sym_assignment,
      sym_augmented_assignment,
      sym__right_hand_side,
      sym_yield,
    STATE(1687), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1057), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [4106] = 22,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(315), 1,
      anon_sym_TILDE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(954), 1,
      sym_identifier,
    ACTIONS(958), 1,
      anon_sym_LPAREN,
    ACTIONS(960), 1,
      anon_sym_STAR,
    ACTIONS(964), 1,
      anon_sym_type,
    ACTIONS(966), 1,
      anon_sym_LBRACK,
    ACTIONS(968), 1,
      anon_sym_await,
    STATE(1004), 1,
      sym_string,
    STATE(1401), 1,
      sym_list_splat_pattern,
    STATE(1631), 1,
      sym_primary_expression,
    STATE(1635), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(414), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1400), 2,
      sym_attribute,
      sym_subscript,
    STATE(1628), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(962), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
    ACTIONS(956), 17,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [4213] = 22,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(315), 1,
      anon_sym_TILDE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(954), 1,
      sym_identifier,
    ACTIONS(958), 1,
      anon_sym_LPAREN,
    ACTIONS(960), 1,
      anon_sym_STAR,
    ACTIONS(964), 1,
      anon_sym_type,
    ACTIONS(966), 1,
      anon_sym_LBRACK,
    ACTIONS(968), 1,
      anon_sym_await,
    STATE(1004), 1,
      sym_string,
    STATE(1401), 1,
      sym_list_splat_pattern,
    STATE(1631), 1,
      sym_primary_expression,
    STATE(1635), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(414), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1400), 2,
      sym_attribute,
      sym_subscript,
    STATE(1628), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(962), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
    ACTIONS(970), 17,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [4320] = 26,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(972), 1,
      sym_identifier,
    ACTIONS(974), 1,
      anon_sym_STAR,
    ACTIONS(978), 1,
      anon_sym_STAR_STAR,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(982), 1,
      anon_sym_RBRACK,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1786), 1,
      sym_expression,
    STATE(2069), 1,
      sym_type,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(2044), 5,
      sym_splat_type,
      sym_generic_type,
      sym_union_type,
      sym_constrained_type,
      sym_member_type,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [4434] = 26,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(972), 1,
      sym_identifier,
    ACTIONS(974), 1,
      anon_sym_STAR,
    ACTIONS(978), 1,
      anon_sym_STAR_STAR,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(990), 1,
      anon_sym_RBRACK,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1786), 1,
      sym_expression,
    STATE(2069), 1,
      sym_type,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(2044), 5,
      sym_splat_type,
      sym_generic_type,
      sym_union_type,
      sym_constrained_type,
      sym_member_type,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [4548] = 26,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(972), 1,
      sym_identifier,
    ACTIONS(974), 1,
      anon_sym_STAR,
    ACTIONS(978), 1,
      anon_sym_STAR_STAR,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(992), 1,
      anon_sym_RBRACK,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1786), 1,
      sym_expression,
    STATE(2069), 1,
      sym_type,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(2044), 5,
      sym_splat_type,
      sym_generic_type,
      sym_union_type,
      sym_constrained_type,
      sym_member_type,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [4662] = 27,
    ACTIONS(696), 1,
      anon_sym_LBRACE,
    ACTIONS(702), 1,
      sym_string_start,
    ACTIONS(888), 1,
      anon_sym_yield,
    ACTIONS(994), 1,
      sym_identifier,
    ACTIONS(996), 1,
      anon_sym_LPAREN,
    ACTIONS(998), 1,
      anon_sym_STAR,
    ACTIONS(1002), 1,
      anon_sym_type,
    ACTIONS(1004), 1,
      anon_sym_LBRACK,
    ACTIONS(1006), 1,
      anon_sym_not,
    ACTIONS(1008), 1,
      anon_sym_lambda,
    ACTIONS(1010), 1,
      anon_sym_await,
    STATE(979), 1,
      sym_string,
    STATE(996), 1,
      sym_primary_expression,
    STATE(1167), 1,
      sym_list_splat_pattern,
    STATE(1732), 1,
      sym_expression,
    STATE(2605), 1,
      sym_pattern,
    STATE(2830), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(698), 2,
      sym_ellipsis,
      sym_float,
    STATE(1166), 2,
      sym_attribute,
      sym_subscript,
    STATE(1668), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(694), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(682), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1000), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(2053), 4,
      sym_expression_list,
      sym_pattern_list,
      sym_yield,
      sym__f_expression,
    STATE(1783), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1241), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [4778] = 27,
    ACTIONS(696), 1,
      anon_sym_LBRACE,
    ACTIONS(702), 1,
      sym_string_start,
    ACTIONS(888), 1,
      anon_sym_yield,
    ACTIONS(994), 1,
      sym_identifier,
    ACTIONS(996), 1,
      anon_sym_LPAREN,
    ACTIONS(998), 1,
      anon_sym_STAR,
    ACTIONS(1002), 1,
      anon_sym_type,
    ACTIONS(1004), 1,
      anon_sym_LBRACK,
    ACTIONS(1006), 1,
      anon_sym_not,
    ACTIONS(1008), 1,
      anon_sym_lambda,
    ACTIONS(1010), 1,
      anon_sym_await,
    STATE(979), 1,
      sym_string,
    STATE(996), 1,
      sym_primary_expression,
    STATE(1167), 1,
      sym_list_splat_pattern,
    STATE(1732), 1,
      sym_expression,
    STATE(2605), 1,
      sym_pattern,
    STATE(2830), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(698), 2,
      sym_ellipsis,
      sym_float,
    STATE(1166), 2,
      sym_attribute,
      sym_subscript,
    STATE(1668), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(694), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(682), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1000), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(2101), 4,
      sym_expression_list,
      sym_pattern_list,
      sym_yield,
      sym__f_expression,
    STATE(1783), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1241), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [4894] = 26,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(972), 1,
      sym_identifier,
    ACTIONS(974), 1,
      anon_sym_STAR,
    ACTIONS(978), 1,
      anon_sym_STAR_STAR,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1012), 1,
      anon_sym_RBRACK,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1786), 1,
      sym_expression,
    STATE(2069), 1,
      sym_type,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(2044), 5,
      sym_splat_type,
      sym_generic_type,
      sym_union_type,
      sym_constrained_type,
      sym_member_type,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [5008] = 26,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(972), 1,
      sym_identifier,
    ACTIONS(974), 1,
      anon_sym_STAR,
    ACTIONS(978), 1,
      anon_sym_STAR_STAR,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1014), 1,
      anon_sym_RBRACK,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1786), 1,
      sym_expression,
    STATE(2069), 1,
      sym_type,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(2044), 5,
      sym_splat_type,
      sym_generic_type,
      sym_union_type,
      sym_constrained_type,
      sym_member_type,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [5122] = 26,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(972), 1,
      sym_identifier,
    ACTIONS(974), 1,
      anon_sym_STAR,
    ACTIONS(978), 1,
      anon_sym_STAR_STAR,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1016), 1,
      anon_sym_RBRACK,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1786), 1,
      sym_expression,
    STATE(2069), 1,
      sym_type,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(2044), 5,
      sym_splat_type,
      sym_generic_type,
      sym_union_type,
      sym_constrained_type,
      sym_member_type,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [5236] = 26,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(972), 1,
      sym_identifier,
    ACTIONS(974), 1,
      anon_sym_STAR,
    ACTIONS(978), 1,
      anon_sym_STAR_STAR,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1018), 1,
      anon_sym_RBRACK,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1786), 1,
      sym_expression,
    STATE(2069), 1,
      sym_type,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(2044), 5,
      sym_splat_type,
      sym_generic_type,
      sym_union_type,
      sym_constrained_type,
      sym_member_type,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [5350] = 26,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(972), 1,
      sym_identifier,
    ACTIONS(974), 1,
      anon_sym_STAR,
    ACTIONS(978), 1,
      anon_sym_STAR_STAR,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1020), 1,
      anon_sym_RBRACK,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1786), 1,
      sym_expression,
    STATE(2069), 1,
      sym_type,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(2044), 5,
      sym_splat_type,
      sym_generic_type,
      sym_union_type,
      sym_constrained_type,
      sym_member_type,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [5464] = 25,
    ACTIONS(67), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_not,
    ACTIONS(71), 1,
      anon_sym_lambda,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(393), 1,
      anon_sym_type,
    ACTIONS(404), 1,
      anon_sym_await,
    ACTIONS(652), 1,
      anon_sym_LPAREN,
    ACTIONS(660), 1,
      anon_sym_LBRACK,
    ACTIONS(1022), 1,
      sym_identifier,
    ACTIONS(1024), 1,
      anon_sym_STAR,
    ACTIONS(1026), 1,
      anon_sym_STAR_STAR,
    STATE(975), 1,
      sym_string,
    STATE(977), 1,
      sym_primary_expression,
    STATE(1117), 1,
      sym_list_splat_pattern,
    STATE(1753), 1,
      sym_expression,
    STATE(1997), 1,
      sym_type,
    STATE(2782), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(75), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(65), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(77), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(389), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1956), 5,
      sym_splat_type,
      sym_generic_type,
      sym_union_type,
      sym_constrained_type,
      sym_member_type,
    STATE(1687), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1057), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [5575] = 25,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(972), 1,
      sym_identifier,
    ACTIONS(974), 1,
      anon_sym_STAR,
    ACTIONS(978), 1,
      anon_sym_STAR_STAR,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1786), 1,
      sym_expression,
    STATE(1992), 1,
      sym_type,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(2044), 5,
      sym_splat_type,
      sym_generic_type,
      sym_union_type,
      sym_constrained_type,
      sym_member_type,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [5686] = 27,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(854), 1,
      anon_sym_lambda,
    ACTIONS(1028), 1,
      sym_identifier,
    ACTIONS(1030), 1,
      anon_sym_LPAREN,
    ACTIONS(1032), 1,
      anon_sym_RPAREN,
    ACTIONS(1034), 1,
      anon_sym_COMMA,
    ACTIONS(1036), 1,
      anon_sym_STAR,
    ACTIONS(1040), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1042), 1,
      anon_sym_type,
    ACTIONS(1044), 1,
      anon_sym_await,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1290), 1,
      sym_list_splat_pattern,
    STATE(1720), 1,
      sym_expression,
    STATE(2297), 1,
      sym_parenthesized_list_splat,
    STATE(2803), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2296), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1038), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [5801] = 25,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(972), 1,
      sym_identifier,
    ACTIONS(974), 1,
      anon_sym_STAR,
    ACTIONS(978), 1,
      anon_sym_STAR_STAR,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1786), 1,
      sym_expression,
    STATE(1925), 1,
      sym_type,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(2044), 5,
      sym_splat_type,
      sym_generic_type,
      sym_union_type,
      sym_constrained_type,
      sym_member_type,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [5912] = 27,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(854), 1,
      anon_sym_lambda,
    ACTIONS(1028), 1,
      sym_identifier,
    ACTIONS(1030), 1,
      anon_sym_LPAREN,
    ACTIONS(1036), 1,
      anon_sym_STAR,
    ACTIONS(1040), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1042), 1,
      anon_sym_type,
    ACTIONS(1044), 1,
      anon_sym_await,
    ACTIONS(1046), 1,
      anon_sym_RPAREN,
    ACTIONS(1048), 1,
      anon_sym_COMMA,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1290), 1,
      sym_list_splat_pattern,
    STATE(1705), 1,
      sym_expression,
    STATE(2496), 1,
      sym_parenthesized_list_splat,
    STATE(2803), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2495), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1038), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [6027] = 25,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(339), 1,
      anon_sym_STAR_STAR,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1050), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1796), 1,
      sym_expression,
    STATE(2342), 1,
      sym_type,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(2137), 5,
      sym_splat_type,
      sym_generic_type,
      sym_union_type,
      sym_constrained_type,
      sym_member_type,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [6138] = 27,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(854), 1,
      anon_sym_lambda,
    ACTIONS(1028), 1,
      sym_identifier,
    ACTIONS(1030), 1,
      anon_sym_LPAREN,
    ACTIONS(1036), 1,
      anon_sym_STAR,
    ACTIONS(1040), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1042), 1,
      anon_sym_type,
    ACTIONS(1044), 1,
      anon_sym_await,
    ACTIONS(1052), 1,
      anon_sym_RPAREN,
    ACTIONS(1054), 1,
      anon_sym_COMMA,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1290), 1,
      sym_list_splat_pattern,
    STATE(1704), 1,
      sym_expression,
    STATE(2500), 1,
      sym_parenthesized_list_splat,
    STATE(2803), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2501), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1038), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [6253] = 25,
    ACTIONS(752), 1,
      anon_sym_LPAREN,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1056), 1,
      sym_identifier,
    ACTIONS(1058), 1,
      anon_sym_STAR,
    ACTIONS(1062), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1064), 1,
      anon_sym_type,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1070), 1,
      anon_sym_await,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1755), 1,
      sym_expression,
    STATE(1964), 1,
      sym_type,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1060), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1934), 5,
      sym_splat_type,
      sym_generic_type,
      sym_union_type,
      sym_constrained_type,
      sym_member_type,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [6364] = 25,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(339), 1,
      anon_sym_STAR_STAR,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1050), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1796), 1,
      sym_expression,
    STATE(2335), 1,
      sym_type,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(2137), 5,
      sym_splat_type,
      sym_generic_type,
      sym_union_type,
      sym_constrained_type,
      sym_member_type,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [6475] = 25,
    ACTIONS(752), 1,
      anon_sym_LPAREN,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1056), 1,
      sym_identifier,
    ACTIONS(1058), 1,
      anon_sym_STAR,
    ACTIONS(1062), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1064), 1,
      anon_sym_type,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1070), 1,
      anon_sym_await,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1755), 1,
      sym_expression,
    STATE(2007), 1,
      sym_type,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1060), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1934), 5,
      sym_splat_type,
      sym_generic_type,
      sym_union_type,
      sym_constrained_type,
      sym_member_type,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [6586] = 25,
    ACTIONS(752), 1,
      anon_sym_LPAREN,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1056), 1,
      sym_identifier,
    ACTIONS(1058), 1,
      anon_sym_STAR,
    ACTIONS(1062), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1064), 1,
      anon_sym_type,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1070), 1,
      anon_sym_await,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1755), 1,
      sym_expression,
    STATE(2078), 1,
      sym_type,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1060), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1934), 5,
      sym_splat_type,
      sym_generic_type,
      sym_union_type,
      sym_constrained_type,
      sym_member_type,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [6697] = 25,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(339), 1,
      anon_sym_STAR_STAR,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1050), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1796), 1,
      sym_expression,
    STATE(2321), 1,
      sym_type,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(2137), 5,
      sym_splat_type,
      sym_generic_type,
      sym_union_type,
      sym_constrained_type,
      sym_member_type,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [6808] = 25,
    ACTIONS(67), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_not,
    ACTIONS(71), 1,
      anon_sym_lambda,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(393), 1,
      anon_sym_type,
    ACTIONS(404), 1,
      anon_sym_await,
    ACTIONS(652), 1,
      anon_sym_LPAREN,
    ACTIONS(660), 1,
      anon_sym_LBRACK,
    ACTIONS(1022), 1,
      sym_identifier,
    ACTIONS(1024), 1,
      anon_sym_STAR,
    ACTIONS(1026), 1,
      anon_sym_STAR_STAR,
    STATE(975), 1,
      sym_string,
    STATE(977), 1,
      sym_primary_expression,
    STATE(1117), 1,
      sym_list_splat_pattern,
    STATE(1753), 1,
      sym_expression,
    STATE(1971), 1,
      sym_type,
    STATE(2782), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(75), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(65), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(77), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(389), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1956), 5,
      sym_splat_type,
      sym_generic_type,
      sym_union_type,
      sym_constrained_type,
      sym_member_type,
    STATE(1687), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1057), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [6919] = 27,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(854), 1,
      anon_sym_lambda,
    ACTIONS(1028), 1,
      sym_identifier,
    ACTIONS(1030), 1,
      anon_sym_LPAREN,
    ACTIONS(1036), 1,
      anon_sym_STAR,
    ACTIONS(1040), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1042), 1,
      anon_sym_type,
    ACTIONS(1044), 1,
      anon_sym_await,
    ACTIONS(1072), 1,
      anon_sym_RPAREN,
    ACTIONS(1074), 1,
      anon_sym_COMMA,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1290), 1,
      sym_list_splat_pattern,
    STATE(1716), 1,
      sym_expression,
    STATE(2404), 1,
      sym_parenthesized_list_splat,
    STATE(2803), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2406), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1038), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [7034] = 27,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(854), 1,
      anon_sym_lambda,
    ACTIONS(1028), 1,
      sym_identifier,
    ACTIONS(1030), 1,
      anon_sym_LPAREN,
    ACTIONS(1036), 1,
      anon_sym_STAR,
    ACTIONS(1040), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1042), 1,
      anon_sym_type,
    ACTIONS(1044), 1,
      anon_sym_await,
    ACTIONS(1076), 1,
      anon_sym_RPAREN,
    ACTIONS(1078), 1,
      anon_sym_COMMA,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1290), 1,
      sym_list_splat_pattern,
    STATE(1724), 1,
      sym_expression,
    STATE(2524), 1,
      sym_parenthesized_list_splat,
    STATE(2803), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2437), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1038), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [7149] = 27,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(854), 1,
      anon_sym_lambda,
    ACTIONS(1028), 1,
      sym_identifier,
    ACTIONS(1030), 1,
      anon_sym_LPAREN,
    ACTIONS(1036), 1,
      anon_sym_STAR,
    ACTIONS(1040), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1042), 1,
      anon_sym_type,
    ACTIONS(1044), 1,
      anon_sym_await,
    ACTIONS(1080), 1,
      anon_sym_RPAREN,
    ACTIONS(1082), 1,
      anon_sym_COMMA,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1290), 1,
      sym_list_splat_pattern,
    STATE(1711), 1,
      sym_expression,
    STATE(2455), 1,
      sym_parenthesized_list_splat,
    STATE(2803), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2457), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1038), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [7264] = 27,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(854), 1,
      anon_sym_lambda,
    ACTIONS(1028), 1,
      sym_identifier,
    ACTIONS(1030), 1,
      anon_sym_LPAREN,
    ACTIONS(1036), 1,
      anon_sym_STAR,
    ACTIONS(1040), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1042), 1,
      anon_sym_type,
    ACTIONS(1044), 1,
      anon_sym_await,
    ACTIONS(1084), 1,
      anon_sym_RPAREN,
    ACTIONS(1086), 1,
      anon_sym_COMMA,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1290), 1,
      sym_list_splat_pattern,
    STATE(1726), 1,
      sym_expression,
    STATE(2466), 1,
      sym_parenthesized_list_splat,
    STATE(2803), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2460), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1038), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [7379] = 22,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(315), 1,
      anon_sym_TILDE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(1088), 1,
      sym_identifier,
    ACTIONS(1090), 1,
      anon_sym_LPAREN,
    ACTIONS(1092), 1,
      anon_sym_STAR,
    ACTIONS(1096), 1,
      anon_sym_type,
    ACTIONS(1098), 1,
      anon_sym_LBRACK,
    ACTIONS(1100), 1,
      anon_sym_await,
    STATE(1004), 1,
      sym_string,
    STATE(1502), 1,
      sym_list_splat_pattern,
    STATE(1650), 1,
      sym_primary_expression,
    STATE(1664), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(414), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1498), 2,
      sym_attribute,
      sym_subscript,
    STATE(1668), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1094), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
    ACTIONS(970), 15,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [7484] = 25,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(339), 1,
      anon_sym_STAR_STAR,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1050), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1796), 1,
      sym_expression,
    STATE(2283), 1,
      sym_type,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(2137), 5,
      sym_splat_type,
      sym_generic_type,
      sym_union_type,
      sym_constrained_type,
      sym_member_type,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [7595] = 25,
    ACTIONS(684), 1,
      anon_sym_LPAREN,
    ACTIONS(692), 1,
      anon_sym_LBRACK,
    ACTIONS(696), 1,
      anon_sym_LBRACE,
    ACTIONS(702), 1,
      sym_string_start,
    ACTIONS(998), 1,
      anon_sym_STAR,
    ACTIONS(1006), 1,
      anon_sym_not,
    ACTIONS(1008), 1,
      anon_sym_lambda,
    ACTIONS(1102), 1,
      sym_identifier,
    ACTIONS(1104), 1,
      anon_sym_from,
    ACTIONS(1110), 1,
      anon_sym_type,
    ACTIONS(1112), 1,
      anon_sym_await,
    STATE(979), 1,
      sym_string,
    STATE(996), 1,
      sym_primary_expression,
    STATE(1183), 1,
      sym_list_splat_pattern,
    STATE(1752), 1,
      sym_expression,
    STATE(2065), 1,
      sym_expression_list,
    STATE(2830), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(698), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(694), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(682), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1108), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(1106), 5,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACE,
      sym_type_conversion,
    STATE(1783), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1241), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [7706] = 22,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(315), 1,
      anon_sym_TILDE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(1088), 1,
      sym_identifier,
    ACTIONS(1090), 1,
      anon_sym_LPAREN,
    ACTIONS(1092), 1,
      anon_sym_STAR,
    ACTIONS(1096), 1,
      anon_sym_type,
    ACTIONS(1098), 1,
      anon_sym_LBRACK,
    ACTIONS(1100), 1,
      anon_sym_await,
    STATE(1004), 1,
      sym_string,
    STATE(1502), 1,
      sym_list_splat_pattern,
    STATE(1650), 1,
      sym_primary_expression,
    STATE(1664), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(414), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1498), 2,
      sym_attribute,
      sym_subscript,
    STATE(1668), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1094), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
    ACTIONS(956), 15,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [7811] = 25,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(972), 1,
      sym_identifier,
    ACTIONS(974), 1,
      anon_sym_STAR,
    ACTIONS(978), 1,
      anon_sym_STAR_STAR,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1786), 1,
      sym_expression,
    STATE(1928), 1,
      sym_type,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(2044), 5,
      sym_splat_type,
      sym_generic_type,
      sym_union_type,
      sym_constrained_type,
      sym_member_type,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [7922] = 28,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(844), 1,
      anon_sym_STAR,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(854), 1,
      anon_sym_lambda,
    ACTIONS(856), 1,
      anon_sym_yield,
    ACTIONS(1030), 1,
      anon_sym_LPAREN,
    ACTIONS(1114), 1,
      sym_identifier,
    ACTIONS(1116), 1,
      anon_sym_RPAREN,
    ACTIONS(1120), 1,
      anon_sym_type,
    ACTIONS(1122), 1,
      anon_sym_await,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1290), 1,
      sym_list_splat_pattern,
    STATE(1717), 1,
      sym_expression,
    STATE(2329), 1,
      sym_with_item,
    STATE(2379), 1,
      sym_yield,
    STATE(2803), 1,
      sym__named_expression_lhs,
    STATE(2826), 1,
      sym__collection_elements,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    STATE(2269), 2,
      sym_list_splat,
      sym_parenthesized_list_splat,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1118), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [8039] = 27,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(854), 1,
      anon_sym_lambda,
    ACTIONS(1028), 1,
      sym_identifier,
    ACTIONS(1030), 1,
      anon_sym_LPAREN,
    ACTIONS(1036), 1,
      anon_sym_STAR,
    ACTIONS(1040), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1042), 1,
      anon_sym_type,
    ACTIONS(1044), 1,
      anon_sym_await,
    ACTIONS(1124), 1,
      anon_sym_RPAREN,
    ACTIONS(1126), 1,
      anon_sym_COMMA,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1290), 1,
      sym_list_splat_pattern,
    STATE(1721), 1,
      sym_expression,
    STATE(2402), 1,
      sym_parenthesized_list_splat,
    STATE(2803), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2401), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1038), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [8154] = 25,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(972), 1,
      sym_identifier,
    ACTIONS(974), 1,
      anon_sym_STAR,
    ACTIONS(978), 1,
      anon_sym_STAR_STAR,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1786), 1,
      sym_expression,
    STATE(2069), 1,
      sym_type,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(2044), 5,
      sym_splat_type,
      sym_generic_type,
      sym_union_type,
      sym_constrained_type,
      sym_member_type,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [8265] = 25,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(972), 1,
      sym_identifier,
    ACTIONS(974), 1,
      anon_sym_STAR,
    ACTIONS(978), 1,
      anon_sym_STAR_STAR,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1786), 1,
      sym_expression,
    STATE(1939), 1,
      sym_type,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(2044), 5,
      sym_splat_type,
      sym_generic_type,
      sym_union_type,
      sym_constrained_type,
      sym_member_type,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [8376] = 25,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(972), 1,
      sym_identifier,
    ACTIONS(974), 1,
      anon_sym_STAR,
    ACTIONS(978), 1,
      anon_sym_STAR_STAR,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1786), 1,
      sym_expression,
    STATE(2073), 1,
      sym_type,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(2044), 5,
      sym_splat_type,
      sym_generic_type,
      sym_union_type,
      sym_constrained_type,
      sym_member_type,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [8487] = 25,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(972), 1,
      sym_identifier,
    ACTIONS(974), 1,
      anon_sym_STAR,
    ACTIONS(978), 1,
      anon_sym_STAR_STAR,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1786), 1,
      sym_expression,
    STATE(2077), 1,
      sym_type,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(2044), 5,
      sym_splat_type,
      sym_generic_type,
      sym_union_type,
      sym_constrained_type,
      sym_member_type,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [8598] = 25,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(339), 1,
      anon_sym_STAR_STAR,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1050), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1796), 1,
      sym_expression,
    STATE(2348), 1,
      sym_type,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(2137), 5,
      sym_splat_type,
      sym_generic_type,
      sym_union_type,
      sym_constrained_type,
      sym_member_type,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [8709] = 25,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(339), 1,
      anon_sym_STAR_STAR,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1050), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1796), 1,
      sym_expression,
    STATE(2429), 1,
      sym_type,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(2137), 5,
      sym_splat_type,
      sym_generic_type,
      sym_union_type,
      sym_constrained_type,
      sym_member_type,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [8820] = 25,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(339), 1,
      anon_sym_STAR_STAR,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1050), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1796), 1,
      sym_expression,
    STATE(2346), 1,
      sym_type,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(2137), 5,
      sym_splat_type,
      sym_generic_type,
      sym_union_type,
      sym_constrained_type,
      sym_member_type,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [8931] = 25,
    ACTIONS(752), 1,
      anon_sym_LPAREN,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1056), 1,
      sym_identifier,
    ACTIONS(1058), 1,
      anon_sym_STAR,
    ACTIONS(1062), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1064), 1,
      anon_sym_type,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1070), 1,
      anon_sym_await,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1755), 1,
      sym_expression,
    STATE(1963), 1,
      sym_type,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1060), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1934), 5,
      sym_splat_type,
      sym_generic_type,
      sym_union_type,
      sym_constrained_type,
      sym_member_type,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [9042] = 25,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(339), 1,
      anon_sym_STAR_STAR,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1050), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1796), 1,
      sym_expression,
    STATE(2344), 1,
      sym_type,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(2137), 5,
      sym_splat_type,
      sym_generic_type,
      sym_union_type,
      sym_constrained_type,
      sym_member_type,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [9153] = 25,
    ACTIONS(67), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_not,
    ACTIONS(71), 1,
      anon_sym_lambda,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(393), 1,
      anon_sym_type,
    ACTIONS(404), 1,
      anon_sym_await,
    ACTIONS(652), 1,
      anon_sym_LPAREN,
    ACTIONS(660), 1,
      anon_sym_LBRACK,
    ACTIONS(1022), 1,
      sym_identifier,
    ACTIONS(1024), 1,
      anon_sym_STAR,
    ACTIONS(1026), 1,
      anon_sym_STAR_STAR,
    STATE(975), 1,
      sym_string,
    STATE(977), 1,
      sym_primary_expression,
    STATE(1117), 1,
      sym_list_splat_pattern,
    STATE(1753), 1,
      sym_expression,
    STATE(2001), 1,
      sym_type,
    STATE(2782), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(75), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(65), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(77), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(389), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1956), 5,
      sym_splat_type,
      sym_generic_type,
      sym_union_type,
      sym_constrained_type,
      sym_member_type,
    STATE(1687), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1057), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [9264] = 25,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(339), 1,
      anon_sym_STAR_STAR,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1050), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1796), 1,
      sym_expression,
    STATE(2063), 1,
      sym_type,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(2137), 5,
      sym_splat_type,
      sym_generic_type,
      sym_union_type,
      sym_constrained_type,
      sym_member_type,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [9375] = 25,
    ACTIONS(67), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_not,
    ACTIONS(71), 1,
      anon_sym_lambda,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(393), 1,
      anon_sym_type,
    ACTIONS(404), 1,
      anon_sym_await,
    ACTIONS(652), 1,
      anon_sym_LPAREN,
    ACTIONS(660), 1,
      anon_sym_LBRACK,
    ACTIONS(1022), 1,
      sym_identifier,
    ACTIONS(1024), 1,
      anon_sym_STAR,
    ACTIONS(1026), 1,
      anon_sym_STAR_STAR,
    STATE(975), 1,
      sym_string,
    STATE(977), 1,
      sym_primary_expression,
    STATE(1117), 1,
      sym_list_splat_pattern,
    STATE(1753), 1,
      sym_expression,
    STATE(2080), 1,
      sym_type,
    STATE(2782), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(75), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(65), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(77), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(389), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1956), 5,
      sym_splat_type,
      sym_generic_type,
      sym_union_type,
      sym_constrained_type,
      sym_member_type,
    STATE(1687), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1057), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [9486] = 25,
    ACTIONS(275), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(339), 1,
      anon_sym_STAR_STAR,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1050), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1796), 1,
      sym_expression,
    STATE(2092), 1,
      sym_type,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(2137), 5,
      sym_splat_type,
      sym_generic_type,
      sym_union_type,
      sym_constrained_type,
      sym_member_type,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [9597] = 27,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1032), 1,
      anon_sym_RPAREN,
    ACTIONS(1034), 1,
      anon_sym_COMMA,
    ACTIONS(1040), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1128), 1,
      sym_identifier,
    ACTIONS(1130), 1,
      anon_sym_LPAREN,
    ACTIONS(1132), 1,
      anon_sym_STAR,
    ACTIONS(1136), 1,
      anon_sym_type,
    ACTIONS(1138), 1,
      anon_sym_await,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1882), 1,
      sym_expression,
    STATE(2297), 1,
      sym_parenthesized_list_splat,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2296), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1134), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [9712] = 26,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1040), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1128), 1,
      sym_identifier,
    ACTIONS(1130), 1,
      anon_sym_LPAREN,
    ACTIONS(1132), 1,
      anon_sym_STAR,
    ACTIONS(1136), 1,
      anon_sym_type,
    ACTIONS(1138), 1,
      anon_sym_await,
    ACTIONS(1140), 1,
      anon_sym_RPAREN,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1952), 1,
      sym_expression,
    STATE(2611), 1,
      sym_parenthesized_list_splat,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2602), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1134), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [9824] = 26,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1040), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1128), 1,
      sym_identifier,
    ACTIONS(1130), 1,
      anon_sym_LPAREN,
    ACTIONS(1132), 1,
      anon_sym_STAR,
    ACTIONS(1136), 1,
      anon_sym_type,
    ACTIONS(1138), 1,
      anon_sym_await,
    ACTIONS(1142), 1,
      anon_sym_RPAREN,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1952), 1,
      sym_expression,
    STATE(2611), 1,
      sym_parenthesized_list_splat,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2602), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1134), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [9936] = 26,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1040), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1128), 1,
      sym_identifier,
    ACTIONS(1130), 1,
      anon_sym_LPAREN,
    ACTIONS(1132), 1,
      anon_sym_STAR,
    ACTIONS(1136), 1,
      anon_sym_type,
    ACTIONS(1138), 1,
      anon_sym_await,
    ACTIONS(1144), 1,
      anon_sym_RPAREN,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1952), 1,
      sym_expression,
    STATE(2611), 1,
      sym_parenthesized_list_splat,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2602), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1134), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [10048] = 26,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1040), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1128), 1,
      sym_identifier,
    ACTIONS(1130), 1,
      anon_sym_LPAREN,
    ACTIONS(1132), 1,
      anon_sym_STAR,
    ACTIONS(1136), 1,
      anon_sym_type,
    ACTIONS(1138), 1,
      anon_sym_await,
    ACTIONS(1146), 1,
      anon_sym_RPAREN,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1952), 1,
      sym_expression,
    STATE(2611), 1,
      sym_parenthesized_list_splat,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2602), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1134), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [10160] = 26,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1040), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1128), 1,
      sym_identifier,
    ACTIONS(1130), 1,
      anon_sym_LPAREN,
    ACTIONS(1132), 1,
      anon_sym_STAR,
    ACTIONS(1136), 1,
      anon_sym_type,
    ACTIONS(1138), 1,
      anon_sym_await,
    ACTIONS(1148), 1,
      anon_sym_RPAREN,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1952), 1,
      sym_expression,
    STATE(2611), 1,
      sym_parenthesized_list_splat,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2602), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1134), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [10272] = 26,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(808), 1,
      anon_sym_LBRACE,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(820), 1,
      anon_sym_STAR,
    ACTIONS(830), 1,
      anon_sym_not,
    ACTIONS(832), 1,
      anon_sym_lambda,
    ACTIONS(834), 1,
      anon_sym_yield,
    ACTIONS(1150), 1,
      sym_identifier,
    ACTIONS(1152), 1,
      anon_sym_LPAREN,
    ACTIONS(1156), 1,
      anon_sym_type,
    ACTIONS(1158), 1,
      anon_sym_RBRACK,
    ACTIONS(1160), 1,
      anon_sym_await,
    STATE(1016), 1,
      sym_primary_expression,
    STATE(1017), 1,
      sym_string,
    STATE(1367), 1,
      sym_list_splat_pattern,
    STATE(1723), 1,
      sym_expression,
    STATE(2691), 1,
      sym__collection_elements,
    STATE(2702), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(806), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2399), 3,
      sym_list_splat,
      sym_parenthesized_list_splat,
      sym_yield,
    ACTIONS(794), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1154), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1809), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1414), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [10384] = 28,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(844), 1,
      anon_sym_STAR,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(854), 1,
      anon_sym_lambda,
    ACTIONS(856), 1,
      anon_sym_yield,
    ACTIONS(1030), 1,
      anon_sym_LPAREN,
    ACTIONS(1114), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_type,
    ACTIONS(1122), 1,
      anon_sym_await,
    ACTIONS(1162), 1,
      anon_sym_RPAREN,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1290), 1,
      sym_list_splat_pattern,
    STATE(1718), 1,
      sym_expression,
    STATE(2397), 1,
      sym_list_splat,
    STATE(2400), 1,
      sym_parenthesized_list_splat,
    STATE(2424), 1,
      sym_yield,
    STATE(2637), 1,
      sym__collection_elements,
    STATE(2803), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1118), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [10500] = 28,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(844), 1,
      anon_sym_STAR,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(854), 1,
      anon_sym_lambda,
    ACTIONS(856), 1,
      anon_sym_yield,
    ACTIONS(1030), 1,
      anon_sym_LPAREN,
    ACTIONS(1114), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_type,
    ACTIONS(1122), 1,
      anon_sym_await,
    ACTIONS(1164), 1,
      anon_sym_RPAREN,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1290), 1,
      sym_list_splat_pattern,
    STATE(1713), 1,
      sym_expression,
    STATE(2284), 1,
      sym_list_splat,
    STATE(2285), 1,
      sym_parenthesized_list_splat,
    STATE(2527), 1,
      sym_yield,
    STATE(2754), 1,
      sym__collection_elements,
    STATE(2803), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1118), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [10616] = 28,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(844), 1,
      anon_sym_STAR,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(854), 1,
      anon_sym_lambda,
    ACTIONS(856), 1,
      anon_sym_yield,
    ACTIONS(1030), 1,
      anon_sym_LPAREN,
    ACTIONS(1114), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_type,
    ACTIONS(1122), 1,
      anon_sym_await,
    ACTIONS(1166), 1,
      anon_sym_RPAREN,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1290), 1,
      sym_list_splat_pattern,
    STATE(1708), 1,
      sym_expression,
    STATE(2284), 1,
      sym_list_splat,
    STATE(2285), 1,
      sym_parenthesized_list_splat,
    STATE(2468), 1,
      sym_yield,
    STATE(2712), 1,
      sym__collection_elements,
    STATE(2803), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1118), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [10732] = 26,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1040), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1128), 1,
      sym_identifier,
    ACTIONS(1130), 1,
      anon_sym_LPAREN,
    ACTIONS(1132), 1,
      anon_sym_STAR,
    ACTIONS(1136), 1,
      anon_sym_type,
    ACTIONS(1138), 1,
      anon_sym_await,
    ACTIONS(1168), 1,
      anon_sym_RPAREN,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1952), 1,
      sym_expression,
    STATE(2611), 1,
      sym_parenthesized_list_splat,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2602), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1134), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [10844] = 26,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1040), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1128), 1,
      sym_identifier,
    ACTIONS(1130), 1,
      anon_sym_LPAREN,
    ACTIONS(1132), 1,
      anon_sym_STAR,
    ACTIONS(1136), 1,
      anon_sym_type,
    ACTIONS(1138), 1,
      anon_sym_await,
    ACTIONS(1170), 1,
      anon_sym_RPAREN,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1952), 1,
      sym_expression,
    STATE(2611), 1,
      sym_parenthesized_list_splat,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2602), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1134), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [10956] = 26,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1040), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1128), 1,
      sym_identifier,
    ACTIONS(1130), 1,
      anon_sym_LPAREN,
    ACTIONS(1132), 1,
      anon_sym_STAR,
    ACTIONS(1136), 1,
      anon_sym_type,
    ACTIONS(1138), 1,
      anon_sym_await,
    ACTIONS(1172), 1,
      anon_sym_RPAREN,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1952), 1,
      sym_expression,
    STATE(2611), 1,
      sym_parenthesized_list_splat,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2602), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1134), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [11068] = 26,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1040), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1128), 1,
      sym_identifier,
    ACTIONS(1130), 1,
      anon_sym_LPAREN,
    ACTIONS(1132), 1,
      anon_sym_STAR,
    ACTIONS(1136), 1,
      anon_sym_type,
    ACTIONS(1138), 1,
      anon_sym_await,
    ACTIONS(1174), 1,
      anon_sym_RPAREN,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1952), 1,
      sym_expression,
    STATE(2611), 1,
      sym_parenthesized_list_splat,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2602), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1134), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [11180] = 26,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1040), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1128), 1,
      sym_identifier,
    ACTIONS(1130), 1,
      anon_sym_LPAREN,
    ACTIONS(1132), 1,
      anon_sym_STAR,
    ACTIONS(1136), 1,
      anon_sym_type,
    ACTIONS(1138), 1,
      anon_sym_await,
    ACTIONS(1176), 1,
      anon_sym_RPAREN,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1952), 1,
      sym_expression,
    STATE(2611), 1,
      sym_parenthesized_list_splat,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2602), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1134), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [11292] = 26,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(808), 1,
      anon_sym_LBRACE,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(820), 1,
      anon_sym_STAR,
    ACTIONS(830), 1,
      anon_sym_not,
    ACTIONS(832), 1,
      anon_sym_lambda,
    ACTIONS(834), 1,
      anon_sym_yield,
    ACTIONS(1150), 1,
      sym_identifier,
    ACTIONS(1152), 1,
      anon_sym_LPAREN,
    ACTIONS(1156), 1,
      anon_sym_type,
    ACTIONS(1160), 1,
      anon_sym_await,
    ACTIONS(1178), 1,
      anon_sym_RBRACK,
    STATE(1016), 1,
      sym_primary_expression,
    STATE(1017), 1,
      sym_string,
    STATE(1367), 1,
      sym_list_splat_pattern,
    STATE(1703), 1,
      sym_expression,
    STATE(2702), 1,
      sym__named_expression_lhs,
    STATE(2738), 1,
      sym__collection_elements,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(806), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2399), 3,
      sym_list_splat,
      sym_parenthesized_list_splat,
      sym_yield,
    ACTIONS(794), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1154), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1809), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1414), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [11404] = 26,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1040), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1128), 1,
      sym_identifier,
    ACTIONS(1130), 1,
      anon_sym_LPAREN,
    ACTIONS(1132), 1,
      anon_sym_STAR,
    ACTIONS(1136), 1,
      anon_sym_type,
    ACTIONS(1138), 1,
      anon_sym_await,
    ACTIONS(1180), 1,
      anon_sym_RPAREN,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1952), 1,
      sym_expression,
    STATE(2611), 1,
      sym_parenthesized_list_splat,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2602), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1134), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [11516] = 27,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(844), 1,
      anon_sym_STAR,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(854), 1,
      anon_sym_lambda,
    ACTIONS(856), 1,
      anon_sym_yield,
    ACTIONS(1030), 1,
      anon_sym_LPAREN,
    ACTIONS(1114), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_type,
    ACTIONS(1122), 1,
      anon_sym_await,
    ACTIONS(1182), 1,
      anon_sym_RPAREN,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1290), 1,
      sym_list_splat_pattern,
    STATE(1706), 1,
      sym_expression,
    STATE(2473), 1,
      sym_yield,
    STATE(2735), 1,
      sym__collection_elements,
    STATE(2803), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    STATE(2269), 2,
      sym_list_splat,
      sym_parenthesized_list_splat,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1118), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [11630] = 26,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1040), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1128), 1,
      sym_identifier,
    ACTIONS(1130), 1,
      anon_sym_LPAREN,
    ACTIONS(1132), 1,
      anon_sym_STAR,
    ACTIONS(1136), 1,
      anon_sym_type,
    ACTIONS(1138), 1,
      anon_sym_await,
    ACTIONS(1184), 1,
      anon_sym_RPAREN,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1952), 1,
      sym_expression,
    STATE(2611), 1,
      sym_parenthesized_list_splat,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2602), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1134), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [11742] = 26,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(808), 1,
      anon_sym_LBRACE,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(820), 1,
      anon_sym_STAR,
    ACTIONS(830), 1,
      anon_sym_not,
    ACTIONS(832), 1,
      anon_sym_lambda,
    ACTIONS(834), 1,
      anon_sym_yield,
    ACTIONS(1150), 1,
      sym_identifier,
    ACTIONS(1152), 1,
      anon_sym_LPAREN,
    ACTIONS(1156), 1,
      anon_sym_type,
    ACTIONS(1160), 1,
      anon_sym_await,
    ACTIONS(1186), 1,
      anon_sym_RBRACK,
    STATE(1016), 1,
      sym_primary_expression,
    STATE(1017), 1,
      sym_string,
    STATE(1367), 1,
      sym_list_splat_pattern,
    STATE(1714), 1,
      sym_expression,
    STATE(2702), 1,
      sym__named_expression_lhs,
    STATE(2736), 1,
      sym__collection_elements,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(806), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2399), 3,
      sym_list_splat,
      sym_parenthesized_list_splat,
      sym_yield,
    ACTIONS(794), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1154), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1809), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1414), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [11854] = 26,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1040), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1128), 1,
      sym_identifier,
    ACTIONS(1130), 1,
      anon_sym_LPAREN,
    ACTIONS(1132), 1,
      anon_sym_STAR,
    ACTIONS(1136), 1,
      anon_sym_type,
    ACTIONS(1138), 1,
      anon_sym_await,
    ACTIONS(1188), 1,
      anon_sym_RPAREN,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1952), 1,
      sym_expression,
    STATE(2611), 1,
      sym_parenthesized_list_splat,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2602), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1134), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [11966] = 28,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(844), 1,
      anon_sym_STAR,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(854), 1,
      anon_sym_lambda,
    ACTIONS(856), 1,
      anon_sym_yield,
    ACTIONS(1030), 1,
      anon_sym_LPAREN,
    ACTIONS(1114), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_type,
    ACTIONS(1122), 1,
      anon_sym_await,
    ACTIONS(1190), 1,
      anon_sym_RPAREN,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1290), 1,
      sym_list_splat_pattern,
    STATE(1712), 1,
      sym_expression,
    STATE(2371), 1,
      sym_yield,
    STATE(2397), 1,
      sym_list_splat,
    STATE(2400), 1,
      sym_parenthesized_list_splat,
    STATE(2698), 1,
      sym__collection_elements,
    STATE(2803), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1118), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [12082] = 27,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(844), 1,
      anon_sym_STAR,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(854), 1,
      anon_sym_lambda,
    ACTIONS(856), 1,
      anon_sym_yield,
    ACTIONS(1030), 1,
      anon_sym_LPAREN,
    ACTIONS(1114), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_type,
    ACTIONS(1122), 1,
      anon_sym_await,
    ACTIONS(1164), 1,
      anon_sym_RPAREN,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1290), 1,
      sym_list_splat_pattern,
    STATE(1713), 1,
      sym_expression,
    STATE(2527), 1,
      sym_yield,
    STATE(2754), 1,
      sym__collection_elements,
    STATE(2803), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    STATE(2269), 2,
      sym_list_splat,
      sym_parenthesized_list_splat,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1118), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [12196] = 26,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(808), 1,
      anon_sym_LBRACE,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(820), 1,
      anon_sym_STAR,
    ACTIONS(830), 1,
      anon_sym_not,
    ACTIONS(832), 1,
      anon_sym_lambda,
    ACTIONS(834), 1,
      anon_sym_yield,
    ACTIONS(1150), 1,
      sym_identifier,
    ACTIONS(1152), 1,
      anon_sym_LPAREN,
    ACTIONS(1156), 1,
      anon_sym_type,
    ACTIONS(1160), 1,
      anon_sym_await,
    ACTIONS(1192), 1,
      anon_sym_RBRACK,
    STATE(1016), 1,
      sym_primary_expression,
    STATE(1017), 1,
      sym_string,
    STATE(1367), 1,
      sym_list_splat_pattern,
    STATE(1715), 1,
      sym_expression,
    STATE(2640), 1,
      sym__collection_elements,
    STATE(2702), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(806), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2399), 3,
      sym_list_splat,
      sym_parenthesized_list_splat,
      sym_yield,
    ACTIONS(794), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1154), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1809), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1414), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [12308] = 26,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1040), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1128), 1,
      sym_identifier,
    ACTIONS(1130), 1,
      anon_sym_LPAREN,
    ACTIONS(1132), 1,
      anon_sym_STAR,
    ACTIONS(1136), 1,
      anon_sym_type,
    ACTIONS(1138), 1,
      anon_sym_await,
    ACTIONS(1194), 1,
      anon_sym_RPAREN,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1952), 1,
      sym_expression,
    STATE(2611), 1,
      sym_parenthesized_list_splat,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2602), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1134), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [12420] = 27,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(844), 1,
      anon_sym_STAR,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(854), 1,
      anon_sym_lambda,
    ACTIONS(856), 1,
      anon_sym_yield,
    ACTIONS(1030), 1,
      anon_sym_LPAREN,
    ACTIONS(1114), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_type,
    ACTIONS(1122), 1,
      anon_sym_await,
    ACTIONS(1162), 1,
      anon_sym_RPAREN,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1290), 1,
      sym_list_splat_pattern,
    STATE(1718), 1,
      sym_expression,
    STATE(2424), 1,
      sym_yield,
    STATE(2637), 1,
      sym__collection_elements,
    STATE(2803), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    STATE(2269), 2,
      sym_list_splat,
      sym_parenthesized_list_splat,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1118), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [12534] = 26,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1040), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1128), 1,
      sym_identifier,
    ACTIONS(1130), 1,
      anon_sym_LPAREN,
    ACTIONS(1132), 1,
      anon_sym_STAR,
    ACTIONS(1136), 1,
      anon_sym_type,
    ACTIONS(1138), 1,
      anon_sym_await,
    ACTIONS(1196), 1,
      anon_sym_RPAREN,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1952), 1,
      sym_expression,
    STATE(2611), 1,
      sym_parenthesized_list_splat,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2602), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1134), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [12646] = 27,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(844), 1,
      anon_sym_STAR,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(854), 1,
      anon_sym_lambda,
    ACTIONS(856), 1,
      anon_sym_yield,
    ACTIONS(1030), 1,
      anon_sym_LPAREN,
    ACTIONS(1114), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_type,
    ACTIONS(1122), 1,
      anon_sym_await,
    ACTIONS(1198), 1,
      anon_sym_RPAREN,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1290), 1,
      sym_list_splat_pattern,
    STATE(1707), 1,
      sym_expression,
    STATE(2390), 1,
      sym_yield,
    STATE(2677), 1,
      sym__collection_elements,
    STATE(2803), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    STATE(2269), 2,
      sym_list_splat,
      sym_parenthesized_list_splat,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1118), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [12760] = 26,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(808), 1,
      anon_sym_LBRACE,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(820), 1,
      anon_sym_STAR,
    ACTIONS(830), 1,
      anon_sym_not,
    ACTIONS(832), 1,
      anon_sym_lambda,
    ACTIONS(834), 1,
      anon_sym_yield,
    ACTIONS(1150), 1,
      sym_identifier,
    ACTIONS(1152), 1,
      anon_sym_LPAREN,
    ACTIONS(1156), 1,
      anon_sym_type,
    ACTIONS(1160), 1,
      anon_sym_await,
    ACTIONS(1200), 1,
      anon_sym_RBRACK,
    STATE(1016), 1,
      sym_primary_expression,
    STATE(1017), 1,
      sym_string,
    STATE(1367), 1,
      sym_list_splat_pattern,
    STATE(1701), 1,
      sym_expression,
    STATE(2702), 1,
      sym__named_expression_lhs,
    STATE(2767), 1,
      sym__collection_elements,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(806), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2399), 3,
      sym_list_splat,
      sym_parenthesized_list_splat,
      sym_yield,
    ACTIONS(794), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1154), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1809), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1414), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [12872] = 28,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(844), 1,
      anon_sym_STAR,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(854), 1,
      anon_sym_lambda,
    ACTIONS(856), 1,
      anon_sym_yield,
    ACTIONS(1030), 1,
      anon_sym_LPAREN,
    ACTIONS(1114), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_type,
    ACTIONS(1122), 1,
      anon_sym_await,
    ACTIONS(1202), 1,
      anon_sym_RPAREN,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1290), 1,
      sym_list_splat_pattern,
    STATE(1722), 1,
      sym_expression,
    STATE(2317), 1,
      sym_yield,
    STATE(2328), 1,
      sym_parenthesized_list_splat,
    STATE(2336), 1,
      sym_list_splat,
    STATE(2763), 1,
      sym__collection_elements,
    STATE(2803), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1118), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [12988] = 26,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1040), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1128), 1,
      sym_identifier,
    ACTIONS(1130), 1,
      anon_sym_LPAREN,
    ACTIONS(1132), 1,
      anon_sym_STAR,
    ACTIONS(1136), 1,
      anon_sym_type,
    ACTIONS(1138), 1,
      anon_sym_await,
    ACTIONS(1204), 1,
      anon_sym_RPAREN,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1952), 1,
      sym_expression,
    STATE(2611), 1,
      sym_parenthesized_list_splat,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2602), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1134), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [13100] = 26,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1040), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1128), 1,
      sym_identifier,
    ACTIONS(1130), 1,
      anon_sym_LPAREN,
    ACTIONS(1132), 1,
      anon_sym_STAR,
    ACTIONS(1136), 1,
      anon_sym_type,
    ACTIONS(1138), 1,
      anon_sym_await,
    ACTIONS(1206), 1,
      anon_sym_RPAREN,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1952), 1,
      sym_expression,
    STATE(2611), 1,
      sym_parenthesized_list_splat,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2602), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1134), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [13212] = 26,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1040), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1128), 1,
      sym_identifier,
    ACTIONS(1130), 1,
      anon_sym_LPAREN,
    ACTIONS(1132), 1,
      anon_sym_STAR,
    ACTIONS(1136), 1,
      anon_sym_type,
    ACTIONS(1138), 1,
      anon_sym_await,
    ACTIONS(1208), 1,
      anon_sym_RPAREN,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1952), 1,
      sym_expression,
    STATE(2611), 1,
      sym_parenthesized_list_splat,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2602), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1134), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [13324] = 26,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1040), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1128), 1,
      sym_identifier,
    ACTIONS(1130), 1,
      anon_sym_LPAREN,
    ACTIONS(1132), 1,
      anon_sym_STAR,
    ACTIONS(1136), 1,
      anon_sym_type,
    ACTIONS(1138), 1,
      anon_sym_await,
    ACTIONS(1210), 1,
      anon_sym_RPAREN,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1952), 1,
      sym_expression,
    STATE(2611), 1,
      sym_parenthesized_list_splat,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2602), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1134), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [13436] = 26,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1040), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1128), 1,
      sym_identifier,
    ACTIONS(1130), 1,
      anon_sym_LPAREN,
    ACTIONS(1132), 1,
      anon_sym_STAR,
    ACTIONS(1136), 1,
      anon_sym_type,
    ACTIONS(1138), 1,
      anon_sym_await,
    ACTIONS(1212), 1,
      anon_sym_RPAREN,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1952), 1,
      sym_expression,
    STATE(2611), 1,
      sym_parenthesized_list_splat,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2602), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1134), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [13548] = 26,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1040), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1128), 1,
      sym_identifier,
    ACTIONS(1130), 1,
      anon_sym_LPAREN,
    ACTIONS(1132), 1,
      anon_sym_STAR,
    ACTIONS(1136), 1,
      anon_sym_type,
    ACTIONS(1138), 1,
      anon_sym_await,
    ACTIONS(1214), 1,
      anon_sym_RPAREN,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1952), 1,
      sym_expression,
    STATE(2611), 1,
      sym_parenthesized_list_splat,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2602), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1134), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [13660] = 27,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(844), 1,
      anon_sym_STAR,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(854), 1,
      anon_sym_lambda,
    ACTIONS(856), 1,
      anon_sym_yield,
    ACTIONS(1030), 1,
      anon_sym_LPAREN,
    ACTIONS(1114), 1,
      sym_identifier,
    ACTIONS(1116), 1,
      anon_sym_RPAREN,
    ACTIONS(1120), 1,
      anon_sym_type,
    ACTIONS(1122), 1,
      anon_sym_await,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1290), 1,
      sym_list_splat_pattern,
    STATE(1719), 1,
      sym_expression,
    STATE(2379), 1,
      sym_yield,
    STATE(2803), 1,
      sym__named_expression_lhs,
    STATE(2826), 1,
      sym__collection_elements,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    STATE(2269), 2,
      sym_list_splat,
      sym_parenthesized_list_splat,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1118), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [13774] = 26,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1040), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1128), 1,
      sym_identifier,
    ACTIONS(1130), 1,
      anon_sym_LPAREN,
    ACTIONS(1132), 1,
      anon_sym_STAR,
    ACTIONS(1136), 1,
      anon_sym_type,
    ACTIONS(1138), 1,
      anon_sym_await,
    ACTIONS(1216), 1,
      anon_sym_RPAREN,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1952), 1,
      sym_expression,
    STATE(2611), 1,
      sym_parenthesized_list_splat,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2602), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1134), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [13886] = 26,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1040), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1128), 1,
      sym_identifier,
    ACTIONS(1130), 1,
      anon_sym_LPAREN,
    ACTIONS(1132), 1,
      anon_sym_STAR,
    ACTIONS(1136), 1,
      anon_sym_type,
    ACTIONS(1138), 1,
      anon_sym_await,
    ACTIONS(1218), 1,
      anon_sym_RPAREN,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1952), 1,
      sym_expression,
    STATE(2611), 1,
      sym_parenthesized_list_splat,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2602), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1134), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [13998] = 26,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1040), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1128), 1,
      sym_identifier,
    ACTIONS(1130), 1,
      anon_sym_LPAREN,
    ACTIONS(1132), 1,
      anon_sym_STAR,
    ACTIONS(1136), 1,
      anon_sym_type,
    ACTIONS(1138), 1,
      anon_sym_await,
    ACTIONS(1220), 1,
      anon_sym_RPAREN,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1952), 1,
      sym_expression,
    STATE(2611), 1,
      sym_parenthesized_list_splat,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2602), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1134), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [14110] = 26,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1040), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1128), 1,
      sym_identifier,
    ACTIONS(1130), 1,
      anon_sym_LPAREN,
    ACTIONS(1132), 1,
      anon_sym_STAR,
    ACTIONS(1136), 1,
      anon_sym_type,
    ACTIONS(1138), 1,
      anon_sym_await,
    ACTIONS(1222), 1,
      anon_sym_RPAREN,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1952), 1,
      sym_expression,
    STATE(2611), 1,
      sym_parenthesized_list_splat,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2602), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1134), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [14222] = 26,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1040), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1128), 1,
      sym_identifier,
    ACTIONS(1130), 1,
      anon_sym_LPAREN,
    ACTIONS(1132), 1,
      anon_sym_STAR,
    ACTIONS(1136), 1,
      anon_sym_type,
    ACTIONS(1138), 1,
      anon_sym_await,
    ACTIONS(1224), 1,
      anon_sym_RPAREN,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1952), 1,
      sym_expression,
    STATE(2611), 1,
      sym_parenthesized_list_splat,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2602), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1134), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [14334] = 27,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(844), 1,
      anon_sym_STAR,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(854), 1,
      anon_sym_lambda,
    ACTIONS(856), 1,
      anon_sym_yield,
    ACTIONS(1030), 1,
      anon_sym_LPAREN,
    ACTIONS(1114), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_type,
    ACTIONS(1122), 1,
      anon_sym_await,
    ACTIONS(1190), 1,
      anon_sym_RPAREN,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1290), 1,
      sym_list_splat_pattern,
    STATE(1712), 1,
      sym_expression,
    STATE(2371), 1,
      sym_yield,
    STATE(2698), 1,
      sym__collection_elements,
    STATE(2803), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    STATE(2269), 2,
      sym_list_splat,
      sym_parenthesized_list_splat,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1118), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [14448] = 26,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1040), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1128), 1,
      sym_identifier,
    ACTIONS(1130), 1,
      anon_sym_LPAREN,
    ACTIONS(1132), 1,
      anon_sym_STAR,
    ACTIONS(1136), 1,
      anon_sym_type,
    ACTIONS(1138), 1,
      anon_sym_await,
    ACTIONS(1226), 1,
      anon_sym_RPAREN,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1952), 1,
      sym_expression,
    STATE(2611), 1,
      sym_parenthesized_list_splat,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2602), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1134), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [14560] = 26,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1040), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1128), 1,
      sym_identifier,
    ACTIONS(1130), 1,
      anon_sym_LPAREN,
    ACTIONS(1132), 1,
      anon_sym_STAR,
    ACTIONS(1136), 1,
      anon_sym_type,
    ACTIONS(1138), 1,
      anon_sym_await,
    ACTIONS(1228), 1,
      anon_sym_RPAREN,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1952), 1,
      sym_expression,
    STATE(2611), 1,
      sym_parenthesized_list_splat,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2602), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1134), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [14672] = 27,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(844), 1,
      anon_sym_STAR,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(854), 1,
      anon_sym_lambda,
    ACTIONS(856), 1,
      anon_sym_yield,
    ACTIONS(1030), 1,
      anon_sym_LPAREN,
    ACTIONS(1114), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_type,
    ACTIONS(1122), 1,
      anon_sym_await,
    ACTIONS(1202), 1,
      anon_sym_RPAREN,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1290), 1,
      sym_list_splat_pattern,
    STATE(1722), 1,
      sym_expression,
    STATE(2317), 1,
      sym_yield,
    STATE(2763), 1,
      sym__collection_elements,
    STATE(2803), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    STATE(2269), 2,
      sym_list_splat,
      sym_parenthesized_list_splat,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1118), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [14786] = 26,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(808), 1,
      anon_sym_LBRACE,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(820), 1,
      anon_sym_STAR,
    ACTIONS(830), 1,
      anon_sym_not,
    ACTIONS(832), 1,
      anon_sym_lambda,
    ACTIONS(834), 1,
      anon_sym_yield,
    ACTIONS(1150), 1,
      sym_identifier,
    ACTIONS(1152), 1,
      anon_sym_LPAREN,
    ACTIONS(1156), 1,
      anon_sym_type,
    ACTIONS(1160), 1,
      anon_sym_await,
    ACTIONS(1230), 1,
      anon_sym_RBRACK,
    STATE(1016), 1,
      sym_primary_expression,
    STATE(1017), 1,
      sym_string,
    STATE(1367), 1,
      sym_list_splat_pattern,
    STATE(1710), 1,
      sym_expression,
    STATE(2702), 1,
      sym__named_expression_lhs,
    STATE(2726), 1,
      sym__collection_elements,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(806), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2399), 3,
      sym_list_splat,
      sym_parenthesized_list_splat,
      sym_yield,
    ACTIONS(794), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1154), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1809), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1414), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [14898] = 26,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(808), 1,
      anon_sym_LBRACE,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(820), 1,
      anon_sym_STAR,
    ACTIONS(830), 1,
      anon_sym_not,
    ACTIONS(832), 1,
      anon_sym_lambda,
    ACTIONS(834), 1,
      anon_sym_yield,
    ACTIONS(1150), 1,
      sym_identifier,
    ACTIONS(1152), 1,
      anon_sym_LPAREN,
    ACTIONS(1156), 1,
      anon_sym_type,
    ACTIONS(1160), 1,
      anon_sym_await,
    ACTIONS(1232), 1,
      anon_sym_RBRACK,
    STATE(1016), 1,
      sym_primary_expression,
    STATE(1017), 1,
      sym_string,
    STATE(1367), 1,
      sym_list_splat_pattern,
    STATE(1725), 1,
      sym_expression,
    STATE(2702), 1,
      sym__named_expression_lhs,
    STATE(2817), 1,
      sym__collection_elements,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(806), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2399), 3,
      sym_list_splat,
      sym_parenthesized_list_splat,
      sym_yield,
    ACTIONS(794), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1154), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1809), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1414), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [15010] = 26,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1040), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1128), 1,
      sym_identifier,
    ACTIONS(1130), 1,
      anon_sym_LPAREN,
    ACTIONS(1132), 1,
      anon_sym_STAR,
    ACTIONS(1136), 1,
      anon_sym_type,
    ACTIONS(1138), 1,
      anon_sym_await,
    ACTIONS(1234), 1,
      anon_sym_RPAREN,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1952), 1,
      sym_expression,
    STATE(2611), 1,
      sym_parenthesized_list_splat,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2602), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1134), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [15122] = 26,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(808), 1,
      anon_sym_LBRACE,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(820), 1,
      anon_sym_STAR,
    ACTIONS(830), 1,
      anon_sym_not,
    ACTIONS(832), 1,
      anon_sym_lambda,
    ACTIONS(834), 1,
      anon_sym_yield,
    ACTIONS(1150), 1,
      sym_identifier,
    ACTIONS(1152), 1,
      anon_sym_LPAREN,
    ACTIONS(1156), 1,
      anon_sym_type,
    ACTIONS(1160), 1,
      anon_sym_await,
    ACTIONS(1236), 1,
      anon_sym_RBRACK,
    STATE(1016), 1,
      sym_primary_expression,
    STATE(1017), 1,
      sym_string,
    STATE(1367), 1,
      sym_list_splat_pattern,
    STATE(1702), 1,
      sym_expression,
    STATE(2702), 1,
      sym__named_expression_lhs,
    STATE(2829), 1,
      sym__collection_elements,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(806), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2399), 3,
      sym_list_splat,
      sym_parenthesized_list_splat,
      sym_yield,
    ACTIONS(794), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1154), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1809), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1414), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [15234] = 26,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1040), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1128), 1,
      sym_identifier,
    ACTIONS(1130), 1,
      anon_sym_LPAREN,
    ACTIONS(1132), 1,
      anon_sym_STAR,
    ACTIONS(1136), 1,
      anon_sym_type,
    ACTIONS(1138), 1,
      anon_sym_await,
    ACTIONS(1238), 1,
      anon_sym_RPAREN,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1952), 1,
      sym_expression,
    STATE(2611), 1,
      sym_parenthesized_list_splat,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2602), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1134), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [15346] = 26,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1040), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1128), 1,
      sym_identifier,
    ACTIONS(1130), 1,
      anon_sym_LPAREN,
    ACTIONS(1132), 1,
      anon_sym_STAR,
    ACTIONS(1136), 1,
      anon_sym_type,
    ACTIONS(1138), 1,
      anon_sym_await,
    ACTIONS(1240), 1,
      anon_sym_RPAREN,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1952), 1,
      sym_expression,
    STATE(2611), 1,
      sym_parenthesized_list_splat,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2602), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1134), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [15458] = 27,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(844), 1,
      anon_sym_STAR,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(854), 1,
      anon_sym_lambda,
    ACTIONS(856), 1,
      anon_sym_yield,
    ACTIONS(1030), 1,
      anon_sym_LPAREN,
    ACTIONS(1114), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_type,
    ACTIONS(1122), 1,
      anon_sym_await,
    ACTIONS(1166), 1,
      anon_sym_RPAREN,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1290), 1,
      sym_list_splat_pattern,
    STATE(1708), 1,
      sym_expression,
    STATE(2468), 1,
      sym_yield,
    STATE(2712), 1,
      sym__collection_elements,
    STATE(2803), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    STATE(2269), 2,
      sym_list_splat,
      sym_parenthesized_list_splat,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1118), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [15572] = 28,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(844), 1,
      anon_sym_STAR,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(854), 1,
      anon_sym_lambda,
    ACTIONS(856), 1,
      anon_sym_yield,
    ACTIONS(1030), 1,
      anon_sym_LPAREN,
    ACTIONS(1114), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_type,
    ACTIONS(1122), 1,
      anon_sym_await,
    ACTIONS(1182), 1,
      anon_sym_RPAREN,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1290), 1,
      sym_list_splat_pattern,
    STATE(1706), 1,
      sym_expression,
    STATE(2328), 1,
      sym_parenthesized_list_splat,
    STATE(2336), 1,
      sym_list_splat,
    STATE(2473), 1,
      sym_yield,
    STATE(2735), 1,
      sym__collection_elements,
    STATE(2803), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1118), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [15688] = 26,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1040), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1128), 1,
      sym_identifier,
    ACTIONS(1130), 1,
      anon_sym_LPAREN,
    ACTIONS(1132), 1,
      anon_sym_STAR,
    ACTIONS(1136), 1,
      anon_sym_type,
    ACTIONS(1138), 1,
      anon_sym_await,
    ACTIONS(1242), 1,
      anon_sym_RPAREN,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1952), 1,
      sym_expression,
    STATE(2611), 1,
      sym_parenthesized_list_splat,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2602), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1134), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [15800] = 25,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(834), 1,
      anon_sym_yield,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1246), 1,
      anon_sym_LPAREN,
    ACTIONS(1248), 1,
      anon_sym_STAR,
    ACTIONS(1250), 1,
      anon_sym_RBRACK,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1967), 1,
      sym_expression,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2627), 3,
      sym_list_splat,
      sym_parenthesized_list_splat,
      sym_yield,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [15909] = 25,
    ACTIONS(706), 1,
      anon_sym_LPAREN,
    ACTIONS(714), 1,
      anon_sym_LBRACK,
    ACTIONS(718), 1,
      anon_sym_LBRACE,
    ACTIONS(724), 1,
      sym_string_start,
    ACTIONS(868), 1,
      sym_identifier,
    ACTIONS(880), 1,
      anon_sym_type,
    ACTIONS(884), 1,
      anon_sym_not,
    ACTIONS(890), 1,
      anon_sym_await,
    ACTIONS(1252), 1,
      anon_sym_STAR,
    ACTIONS(1256), 1,
      anon_sym_RBRACE,
    ACTIONS(1258), 1,
      anon_sym_lambda,
    STATE(993), 1,
      sym_string,
    STATE(994), 1,
      sym_primary_expression,
    STATE(1218), 1,
      sym_list_splat_pattern,
    STATE(1845), 1,
      sym_expression,
    STATE(2685), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(720), 2,
      sym_ellipsis,
      sym_float,
    STATE(2058), 2,
      sym__expression_within_for_in_clause,
      sym_lambda_within_for_in_clause,
    ACTIONS(716), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(876), 3,
      anon_sym_print,
      anon_sym_match,
      anon_sym_exec,
    ACTIONS(1254), 3,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
    ACTIONS(704), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1768), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1169), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [16018] = 19,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(410), 1,
      anon_sym_STAR,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(675), 1,
      anon_sym_type,
    ACTIONS(677), 1,
      anon_sym_await,
    STATE(1004), 1,
      sym_string,
    STATE(1097), 1,
      sym_primary_expression,
    STATE(1433), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 2,
      anon_sym_DOT,
      anon_sym_SLASH,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(673), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(319), 5,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACE,
      sym_type_conversion,
    ACTIONS(323), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(277), 9,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_PIPE,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [16115] = 25,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1040), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1128), 1,
      sym_identifier,
    ACTIONS(1130), 1,
      anon_sym_LPAREN,
    ACTIONS(1132), 1,
      anon_sym_STAR,
    ACTIONS(1136), 1,
      anon_sym_type,
    ACTIONS(1138), 1,
      anon_sym_await,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1952), 1,
      sym_expression,
    STATE(2611), 1,
      sym_parenthesized_list_splat,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2602), 3,
      sym_list_splat,
      sym_dictionary_splat,
      sym_keyword_argument,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1134), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [16224] = 25,
    ACTIONS(728), 1,
      anon_sym_LPAREN,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(1114), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_type,
    ACTIONS(1122), 1,
      anon_sym_await,
    ACTIONS(1260), 1,
      anon_sym_RPAREN,
    ACTIONS(1262), 1,
      anon_sym_STAR,
    ACTIONS(1266), 1,
      anon_sym_lambda,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1290), 1,
      sym_list_splat_pattern,
    STATE(1805), 1,
      sym_expression,
    STATE(2803), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    STATE(2035), 2,
      sym__expression_within_for_in_clause,
      sym_lambda_within_for_in_clause,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(1118), 3,
      anon_sym_print,
      anon_sym_match,
      anon_sym_exec,
    ACTIONS(1264), 3,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [16333] = 25,
    ACTIONS(728), 1,
      anon_sym_LPAREN,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(1114), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_type,
    ACTIONS(1122), 1,
      anon_sym_await,
    ACTIONS(1262), 1,
      anon_sym_STAR,
    ACTIONS(1266), 1,
      anon_sym_lambda,
    ACTIONS(1268), 1,
      anon_sym_RPAREN,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1290), 1,
      sym_list_splat_pattern,
    STATE(1805), 1,
      sym_expression,
    STATE(2803), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    STATE(2035), 2,
      sym__expression_within_for_in_clause,
      sym_lambda_within_for_in_clause,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(1118), 3,
      anon_sym_print,
      anon_sym_match,
      anon_sym_exec,
    ACTIONS(1270), 3,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [16442] = 25,
    ACTIONS(728), 1,
      anon_sym_LPAREN,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(1114), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_type,
    ACTIONS(1122), 1,
      anon_sym_await,
    ACTIONS(1262), 1,
      anon_sym_STAR,
    ACTIONS(1266), 1,
      anon_sym_lambda,
    ACTIONS(1272), 1,
      anon_sym_RPAREN,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1290), 1,
      sym_list_splat_pattern,
    STATE(1805), 1,
      sym_expression,
    STATE(2803), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    STATE(2035), 2,
      sym__expression_within_for_in_clause,
      sym_lambda_within_for_in_clause,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(1118), 3,
      anon_sym_print,
      anon_sym_match,
      anon_sym_exec,
    ACTIONS(1274), 3,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [16551] = 25,
    ACTIONS(728), 1,
      anon_sym_LPAREN,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(1114), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_type,
    ACTIONS(1122), 1,
      anon_sym_await,
    ACTIONS(1256), 1,
      anon_sym_RPAREN,
    ACTIONS(1262), 1,
      anon_sym_STAR,
    ACTIONS(1266), 1,
      anon_sym_lambda,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1290), 1,
      sym_list_splat_pattern,
    STATE(1805), 1,
      sym_expression,
    STATE(2803), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    STATE(2035), 2,
      sym__expression_within_for_in_clause,
      sym_lambda_within_for_in_clause,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(1118), 3,
      anon_sym_print,
      anon_sym_match,
      anon_sym_exec,
    ACTIONS(1254), 3,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [16660] = 25,
    ACTIONS(706), 1,
      anon_sym_LPAREN,
    ACTIONS(714), 1,
      anon_sym_LBRACK,
    ACTIONS(718), 1,
      anon_sym_LBRACE,
    ACTIONS(724), 1,
      sym_string_start,
    ACTIONS(868), 1,
      sym_identifier,
    ACTIONS(880), 1,
      anon_sym_type,
    ACTIONS(884), 1,
      anon_sym_not,
    ACTIONS(890), 1,
      anon_sym_await,
    ACTIONS(1252), 1,
      anon_sym_STAR,
    ACTIONS(1258), 1,
      anon_sym_lambda,
    ACTIONS(1272), 1,
      anon_sym_RBRACE,
    STATE(993), 1,
      sym_string,
    STATE(994), 1,
      sym_primary_expression,
    STATE(1218), 1,
      sym_list_splat_pattern,
    STATE(1845), 1,
      sym_expression,
    STATE(2685), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(720), 2,
      sym_ellipsis,
      sym_float,
    STATE(2058), 2,
      sym__expression_within_for_in_clause,
      sym_lambda_within_for_in_clause,
    ACTIONS(716), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(876), 3,
      anon_sym_print,
      anon_sym_match,
      anon_sym_exec,
    ACTIONS(1274), 3,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
    ACTIONS(704), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1768), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1169), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [16769] = 25,
    ACTIONS(706), 1,
      anon_sym_LPAREN,
    ACTIONS(714), 1,
      anon_sym_LBRACK,
    ACTIONS(718), 1,
      anon_sym_LBRACE,
    ACTIONS(724), 1,
      sym_string_start,
    ACTIONS(868), 1,
      sym_identifier,
    ACTIONS(880), 1,
      anon_sym_type,
    ACTIONS(884), 1,
      anon_sym_not,
    ACTIONS(890), 1,
      anon_sym_await,
    ACTIONS(1252), 1,
      anon_sym_STAR,
    ACTIONS(1258), 1,
      anon_sym_lambda,
    ACTIONS(1268), 1,
      anon_sym_RBRACE,
    STATE(993), 1,
      sym_string,
    STATE(994), 1,
      sym_primary_expression,
    STATE(1218), 1,
      sym_list_splat_pattern,
    STATE(1845), 1,
      sym_expression,
    STATE(2685), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(720), 2,
      sym_ellipsis,
      sym_float,
    STATE(2058), 2,
      sym__expression_within_for_in_clause,
      sym_lambda_within_for_in_clause,
    ACTIONS(716), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(876), 3,
      anon_sym_print,
      anon_sym_match,
      anon_sym_exec,
    ACTIONS(1270), 3,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
    ACTIONS(704), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1768), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1169), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [16878] = 25,
    ACTIONS(706), 1,
      anon_sym_LPAREN,
    ACTIONS(714), 1,
      anon_sym_LBRACK,
    ACTIONS(718), 1,
      anon_sym_LBRACE,
    ACTIONS(724), 1,
      sym_string_start,
    ACTIONS(868), 1,
      sym_identifier,
    ACTIONS(880), 1,
      anon_sym_type,
    ACTIONS(884), 1,
      anon_sym_not,
    ACTIONS(890), 1,
      anon_sym_await,
    ACTIONS(1252), 1,
      anon_sym_STAR,
    ACTIONS(1258), 1,
      anon_sym_lambda,
    ACTIONS(1260), 1,
      anon_sym_RBRACE,
    STATE(993), 1,
      sym_string,
    STATE(994), 1,
      sym_primary_expression,
    STATE(1218), 1,
      sym_list_splat_pattern,
    STATE(1845), 1,
      sym_expression,
    STATE(2685), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(720), 2,
      sym_ellipsis,
      sym_float,
    STATE(2058), 2,
      sym__expression_within_for_in_clause,
      sym_lambda_within_for_in_clause,
    ACTIONS(716), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(876), 3,
      anon_sym_print,
      anon_sym_match,
      anon_sym_exec,
    ACTIONS(1264), 3,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
    ACTIONS(704), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1768), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1169), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [16987] = 25,
    ACTIONS(692), 1,
      anon_sym_LBRACK,
    ACTIONS(696), 1,
      anon_sym_LBRACE,
    ACTIONS(702), 1,
      sym_string_start,
    ACTIONS(888), 1,
      anon_sym_yield,
    ACTIONS(1006), 1,
      anon_sym_not,
    ACTIONS(1008), 1,
      anon_sym_lambda,
    ACTIONS(1102), 1,
      sym_identifier,
    ACTIONS(1110), 1,
      anon_sym_type,
    ACTIONS(1112), 1,
      anon_sym_await,
    ACTIONS(1276), 1,
      anon_sym_LPAREN,
    ACTIONS(1278), 1,
      anon_sym_STAR,
    ACTIONS(1280), 1,
      anon_sym_RBRACE,
    STATE(979), 1,
      sym_string,
    STATE(996), 1,
      sym_primary_expression,
    STATE(1183), 1,
      sym_list_splat_pattern,
    STATE(1953), 1,
      sym_expression,
    STATE(2830), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(698), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(694), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2628), 3,
      sym_list_splat,
      sym_parenthesized_list_splat,
      sym_yield,
    ACTIONS(682), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1108), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1783), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1241), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [17096] = 25,
    ACTIONS(692), 1,
      anon_sym_LBRACK,
    ACTIONS(696), 1,
      anon_sym_LBRACE,
    ACTIONS(702), 1,
      sym_string_start,
    ACTIONS(888), 1,
      anon_sym_yield,
    ACTIONS(1006), 1,
      anon_sym_not,
    ACTIONS(1008), 1,
      anon_sym_lambda,
    ACTIONS(1102), 1,
      sym_identifier,
    ACTIONS(1110), 1,
      anon_sym_type,
    ACTIONS(1112), 1,
      anon_sym_await,
    ACTIONS(1250), 1,
      anon_sym_RBRACE,
    ACTIONS(1276), 1,
      anon_sym_LPAREN,
    ACTIONS(1278), 1,
      anon_sym_STAR,
    STATE(979), 1,
      sym_string,
    STATE(996), 1,
      sym_primary_expression,
    STATE(1183), 1,
      sym_list_splat_pattern,
    STATE(1953), 1,
      sym_expression,
    STATE(2830), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(698), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(694), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2628), 3,
      sym_list_splat,
      sym_parenthesized_list_splat,
      sym_yield,
    ACTIONS(682), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1108), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1783), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1241), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [17205] = 25,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(856), 1,
      anon_sym_yield,
    ACTIONS(1064), 1,
      anon_sym_type,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1070), 1,
      anon_sym_await,
    ACTIONS(1130), 1,
      anon_sym_LPAREN,
    ACTIONS(1280), 1,
      anon_sym_RPAREN,
    ACTIONS(1282), 1,
      sym_identifier,
    ACTIONS(1284), 1,
      anon_sym_STAR,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1944), 1,
      sym_expression,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2578), 3,
      sym_list_splat,
      sym_parenthesized_list_splat,
      sym_yield,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1060), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [17314] = 25,
    ACTIONS(796), 1,
      anon_sym_LPAREN,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(808), 1,
      anon_sym_LBRACE,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(830), 1,
      anon_sym_not,
    ACTIONS(1150), 1,
      sym_identifier,
    ACTIONS(1156), 1,
      anon_sym_type,
    ACTIONS(1160), 1,
      anon_sym_await,
    ACTIONS(1256), 1,
      anon_sym_RBRACK,
    ACTIONS(1286), 1,
      anon_sym_STAR,
    ACTIONS(1288), 1,
      anon_sym_lambda,
    STATE(1016), 1,
      sym_primary_expression,
    STATE(1017), 1,
      sym_string,
    STATE(1367), 1,
      sym_list_splat_pattern,
    STATE(1818), 1,
      sym_expression,
    STATE(2702), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      sym_ellipsis,
      sym_float,
    STATE(2133), 2,
      sym__expression_within_for_in_clause,
      sym_lambda_within_for_in_clause,
    ACTIONS(806), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(1154), 3,
      anon_sym_print,
      anon_sym_match,
      anon_sym_exec,
    ACTIONS(1254), 3,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
    ACTIONS(794), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1809), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1414), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [17423] = 25,
    ACTIONS(796), 1,
      anon_sym_LPAREN,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(808), 1,
      anon_sym_LBRACE,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(830), 1,
      anon_sym_not,
    ACTIONS(1150), 1,
      sym_identifier,
    ACTIONS(1156), 1,
      anon_sym_type,
    ACTIONS(1160), 1,
      anon_sym_await,
    ACTIONS(1272), 1,
      anon_sym_RBRACK,
    ACTIONS(1286), 1,
      anon_sym_STAR,
    ACTIONS(1288), 1,
      anon_sym_lambda,
    STATE(1016), 1,
      sym_primary_expression,
    STATE(1017), 1,
      sym_string,
    STATE(1367), 1,
      sym_list_splat_pattern,
    STATE(1818), 1,
      sym_expression,
    STATE(2702), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      sym_ellipsis,
      sym_float,
    STATE(2133), 2,
      sym__expression_within_for_in_clause,
      sym_lambda_within_for_in_clause,
    ACTIONS(806), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(1154), 3,
      anon_sym_print,
      anon_sym_match,
      anon_sym_exec,
    ACTIONS(1274), 3,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
    ACTIONS(794), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1809), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1414), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [17532] = 25,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(856), 1,
      anon_sym_yield,
    ACTIONS(1064), 1,
      anon_sym_type,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1070), 1,
      anon_sym_await,
    ACTIONS(1130), 1,
      anon_sym_LPAREN,
    ACTIONS(1250), 1,
      anon_sym_RPAREN,
    ACTIONS(1282), 1,
      sym_identifier,
    ACTIONS(1284), 1,
      anon_sym_STAR,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1944), 1,
      sym_expression,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2578), 3,
      sym_list_splat,
      sym_parenthesized_list_splat,
      sym_yield,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1060), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [17641] = 23,
    ACTIONS(684), 1,
      anon_sym_LPAREN,
    ACTIONS(692), 1,
      anon_sym_LBRACK,
    ACTIONS(696), 1,
      anon_sym_LBRACE,
    ACTIONS(702), 1,
      sym_string_start,
    ACTIONS(998), 1,
      anon_sym_STAR,
    ACTIONS(1006), 1,
      anon_sym_not,
    ACTIONS(1008), 1,
      anon_sym_lambda,
    ACTIONS(1102), 1,
      sym_identifier,
    ACTIONS(1110), 1,
      anon_sym_type,
    ACTIONS(1112), 1,
      anon_sym_await,
    STATE(979), 1,
      sym_string,
    STATE(996), 1,
      sym_primary_expression,
    STATE(1183), 1,
      sym_list_splat_pattern,
    STATE(1781), 1,
      sym_expression,
    STATE(2830), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(698), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(694), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(682), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1108), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(1290), 5,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACE,
      sym_type_conversion,
    STATE(1783), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1241), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [17746] = 25,
    ACTIONS(796), 1,
      anon_sym_LPAREN,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(808), 1,
      anon_sym_LBRACE,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(830), 1,
      anon_sym_not,
    ACTIONS(1150), 1,
      sym_identifier,
    ACTIONS(1156), 1,
      anon_sym_type,
    ACTIONS(1160), 1,
      anon_sym_await,
    ACTIONS(1268), 1,
      anon_sym_RBRACK,
    ACTIONS(1286), 1,
      anon_sym_STAR,
    ACTIONS(1288), 1,
      anon_sym_lambda,
    STATE(1016), 1,
      sym_primary_expression,
    STATE(1017), 1,
      sym_string,
    STATE(1367), 1,
      sym_list_splat_pattern,
    STATE(1818), 1,
      sym_expression,
    STATE(2702), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      sym_ellipsis,
      sym_float,
    STATE(2133), 2,
      sym__expression_within_for_in_clause,
      sym_lambda_within_for_in_clause,
    ACTIONS(806), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(1154), 3,
      anon_sym_print,
      anon_sym_match,
      anon_sym_exec,
    ACTIONS(1270), 3,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
    ACTIONS(794), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1809), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1414), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [17855] = 25,
    ACTIONS(796), 1,
      anon_sym_LPAREN,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(808), 1,
      anon_sym_LBRACE,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(830), 1,
      anon_sym_not,
    ACTIONS(1150), 1,
      sym_identifier,
    ACTIONS(1156), 1,
      anon_sym_type,
    ACTIONS(1160), 1,
      anon_sym_await,
    ACTIONS(1260), 1,
      anon_sym_RBRACK,
    ACTIONS(1286), 1,
      anon_sym_STAR,
    ACTIONS(1288), 1,
      anon_sym_lambda,
    STATE(1016), 1,
      sym_primary_expression,
    STATE(1017), 1,
      sym_string,
    STATE(1367), 1,
      sym_list_splat_pattern,
    STATE(1818), 1,
      sym_expression,
    STATE(2702), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      sym_ellipsis,
      sym_float,
    STATE(2133), 2,
      sym__expression_within_for_in_clause,
      sym_lambda_within_for_in_clause,
    ACTIONS(806), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(1154), 3,
      anon_sym_print,
      anon_sym_match,
      anon_sym_exec,
    ACTIONS(1264), 3,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
    ACTIONS(794), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1809), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1414), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [17964] = 23,
    ACTIONS(684), 1,
      anon_sym_LPAREN,
    ACTIONS(692), 1,
      anon_sym_LBRACK,
    ACTIONS(696), 1,
      anon_sym_LBRACE,
    ACTIONS(702), 1,
      sym_string_start,
    ACTIONS(998), 1,
      anon_sym_STAR,
    ACTIONS(1006), 1,
      anon_sym_not,
    ACTIONS(1008), 1,
      anon_sym_lambda,
    ACTIONS(1102), 1,
      sym_identifier,
    ACTIONS(1110), 1,
      anon_sym_type,
    ACTIONS(1112), 1,
      anon_sym_await,
    STATE(979), 1,
      sym_string,
    STATE(996), 1,
      sym_primary_expression,
    STATE(1183), 1,
      sym_list_splat_pattern,
    STATE(1781), 1,
      sym_expression,
    STATE(2830), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(698), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(694), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(682), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1108), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(1292), 5,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACE,
      sym_type_conversion,
    STATE(1783), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1241), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [18069] = 25,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(834), 1,
      anon_sym_yield,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1246), 1,
      anon_sym_LPAREN,
    ACTIONS(1248), 1,
      anon_sym_STAR,
    ACTIONS(1280), 1,
      anon_sym_RBRACK,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1967), 1,
      sym_expression,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2627), 3,
      sym_list_splat,
      sym_parenthesized_list_splat,
      sym_yield,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [18178] = 25,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(410), 1,
      anon_sym_STAR,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(878), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1294), 1,
      anon_sym_RBRACE,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(2072), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(2595), 2,
      sym_dictionary_splat,
      sym_pair,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [18286] = 25,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(410), 1,
      anon_sym_STAR,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(878), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1296), 1,
      anon_sym_RBRACE,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(2072), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(2595), 2,
      sym_dictionary_splat,
      sym_pair,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [18394] = 25,
    ACTIONS(67), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_not,
    ACTIONS(71), 1,
      anon_sym_lambda,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(381), 1,
      sym_identifier,
    ACTIONS(393), 1,
      anon_sym_type,
    ACTIONS(404), 1,
      anon_sym_await,
    ACTIONS(652), 1,
      anon_sym_LPAREN,
    ACTIONS(660), 1,
      anon_sym_LBRACK,
    ACTIONS(1300), 1,
      anon_sym_from,
    ACTIONS(1302), 1,
      anon_sym_STAR,
    STATE(975), 1,
      sym_string,
    STATE(977), 1,
      sym_primary_expression,
    STATE(1117), 1,
      sym_list_splat_pattern,
    STATE(1792), 1,
      sym_expression,
    STATE(2268), 1,
      sym_expression_list,
    STATE(2782), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(75), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(1298), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(65), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(77), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(389), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1687), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1057), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [18502] = 25,
    ACTIONS(752), 1,
      anon_sym_LPAREN,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1064), 1,
      anon_sym_type,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1070), 1,
      anon_sym_await,
    ACTIONS(1282), 1,
      sym_identifier,
    ACTIONS(1304), 1,
      anon_sym_from,
    ACTIONS(1306), 1,
      anon_sym_STAR,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1894), 1,
      sym_expression,
    STATE(2556), 1,
      sym_expression_list,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(1106), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1060), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [18610] = 25,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(410), 1,
      anon_sym_STAR,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(878), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1308), 1,
      anon_sym_RBRACE,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(2072), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(2595), 2,
      sym_dictionary_splat,
      sym_pair,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [18718] = 25,
    ACTIONS(67), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_not,
    ACTIONS(71), 1,
      anon_sym_lambda,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(381), 1,
      sym_identifier,
    ACTIONS(393), 1,
      anon_sym_type,
    ACTIONS(404), 1,
      anon_sym_await,
    ACTIONS(652), 1,
      anon_sym_LPAREN,
    ACTIONS(660), 1,
      anon_sym_LBRACK,
    ACTIONS(1302), 1,
      anon_sym_STAR,
    ACTIONS(1310), 1,
      anon_sym_from,
    STATE(975), 1,
      sym_string,
    STATE(977), 1,
      sym_primary_expression,
    STATE(1117), 1,
      sym_list_splat_pattern,
    STATE(1829), 1,
      sym_expression,
    STATE(2553), 1,
      sym_expression_list,
    STATE(2782), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(75), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(1106), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(65), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(77), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(389), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1687), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1057), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [18826] = 25,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(410), 1,
      anon_sym_STAR,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(878), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1312), 1,
      anon_sym_RBRACE,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(2072), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(2595), 2,
      sym_dictionary_splat,
      sym_pair,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [18934] = 25,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(410), 1,
      anon_sym_STAR,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(878), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1314), 1,
      anon_sym_RBRACE,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(2072), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(2595), 2,
      sym_dictionary_splat,
      sym_pair,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [19042] = 24,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(834), 1,
      anon_sym_yield,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1246), 1,
      anon_sym_LPAREN,
    ACTIONS(1248), 1,
      anon_sym_STAR,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1967), 1,
      sym_expression,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2627), 3,
      sym_list_splat,
      sym_parenthesized_list_splat,
      sym_yield,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [19148] = 25,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(410), 1,
      anon_sym_STAR,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(878), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1316), 1,
      anon_sym_RBRACE,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(2072), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(2595), 2,
      sym_dictionary_splat,
      sym_pair,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [19256] = 25,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(410), 1,
      anon_sym_STAR,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(878), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1318), 1,
      anon_sym_RBRACE,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(2072), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(2595), 2,
      sym_dictionary_splat,
      sym_pair,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [19364] = 25,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(410), 1,
      anon_sym_STAR,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(878), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1320), 1,
      anon_sym_RBRACE,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(2072), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(2595), 2,
      sym_dictionary_splat,
      sym_pair,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [19472] = 25,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(410), 1,
      anon_sym_STAR,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(878), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1322), 1,
      anon_sym_RBRACE,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(2072), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(2595), 2,
      sym_dictionary_splat,
      sym_pair,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [19580] = 25,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(410), 1,
      anon_sym_STAR,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(878), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1324), 1,
      anon_sym_RBRACE,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(2072), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(2595), 2,
      sym_dictionary_splat,
      sym_pair,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [19688] = 25,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(410), 1,
      anon_sym_STAR,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(878), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1326), 1,
      anon_sym_RBRACE,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(2072), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(2595), 2,
      sym_dictionary_splat,
      sym_pair,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [19796] = 25,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(410), 1,
      anon_sym_STAR,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(878), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1328), 1,
      anon_sym_RBRACE,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(2072), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(2595), 2,
      sym_dictionary_splat,
      sym_pair,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [19904] = 24,
    ACTIONS(692), 1,
      anon_sym_LBRACK,
    ACTIONS(696), 1,
      anon_sym_LBRACE,
    ACTIONS(702), 1,
      sym_string_start,
    ACTIONS(888), 1,
      anon_sym_yield,
    ACTIONS(1006), 1,
      anon_sym_not,
    ACTIONS(1008), 1,
      anon_sym_lambda,
    ACTIONS(1102), 1,
      sym_identifier,
    ACTIONS(1110), 1,
      anon_sym_type,
    ACTIONS(1112), 1,
      anon_sym_await,
    ACTIONS(1276), 1,
      anon_sym_LPAREN,
    ACTIONS(1278), 1,
      anon_sym_STAR,
    STATE(979), 1,
      sym_string,
    STATE(996), 1,
      sym_primary_expression,
    STATE(1183), 1,
      sym_list_splat_pattern,
    STATE(1953), 1,
      sym_expression,
    STATE(2830), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(698), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(694), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2628), 3,
      sym_list_splat,
      sym_parenthesized_list_splat,
      sym_yield,
    ACTIONS(682), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1108), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1783), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1241), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [20010] = 24,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(856), 1,
      anon_sym_yield,
    ACTIONS(1064), 1,
      anon_sym_type,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1070), 1,
      anon_sym_await,
    ACTIONS(1130), 1,
      anon_sym_LPAREN,
    ACTIONS(1282), 1,
      sym_identifier,
    ACTIONS(1284), 1,
      anon_sym_STAR,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1944), 1,
      sym_expression,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    STATE(2578), 3,
      sym_list_splat,
      sym_parenthesized_list_splat,
      sym_yield,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1060), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [20116] = 25,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(410), 1,
      anon_sym_STAR,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(878), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1330), 1,
      anon_sym_RBRACE,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(2072), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(2595), 2,
      sym_dictionary_splat,
      sym_pair,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [20224] = 25,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(410), 1,
      anon_sym_STAR,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(878), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1332), 1,
      anon_sym_RBRACE,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(2072), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(2595), 2,
      sym_dictionary_splat,
      sym_pair,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [20332] = 25,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1334), 1,
      anon_sym_from,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1911), 1,
      sym_expression,
    STATE(2580), 1,
      sym_expression_list,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(1106), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [20440] = 25,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(410), 1,
      anon_sym_STAR,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(878), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1338), 1,
      anon_sym_RBRACE,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(2072), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(2595), 2,
      sym_dictionary_splat,
      sym_pair,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [20548] = 25,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(410), 1,
      anon_sym_STAR,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(878), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1340), 1,
      anon_sym_RBRACE,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(2072), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(2595), 2,
      sym_dictionary_splat,
      sym_pair,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [20656] = 19,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(410), 1,
      anon_sym_STAR,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(675), 1,
      anon_sym_type,
    ACTIONS(677), 1,
      anon_sym_await,
    STATE(1004), 1,
      sym_string,
    STATE(1097), 1,
      sym_primary_expression,
    STATE(1433), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 2,
      anon_sym_DOT,
      anon_sym_SLASH,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(666), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(673), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(277), 9,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_PIPE,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [20751] = 25,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    ACTIONS(1342), 1,
      anon_sym_COLON,
    ACTIONS(1344), 1,
      anon_sym_RBRACK,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1903), 1,
      sym_expression,
    STATE(2603), 1,
      sym_slice,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [20858] = 25,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    ACTIONS(1342), 1,
      anon_sym_COLON,
    ACTIONS(1346), 1,
      anon_sym_RBRACK,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1903), 1,
      sym_expression,
    STATE(2603), 1,
      sym_slice,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [20965] = 25,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    ACTIONS(1342), 1,
      anon_sym_COLON,
    ACTIONS(1348), 1,
      anon_sym_RBRACK,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1903), 1,
      sym_expression,
    STATE(2603), 1,
      sym_slice,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [21072] = 24,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    ACTIONS(1352), 1,
      anon_sym_COLON,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1893), 1,
      sym_expression,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(1350), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [21177] = 25,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    ACTIONS(1342), 1,
      anon_sym_COLON,
    ACTIONS(1354), 1,
      anon_sym_RBRACK,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1903), 1,
      sym_expression,
    STATE(2603), 1,
      sym_slice,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [21284] = 24,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    ACTIONS(1358), 1,
      anon_sym_COLON,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1880), 1,
      sym_expression,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(1356), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [21389] = 25,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    ACTIONS(1342), 1,
      anon_sym_COLON,
    ACTIONS(1360), 1,
      anon_sym_RBRACK,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1903), 1,
      sym_expression,
    STATE(2603), 1,
      sym_slice,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [21496] = 24,
    ACTIONS(67), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_not,
    ACTIONS(71), 1,
      anon_sym_lambda,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(381), 1,
      sym_identifier,
    ACTIONS(393), 1,
      anon_sym_type,
    ACTIONS(404), 1,
      anon_sym_await,
    ACTIONS(652), 1,
      anon_sym_LPAREN,
    ACTIONS(660), 1,
      anon_sym_LBRACK,
    ACTIONS(1302), 1,
      anon_sym_STAR,
    ACTIONS(1362), 1,
      anon_sym_from,
    STATE(975), 1,
      sym_string,
    STATE(977), 1,
      sym_primary_expression,
    STATE(1117), 1,
      sym_list_splat_pattern,
    STATE(1850), 1,
      sym_expression,
    STATE(2782), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(75), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(1290), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(65), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(77), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(389), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1687), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1057), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [21601] = 25,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    ACTIONS(1342), 1,
      anon_sym_COLON,
    ACTIONS(1364), 1,
      anon_sym_RBRACK,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1903), 1,
      sym_expression,
    STATE(2603), 1,
      sym_slice,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [21708] = 25,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    ACTIONS(1342), 1,
      anon_sym_COLON,
    ACTIONS(1366), 1,
      anon_sym_RBRACK,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1903), 1,
      sym_expression,
    STATE(2603), 1,
      sym_slice,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [21815] = 24,
    ACTIONS(67), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_not,
    ACTIONS(71), 1,
      anon_sym_lambda,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(381), 1,
      sym_identifier,
    ACTIONS(393), 1,
      anon_sym_type,
    ACTIONS(404), 1,
      anon_sym_await,
    ACTIONS(652), 1,
      anon_sym_LPAREN,
    ACTIONS(660), 1,
      anon_sym_LBRACK,
    ACTIONS(1302), 1,
      anon_sym_STAR,
    ACTIONS(1368), 1,
      anon_sym_from,
    STATE(975), 1,
      sym_string,
    STATE(977), 1,
      sym_primary_expression,
    STATE(1117), 1,
      sym_list_splat_pattern,
    STATE(1850), 1,
      sym_expression,
    STATE(2782), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(75), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(1292), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(65), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(77), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(389), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1687), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1057), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [21920] = 25,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    ACTIONS(1342), 1,
      anon_sym_COLON,
    ACTIONS(1370), 1,
      anon_sym_RBRACK,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1903), 1,
      sym_expression,
    STATE(2603), 1,
      sym_slice,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [22027] = 25,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    ACTIONS(1342), 1,
      anon_sym_COLON,
    ACTIONS(1372), 1,
      anon_sym_RBRACK,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1903), 1,
      sym_expression,
    STATE(2603), 1,
      sym_slice,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [22134] = 24,
    ACTIONS(67), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_not,
    ACTIONS(71), 1,
      anon_sym_lambda,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(381), 1,
      sym_identifier,
    ACTIONS(393), 1,
      anon_sym_type,
    ACTIONS(404), 1,
      anon_sym_await,
    ACTIONS(652), 1,
      anon_sym_LPAREN,
    ACTIONS(660), 1,
      anon_sym_LBRACK,
    ACTIONS(1302), 1,
      anon_sym_STAR,
    STATE(975), 1,
      sym_string,
    STATE(977), 1,
      sym_primary_expression,
    STATE(1117), 1,
      sym_list_splat_pattern,
    STATE(1853), 1,
      sym_expression,
    STATE(2621), 1,
      sym_expression_list,
    STATE(2782), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(75), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(1374), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(65), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(77), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(389), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1687), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1057), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [22239] = 25,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    ACTIONS(1342), 1,
      anon_sym_COLON,
    ACTIONS(1376), 1,
      anon_sym_RBRACK,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1903), 1,
      sym_expression,
    STATE(2603), 1,
      sym_slice,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [22346] = 24,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(410), 1,
      anon_sym_STAR,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(878), 1,
      anon_sym_STAR_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(2072), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(2595), 2,
      sym_dictionary_splat,
      sym_pair,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [22451] = 25,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    ACTIONS(1342), 1,
      anon_sym_COLON,
    ACTIONS(1378), 1,
      anon_sym_RBRACK,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1903), 1,
      sym_expression,
    STATE(2603), 1,
      sym_slice,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [22558] = 25,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    ACTIONS(1342), 1,
      anon_sym_COLON,
    ACTIONS(1380), 1,
      anon_sym_RBRACK,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1903), 1,
      sym_expression,
    STATE(2603), 1,
      sym_slice,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [22665] = 25,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    ACTIONS(1342), 1,
      anon_sym_COLON,
    ACTIONS(1382), 1,
      anon_sym_RBRACK,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1903), 1,
      sym_expression,
    STATE(2603), 1,
      sym_slice,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [22772] = 25,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    ACTIONS(1342), 1,
      anon_sym_COLON,
    ACTIONS(1384), 1,
      anon_sym_RBRACK,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1903), 1,
      sym_expression,
    STATE(2603), 1,
      sym_slice,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [22879] = 25,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    ACTIONS(1342), 1,
      anon_sym_COLON,
    ACTIONS(1386), 1,
      anon_sym_RBRACK,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1903), 1,
      sym_expression,
    STATE(2603), 1,
      sym_slice,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [22986] = 25,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    ACTIONS(1342), 1,
      anon_sym_COLON,
    ACTIONS(1388), 1,
      anon_sym_RBRACK,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1903), 1,
      sym_expression,
    STATE(2603), 1,
      sym_slice,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [23093] = 25,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    ACTIONS(1342), 1,
      anon_sym_COLON,
    ACTIONS(1390), 1,
      anon_sym_RBRACK,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1903), 1,
      sym_expression,
    STATE(2603), 1,
      sym_slice,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [23200] = 25,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    ACTIONS(1342), 1,
      anon_sym_COLON,
    ACTIONS(1392), 1,
      anon_sym_RBRACK,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1903), 1,
      sym_expression,
    STATE(2603), 1,
      sym_slice,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [23307] = 25,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    ACTIONS(1342), 1,
      anon_sym_COLON,
    ACTIONS(1394), 1,
      anon_sym_RBRACK,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1903), 1,
      sym_expression,
    STATE(2603), 1,
      sym_slice,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [23414] = 25,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    ACTIONS(1342), 1,
      anon_sym_COLON,
    ACTIONS(1396), 1,
      anon_sym_RBRACK,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1903), 1,
      sym_expression,
    STATE(2603), 1,
      sym_slice,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [23521] = 25,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    ACTIONS(1342), 1,
      anon_sym_COLON,
    ACTIONS(1398), 1,
      anon_sym_RBRACK,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1903), 1,
      sym_expression,
    STATE(2603), 1,
      sym_slice,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [23628] = 25,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    ACTIONS(1342), 1,
      anon_sym_COLON,
    ACTIONS(1400), 1,
      anon_sym_RBRACK,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1903), 1,
      sym_expression,
    STATE(2603), 1,
      sym_slice,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [23735] = 25,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    ACTIONS(1342), 1,
      anon_sym_COLON,
    ACTIONS(1402), 1,
      anon_sym_RBRACK,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1903), 1,
      sym_expression,
    STATE(2603), 1,
      sym_slice,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [23842] = 19,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(410), 1,
      anon_sym_STAR,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(675), 1,
      anon_sym_type,
    ACTIONS(677), 1,
      anon_sym_await,
    STATE(1004), 1,
      sym_string,
    STATE(1097), 1,
      sym_primary_expression,
    STATE(1433), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 2,
      anon_sym_DOT,
      anon_sym_SLASH,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(1404), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(673), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(277), 9,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_PIPE,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [23937] = 25,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    ACTIONS(1342), 1,
      anon_sym_COLON,
    ACTIONS(1406), 1,
      anon_sym_RBRACK,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1903), 1,
      sym_expression,
    STATE(2603), 1,
      sym_slice,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [24044] = 25,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    ACTIONS(1342), 1,
      anon_sym_COLON,
    ACTIONS(1408), 1,
      anon_sym_RBRACK,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1903), 1,
      sym_expression,
    STATE(2603), 1,
      sym_slice,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [24151] = 25,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    ACTIONS(1342), 1,
      anon_sym_COLON,
    ACTIONS(1410), 1,
      anon_sym_RBRACK,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1903), 1,
      sym_expression,
    STATE(2603), 1,
      sym_slice,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [24258] = 25,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    ACTIONS(1342), 1,
      anon_sym_COLON,
    ACTIONS(1412), 1,
      anon_sym_RBRACK,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1903), 1,
      sym_expression,
    STATE(2603), 1,
      sym_slice,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [24365] = 25,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    ACTIONS(1342), 1,
      anon_sym_COLON,
    ACTIONS(1414), 1,
      anon_sym_RBRACK,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1903), 1,
      sym_expression,
    STATE(2603), 1,
      sym_slice,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [24472] = 25,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    ACTIONS(1342), 1,
      anon_sym_COLON,
    ACTIONS(1416), 1,
      anon_sym_RBRACK,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1903), 1,
      sym_expression,
    STATE(2603), 1,
      sym_slice,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [24579] = 25,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    ACTIONS(1342), 1,
      anon_sym_COLON,
    ACTIONS(1418), 1,
      anon_sym_RBRACK,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1903), 1,
      sym_expression,
    STATE(2603), 1,
      sym_slice,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [24686] = 19,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(410), 1,
      anon_sym_STAR,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(675), 1,
      anon_sym_type,
    ACTIONS(677), 1,
      anon_sym_await,
    STATE(1004), 1,
      sym_string,
    STATE(1097), 1,
      sym_primary_expression,
    STATE(1433), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 2,
      anon_sym_DOT,
      anon_sym_SLASH,
    ACTIONS(319), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(673), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(277), 9,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_PIPE,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [24780] = 24,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    ACTIONS(1342), 1,
      anon_sym_COLON,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1807), 1,
      sym_expression,
    STATE(2405), 1,
      sym_slice,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [24884] = 23,
    ACTIONS(796), 1,
      anon_sym_LPAREN,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(808), 1,
      anon_sym_LBRACE,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(830), 1,
      anon_sym_not,
    ACTIONS(1150), 1,
      sym_identifier,
    ACTIONS(1156), 1,
      anon_sym_type,
    ACTIONS(1160), 1,
      anon_sym_await,
    ACTIONS(1286), 1,
      anon_sym_STAR,
    ACTIONS(1288), 1,
      anon_sym_lambda,
    STATE(1016), 1,
      sym_primary_expression,
    STATE(1017), 1,
      sym_string,
    STATE(1367), 1,
      sym_list_splat_pattern,
    STATE(1818), 1,
      sym_expression,
    STATE(2702), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      sym_ellipsis,
      sym_float,
    STATE(2133), 2,
      sym__expression_within_for_in_clause,
      sym_lambda_within_for_in_clause,
    ACTIONS(806), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(794), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1154), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1809), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1414), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [24986] = 24,
    ACTIONS(752), 1,
      anon_sym_LPAREN,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1064), 1,
      anon_sym_type,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1070), 1,
      anon_sym_await,
    ACTIONS(1282), 1,
      sym_identifier,
    ACTIONS(1306), 1,
      anon_sym_STAR,
    ACTIONS(1420), 1,
      anon_sym_RPAREN,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1962), 1,
      sym_expression,
    STATE(2599), 1,
      sym_with_item,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1060), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [25090] = 20,
    ACTIONS(302), 1,
      anon_sym_in,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(319), 1,
      anon_sym_COMMA,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(410), 1,
      anon_sym_STAR,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(675), 1,
      anon_sym_type,
    ACTIONS(677), 1,
      anon_sym_await,
    STATE(1004), 1,
      sym_string,
    STATE(1097), 1,
      sym_primary_expression,
    STATE(1433), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 2,
      anon_sym_DOT,
      anon_sym_SLASH,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(673), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(277), 9,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_PIPE,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [25186] = 24,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    ACTIONS(1342), 1,
      anon_sym_COLON,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1834), 1,
      sym_expression,
    STATE(2521), 1,
      sym_slice,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [25290] = 24,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1422), 1,
      anon_sym_LPAREN,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1950), 1,
      sym_expression,
    STATE(2461), 1,
      sym_with_item,
    STATE(2729), 1,
      sym_with_clause,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [25394] = 23,
    ACTIONS(796), 1,
      anon_sym_LPAREN,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(808), 1,
      anon_sym_LBRACE,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(830), 1,
      anon_sym_not,
    ACTIONS(1150), 1,
      sym_identifier,
    ACTIONS(1156), 1,
      anon_sym_type,
    ACTIONS(1160), 1,
      anon_sym_await,
    ACTIONS(1286), 1,
      anon_sym_STAR,
    ACTIONS(1288), 1,
      anon_sym_lambda,
    STATE(1016), 1,
      sym_primary_expression,
    STATE(1017), 1,
      sym_string,
    STATE(1367), 1,
      sym_list_splat_pattern,
    STATE(1827), 1,
      sym_expression,
    STATE(2702), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      sym_ellipsis,
      sym_float,
    STATE(2106), 2,
      sym__expression_within_for_in_clause,
      sym_lambda_within_for_in_clause,
    ACTIONS(806), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(794), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1154), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1809), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1414), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [25496] = 24,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    ACTIONS(1426), 1,
      anon_sym_COLON,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1950), 1,
      sym_expression,
    STATE(2561), 1,
      sym_with_item,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [25600] = 23,
    ACTIONS(706), 1,
      anon_sym_LPAREN,
    ACTIONS(714), 1,
      anon_sym_LBRACK,
    ACTIONS(718), 1,
      anon_sym_LBRACE,
    ACTIONS(724), 1,
      sym_string_start,
    ACTIONS(868), 1,
      sym_identifier,
    ACTIONS(880), 1,
      anon_sym_type,
    ACTIONS(884), 1,
      anon_sym_not,
    ACTIONS(890), 1,
      anon_sym_await,
    ACTIONS(1252), 1,
      anon_sym_STAR,
    ACTIONS(1258), 1,
      anon_sym_lambda,
    STATE(993), 1,
      sym_string,
    STATE(994), 1,
      sym_primary_expression,
    STATE(1218), 1,
      sym_list_splat_pattern,
    STATE(1845), 1,
      sym_expression,
    STATE(2685), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(720), 2,
      sym_ellipsis,
      sym_float,
    STATE(2058), 2,
      sym__expression_within_for_in_clause,
      sym_lambda_within_for_in_clause,
    ACTIONS(716), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(704), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(876), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1768), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1169), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [25702] = 24,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1422), 1,
      anon_sym_LPAREN,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1950), 1,
      sym_expression,
    STATE(2461), 1,
      sym_with_item,
    STATE(2658), 1,
      sym_with_clause,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [25806] = 24,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    ACTIONS(1428), 1,
      anon_sym_COLON,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1950), 1,
      sym_expression,
    STATE(2561), 1,
      sym_with_item,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [25910] = 23,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1924), 1,
      sym_expression,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(1430), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [26012] = 24,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    ACTIONS(1342), 1,
      anon_sym_COLON,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1903), 1,
      sym_expression,
    STATE(2603), 1,
      sym_slice,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [26116] = 23,
    ACTIONS(796), 1,
      anon_sym_LPAREN,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(808), 1,
      anon_sym_LBRACE,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(830), 1,
      anon_sym_not,
    ACTIONS(1150), 1,
      sym_identifier,
    ACTIONS(1156), 1,
      anon_sym_type,
    ACTIONS(1160), 1,
      anon_sym_await,
    ACTIONS(1286), 1,
      anon_sym_STAR,
    ACTIONS(1288), 1,
      anon_sym_lambda,
    STATE(1016), 1,
      sym_primary_expression,
    STATE(1017), 1,
      sym_string,
    STATE(1367), 1,
      sym_list_splat_pattern,
    STATE(1818), 1,
      sym_expression,
    STATE(2702), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      sym_ellipsis,
      sym_float,
    STATE(2015), 2,
      sym__expression_within_for_in_clause,
      sym_lambda_within_for_in_clause,
    ACTIONS(806), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(794), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1154), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1809), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1414), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [26218] = 23,
    ACTIONS(728), 1,
      anon_sym_LPAREN,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(1114), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_type,
    ACTIONS(1122), 1,
      anon_sym_await,
    ACTIONS(1262), 1,
      anon_sym_STAR,
    ACTIONS(1266), 1,
      anon_sym_lambda,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1290), 1,
      sym_list_splat_pattern,
    STATE(1837), 1,
      sym_expression,
    STATE(2803), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    STATE(2131), 2,
      sym__expression_within_for_in_clause,
      sym_lambda_within_for_in_clause,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1118), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [26320] = 24,
    ACTIONS(752), 1,
      anon_sym_LPAREN,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1064), 1,
      anon_sym_type,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1070), 1,
      anon_sym_await,
    ACTIONS(1282), 1,
      sym_identifier,
    ACTIONS(1306), 1,
      anon_sym_STAR,
    ACTIONS(1432), 1,
      anon_sym_RPAREN,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1962), 1,
      sym_expression,
    STATE(2599), 1,
      sym_with_item,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1060), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [26424] = 24,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1422), 1,
      anon_sym_LPAREN,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1950), 1,
      sym_expression,
    STATE(2461), 1,
      sym_with_item,
    STATE(2716), 1,
      sym_with_clause,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [26528] = 24,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1422), 1,
      anon_sym_LPAREN,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1950), 1,
      sym_expression,
    STATE(2461), 1,
      sym_with_item,
    STATE(2709), 1,
      sym_with_clause,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [26632] = 23,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1976), 1,
      sym_expression,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(1292), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [26734] = 23,
    ACTIONS(706), 1,
      anon_sym_LPAREN,
    ACTIONS(714), 1,
      anon_sym_LBRACK,
    ACTIONS(718), 1,
      anon_sym_LBRACE,
    ACTIONS(724), 1,
      sym_string_start,
    ACTIONS(868), 1,
      sym_identifier,
    ACTIONS(880), 1,
      anon_sym_type,
    ACTIONS(884), 1,
      anon_sym_not,
    ACTIONS(890), 1,
      anon_sym_await,
    ACTIONS(1252), 1,
      anon_sym_STAR,
    ACTIONS(1258), 1,
      anon_sym_lambda,
    STATE(993), 1,
      sym_string,
    STATE(994), 1,
      sym_primary_expression,
    STATE(1218), 1,
      sym_list_splat_pattern,
    STATE(1806), 1,
      sym_expression,
    STATE(2685), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(720), 2,
      sym_ellipsis,
      sym_float,
    STATE(2026), 2,
      sym__expression_within_for_in_clause,
      sym_lambda_within_for_in_clause,
    ACTIONS(716), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(704), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(876), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1768), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1169), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [26836] = 23,
    ACTIONS(728), 1,
      anon_sym_LPAREN,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(1114), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_type,
    ACTIONS(1122), 1,
      anon_sym_await,
    ACTIONS(1262), 1,
      anon_sym_STAR,
    ACTIONS(1266), 1,
      anon_sym_lambda,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1290), 1,
      sym_list_splat_pattern,
    STATE(1805), 1,
      sym_expression,
    STATE(2803), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    STATE(1975), 2,
      sym__expression_within_for_in_clause,
      sym_lambda_within_for_in_clause,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1118), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [26938] = 23,
    ACTIONS(752), 1,
      anon_sym_LPAREN,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1064), 1,
      anon_sym_type,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1070), 1,
      anon_sym_await,
    ACTIONS(1282), 1,
      sym_identifier,
    ACTIONS(1306), 1,
      anon_sym_STAR,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1946), 1,
      sym_expression,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(1290), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1060), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [27040] = 24,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    ACTIONS(1342), 1,
      anon_sym_COLON,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1852), 1,
      sym_expression,
    STATE(2377), 1,
      sym_slice,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [27144] = 23,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1976), 1,
      sym_expression,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(1290), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [27246] = 24,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    ACTIONS(1342), 1,
      anon_sym_COLON,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1854), 1,
      sym_expression,
    STATE(2385), 1,
      sym_slice,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [27350] = 24,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    ACTIONS(1342), 1,
      anon_sym_COLON,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1860), 1,
      sym_expression,
    STATE(2403), 1,
      sym_slice,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [27454] = 23,
    ACTIONS(796), 1,
      anon_sym_LPAREN,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(808), 1,
      anon_sym_LBRACE,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(830), 1,
      anon_sym_not,
    ACTIONS(1150), 1,
      sym_identifier,
    ACTIONS(1156), 1,
      anon_sym_type,
    ACTIONS(1160), 1,
      anon_sym_await,
    ACTIONS(1286), 1,
      anon_sym_STAR,
    ACTIONS(1288), 1,
      anon_sym_lambda,
    STATE(1016), 1,
      sym_primary_expression,
    STATE(1017), 1,
      sym_string,
    STATE(1367), 1,
      sym_list_splat_pattern,
    STATE(1839), 1,
      sym_expression,
    STATE(2702), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      sym_ellipsis,
      sym_float,
    STATE(2135), 2,
      sym__expression_within_for_in_clause,
      sym_lambda_within_for_in_clause,
    ACTIONS(806), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(794), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1154), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1809), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1414), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [27556] = 23,
    ACTIONS(728), 1,
      anon_sym_LPAREN,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(1114), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_type,
    ACTIONS(1122), 1,
      anon_sym_await,
    ACTIONS(1262), 1,
      anon_sym_STAR,
    ACTIONS(1266), 1,
      anon_sym_lambda,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1290), 1,
      sym_list_splat_pattern,
    STATE(1844), 1,
      sym_expression,
    STATE(2803), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    STATE(2047), 2,
      sym__expression_within_for_in_clause,
      sym_lambda_within_for_in_clause,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1118), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [27658] = 23,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1989), 1,
      sym_expression,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(1350), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [27760] = 24,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    ACTIONS(1342), 1,
      anon_sym_COLON,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1847), 1,
      sym_expression,
    STATE(2450), 1,
      sym_slice,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [27864] = 23,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1979), 1,
      sym_expression,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(1434), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [27966] = 24,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    ACTIONS(1342), 1,
      anon_sym_COLON,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1838), 1,
      sym_expression,
    STATE(2492), 1,
      sym_slice,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [28070] = 23,
    ACTIONS(706), 1,
      anon_sym_LPAREN,
    ACTIONS(714), 1,
      anon_sym_LBRACK,
    ACTIONS(718), 1,
      anon_sym_LBRACE,
    ACTIONS(724), 1,
      sym_string_start,
    ACTIONS(868), 1,
      sym_identifier,
    ACTIONS(880), 1,
      anon_sym_type,
    ACTIONS(884), 1,
      anon_sym_not,
    ACTIONS(890), 1,
      anon_sym_await,
    ACTIONS(1252), 1,
      anon_sym_STAR,
    ACTIONS(1258), 1,
      anon_sym_lambda,
    STATE(993), 1,
      sym_string,
    STATE(994), 1,
      sym_primary_expression,
    STATE(1218), 1,
      sym_list_splat_pattern,
    STATE(1817), 1,
      sym_expression,
    STATE(2685), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(720), 2,
      sym_ellipsis,
      sym_float,
    STATE(2059), 2,
      sym__expression_within_for_in_clause,
      sym_lambda_within_for_in_clause,
    ACTIONS(716), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(704), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(876), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1768), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1169), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [28172] = 24,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    ACTIONS(1342), 1,
      anon_sym_COLON,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1835), 1,
      sym_expression,
    STATE(2499), 1,
      sym_slice,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [28276] = 23,
    ACTIONS(728), 1,
      anon_sym_LPAREN,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(1114), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_type,
    ACTIONS(1122), 1,
      anon_sym_await,
    ACTIONS(1262), 1,
      anon_sym_STAR,
    ACTIONS(1266), 1,
      anon_sym_lambda,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1290), 1,
      sym_list_splat_pattern,
    STATE(1805), 1,
      sym_expression,
    STATE(2803), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    STATE(1940), 2,
      sym__expression_within_for_in_clause,
      sym_lambda_within_for_in_clause,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1118), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [28378] = 19,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(410), 1,
      anon_sym_STAR,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(675), 1,
      anon_sym_type,
    ACTIONS(677), 1,
      anon_sym_await,
    STATE(1004), 1,
      sym_string,
    STATE(1097), 1,
      sym_primary_expression,
    STATE(1433), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 2,
      anon_sym_DOT,
      anon_sym_SLASH,
    ACTIONS(319), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(673), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(277), 9,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_PIPE,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [28472] = 23,
    ACTIONS(728), 1,
      anon_sym_LPAREN,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(1114), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_type,
    ACTIONS(1122), 1,
      anon_sym_await,
    ACTIONS(1262), 1,
      anon_sym_STAR,
    ACTIONS(1266), 1,
      anon_sym_lambda,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1290), 1,
      sym_list_splat_pattern,
    STATE(1805), 1,
      sym_expression,
    STATE(2803), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    STATE(2035), 2,
      sym__expression_within_for_in_clause,
      sym_lambda_within_for_in_clause,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1118), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [28574] = 19,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(410), 1,
      anon_sym_STAR,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(675), 1,
      anon_sym_type,
    ACTIONS(677), 1,
      anon_sym_await,
    STATE(1004), 1,
      sym_string,
    STATE(1097), 1,
      sym_primary_expression,
    STATE(1433), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 2,
      anon_sym_DOT,
      anon_sym_SLASH,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(666), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(673), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(277), 9,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_PIPE,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [28668] = 23,
    ACTIONS(67), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_not,
    ACTIONS(71), 1,
      anon_sym_lambda,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(381), 1,
      sym_identifier,
    ACTIONS(393), 1,
      anon_sym_type,
    ACTIONS(404), 1,
      anon_sym_await,
    ACTIONS(652), 1,
      anon_sym_LPAREN,
    ACTIONS(660), 1,
      anon_sym_LBRACK,
    ACTIONS(1302), 1,
      anon_sym_STAR,
    STATE(975), 1,
      sym_string,
    STATE(977), 1,
      sym_primary_expression,
    STATE(1117), 1,
      sym_list_splat_pattern,
    STATE(1850), 1,
      sym_expression,
    STATE(2782), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(75), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(1436), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(65), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(77), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(389), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1687), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1057), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [28770] = 24,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    ACTIONS(1342), 1,
      anon_sym_COLON,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1815), 1,
      sym_expression,
    STATE(2300), 1,
      sym_slice,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [28874] = 23,
    ACTIONS(67), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_not,
    ACTIONS(71), 1,
      anon_sym_lambda,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(381), 1,
      sym_identifier,
    ACTIONS(393), 1,
      anon_sym_type,
    ACTIONS(404), 1,
      anon_sym_await,
    ACTIONS(652), 1,
      anon_sym_LPAREN,
    ACTIONS(660), 1,
      anon_sym_LBRACK,
    ACTIONS(1302), 1,
      anon_sym_STAR,
    STATE(975), 1,
      sym_string,
    STATE(977), 1,
      sym_primary_expression,
    STATE(1117), 1,
      sym_list_splat_pattern,
    STATE(1872), 1,
      sym_expression,
    STATE(2782), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(75), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(1438), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(65), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(77), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(389), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1687), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1057), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [28976] = 23,
    ACTIONS(706), 1,
      anon_sym_LPAREN,
    ACTIONS(714), 1,
      anon_sym_LBRACK,
    ACTIONS(718), 1,
      anon_sym_LBRACE,
    ACTIONS(724), 1,
      sym_string_start,
    ACTIONS(868), 1,
      sym_identifier,
    ACTIONS(880), 1,
      anon_sym_type,
    ACTIONS(884), 1,
      anon_sym_not,
    ACTIONS(890), 1,
      anon_sym_await,
    ACTIONS(1252), 1,
      anon_sym_STAR,
    ACTIONS(1258), 1,
      anon_sym_lambda,
    STATE(993), 1,
      sym_string,
    STATE(994), 1,
      sym_primary_expression,
    STATE(1218), 1,
      sym_list_splat_pattern,
    STATE(1845), 1,
      sym_expression,
    STATE(2685), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(720), 2,
      sym_ellipsis,
      sym_float,
    STATE(1996), 2,
      sym__expression_within_for_in_clause,
      sym_lambda_within_for_in_clause,
    ACTIONS(716), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(704), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(876), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1768), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1169), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [29078] = 23,
    ACTIONS(67), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_not,
    ACTIONS(71), 1,
      anon_sym_lambda,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(381), 1,
      sym_identifier,
    ACTIONS(393), 1,
      anon_sym_type,
    ACTIONS(404), 1,
      anon_sym_await,
    ACTIONS(652), 1,
      anon_sym_LPAREN,
    ACTIONS(660), 1,
      anon_sym_LBRACK,
    ACTIONS(1302), 1,
      anon_sym_STAR,
    STATE(975), 1,
      sym_string,
    STATE(977), 1,
      sym_primary_expression,
    STATE(1117), 1,
      sym_list_splat_pattern,
    STATE(1850), 1,
      sym_expression,
    STATE(2782), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(75), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(1440), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(65), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(77), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(389), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1687), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1057), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [29180] = 24,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    ACTIONS(1342), 1,
      anon_sym_COLON,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1831), 1,
      sym_expression,
    STATE(2475), 1,
      sym_slice,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [29284] = 23,
    ACTIONS(67), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_not,
    ACTIONS(71), 1,
      anon_sym_lambda,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(381), 1,
      sym_identifier,
    ACTIONS(393), 1,
      anon_sym_type,
    ACTIONS(404), 1,
      anon_sym_await,
    ACTIONS(652), 1,
      anon_sym_LPAREN,
    ACTIONS(660), 1,
      anon_sym_LBRACK,
    ACTIONS(1302), 1,
      anon_sym_STAR,
    STATE(975), 1,
      sym_string,
    STATE(977), 1,
      sym_primary_expression,
    STATE(1117), 1,
      sym_list_splat_pattern,
    STATE(1872), 1,
      sym_expression,
    STATE(2782), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(75), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(1442), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(65), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(77), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(389), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1687), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1057), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [29386] = 23,
    ACTIONS(67), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_not,
    ACTIONS(71), 1,
      anon_sym_lambda,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(381), 1,
      sym_identifier,
    ACTIONS(393), 1,
      anon_sym_type,
    ACTIONS(404), 1,
      anon_sym_await,
    ACTIONS(652), 1,
      anon_sym_LPAREN,
    ACTIONS(660), 1,
      anon_sym_LBRACK,
    ACTIONS(1302), 1,
      anon_sym_STAR,
    STATE(975), 1,
      sym_string,
    STATE(977), 1,
      sym_primary_expression,
    STATE(1117), 1,
      sym_list_splat_pattern,
    STATE(1872), 1,
      sym_expression,
    STATE(2782), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(75), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(1444), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(65), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(77), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(389), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1687), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1057), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [29488] = 19,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(410), 1,
      anon_sym_STAR,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(675), 1,
      anon_sym_type,
    ACTIONS(677), 1,
      anon_sym_await,
    STATE(1004), 1,
      sym_string,
    STATE(1097), 1,
      sym_primary_expression,
    STATE(1433), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 2,
      anon_sym_DOT,
      anon_sym_SLASH,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(1404), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(673), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(277), 9,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_PIPE,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [29582] = 23,
    ACTIONS(752), 1,
      anon_sym_LPAREN,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1064), 1,
      anon_sym_type,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1070), 1,
      anon_sym_await,
    ACTIONS(1282), 1,
      sym_identifier,
    ACTIONS(1306), 1,
      anon_sym_STAR,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1946), 1,
      sym_expression,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(1292), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1060), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [29684] = 23,
    ACTIONS(796), 1,
      anon_sym_LPAREN,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(808), 1,
      anon_sym_LBRACE,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(830), 1,
      anon_sym_not,
    ACTIONS(1150), 1,
      sym_identifier,
    ACTIONS(1156), 1,
      anon_sym_type,
    ACTIONS(1160), 1,
      anon_sym_await,
    ACTIONS(1286), 1,
      anon_sym_STAR,
    ACTIONS(1288), 1,
      anon_sym_lambda,
    STATE(1016), 1,
      sym_primary_expression,
    STATE(1017), 1,
      sym_string,
    STATE(1367), 1,
      sym_list_splat_pattern,
    STATE(1818), 1,
      sym_expression,
    STATE(2702), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      sym_ellipsis,
      sym_float,
    STATE(1947), 2,
      sym__expression_within_for_in_clause,
      sym_lambda_within_for_in_clause,
    ACTIONS(806), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(794), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1154), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1809), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1414), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [29786] = 23,
    ACTIONS(67), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_not,
    ACTIONS(71), 1,
      anon_sym_lambda,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(381), 1,
      sym_identifier,
    ACTIONS(393), 1,
      anon_sym_type,
    ACTIONS(404), 1,
      anon_sym_await,
    ACTIONS(652), 1,
      anon_sym_LPAREN,
    ACTIONS(660), 1,
      anon_sym_LBRACK,
    ACTIONS(1302), 1,
      anon_sym_STAR,
    STATE(975), 1,
      sym_string,
    STATE(977), 1,
      sym_primary_expression,
    STATE(1117), 1,
      sym_list_splat_pattern,
    STATE(1872), 1,
      sym_expression,
    STATE(2782), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(75), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(1446), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(65), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(77), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(389), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1687), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1057), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [29888] = 23,
    ACTIONS(706), 1,
      anon_sym_LPAREN,
    ACTIONS(714), 1,
      anon_sym_LBRACK,
    ACTIONS(718), 1,
      anon_sym_LBRACE,
    ACTIONS(724), 1,
      sym_string_start,
    ACTIONS(868), 1,
      sym_identifier,
    ACTIONS(880), 1,
      anon_sym_type,
    ACTIONS(884), 1,
      anon_sym_not,
    ACTIONS(890), 1,
      anon_sym_await,
    ACTIONS(1252), 1,
      anon_sym_STAR,
    ACTIONS(1258), 1,
      anon_sym_lambda,
    STATE(993), 1,
      sym_string,
    STATE(994), 1,
      sym_primary_expression,
    STATE(1218), 1,
      sym_list_splat_pattern,
    STATE(1845), 1,
      sym_expression,
    STATE(2685), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(720), 2,
      sym_ellipsis,
      sym_float,
    STATE(1982), 2,
      sym__expression_within_for_in_clause,
      sym_lambda_within_for_in_clause,
    ACTIONS(716), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(704), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(876), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1768), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1169), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [29990] = 23,
    ACTIONS(752), 1,
      anon_sym_LPAREN,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1064), 1,
      anon_sym_type,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1070), 1,
      anon_sym_await,
    ACTIONS(1282), 1,
      sym_identifier,
    ACTIONS(1306), 1,
      anon_sym_STAR,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1962), 1,
      sym_expression,
    STATE(2599), 1,
      sym_with_item,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1060), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [30091] = 23,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    ACTIONS(1448), 1,
      anon_sym_COLON,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1994), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [30192] = 11,
    ACTIONS(284), 1,
      anon_sym_COMMA,
    ACTIONS(292), 1,
      anon_sym_COLON_EQ,
    ACTIONS(294), 1,
      anon_sym_COLON,
    ACTIONS(302), 1,
      anon_sym_EQ,
    ACTIONS(1450), 1,
      sym_identifier,
    ACTIONS(1452), 1,
      sym_string_start,
    STATE(2472), 1,
      sym_string,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(277), 10,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
    ACTIONS(319), 13,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(279), 22,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_is,
  [30269] = 23,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    ACTIONS(1454), 1,
      anon_sym_COLON,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1993), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [30370] = 23,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    ACTIONS(1456), 1,
      anon_sym_COLON,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1994), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [30471] = 23,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1907), 1,
      sym_expression,
    STATE(2715), 1,
      sym_expression_list,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [30572] = 23,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    ACTIONS(1458), 1,
      anon_sym_COLON,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1994), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [30673] = 23,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1879), 1,
      sym_expression,
    STATE(2717), 1,
      sym_expression_list,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [30774] = 23,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1950), 1,
      sym_expression,
    STATE(2561), 1,
      sym_with_item,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [30875] = 10,
    ACTIONS(284), 1,
      anon_sym_COMMA,
    ACTIONS(292), 1,
      anon_sym_COLON_EQ,
    ACTIONS(1450), 1,
      sym_identifier,
    ACTIONS(1452), 1,
      sym_string_start,
    STATE(2472), 1,
      sym_string,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(302), 2,
      anon_sym_COLON,
      anon_sym_EQ,
    ACTIONS(277), 10,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
    ACTIONS(319), 13,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(279), 22,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_is,
  [30950] = 23,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1884), 1,
      sym_expression,
    STATE(2725), 1,
      sym_expression_list,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [31051] = 23,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1292), 1,
      anon_sym_COLON,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1958), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [31152] = 23,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1885), 1,
      sym_expression,
    STATE(2734), 1,
      sym_expression_list,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [31253] = 10,
    ACTIONS(284), 1,
      anon_sym_COMMA,
    ACTIONS(292), 1,
      anon_sym_COLON_EQ,
    ACTIONS(1460), 1,
      anon_sym_for,
    ACTIONS(1462), 1,
      anon_sym_with,
    ACTIONS(1464), 1,
      anon_sym_def,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(302), 2,
      anon_sym_COLON,
      anon_sym_EQ,
    ACTIONS(319), 13,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(279), 15,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(277), 17,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_as,
      anon_sym_if,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [31328] = 23,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    ACTIONS(1466), 1,
      anon_sym_COLON,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1994), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [31429] = 10,
    ACTIONS(284), 1,
      anon_sym_COMMA,
    ACTIONS(292), 1,
      anon_sym_COLON_EQ,
    ACTIONS(1468), 1,
      anon_sym_for,
    ACTIONS(1470), 1,
      anon_sym_with,
    ACTIONS(1472), 1,
      anon_sym_def,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(302), 2,
      anon_sym_COLON,
      anon_sym_EQ,
    ACTIONS(319), 13,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(279), 15,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(277), 17,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_as,
      anon_sym_if,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [31504] = 23,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    ACTIONS(1474), 1,
      anon_sym_COLON,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1961), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [31605] = 23,
    ACTIONS(67), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_not,
    ACTIONS(71), 1,
      anon_sym_lambda,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(381), 1,
      sym_identifier,
    ACTIONS(393), 1,
      anon_sym_type,
    ACTIONS(404), 1,
      anon_sym_await,
    ACTIONS(652), 1,
      anon_sym_LPAREN,
    ACTIONS(660), 1,
      anon_sym_LBRACK,
    ACTIONS(1302), 1,
      anon_sym_STAR,
    STATE(975), 1,
      sym_string,
    STATE(977), 1,
      sym_primary_expression,
    STATE(1117), 1,
      sym_list_splat_pattern,
    STATE(1849), 1,
      sym_expression,
    STATE(2622), 1,
      sym_expression_list,
    STATE(2782), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(75), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(65), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(77), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(389), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1687), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1057), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [31706] = 23,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1290), 1,
      anon_sym_COLON,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1958), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [31807] = 22,
    ACTIONS(67), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_not,
    ACTIONS(71), 1,
      anon_sym_lambda,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(381), 1,
      sym_identifier,
    ACTIONS(393), 1,
      anon_sym_type,
    ACTIONS(404), 1,
      anon_sym_await,
    ACTIONS(652), 1,
      anon_sym_LPAREN,
    ACTIONS(660), 1,
      anon_sym_LBRACK,
    ACTIONS(1302), 1,
      anon_sym_STAR,
    STATE(975), 1,
      sym_string,
    STATE(977), 1,
      sym_primary_expression,
    STATE(1117), 1,
      sym_list_splat_pattern,
    STATE(1693), 1,
      sym_expression,
    STATE(2782), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(75), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(65), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(77), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(389), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1687), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1057), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [31905] = 23,
    ACTIONS(752), 1,
      anon_sym_LPAREN,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1306), 1,
      anon_sym_STAR,
    ACTIONS(1476), 1,
      sym_identifier,
    ACTIONS(1480), 1,
      anon_sym_type,
    ACTIONS(1482), 1,
      anon_sym_await,
    STATE(1032), 1,
      sym_string,
    STATE(1274), 1,
      sym_primary_expression,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1922), 1,
      sym_expression,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    STATE(1442), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1478), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [32005] = 22,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1744), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [32103] = 22,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1741), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [32201] = 22,
    ACTIONS(67), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_not,
    ACTIONS(71), 1,
      anon_sym_lambda,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(381), 1,
      sym_identifier,
    ACTIONS(393), 1,
      anon_sym_type,
    ACTIONS(404), 1,
      anon_sym_await,
    ACTIONS(652), 1,
      anon_sym_LPAREN,
    ACTIONS(660), 1,
      anon_sym_LBRACK,
    ACTIONS(1302), 1,
      anon_sym_STAR,
    STATE(975), 1,
      sym_string,
    STATE(977), 1,
      sym_primary_expression,
    STATE(1117), 1,
      sym_list_splat_pattern,
    STATE(1689), 1,
      sym_expression,
    STATE(2782), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(75), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(65), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(77), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(389), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1687), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1057), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [32299] = 22,
    ACTIONS(67), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_not,
    ACTIONS(71), 1,
      anon_sym_lambda,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(381), 1,
      sym_identifier,
    ACTIONS(393), 1,
      anon_sym_type,
    ACTIONS(404), 1,
      anon_sym_await,
    ACTIONS(652), 1,
      anon_sym_LPAREN,
    ACTIONS(660), 1,
      anon_sym_LBRACK,
    ACTIONS(1302), 1,
      anon_sym_STAR,
    STATE(975), 1,
      sym_string,
    STATE(977), 1,
      sym_primary_expression,
    STATE(1117), 1,
      sym_list_splat_pattern,
    STATE(1688), 1,
      sym_expression,
    STATE(2782), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(75), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(65), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(77), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(389), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1687), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1057), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [32397] = 22,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1791), 1,
      sym_expression,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [32495] = 22,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1769), 1,
      sym_expression,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [32593] = 22,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1794), 1,
      sym_expression,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [32691] = 22,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1802), 1,
      sym_expression,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [32789] = 22,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1784), 1,
      sym_expression,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [32887] = 22,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1795), 1,
      sym_expression,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [32985] = 9,
    ACTIONS(1488), 1,
      anon_sym_else,
    ACTIONS(1490), 1,
      anon_sym_except_STAR,
    ACTIONS(1492), 1,
      anon_sym_finally,
    STATE(718), 1,
      sym_else_clause,
    STATE(771), 1,
      sym_finally_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(620), 2,
      sym_except_group_clause,
      aux_sym_try_statement_repeat2,
    ACTIONS(1486), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1484), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [33057] = 9,
    ACTIONS(1488), 1,
      anon_sym_else,
    ACTIONS(1492), 1,
      anon_sym_finally,
    ACTIONS(1494), 1,
      anon_sym_except,
    STATE(718), 1,
      sym_else_clause,
    STATE(771), 1,
      sym_finally_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(611), 2,
      sym_except_clause,
      aux_sym_try_statement_repeat1,
    ACTIONS(1486), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1484), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [33129] = 22,
    ACTIONS(67), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_not,
    ACTIONS(71), 1,
      anon_sym_lambda,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(381), 1,
      sym_identifier,
    ACTIONS(393), 1,
      anon_sym_type,
    ACTIONS(404), 1,
      anon_sym_await,
    ACTIONS(652), 1,
      anon_sym_LPAREN,
    ACTIONS(660), 1,
      anon_sym_LBRACK,
    ACTIONS(1302), 1,
      anon_sym_STAR,
    STATE(975), 1,
      sym_string,
    STATE(977), 1,
      sym_primary_expression,
    STATE(1117), 1,
      sym_list_splat_pattern,
    STATE(1872), 1,
      sym_expression,
    STATE(2782), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(75), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(65), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(77), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(389), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1687), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1057), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [33227] = 22,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(2103), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [33325] = 22,
    ACTIONS(728), 1,
      anon_sym_LPAREN,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(854), 1,
      anon_sym_lambda,
    ACTIONS(1114), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_type,
    ACTIONS(1122), 1,
      anon_sym_await,
    ACTIONS(1262), 1,
      anon_sym_STAR,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1290), 1,
      sym_list_splat_pattern,
    STATE(1816), 1,
      sym_expression,
    STATE(2803), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1118), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [33423] = 9,
    ACTIONS(1488), 1,
      anon_sym_else,
    ACTIONS(1490), 1,
      anon_sym_except_STAR,
    ACTIONS(1492), 1,
      anon_sym_finally,
    STATE(704), 1,
      sym_else_clause,
    STATE(733), 1,
      sym_finally_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(620), 2,
      sym_except_group_clause,
      aux_sym_try_statement_repeat2,
    ACTIONS(1498), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1496), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [33495] = 9,
    ACTIONS(1488), 1,
      anon_sym_else,
    ACTIONS(1492), 1,
      anon_sym_finally,
    ACTIONS(1494), 1,
      anon_sym_except,
    STATE(704), 1,
      sym_else_clause,
    STATE(733), 1,
      sym_finally_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(611), 2,
      sym_except_clause,
      aux_sym_try_statement_repeat1,
    ACTIONS(1498), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1496), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [33567] = 22,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1782), 1,
      sym_expression,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [33665] = 23,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    ACTIONS(1500), 1,
      sym_identifier,
    ACTIONS(1504), 1,
      anon_sym_type,
    ACTIONS(1506), 1,
      anon_sym_await,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1999), 1,
      sym_expression,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    STATE(1514), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1502), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [33765] = 22,
    ACTIONS(706), 1,
      anon_sym_LPAREN,
    ACTIONS(714), 1,
      anon_sym_LBRACK,
    ACTIONS(718), 1,
      anon_sym_LBRACE,
    ACTIONS(724), 1,
      sym_string_start,
    ACTIONS(868), 1,
      sym_identifier,
    ACTIONS(880), 1,
      anon_sym_type,
    ACTIONS(884), 1,
      anon_sym_not,
    ACTIONS(886), 1,
      anon_sym_lambda,
    ACTIONS(890), 1,
      anon_sym_await,
    ACTIONS(1252), 1,
      anon_sym_STAR,
    STATE(993), 1,
      sym_string,
    STATE(994), 1,
      sym_primary_expression,
    STATE(1218), 1,
      sym_list_splat_pattern,
    STATE(1788), 1,
      sym_expression,
    STATE(2685), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(720), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(716), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(704), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(876), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1768), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1169), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [33863] = 22,
    ACTIONS(728), 1,
      anon_sym_LPAREN,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(854), 1,
      anon_sym_lambda,
    ACTIONS(1114), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_type,
    ACTIONS(1122), 1,
      anon_sym_await,
    ACTIONS(1262), 1,
      anon_sym_STAR,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1290), 1,
      sym_list_splat_pattern,
    STATE(1823), 1,
      sym_expression,
    STATE(2803), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1118), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [33961] = 22,
    ACTIONS(728), 1,
      anon_sym_LPAREN,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(854), 1,
      anon_sym_lambda,
    ACTIONS(1114), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_type,
    ACTIONS(1122), 1,
      anon_sym_await,
    ACTIONS(1262), 1,
      anon_sym_STAR,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1290), 1,
      sym_list_splat_pattern,
    STATE(1843), 1,
      sym_expression,
    STATE(2803), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1118), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [34059] = 23,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    ACTIONS(1506), 1,
      anon_sym_await,
    ACTIONS(1508), 1,
      sym_identifier,
    ACTIONS(1512), 1,
      anon_sym_type,
    STATE(1150), 1,
      sym_string,
    STATE(1179), 1,
      sym_primary_expression,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1999), 1,
      sym_expression,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    STATE(1291), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1510), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [34159] = 22,
    ACTIONS(752), 1,
      anon_sym_LPAREN,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1064), 1,
      anon_sym_type,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1070), 1,
      anon_sym_await,
    ACTIONS(1282), 1,
      sym_identifier,
    ACTIONS(1306), 1,
      anon_sym_STAR,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1945), 1,
      sym_expression,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1060), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [34257] = 22,
    ACTIONS(684), 1,
      anon_sym_LPAREN,
    ACTIONS(692), 1,
      anon_sym_LBRACK,
    ACTIONS(696), 1,
      anon_sym_LBRACE,
    ACTIONS(702), 1,
      sym_string_start,
    ACTIONS(998), 1,
      anon_sym_STAR,
    ACTIONS(1006), 1,
      anon_sym_not,
    ACTIONS(1008), 1,
      anon_sym_lambda,
    ACTIONS(1102), 1,
      sym_identifier,
    ACTIONS(1110), 1,
      anon_sym_type,
    ACTIONS(1112), 1,
      anon_sym_await,
    STATE(979), 1,
      sym_string,
    STATE(996), 1,
      sym_primary_expression,
    STATE(1183), 1,
      sym_list_splat_pattern,
    STATE(2006), 1,
      sym_expression,
    STATE(2830), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(698), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(694), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(682), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1108), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1783), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1241), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [34355] = 22,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1994), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [34453] = 22,
    ACTIONS(684), 1,
      anon_sym_LPAREN,
    ACTIONS(692), 1,
      anon_sym_LBRACK,
    ACTIONS(696), 1,
      anon_sym_LBRACE,
    ACTIONS(702), 1,
      sym_string_start,
    ACTIONS(998), 1,
      anon_sym_STAR,
    ACTIONS(1006), 1,
      anon_sym_not,
    ACTIONS(1008), 1,
      anon_sym_lambda,
    ACTIONS(1102), 1,
      sym_identifier,
    ACTIONS(1110), 1,
      anon_sym_type,
    ACTIONS(1112), 1,
      anon_sym_await,
    STATE(979), 1,
      sym_string,
    STATE(996), 1,
      sym_primary_expression,
    STATE(1183), 1,
      sym_list_splat_pattern,
    STATE(1781), 1,
      sym_expression,
    STATE(2830), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(698), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(694), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(682), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1108), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1783), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1241), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [34551] = 22,
    ACTIONS(752), 1,
      anon_sym_LPAREN,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1064), 1,
      anon_sym_type,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1070), 1,
      anon_sym_await,
    ACTIONS(1282), 1,
      sym_identifier,
    ACTIONS(1306), 1,
      anon_sym_STAR,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(2009), 1,
      sym_expression,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1060), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [34649] = 22,
    ACTIONS(796), 1,
      anon_sym_LPAREN,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(808), 1,
      anon_sym_LBRACE,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(830), 1,
      anon_sym_not,
    ACTIONS(832), 1,
      anon_sym_lambda,
    ACTIONS(1150), 1,
      sym_identifier,
    ACTIONS(1156), 1,
      anon_sym_type,
    ACTIONS(1160), 1,
      anon_sym_await,
    ACTIONS(1286), 1,
      anon_sym_STAR,
    STATE(1016), 1,
      sym_primary_expression,
    STATE(1017), 1,
      sym_string,
    STATE(1367), 1,
      sym_list_splat_pattern,
    STATE(1875), 1,
      sym_expression,
    STATE(2702), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(806), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(794), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1154), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1809), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1414), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [34747] = 22,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(2067), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [34845] = 22,
    ACTIONS(706), 1,
      anon_sym_LPAREN,
    ACTIONS(714), 1,
      anon_sym_LBRACK,
    ACTIONS(718), 1,
      anon_sym_LBRACE,
    ACTIONS(724), 1,
      sym_string_start,
    ACTIONS(868), 1,
      sym_identifier,
    ACTIONS(880), 1,
      anon_sym_type,
    ACTIONS(884), 1,
      anon_sym_not,
    ACTIONS(886), 1,
      anon_sym_lambda,
    ACTIONS(890), 1,
      anon_sym_await,
    ACTIONS(1252), 1,
      anon_sym_STAR,
    STATE(993), 1,
      sym_string,
    STATE(994), 1,
      sym_primary_expression,
    STATE(1218), 1,
      sym_list_splat_pattern,
    STATE(1771), 1,
      sym_expression,
    STATE(2685), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(720), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(716), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(704), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(876), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1768), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1169), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [34943] = 22,
    ACTIONS(67), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_not,
    ACTIONS(71), 1,
      anon_sym_lambda,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(381), 1,
      sym_identifier,
    ACTIONS(393), 1,
      anon_sym_type,
    ACTIONS(404), 1,
      anon_sym_await,
    ACTIONS(652), 1,
      anon_sym_LPAREN,
    ACTIONS(660), 1,
      anon_sym_LBRACK,
    ACTIONS(1302), 1,
      anon_sym_STAR,
    STATE(975), 1,
      sym_string,
    STATE(977), 1,
      sym_primary_expression,
    STATE(1117), 1,
      sym_list_splat_pattern,
    STATE(1936), 1,
      sym_expression,
    STATE(2782), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(75), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(65), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(77), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(389), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1687), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1057), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [35041] = 22,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1787), 1,
      sym_expression,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [35139] = 23,
    ACTIONS(752), 1,
      anon_sym_LPAREN,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1306), 1,
      anon_sym_STAR,
    ACTIONS(1482), 1,
      anon_sym_await,
    ACTIONS(1514), 1,
      sym_identifier,
    ACTIONS(1518), 1,
      anon_sym_type,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1922), 1,
      sym_expression,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    STATE(1513), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1516), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [35239] = 22,
    ACTIONS(728), 1,
      anon_sym_LPAREN,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(854), 1,
      anon_sym_lambda,
    ACTIONS(1114), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_type,
    ACTIONS(1122), 1,
      anon_sym_await,
    ACTIONS(1262), 1,
      anon_sym_STAR,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1290), 1,
      sym_list_splat_pattern,
    STATE(1826), 1,
      sym_expression,
    STATE(2803), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1118), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [35337] = 22,
    ACTIONS(728), 1,
      anon_sym_LPAREN,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(854), 1,
      anon_sym_lambda,
    ACTIONS(1114), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_type,
    ACTIONS(1122), 1,
      anon_sym_await,
    ACTIONS(1262), 1,
      anon_sym_STAR,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1290), 1,
      sym_list_splat_pattern,
    STATE(1822), 1,
      sym_expression,
    STATE(2803), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1118), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [35435] = 22,
    ACTIONS(796), 1,
      anon_sym_LPAREN,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(808), 1,
      anon_sym_LBRACE,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(830), 1,
      anon_sym_not,
    ACTIONS(832), 1,
      anon_sym_lambda,
    ACTIONS(1150), 1,
      sym_identifier,
    ACTIONS(1156), 1,
      anon_sym_type,
    ACTIONS(1160), 1,
      anon_sym_await,
    ACTIONS(1286), 1,
      anon_sym_STAR,
    STATE(1016), 1,
      sym_primary_expression,
    STATE(1017), 1,
      sym_string,
    STATE(1367), 1,
      sym_list_splat_pattern,
    STATE(1819), 1,
      sym_expression,
    STATE(2702), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(806), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(794), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1154), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1809), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1414), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [35533] = 22,
    ACTIONS(728), 1,
      anon_sym_LPAREN,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(854), 1,
      anon_sym_lambda,
    ACTIONS(1114), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_type,
    ACTIONS(1122), 1,
      anon_sym_await,
    ACTIONS(1262), 1,
      anon_sym_STAR,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1290), 1,
      sym_list_splat_pattern,
    STATE(1814), 1,
      sym_expression,
    STATE(2803), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1118), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [35631] = 22,
    ACTIONS(728), 1,
      anon_sym_LPAREN,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(854), 1,
      anon_sym_lambda,
    ACTIONS(1114), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_type,
    ACTIONS(1122), 1,
      anon_sym_await,
    ACTIONS(1262), 1,
      anon_sym_STAR,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1290), 1,
      sym_list_splat_pattern,
    STATE(1810), 1,
      sym_expression,
    STATE(2803), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1118), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [35729] = 22,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1976), 1,
      sym_expression,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [35827] = 22,
    ACTIONS(752), 1,
      anon_sym_LPAREN,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1064), 1,
      anon_sym_type,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1070), 1,
      anon_sym_await,
    ACTIONS(1282), 1,
      sym_identifier,
    ACTIONS(1306), 1,
      anon_sym_STAR,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1920), 1,
      sym_expression,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1060), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [35925] = 22,
    ACTIONS(728), 1,
      anon_sym_LPAREN,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(854), 1,
      anon_sym_lambda,
    ACTIONS(1114), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_type,
    ACTIONS(1122), 1,
      anon_sym_await,
    ACTIONS(1262), 1,
      anon_sym_STAR,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1290), 1,
      sym_list_splat_pattern,
    STATE(1811), 1,
      sym_expression,
    STATE(2803), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1118), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [36023] = 22,
    ACTIONS(67), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_not,
    ACTIONS(71), 1,
      anon_sym_lambda,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(381), 1,
      sym_identifier,
    ACTIONS(393), 1,
      anon_sym_type,
    ACTIONS(404), 1,
      anon_sym_await,
    ACTIONS(652), 1,
      anon_sym_LPAREN,
    ACTIONS(660), 1,
      anon_sym_LBRACK,
    ACTIONS(1302), 1,
      anon_sym_STAR,
    STATE(975), 1,
      sym_string,
    STATE(977), 1,
      sym_primary_expression,
    STATE(1117), 1,
      sym_list_splat_pattern,
    STATE(1899), 1,
      sym_expression,
    STATE(2782), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(75), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(65), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(77), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(389), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1687), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1057), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [36121] = 22,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1749), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [36219] = 22,
    ACTIONS(684), 1,
      anon_sym_LPAREN,
    ACTIONS(692), 1,
      anon_sym_LBRACK,
    ACTIONS(696), 1,
      anon_sym_LBRACE,
    ACTIONS(702), 1,
      sym_string_start,
    ACTIONS(998), 1,
      anon_sym_STAR,
    ACTIONS(1006), 1,
      anon_sym_not,
    ACTIONS(1008), 1,
      anon_sym_lambda,
    ACTIONS(1102), 1,
      sym_identifier,
    ACTIONS(1110), 1,
      anon_sym_type,
    ACTIONS(1112), 1,
      anon_sym_await,
    STATE(979), 1,
      sym_string,
    STATE(996), 1,
      sym_primary_expression,
    STATE(1183), 1,
      sym_list_splat_pattern,
    STATE(1797), 1,
      sym_expression,
    STATE(2830), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(698), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(694), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(682), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1108), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1783), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1241), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [36317] = 9,
    ACTIONS(1520), 1,
      anon_sym_else,
    ACTIONS(1522), 1,
      anon_sym_except,
    ACTIONS(1524), 1,
      anon_sym_finally,
    STATE(709), 1,
      sym_else_clause,
    STATE(824), 1,
      sym_finally_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(624), 2,
      sym_except_clause,
      aux_sym_try_statement_repeat1,
    ACTIONS(1486), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1484), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [36389] = 9,
    ACTIONS(1520), 1,
      anon_sym_else,
    ACTIONS(1524), 1,
      anon_sym_finally,
    ACTIONS(1526), 1,
      anon_sym_except_STAR,
    STATE(709), 1,
      sym_else_clause,
    STATE(824), 1,
      sym_finally_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(625), 2,
      sym_except_group_clause,
      aux_sym_try_statement_repeat2,
    ACTIONS(1486), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1484), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [36461] = 22,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1750), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [36559] = 22,
    ACTIONS(752), 1,
      anon_sym_LPAREN,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1064), 1,
      anon_sym_type,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1070), 1,
      anon_sym_await,
    ACTIONS(1282), 1,
      sym_identifier,
    ACTIONS(1306), 1,
      anon_sym_STAR,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1760), 1,
      sym_expression,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1060), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [36657] = 22,
    ACTIONS(752), 1,
      anon_sym_LPAREN,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1064), 1,
      anon_sym_type,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1070), 1,
      anon_sym_await,
    ACTIONS(1282), 1,
      sym_identifier,
    ACTIONS(1306), 1,
      anon_sym_STAR,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1754), 1,
      sym_expression,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1060), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [36755] = 22,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1958), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [36853] = 22,
    ACTIONS(728), 1,
      anon_sym_LPAREN,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(852), 1,
      anon_sym_not,
    ACTIONS(854), 1,
      anon_sym_lambda,
    ACTIONS(1114), 1,
      sym_identifier,
    ACTIONS(1120), 1,
      anon_sym_type,
    ACTIONS(1122), 1,
      anon_sym_await,
    ACTIONS(1262), 1,
      anon_sym_STAR,
    STATE(1024), 1,
      sym_primary_expression,
    STATE(1030), 1,
      sym_string,
    STATE(1290), 1,
      sym_list_splat_pattern,
    STATE(1873), 1,
      sym_expression,
    STATE(2803), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(726), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1118), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1832), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [36951] = 22,
    ACTIONS(752), 1,
      anon_sym_LPAREN,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1064), 1,
      anon_sym_type,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1070), 1,
      anon_sym_await,
    ACTIONS(1282), 1,
      sym_identifier,
    ACTIONS(1306), 1,
      anon_sym_STAR,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1738), 1,
      sym_expression,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1060), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [37049] = 22,
    ACTIONS(752), 1,
      anon_sym_LPAREN,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1064), 1,
      anon_sym_type,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1070), 1,
      anon_sym_await,
    ACTIONS(1282), 1,
      sym_identifier,
    ACTIONS(1306), 1,
      anon_sym_STAR,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1737), 1,
      sym_expression,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1060), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [37147] = 22,
    ACTIONS(752), 1,
      anon_sym_LPAREN,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1064), 1,
      anon_sym_type,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1070), 1,
      anon_sym_await,
    ACTIONS(1282), 1,
      sym_identifier,
    ACTIONS(1306), 1,
      anon_sym_STAR,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1735), 1,
      sym_expression,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1060), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [37245] = 22,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1762), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [37343] = 22,
    ACTIONS(752), 1,
      anon_sym_LPAREN,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1064), 1,
      anon_sym_type,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1070), 1,
      anon_sym_await,
    ACTIONS(1282), 1,
      sym_identifier,
    ACTIONS(1306), 1,
      anon_sym_STAR,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1734), 1,
      sym_expression,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1060), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [37441] = 22,
    ACTIONS(752), 1,
      anon_sym_LPAREN,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1064), 1,
      anon_sym_type,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1070), 1,
      anon_sym_await,
    ACTIONS(1282), 1,
      sym_identifier,
    ACTIONS(1306), 1,
      anon_sym_STAR,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1985), 1,
      sym_expression,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1060), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [37539] = 22,
    ACTIONS(752), 1,
      anon_sym_LPAREN,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1064), 1,
      anon_sym_type,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1070), 1,
      anon_sym_await,
    ACTIONS(1282), 1,
      sym_identifier,
    ACTIONS(1306), 1,
      anon_sym_STAR,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1990), 1,
      sym_expression,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1060), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [37637] = 22,
    ACTIONS(752), 1,
      anon_sym_LPAREN,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1064), 1,
      anon_sym_type,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1070), 1,
      anon_sym_await,
    ACTIONS(1282), 1,
      sym_identifier,
    ACTIONS(1306), 1,
      anon_sym_STAR,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1983), 1,
      sym_expression,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1060), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [37735] = 22,
    ACTIONS(706), 1,
      anon_sym_LPAREN,
    ACTIONS(714), 1,
      anon_sym_LBRACK,
    ACTIONS(718), 1,
      anon_sym_LBRACE,
    ACTIONS(724), 1,
      sym_string_start,
    ACTIONS(868), 1,
      sym_identifier,
    ACTIONS(880), 1,
      anon_sym_type,
    ACTIONS(884), 1,
      anon_sym_not,
    ACTIONS(886), 1,
      anon_sym_lambda,
    ACTIONS(890), 1,
      anon_sym_await,
    ACTIONS(1252), 1,
      anon_sym_STAR,
    STATE(993), 1,
      sym_string,
    STATE(994), 1,
      sym_primary_expression,
    STATE(1218), 1,
      sym_list_splat_pattern,
    STATE(1864), 1,
      sym_expression,
    STATE(2685), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(720), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(716), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(704), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(876), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1768), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1169), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [37833] = 22,
    ACTIONS(67), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_not,
    ACTIONS(71), 1,
      anon_sym_lambda,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(381), 1,
      sym_identifier,
    ACTIONS(393), 1,
      anon_sym_type,
    ACTIONS(404), 1,
      anon_sym_await,
    ACTIONS(652), 1,
      anon_sym_LPAREN,
    ACTIONS(660), 1,
      anon_sym_LBRACK,
    ACTIONS(1302), 1,
      anon_sym_STAR,
    STATE(975), 1,
      sym_string,
    STATE(977), 1,
      sym_primary_expression,
    STATE(1117), 1,
      sym_list_splat_pattern,
    STATE(1696), 1,
      sym_expression,
    STATE(2782), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(75), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(65), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(77), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(389), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1687), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1057), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [37931] = 22,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(2013), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [38029] = 22,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1746), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [38127] = 22,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(2064), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [38225] = 22,
    ACTIONS(752), 1,
      anon_sym_LPAREN,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1064), 1,
      anon_sym_type,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1070), 1,
      anon_sym_await,
    ACTIONS(1282), 1,
      sym_identifier,
    ACTIONS(1306), 1,
      anon_sym_STAR,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1745), 1,
      sym_expression,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1060), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [38323] = 22,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(2096), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [38421] = 22,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(2124), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [38519] = 22,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1748), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [38617] = 22,
    ACTIONS(67), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_not,
    ACTIONS(71), 1,
      anon_sym_lambda,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(381), 1,
      sym_identifier,
    ACTIONS(393), 1,
      anon_sym_type,
    ACTIONS(404), 1,
      anon_sym_await,
    ACTIONS(652), 1,
      anon_sym_LPAREN,
    ACTIONS(660), 1,
      anon_sym_LBRACK,
    ACTIONS(1302), 1,
      anon_sym_STAR,
    STATE(975), 1,
      sym_string,
    STATE(977), 1,
      sym_primary_expression,
    STATE(1117), 1,
      sym_list_splat_pattern,
    STATE(1850), 1,
      sym_expression,
    STATE(2782), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(75), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(65), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(77), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(389), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1687), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1057), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [38715] = 22,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(2010), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [38813] = 22,
    ACTIONS(67), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_not,
    ACTIONS(71), 1,
      anon_sym_lambda,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(381), 1,
      sym_identifier,
    ACTIONS(393), 1,
      anon_sym_type,
    ACTIONS(404), 1,
      anon_sym_await,
    ACTIONS(652), 1,
      anon_sym_LPAREN,
    ACTIONS(660), 1,
      anon_sym_LBRACK,
    ACTIONS(1302), 1,
      anon_sym_STAR,
    STATE(975), 1,
      sym_string,
    STATE(977), 1,
      sym_primary_expression,
    STATE(1117), 1,
      sym_list_splat_pattern,
    STATE(1685), 1,
      sym_expression,
    STATE(2782), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(75), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(65), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(77), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(389), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1687), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1057), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [38911] = 22,
    ACTIONS(684), 1,
      anon_sym_LPAREN,
    ACTIONS(692), 1,
      anon_sym_LBRACK,
    ACTIONS(696), 1,
      anon_sym_LBRACE,
    ACTIONS(702), 1,
      sym_string_start,
    ACTIONS(998), 1,
      anon_sym_STAR,
    ACTIONS(1006), 1,
      anon_sym_not,
    ACTIONS(1008), 1,
      anon_sym_lambda,
    ACTIONS(1102), 1,
      sym_identifier,
    ACTIONS(1110), 1,
      anon_sym_type,
    ACTIONS(1112), 1,
      anon_sym_await,
    STATE(979), 1,
      sym_string,
    STATE(996), 1,
      sym_primary_expression,
    STATE(1183), 1,
      sym_list_splat_pattern,
    STATE(1800), 1,
      sym_expression,
    STATE(2830), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(698), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(694), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(682), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1108), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1783), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1241), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [39009] = 22,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(2031), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [39107] = 22,
    ACTIONS(684), 1,
      anon_sym_LPAREN,
    ACTIONS(692), 1,
      anon_sym_LBRACK,
    ACTIONS(696), 1,
      anon_sym_LBRACE,
    ACTIONS(702), 1,
      sym_string_start,
    ACTIONS(998), 1,
      anon_sym_STAR,
    ACTIONS(1006), 1,
      anon_sym_not,
    ACTIONS(1008), 1,
      anon_sym_lambda,
    ACTIONS(1102), 1,
      sym_identifier,
    ACTIONS(1110), 1,
      anon_sym_type,
    ACTIONS(1112), 1,
      anon_sym_await,
    STATE(979), 1,
      sym_string,
    STATE(996), 1,
      sym_primary_expression,
    STATE(1183), 1,
      sym_list_splat_pattern,
    STATE(1799), 1,
      sym_expression,
    STATE(2830), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(698), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(694), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(682), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1108), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1783), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1241), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [39205] = 22,
    ACTIONS(684), 1,
      anon_sym_LPAREN,
    ACTIONS(692), 1,
      anon_sym_LBRACK,
    ACTIONS(696), 1,
      anon_sym_LBRACE,
    ACTIONS(702), 1,
      sym_string_start,
    ACTIONS(998), 1,
      anon_sym_STAR,
    ACTIONS(1006), 1,
      anon_sym_not,
    ACTIONS(1008), 1,
      anon_sym_lambda,
    ACTIONS(1102), 1,
      sym_identifier,
    ACTIONS(1110), 1,
      anon_sym_type,
    ACTIONS(1112), 1,
      anon_sym_await,
    STATE(979), 1,
      sym_string,
    STATE(996), 1,
      sym_primary_expression,
    STATE(1183), 1,
      sym_list_splat_pattern,
    STATE(1778), 1,
      sym_expression,
    STATE(2830), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(698), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(694), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(682), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1108), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1783), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1241), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [39303] = 23,
    ACTIONS(684), 1,
      anon_sym_LPAREN,
    ACTIONS(692), 1,
      anon_sym_LBRACK,
    ACTIONS(696), 1,
      anon_sym_LBRACE,
    ACTIONS(702), 1,
      sym_string_start,
    ACTIONS(998), 1,
      anon_sym_STAR,
    ACTIONS(1006), 1,
      anon_sym_not,
    ACTIONS(1008), 1,
      anon_sym_lambda,
    ACTIONS(1528), 1,
      sym_identifier,
    ACTIONS(1532), 1,
      anon_sym_type,
    ACTIONS(1534), 1,
      anon_sym_await,
    STATE(979), 1,
      sym_string,
    STATE(1183), 1,
      sym_list_splat_pattern,
    STATE(1235), 1,
      sym_primary_expression,
    STATE(1930), 1,
      sym_expression,
    STATE(2830), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(698), 2,
      sym_ellipsis,
      sym_float,
    STATE(1247), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(694), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(682), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1530), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1783), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1241), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [39403] = 22,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(2054), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [39501] = 22,
    ACTIONS(684), 1,
      anon_sym_LPAREN,
    ACTIONS(692), 1,
      anon_sym_LBRACK,
    ACTIONS(696), 1,
      anon_sym_LBRACE,
    ACTIONS(702), 1,
      sym_string_start,
    ACTIONS(998), 1,
      anon_sym_STAR,
    ACTIONS(1006), 1,
      anon_sym_not,
    ACTIONS(1008), 1,
      anon_sym_lambda,
    ACTIONS(1102), 1,
      sym_identifier,
    ACTIONS(1110), 1,
      anon_sym_type,
    ACTIONS(1112), 1,
      anon_sym_await,
    STATE(979), 1,
      sym_string,
    STATE(996), 1,
      sym_primary_expression,
    STATE(1183), 1,
      sym_list_splat_pattern,
    STATE(1777), 1,
      sym_expression,
    STATE(2830), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(698), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(694), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(682), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1108), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1783), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1241), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [39599] = 22,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(2114), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [39697] = 22,
    ACTIONS(706), 1,
      anon_sym_LPAREN,
    ACTIONS(714), 1,
      anon_sym_LBRACK,
    ACTIONS(718), 1,
      anon_sym_LBRACE,
    ACTIONS(724), 1,
      sym_string_start,
    ACTIONS(868), 1,
      sym_identifier,
    ACTIONS(880), 1,
      anon_sym_type,
    ACTIONS(884), 1,
      anon_sym_not,
    ACTIONS(886), 1,
      anon_sym_lambda,
    ACTIONS(890), 1,
      anon_sym_await,
    ACTIONS(1252), 1,
      anon_sym_STAR,
    STATE(993), 1,
      sym_string,
    STATE(994), 1,
      sym_primary_expression,
    STATE(1218), 1,
      sym_list_splat_pattern,
    STATE(1825), 1,
      sym_expression,
    STATE(2685), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(720), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(716), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(704), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(876), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1768), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1169), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [39795] = 22,
    ACTIONS(684), 1,
      anon_sym_LPAREN,
    ACTIONS(692), 1,
      anon_sym_LBRACK,
    ACTIONS(696), 1,
      anon_sym_LBRACE,
    ACTIONS(702), 1,
      sym_string_start,
    ACTIONS(998), 1,
      anon_sym_STAR,
    ACTIONS(1006), 1,
      anon_sym_not,
    ACTIONS(1008), 1,
      anon_sym_lambda,
    ACTIONS(1102), 1,
      sym_identifier,
    ACTIONS(1110), 1,
      anon_sym_type,
    ACTIONS(1112), 1,
      anon_sym_await,
    STATE(979), 1,
      sym_string,
    STATE(996), 1,
      sym_primary_expression,
    STATE(1183), 1,
      sym_list_splat_pattern,
    STATE(1776), 1,
      sym_expression,
    STATE(2830), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(698), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(694), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(682), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1108), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1783), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1241), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [39893] = 22,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(2132), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [39991] = 22,
    ACTIONS(67), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_not,
    ACTIONS(71), 1,
      anon_sym_lambda,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(381), 1,
      sym_identifier,
    ACTIONS(393), 1,
      anon_sym_type,
    ACTIONS(404), 1,
      anon_sym_await,
    ACTIONS(652), 1,
      anon_sym_LPAREN,
    ACTIONS(660), 1,
      anon_sym_LBRACK,
    ACTIONS(1302), 1,
      anon_sym_STAR,
    STATE(975), 1,
      sym_string,
    STATE(977), 1,
      sym_primary_expression,
    STATE(1117), 1,
      sym_list_splat_pattern,
    STATE(1984), 1,
      sym_expression,
    STATE(2782), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(75), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(65), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(77), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(389), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1687), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1057), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [40089] = 22,
    ACTIONS(796), 1,
      anon_sym_LPAREN,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(808), 1,
      anon_sym_LBRACE,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(830), 1,
      anon_sym_not,
    ACTIONS(832), 1,
      anon_sym_lambda,
    ACTIONS(1150), 1,
      sym_identifier,
    ACTIONS(1156), 1,
      anon_sym_type,
    ACTIONS(1160), 1,
      anon_sym_await,
    ACTIONS(1286), 1,
      anon_sym_STAR,
    STATE(1016), 1,
      sym_primary_expression,
    STATE(1017), 1,
      sym_string,
    STATE(1367), 1,
      sym_list_splat_pattern,
    STATE(1846), 1,
      sym_expression,
    STATE(2702), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(806), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(794), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1154), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1809), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1414), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [40187] = 22,
    ACTIONS(796), 1,
      anon_sym_LPAREN,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(808), 1,
      anon_sym_LBRACE,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(830), 1,
      anon_sym_not,
    ACTIONS(832), 1,
      anon_sym_lambda,
    ACTIONS(1150), 1,
      sym_identifier,
    ACTIONS(1156), 1,
      anon_sym_type,
    ACTIONS(1160), 1,
      anon_sym_await,
    ACTIONS(1286), 1,
      anon_sym_STAR,
    STATE(1016), 1,
      sym_primary_expression,
    STATE(1017), 1,
      sym_string,
    STATE(1367), 1,
      sym_list_splat_pattern,
    STATE(1804), 1,
      sym_expression,
    STATE(2702), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(806), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(794), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1154), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1809), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1414), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [40285] = 22,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(2125), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [40383] = 22,
    ACTIONS(67), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_not,
    ACTIONS(71), 1,
      anon_sym_lambda,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(381), 1,
      sym_identifier,
    ACTIONS(393), 1,
      anon_sym_type,
    ACTIONS(404), 1,
      anon_sym_await,
    ACTIONS(652), 1,
      anon_sym_LPAREN,
    ACTIONS(660), 1,
      anon_sym_LBRACK,
    ACTIONS(1302), 1,
      anon_sym_STAR,
    STATE(975), 1,
      sym_string,
    STATE(977), 1,
      sym_primary_expression,
    STATE(1117), 1,
      sym_list_splat_pattern,
    STATE(1697), 1,
      sym_expression,
    STATE(2782), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(75), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(65), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(77), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(389), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1687), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1057), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [40481] = 22,
    ACTIONS(796), 1,
      anon_sym_LPAREN,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(808), 1,
      anon_sym_LBRACE,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(830), 1,
      anon_sym_not,
    ACTIONS(832), 1,
      anon_sym_lambda,
    ACTIONS(1150), 1,
      sym_identifier,
    ACTIONS(1156), 1,
      anon_sym_type,
    ACTIONS(1160), 1,
      anon_sym_await,
    ACTIONS(1286), 1,
      anon_sym_STAR,
    STATE(1016), 1,
      sym_primary_expression,
    STATE(1017), 1,
      sym_string,
    STATE(1367), 1,
      sym_list_splat_pattern,
    STATE(1855), 1,
      sym_expression,
    STATE(2702), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(806), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(794), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1154), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1809), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1414), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [40579] = 22,
    ACTIONS(796), 1,
      anon_sym_LPAREN,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(808), 1,
      anon_sym_LBRACE,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(830), 1,
      anon_sym_not,
    ACTIONS(832), 1,
      anon_sym_lambda,
    ACTIONS(1150), 1,
      sym_identifier,
    ACTIONS(1156), 1,
      anon_sym_type,
    ACTIONS(1160), 1,
      anon_sym_await,
    ACTIONS(1286), 1,
      anon_sym_STAR,
    STATE(1016), 1,
      sym_primary_expression,
    STATE(1017), 1,
      sym_string,
    STATE(1367), 1,
      sym_list_splat_pattern,
    STATE(1856), 1,
      sym_expression,
    STATE(2702), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(806), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(794), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1154), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1809), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1414), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [40677] = 22,
    ACTIONS(684), 1,
      anon_sym_LPAREN,
    ACTIONS(692), 1,
      anon_sym_LBRACK,
    ACTIONS(696), 1,
      anon_sym_LBRACE,
    ACTIONS(702), 1,
      sym_string_start,
    ACTIONS(998), 1,
      anon_sym_STAR,
    ACTIONS(1006), 1,
      anon_sym_not,
    ACTIONS(1008), 1,
      anon_sym_lambda,
    ACTIONS(1102), 1,
      sym_identifier,
    ACTIONS(1110), 1,
      anon_sym_type,
    ACTIONS(1112), 1,
      anon_sym_await,
    STATE(979), 1,
      sym_string,
    STATE(996), 1,
      sym_primary_expression,
    STATE(1183), 1,
      sym_list_splat_pattern,
    STATE(1775), 1,
      sym_expression,
    STATE(2830), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(698), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(694), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(682), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1108), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1783), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1241), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [40775] = 22,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1740), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [40873] = 22,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(2107), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [40971] = 22,
    ACTIONS(752), 1,
      anon_sym_LPAREN,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1064), 1,
      anon_sym_type,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1070), 1,
      anon_sym_await,
    ACTIONS(1282), 1,
      sym_identifier,
    ACTIONS(1306), 1,
      anon_sym_STAR,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1946), 1,
      sym_expression,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1060), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [41069] = 22,
    ACTIONS(796), 1,
      anon_sym_LPAREN,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(808), 1,
      anon_sym_LBRACE,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(830), 1,
      anon_sym_not,
    ACTIONS(832), 1,
      anon_sym_lambda,
    ACTIONS(1150), 1,
      sym_identifier,
    ACTIONS(1156), 1,
      anon_sym_type,
    ACTIONS(1160), 1,
      anon_sym_await,
    ACTIONS(1286), 1,
      anon_sym_STAR,
    STATE(1016), 1,
      sym_primary_expression,
    STATE(1017), 1,
      sym_string,
    STATE(1367), 1,
      sym_list_splat_pattern,
    STATE(1857), 1,
      sym_expression,
    STATE(2702), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(806), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(794), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1154), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1809), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1414), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [41167] = 22,
    ACTIONS(684), 1,
      anon_sym_LPAREN,
    ACTIONS(692), 1,
      anon_sym_LBRACK,
    ACTIONS(696), 1,
      anon_sym_LBRACE,
    ACTIONS(702), 1,
      sym_string_start,
    ACTIONS(998), 1,
      anon_sym_STAR,
    ACTIONS(1006), 1,
      anon_sym_not,
    ACTIONS(1008), 1,
      anon_sym_lambda,
    ACTIONS(1102), 1,
      sym_identifier,
    ACTIONS(1110), 1,
      anon_sym_type,
    ACTIONS(1112), 1,
      anon_sym_await,
    STATE(979), 1,
      sym_string,
    STATE(996), 1,
      sym_primary_expression,
    STATE(1183), 1,
      sym_list_splat_pattern,
    STATE(1772), 1,
      sym_expression,
    STATE(2830), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(698), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(694), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(682), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1108), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1783), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1241), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [41265] = 22,
    ACTIONS(684), 1,
      anon_sym_LPAREN,
    ACTIONS(692), 1,
      anon_sym_LBRACK,
    ACTIONS(696), 1,
      anon_sym_LBRACE,
    ACTIONS(702), 1,
      sym_string_start,
    ACTIONS(998), 1,
      anon_sym_STAR,
    ACTIONS(1006), 1,
      anon_sym_not,
    ACTIONS(1008), 1,
      anon_sym_lambda,
    ACTIONS(1102), 1,
      sym_identifier,
    ACTIONS(1110), 1,
      anon_sym_type,
    ACTIONS(1112), 1,
      anon_sym_await,
    STATE(979), 1,
      sym_string,
    STATE(996), 1,
      sym_primary_expression,
    STATE(1183), 1,
      sym_list_splat_pattern,
    STATE(1951), 1,
      sym_expression,
    STATE(2830), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(698), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(694), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(682), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1108), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1783), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1241), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [41363] = 22,
    ACTIONS(67), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_not,
    ACTIONS(71), 1,
      anon_sym_lambda,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(381), 1,
      sym_identifier,
    ACTIONS(393), 1,
      anon_sym_type,
    ACTIONS(404), 1,
      anon_sym_await,
    ACTIONS(652), 1,
      anon_sym_LPAREN,
    ACTIONS(660), 1,
      anon_sym_LBRACK,
    ACTIONS(1302), 1,
      anon_sym_STAR,
    STATE(975), 1,
      sym_string,
    STATE(977), 1,
      sym_primary_expression,
    STATE(1117), 1,
      sym_list_splat_pattern,
    STATE(1960), 1,
      sym_expression,
    STATE(2782), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(75), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(65), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(77), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(389), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1687), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1057), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [41461] = 22,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(2090), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [41559] = 22,
    ACTIONS(67), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_not,
    ACTIONS(71), 1,
      anon_sym_lambda,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(381), 1,
      sym_identifier,
    ACTIONS(393), 1,
      anon_sym_type,
    ACTIONS(404), 1,
      anon_sym_await,
    ACTIONS(652), 1,
      anon_sym_LPAREN,
    ACTIONS(660), 1,
      anon_sym_LBRACK,
    ACTIONS(1302), 1,
      anon_sym_STAR,
    STATE(975), 1,
      sym_string,
    STATE(977), 1,
      sym_primary_expression,
    STATE(1117), 1,
      sym_list_splat_pattern,
    STATE(1692), 1,
      sym_expression,
    STATE(2782), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(75), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(65), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(77), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(389), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1687), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1057), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [41657] = 22,
    ACTIONS(67), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_not,
    ACTIONS(71), 1,
      anon_sym_lambda,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(381), 1,
      sym_identifier,
    ACTIONS(393), 1,
      anon_sym_type,
    ACTIONS(404), 1,
      anon_sym_await,
    ACTIONS(652), 1,
      anon_sym_LPAREN,
    ACTIONS(660), 1,
      anon_sym_LBRACK,
    ACTIONS(1302), 1,
      anon_sym_STAR,
    STATE(975), 1,
      sym_string,
    STATE(977), 1,
      sym_primary_expression,
    STATE(1117), 1,
      sym_list_splat_pattern,
    STATE(2086), 1,
      sym_expression,
    STATE(2782), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(75), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(65), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(77), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(389), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1687), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1057), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [41755] = 22,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(2089), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [41853] = 22,
    ACTIONS(752), 1,
      anon_sym_LPAREN,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1064), 1,
      anon_sym_type,
    ACTIONS(1066), 1,
      anon_sym_not,
    ACTIONS(1068), 1,
      anon_sym_lambda,
    ACTIONS(1070), 1,
      anon_sym_await,
    ACTIONS(1282), 1,
      sym_identifier,
    ACTIONS(1306), 1,
      anon_sym_STAR,
    STATE(1008), 1,
      sym_primary_expression,
    STATE(1032), 1,
      sym_string,
    STATE(1432), 1,
      sym_list_splat_pattern,
    STATE(1729), 1,
      sym_expression,
    STATE(2629), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(750), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1060), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1751), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [41951] = 22,
    ACTIONS(796), 1,
      anon_sym_LPAREN,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(808), 1,
      anon_sym_LBRACE,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(830), 1,
      anon_sym_not,
    ACTIONS(832), 1,
      anon_sym_lambda,
    ACTIONS(1150), 1,
      sym_identifier,
    ACTIONS(1156), 1,
      anon_sym_type,
    ACTIONS(1160), 1,
      anon_sym_await,
    ACTIONS(1286), 1,
      anon_sym_STAR,
    STATE(1016), 1,
      sym_primary_expression,
    STATE(1017), 1,
      sym_string,
    STATE(1367), 1,
      sym_list_splat_pattern,
    STATE(1851), 1,
      sym_expression,
    STATE(2702), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(806), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(794), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1154), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1809), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1414), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [42049] = 22,
    ACTIONS(706), 1,
      anon_sym_LPAREN,
    ACTIONS(714), 1,
      anon_sym_LBRACK,
    ACTIONS(718), 1,
      anon_sym_LBRACE,
    ACTIONS(724), 1,
      sym_string_start,
    ACTIONS(868), 1,
      sym_identifier,
    ACTIONS(880), 1,
      anon_sym_type,
    ACTIONS(884), 1,
      anon_sym_not,
    ACTIONS(886), 1,
      anon_sym_lambda,
    ACTIONS(890), 1,
      anon_sym_await,
    ACTIONS(1252), 1,
      anon_sym_STAR,
    STATE(993), 1,
      sym_string,
    STATE(994), 1,
      sym_primary_expression,
    STATE(1218), 1,
      sym_list_splat_pattern,
    STATE(1770), 1,
      sym_expression,
    STATE(2685), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(720), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(716), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(704), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(876), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1768), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1169), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [42147] = 22,
    ACTIONS(796), 1,
      anon_sym_LPAREN,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(808), 1,
      anon_sym_LBRACE,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(830), 1,
      anon_sym_not,
    ACTIONS(832), 1,
      anon_sym_lambda,
    ACTIONS(1150), 1,
      sym_identifier,
    ACTIONS(1156), 1,
      anon_sym_type,
    ACTIONS(1160), 1,
      anon_sym_await,
    ACTIONS(1286), 1,
      anon_sym_STAR,
    STATE(1016), 1,
      sym_primary_expression,
    STATE(1017), 1,
      sym_string,
    STATE(1367), 1,
      sym_list_splat_pattern,
    STATE(1848), 1,
      sym_expression,
    STATE(2702), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(806), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(794), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1154), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1809), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1414), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [42245] = 22,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(980), 1,
      anon_sym_type,
    ACTIONS(984), 1,
      anon_sym_not,
    ACTIONS(986), 1,
      anon_sym_lambda,
    ACTIONS(988), 1,
      anon_sym_await,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    STATE(1099), 1,
      sym_primary_expression,
    STATE(1150), 1,
      sym_string,
    STATE(1470), 1,
      sym_list_splat_pattern,
    STATE(1943), 1,
      sym_expression,
    STATE(2633), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(772), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(976), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1793), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [42343] = 23,
    ACTIONS(684), 1,
      anon_sym_LPAREN,
    ACTIONS(692), 1,
      anon_sym_LBRACK,
    ACTIONS(696), 1,
      anon_sym_LBRACE,
    ACTIONS(702), 1,
      sym_string_start,
    ACTIONS(998), 1,
      anon_sym_STAR,
    ACTIONS(1006), 1,
      anon_sym_not,
    ACTIONS(1008), 1,
      anon_sym_lambda,
    ACTIONS(1534), 1,
      anon_sym_await,
    ACTIONS(1536), 1,
      sym_identifier,
    ACTIONS(1540), 1,
      anon_sym_type,
    STATE(979), 1,
      sym_string,
    STATE(996), 1,
      sym_primary_expression,
    STATE(1183), 1,
      sym_list_splat_pattern,
    STATE(1930), 1,
      sym_expression,
    STATE(2830), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(698), 2,
      sym_ellipsis,
      sym_float,
    STATE(1515), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(694), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(682), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1538), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1783), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1241), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [42443] = 22,
    ACTIONS(684), 1,
      anon_sym_LPAREN,
    ACTIONS(692), 1,
      anon_sym_LBRACK,
    ACTIONS(696), 1,
      anon_sym_LBRACE,
    ACTIONS(702), 1,
      sym_string_start,
    ACTIONS(998), 1,
      anon_sym_STAR,
    ACTIONS(1006), 1,
      anon_sym_not,
    ACTIONS(1008), 1,
      anon_sym_lambda,
    ACTIONS(1102), 1,
      sym_identifier,
    ACTIONS(1110), 1,
      anon_sym_type,
    ACTIONS(1112), 1,
      anon_sym_await,
    STATE(979), 1,
      sym_string,
    STATE(996), 1,
      sym_primary_expression,
    STATE(1183), 1,
      sym_list_splat_pattern,
    STATE(1789), 1,
      sym_expression,
    STATE(2830), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(698), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(694), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(682), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1108), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1783), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1241), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [42541] = 22,
    ACTIONS(67), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_not,
    ACTIONS(71), 1,
      anon_sym_lambda,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(381), 1,
      sym_identifier,
    ACTIONS(393), 1,
      anon_sym_type,
    ACTIONS(404), 1,
      anon_sym_await,
    ACTIONS(652), 1,
      anon_sym_LPAREN,
    ACTIONS(660), 1,
      anon_sym_LBRACK,
    ACTIONS(1302), 1,
      anon_sym_STAR,
    STATE(975), 1,
      sym_string,
    STATE(977), 1,
      sym_primary_expression,
    STATE(1117), 1,
      sym_list_splat_pattern,
    STATE(1699), 1,
      sym_expression,
    STATE(2782), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(75), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(65), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(77), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(389), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1687), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1057), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [42639] = 9,
    ACTIONS(1520), 1,
      anon_sym_else,
    ACTIONS(1524), 1,
      anon_sym_finally,
    ACTIONS(1526), 1,
      anon_sym_except_STAR,
    STATE(703), 1,
      sym_else_clause,
    STATE(842), 1,
      sym_finally_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(625), 2,
      sym_except_group_clause,
      aux_sym_try_statement_repeat2,
    ACTIONS(1498), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1496), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [42711] = 9,
    ACTIONS(1520), 1,
      anon_sym_else,
    ACTIONS(1522), 1,
      anon_sym_except,
    ACTIONS(1524), 1,
      anon_sym_finally,
    STATE(703), 1,
      sym_else_clause,
    STATE(842), 1,
      sym_finally_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(624), 2,
      sym_except_clause,
      aux_sym_try_statement_repeat1,
    ACTIONS(1498), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1496), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [42783] = 22,
    ACTIONS(706), 1,
      anon_sym_LPAREN,
    ACTIONS(714), 1,
      anon_sym_LBRACK,
    ACTIONS(718), 1,
      anon_sym_LBRACE,
    ACTIONS(724), 1,
      sym_string_start,
    ACTIONS(868), 1,
      sym_identifier,
    ACTIONS(880), 1,
      anon_sym_type,
    ACTIONS(884), 1,
      anon_sym_not,
    ACTIONS(886), 1,
      anon_sym_lambda,
    ACTIONS(890), 1,
      anon_sym_await,
    ACTIONS(1252), 1,
      anon_sym_STAR,
    STATE(993), 1,
      sym_string,
    STATE(994), 1,
      sym_primary_expression,
    STATE(1218), 1,
      sym_list_splat_pattern,
    STATE(1773), 1,
      sym_expression,
    STATE(2685), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(720), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(716), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(704), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(876), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1768), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1169), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [42881] = 22,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(2056), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [42979] = 22,
    ACTIONS(706), 1,
      anon_sym_LPAREN,
    ACTIONS(714), 1,
      anon_sym_LBRACK,
    ACTIONS(718), 1,
      anon_sym_LBRACE,
    ACTIONS(724), 1,
      sym_string_start,
    ACTIONS(868), 1,
      sym_identifier,
    ACTIONS(880), 1,
      anon_sym_type,
    ACTIONS(884), 1,
      anon_sym_not,
    ACTIONS(886), 1,
      anon_sym_lambda,
    ACTIONS(890), 1,
      anon_sym_await,
    ACTIONS(1252), 1,
      anon_sym_STAR,
    STATE(993), 1,
      sym_string,
    STATE(994), 1,
      sym_primary_expression,
    STATE(1218), 1,
      sym_list_splat_pattern,
    STATE(1801), 1,
      sym_expression,
    STATE(2685), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(720), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(716), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(704), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(876), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1768), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1169), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [43077] = 22,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(2123), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [43175] = 22,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(2084), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [43273] = 22,
    ACTIONS(706), 1,
      anon_sym_LPAREN,
    ACTIONS(714), 1,
      anon_sym_LBRACK,
    ACTIONS(718), 1,
      anon_sym_LBRACE,
    ACTIONS(724), 1,
      sym_string_start,
    ACTIONS(868), 1,
      sym_identifier,
    ACTIONS(880), 1,
      anon_sym_type,
    ACTIONS(884), 1,
      anon_sym_not,
    ACTIONS(886), 1,
      anon_sym_lambda,
    ACTIONS(890), 1,
      anon_sym_await,
    ACTIONS(1252), 1,
      anon_sym_STAR,
    STATE(993), 1,
      sym_string,
    STATE(994), 1,
      sym_primary_expression,
    STATE(1218), 1,
      sym_list_splat_pattern,
    STATE(1785), 1,
      sym_expression,
    STATE(2685), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(720), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(716), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(704), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(876), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1768), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1169), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [43371] = 22,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(2120), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [43469] = 22,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(2083), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [43567] = 22,
    ACTIONS(706), 1,
      anon_sym_LPAREN,
    ACTIONS(714), 1,
      anon_sym_LBRACK,
    ACTIONS(718), 1,
      anon_sym_LBRACE,
    ACTIONS(724), 1,
      sym_string_start,
    ACTIONS(868), 1,
      sym_identifier,
    ACTIONS(880), 1,
      anon_sym_type,
    ACTIONS(884), 1,
      anon_sym_not,
    ACTIONS(886), 1,
      anon_sym_lambda,
    ACTIONS(890), 1,
      anon_sym_await,
    ACTIONS(1252), 1,
      anon_sym_STAR,
    STATE(993), 1,
      sym_string,
    STATE(994), 1,
      sym_primary_expression,
    STATE(1218), 1,
      sym_list_splat_pattern,
    STATE(1780), 1,
      sym_expression,
    STATE(2685), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(720), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(716), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(704), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(876), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1768), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1169), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [43665] = 22,
    ACTIONS(706), 1,
      anon_sym_LPAREN,
    ACTIONS(714), 1,
      anon_sym_LBRACK,
    ACTIONS(718), 1,
      anon_sym_LBRACE,
    ACTIONS(724), 1,
      sym_string_start,
    ACTIONS(868), 1,
      sym_identifier,
    ACTIONS(880), 1,
      anon_sym_type,
    ACTIONS(884), 1,
      anon_sym_not,
    ACTIONS(886), 1,
      anon_sym_lambda,
    ACTIONS(890), 1,
      anon_sym_await,
    ACTIONS(1252), 1,
      anon_sym_STAR,
    STATE(993), 1,
      sym_string,
    STATE(994), 1,
      sym_primary_expression,
    STATE(1218), 1,
      sym_list_splat_pattern,
    STATE(1774), 1,
      sym_expression,
    STATE(2685), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(720), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(716), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(704), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(876), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1768), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1169), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [43763] = 22,
    ACTIONS(67), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_not,
    ACTIONS(71), 1,
      anon_sym_lambda,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(381), 1,
      sym_identifier,
    ACTIONS(393), 1,
      anon_sym_type,
    ACTIONS(404), 1,
      anon_sym_await,
    ACTIONS(652), 1,
      anon_sym_LPAREN,
    ACTIONS(660), 1,
      anon_sym_LBRACK,
    ACTIONS(1302), 1,
      anon_sym_STAR,
    STATE(975), 1,
      sym_string,
    STATE(977), 1,
      sym_primary_expression,
    STATE(1117), 1,
      sym_list_splat_pattern,
    STATE(1808), 1,
      sym_expression,
    STATE(2782), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(75), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(65), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(77), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(389), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1687), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1057), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [43861] = 22,
    ACTIONS(67), 1,
      anon_sym_LBRACE,
    ACTIONS(69), 1,
      anon_sym_not,
    ACTIONS(71), 1,
      anon_sym_lambda,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(381), 1,
      sym_identifier,
    ACTIONS(393), 1,
      anon_sym_type,
    ACTIONS(404), 1,
      anon_sym_await,
    ACTIONS(652), 1,
      anon_sym_LPAREN,
    ACTIONS(660), 1,
      anon_sym_LBRACK,
    ACTIONS(1302), 1,
      anon_sym_STAR,
    STATE(975), 1,
      sym_string,
    STATE(977), 1,
      sym_primary_expression,
    STATE(1117), 1,
      sym_list_splat_pattern,
    STATE(1859), 1,
      sym_expression,
    STATE(2782), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(75), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(65), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(77), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(389), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1687), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1057), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [43959] = 22,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(2057), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [44057] = 22,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1935), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [44155] = 22,
    ACTIONS(300), 1,
      anon_sym_type,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(317), 1,
      anon_sym_lambda,
    ACTIONS(325), 1,
      anon_sym_await,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(406), 1,
      sym_identifier,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(416), 1,
      anon_sym_not,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1002), 1,
      sym_primary_expression,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(2079), 1,
      sym_expression,
    STATE(2779), 1,
      sym__named_expression_lhs,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(290), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    STATE(1758), 7,
      sym_named_expression,
      sym_as_pattern,
      sym_not_operator,
      sym_boolean_operator,
      sym_comparison_operator,
      sym_lambda,
      sym_conditional_expression,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [44253] = 10,
    ACTIONS(1544), 1,
      anon_sym_COMMA,
    ACTIONS(1549), 1,
      anon_sym_COLON_EQ,
    ACTIONS(1551), 1,
      anon_sym_COLON,
    ACTIONS(1554), 1,
      anon_sym_EQ,
    ACTIONS(1556), 1,
      anon_sym_LBRACK,
    STATE(2052), 1,
      sym_type_parameter,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1558), 13,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(1547), 15,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1542), 16,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_as,
      anon_sym_if,
      anon_sym_in,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [44326] = 8,
    ACTIONS(1520), 1,
      anon_sym_else,
    ACTIONS(1564), 1,
      anon_sym_elif,
    STATE(616), 1,
      aux_sym_if_statement_repeat1,
    STATE(706), 1,
      sym_elif_clause,
    STATE(781), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1560), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1562), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [44394] = 5,
    ACTIONS(1570), 1,
      anon_sym_except,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(611), 2,
      sym_except_clause,
      aux_sym_try_statement_repeat1,
    ACTIONS(1568), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1566), 34,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [44456] = 8,
    ACTIONS(1488), 1,
      anon_sym_else,
    ACTIONS(1577), 1,
      anon_sym_elif,
    STATE(615), 1,
      aux_sym_if_statement_repeat1,
    STATE(720), 1,
      sym_elif_clause,
    STATE(753), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1575), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1573), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [44524] = 8,
    ACTIONS(1488), 1,
      anon_sym_else,
    ACTIONS(1577), 1,
      anon_sym_elif,
    STATE(634), 1,
      aux_sym_if_statement_repeat1,
    STATE(720), 1,
      sym_elif_clause,
    STATE(752), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1581), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1579), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [44592] = 8,
    ACTIONS(1520), 1,
      anon_sym_else,
    ACTIONS(1564), 1,
      anon_sym_elif,
    STATE(644), 1,
      aux_sym_if_statement_repeat1,
    STATE(706), 1,
      sym_elif_clause,
    STATE(806), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1583), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1585), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [44660] = 8,
    ACTIONS(1488), 1,
      anon_sym_else,
    ACTIONS(1577), 1,
      anon_sym_elif,
    STATE(634), 1,
      aux_sym_if_statement_repeat1,
    STATE(720), 1,
      sym_elif_clause,
    STATE(786), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1583), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1585), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [44728] = 8,
    ACTIONS(1520), 1,
      anon_sym_else,
    ACTIONS(1564), 1,
      anon_sym_elif,
    STATE(644), 1,
      aux_sym_if_statement_repeat1,
    STATE(706), 1,
      sym_elif_clause,
    STATE(797), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1581), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1579), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [44796] = 8,
    ACTIONS(1488), 1,
      anon_sym_else,
    ACTIONS(1577), 1,
      anon_sym_elif,
    STATE(613), 1,
      aux_sym_if_statement_repeat1,
    STATE(720), 1,
      sym_elif_clause,
    STATE(744), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1560), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1562), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [44864] = 8,
    ACTIONS(1520), 1,
      anon_sym_else,
    ACTIONS(1564), 1,
      anon_sym_elif,
    STATE(614), 1,
      aux_sym_if_statement_repeat1,
    STATE(706), 1,
      sym_elif_clause,
    STATE(796), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1575), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1573), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [44932] = 7,
    ACTIONS(1544), 1,
      anon_sym_COMMA,
    ACTIONS(1549), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1554), 2,
      anon_sym_COLON,
      anon_sym_EQ,
    ACTIONS(1558), 13,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(1547), 15,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1542), 17,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_as,
      anon_sym_if,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [44998] = 5,
    ACTIONS(1591), 1,
      anon_sym_except_STAR,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(620), 2,
      sym_except_group_clause,
      aux_sym_try_statement_repeat2,
    ACTIONS(1589), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1587), 34,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [45060] = 7,
    ACTIONS(284), 1,
      anon_sym_COMMA,
    ACTIONS(292), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(302), 2,
      anon_sym_COLON,
      anon_sym_EQ,
    ACTIONS(319), 13,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(279), 15,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(277), 17,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_as,
      anon_sym_if,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [45126] = 7,
    ACTIONS(284), 1,
      anon_sym_COMMA,
    ACTIONS(292), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(302), 2,
      anon_sym_COLON,
      anon_sym_EQ,
    ACTIONS(319), 13,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(279), 15,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(277), 17,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_as,
      anon_sym_if,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [45192] = 8,
    ACTIONS(284), 1,
      anon_sym_COMMA,
    ACTIONS(292), 1,
      anon_sym_COLON_EQ,
    ACTIONS(294), 1,
      anon_sym_COLON,
    ACTIONS(302), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(319), 13,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(279), 15,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(277), 17,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_as,
      anon_sym_if,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [45260] = 5,
    ACTIONS(1594), 1,
      anon_sym_except,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(624), 2,
      sym_except_clause,
      aux_sym_try_statement_repeat1,
    ACTIONS(1568), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1566), 34,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [45322] = 5,
    ACTIONS(1597), 1,
      anon_sym_except_STAR,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(625), 2,
      sym_except_group_clause,
      aux_sym_try_statement_repeat2,
    ACTIONS(1589), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1587), 34,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [45384] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1602), 16,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_EQ,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1600), 32,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [45441] = 7,
    ACTIONS(1616), 1,
      anon_sym_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1606), 2,
      anon_sym_DOT,
      anon_sym_COLON,
    ACTIONS(1608), 2,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
    ACTIONS(1614), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1611), 12,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(1604), 28,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_in,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [45506] = 6,
    ACTIONS(1620), 1,
      anon_sym_COMMA,
    ACTIONS(1627), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1625), 14,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(1623), 15,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1618), 17,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_as,
      anon_sym_if,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [45569] = 6,
    ACTIONS(1554), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1631), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(1558), 13,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(1634), 15,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1629), 17,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_as,
      anon_sym_if,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [45632] = 6,
    ACTIONS(1554), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1544), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(1558), 13,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(1547), 15,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1542), 17,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_as,
      anon_sym_if,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [45695] = 6,
    ACTIONS(1627), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1620), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(1625), 13,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(1623), 15,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1618), 17,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_as,
      anon_sym_if,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [45758] = 6,
    ACTIONS(1643), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1638), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(1645), 13,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(1641), 15,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1636), 17,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_as,
      anon_sym_if,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [45821] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1649), 16,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_EQ,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1647), 32,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [45878] = 6,
    ACTIONS(1655), 1,
      anon_sym_elif,
    STATE(634), 1,
      aux_sym_if_statement_repeat1,
    STATE(720), 1,
      sym_elif_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1653), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1651), 33,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [45941] = 6,
    ACTIONS(1554), 1,
      anon_sym_EQ,
    ACTIONS(1631), 1,
      anon_sym_COMMA,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1558), 14,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(1634), 15,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1629), 17,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_as,
      anon_sym_if,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [46004] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1649), 16,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_EQ,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1647), 32,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [46061] = 6,
    ACTIONS(1544), 1,
      anon_sym_COMMA,
    ACTIONS(1554), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1558), 14,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(1547), 15,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1542), 17,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_as,
      anon_sym_if,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [46124] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1660), 16,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_EQ,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1658), 32,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [46181] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1664), 16,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_EQ,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1662), 32,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [46238] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1668), 16,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_EQ,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1666), 32,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [46295] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1664), 16,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_EQ,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1662), 32,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [46352] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(671), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(679), 3,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
    ACTIONS(668), 13,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(666), 29,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [46413] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(671), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(679), 3,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
    ACTIONS(668), 13,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(666), 29,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [46474] = 6,
    ACTIONS(1670), 1,
      anon_sym_elif,
    STATE(644), 1,
      aux_sym_if_statement_repeat1,
    STATE(706), 1,
      sym_elif_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1653), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1651), 33,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [46537] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1608), 3,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
    ACTIONS(1614), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1611), 13,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(1604), 29,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [46598] = 6,
    ACTIONS(1638), 1,
      anon_sym_COMMA,
    ACTIONS(1643), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1645), 14,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(1641), 15,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1636), 17,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_as,
      anon_sym_if,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [46661] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1675), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1673), 35,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_elif,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [46717] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1679), 13,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_except_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1677), 34,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [46773] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1681), 13,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_except_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1683), 34,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [46829] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1675), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1673), 35,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_elif,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [46885] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1685), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1687), 35,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_except,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [46941] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1689), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1691), 35,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_elif,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [46997] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1695), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1693), 35,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_except,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [47053] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1699), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1697), 35,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_except,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [47109] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1703), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1701), 35,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_except,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [47165] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1695), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1693), 35,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_elif,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [47221] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1675), 13,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_except_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1673), 34,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [47277] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1707), 13,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_except_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1705), 34,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [47333] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1699), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1697), 35,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_except,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [47389] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1695), 13,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_except_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1693), 34,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [47445] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1711), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1709), 35,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_except,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [47501] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1715), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1713), 35,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_except,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [47557] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1719), 13,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_except_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1717), 34,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [47613] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1703), 13,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_except_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1701), 34,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [47669] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1689), 13,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_except_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1691), 34,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [47725] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1675), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1673), 35,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_except,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [47781] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1689), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1691), 35,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_except,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [47837] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1685), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1687), 35,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_except,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [47893] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1681), 13,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_except_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1683), 34,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [47949] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1707), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1705), 35,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_except,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [48005] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1723), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1721), 35,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_except,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [48061] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1725), 13,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_except_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1727), 34,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [48117] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1731), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1729), 35,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_except,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [48173] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1725), 13,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_except_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1727), 34,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [48229] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1723), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1721), 35,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_except,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [48285] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1707), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1705), 35,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_elif,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [48341] = 21,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(1733), 1,
      sym_identifier,
    ACTIONS(1735), 1,
      anon_sym_LPAREN,
    ACTIONS(1737), 1,
      anon_sym_STAR,
    ACTIONS(1741), 1,
      anon_sym_type,
    ACTIONS(1743), 1,
      anon_sym_LBRACK,
    ACTIONS(1745), 1,
      anon_sym_await,
    STATE(1004), 1,
      sym_string,
    STATE(1598), 1,
      sym_list_splat_pattern,
    STATE(1621), 1,
      sym_primary_expression,
    STATE(2085), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(1599), 2,
      sym_attribute,
      sym_subscript,
    STATE(2024), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(970), 4,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACE,
      sym_type_conversion,
    ACTIONS(1739), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [48433] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1703), 13,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_except_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1701), 34,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [48489] = 21,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(1733), 1,
      sym_identifier,
    ACTIONS(1735), 1,
      anon_sym_LPAREN,
    ACTIONS(1737), 1,
      anon_sym_STAR,
    ACTIONS(1741), 1,
      anon_sym_type,
    ACTIONS(1743), 1,
      anon_sym_LBRACK,
    ACTIONS(1745), 1,
      anon_sym_await,
    STATE(1004), 1,
      sym_string,
    STATE(1598), 1,
      sym_list_splat_pattern,
    STATE(1621), 1,
      sym_primary_expression,
    STATE(2085), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(1599), 2,
      sym_attribute,
      sym_subscript,
    STATE(2024), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(956), 4,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACE,
      sym_type_conversion,
    ACTIONS(1739), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [48581] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1695), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1693), 35,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_except,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [48637] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1703), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1701), 35,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_elif,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [48693] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1707), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1705), 35,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_elif,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [48749] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1689), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1691), 35,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_except,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [48805] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1703), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1701), 35,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_elif,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [48861] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1707), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1705), 35,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_except,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [48917] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1679), 13,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_except_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1677), 34,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [48973] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1731), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1729), 35,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_except,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [49029] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1675), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1673), 35,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_except,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [49085] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1695), 13,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_except_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1693), 34,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [49141] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1703), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1701), 35,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_except,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [49197] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1689), 13,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_except_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1691), 34,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [49253] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1707), 13,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_except_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1705), 34,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [49309] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1711), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1709), 35,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_except,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [49365] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1675), 13,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_except_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1673), 34,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [49421] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1695), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1693), 35,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_elif,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [49477] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1715), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1713), 35,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_except,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [49533] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1689), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1691), 35,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_elif,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [49589] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1719), 13,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_except_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1717), 34,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [49645] = 5,
    ACTIONS(1488), 1,
      anon_sym_else,
    STATE(813), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1749), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1747), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [49704] = 5,
    ACTIONS(1488), 1,
      anon_sym_else,
    STATE(810), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1753), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1751), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [49763] = 5,
    ACTIONS(1520), 1,
      anon_sym_else,
    STATE(790), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1755), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1757), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [49822] = 5,
    ACTIONS(1520), 1,
      anon_sym_else,
    STATE(766), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1753), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1751), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [49881] = 5,
    ACTIONS(1524), 1,
      anon_sym_finally,
    STATE(755), 1,
      sym_finally_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1759), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1761), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [49940] = 5,
    ACTIONS(1492), 1,
      anon_sym_finally,
    STATE(767), 1,
      sym_finally_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1759), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1761), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [49999] = 5,
    ACTIONS(1520), 1,
      anon_sym_else,
    STATE(761), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1763), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1765), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [50058] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1767), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1769), 34,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_elif,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [50113] = 5,
    ACTIONS(1488), 1,
      anon_sym_else,
    STATE(763), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1773), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1771), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [50172] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1777), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1775), 34,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_elif,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [50227] = 5,
    ACTIONS(1524), 1,
      anon_sym_finally,
    STATE(822), 1,
      sym_finally_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1779), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1781), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [50286] = 5,
    ACTIONS(1520), 1,
      anon_sym_else,
    STATE(840), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1783), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1785), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [50345] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1789), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1787), 34,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_elif,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [50400] = 5,
    ACTIONS(1520), 1,
      anon_sym_else,
    STATE(792), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1773), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1771), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [50459] = 5,
    ACTIONS(1488), 1,
      anon_sym_else,
    STATE(807), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1763), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1765), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [50518] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1777), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1775), 34,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_elif,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [50573] = 5,
    ACTIONS(1520), 1,
      anon_sym_else,
    STATE(798), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1749), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1747), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [50632] = 5,
    ACTIONS(1488), 1,
      anon_sym_else,
    STATE(736), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1755), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1757), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [50691] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1789), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1787), 34,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_elif,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [50746] = 5,
    ACTIONS(1492), 1,
      anon_sym_finally,
    STATE(801), 1,
      sym_finally_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1779), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1781), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [50805] = 5,
    ACTIONS(1488), 1,
      anon_sym_else,
    STATE(795), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1783), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1785), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [50864] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1767), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1769), 34,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_elif,
      anon_sym_else,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [50919] = 22,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(1791), 1,
      sym_identifier,
    ACTIONS(1793), 1,
      anon_sym_LPAREN,
    ACTIONS(1795), 1,
      anon_sym_RPAREN,
    ACTIONS(1797), 1,
      anon_sym_STAR,
    ACTIONS(1801), 1,
      anon_sym_type,
    ACTIONS(1803), 1,
      anon_sym_LBRACK,
    ACTIONS(1805), 1,
      anon_sym_await,
    STATE(1004), 1,
      sym_string,
    STATE(1638), 1,
      sym_list_splat_pattern,
    STATE(1654), 1,
      sym_primary_expression,
    STATE(2384), 1,
      sym_pattern,
    STATE(2769), 1,
      sym__patterns,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(1642), 2,
      sym_attribute,
      sym_subscript,
    STATE(2574), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1799), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [51011] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1809), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1807), 33,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [51065] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1811), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1813), 33,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [51119] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1809), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1807), 33,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [51173] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1811), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1813), 33,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [51227] = 22,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(1791), 1,
      sym_identifier,
    ACTIONS(1793), 1,
      anon_sym_LPAREN,
    ACTIONS(1797), 1,
      anon_sym_STAR,
    ACTIONS(1801), 1,
      anon_sym_type,
    ACTIONS(1803), 1,
      anon_sym_LBRACK,
    ACTIONS(1805), 1,
      anon_sym_await,
    ACTIONS(1815), 1,
      anon_sym_RPAREN,
    STATE(1004), 1,
      sym_string,
    STATE(1638), 1,
      sym_list_splat_pattern,
    STATE(1654), 1,
      sym_primary_expression,
    STATE(2384), 1,
      sym_pattern,
    STATE(2689), 1,
      sym__patterns,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(1642), 2,
      sym_attribute,
      sym_subscript,
    STATE(2574), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1799), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [51319] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1817), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1819), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [51372] = 21,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    ACTIONS(1821), 1,
      sym_identifier,
    ACTIONS(1823), 1,
      anon_sym_LPAREN,
    ACTIONS(1827), 1,
      anon_sym_type,
    ACTIONS(1829), 1,
      anon_sym_LBRACK,
    ACTIONS(1831), 1,
      anon_sym_await,
    STATE(1004), 1,
      sym_string,
    STATE(1620), 1,
      sym_primary_expression,
    STATE(1647), 1,
      sym_list_splat_pattern,
    STATE(2315), 1,
      sym_pattern,
    STATE(2768), 1,
      sym_pattern_list,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(1651), 2,
      sym_attribute,
      sym_subscript,
    STATE(1668), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1825), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [51461] = 21,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    ACTIONS(1821), 1,
      sym_identifier,
    ACTIONS(1823), 1,
      anon_sym_LPAREN,
    ACTIONS(1827), 1,
      anon_sym_type,
    ACTIONS(1829), 1,
      anon_sym_LBRACK,
    ACTIONS(1831), 1,
      anon_sym_await,
    STATE(1004), 1,
      sym_string,
    STATE(1620), 1,
      sym_primary_expression,
    STATE(1647), 1,
      sym_list_splat_pattern,
    STATE(2272), 1,
      sym_pattern,
    STATE(2823), 1,
      sym_pattern_list,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(1651), 2,
      sym_attribute,
      sym_subscript,
    STATE(1668), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1825), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [51550] = 21,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(1791), 1,
      sym_identifier,
    ACTIONS(1793), 1,
      anon_sym_LPAREN,
    ACTIONS(1797), 1,
      anon_sym_STAR,
    ACTIONS(1801), 1,
      anon_sym_type,
    ACTIONS(1803), 1,
      anon_sym_LBRACK,
    ACTIONS(1805), 1,
      anon_sym_await,
    ACTIONS(1833), 1,
      anon_sym_RPAREN,
    STATE(1004), 1,
      sym_string,
    STATE(1638), 1,
      sym_list_splat_pattern,
    STATE(1654), 1,
      sym_primary_expression,
    STATE(2576), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(1642), 2,
      sym_attribute,
      sym_subscript,
    STATE(2574), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1799), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [51639] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1835), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1837), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [51692] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1839), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1841), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [51745] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1759), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1761), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [51798] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1843), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1845), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [51851] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1847), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1849), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [51904] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1853), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1851), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [51957] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1857), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1855), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [52010] = 21,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    ACTIONS(1821), 1,
      sym_identifier,
    ACTIONS(1823), 1,
      anon_sym_LPAREN,
    ACTIONS(1827), 1,
      anon_sym_type,
    ACTIONS(1829), 1,
      anon_sym_LBRACK,
    ACTIONS(1831), 1,
      anon_sym_await,
    STATE(1004), 1,
      sym_string,
    STATE(1620), 1,
      sym_primary_expression,
    STATE(1647), 1,
      sym_list_splat_pattern,
    STATE(2352), 1,
      sym_pattern,
    STATE(2636), 1,
      sym_pattern_list,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(1651), 2,
      sym_attribute,
      sym_subscript,
    STATE(1668), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1825), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [52099] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1861), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1859), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [52152] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1817), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1819), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [52205] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1865), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1863), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [52258] = 21,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    ACTIONS(1821), 1,
      sym_identifier,
    ACTIONS(1823), 1,
      anon_sym_LPAREN,
    ACTIONS(1827), 1,
      anon_sym_type,
    ACTIONS(1829), 1,
      anon_sym_LBRACK,
    ACTIONS(1831), 1,
      anon_sym_await,
    STATE(1004), 1,
      sym_string,
    STATE(1620), 1,
      sym_primary_expression,
    STATE(1647), 1,
      sym_list_splat_pattern,
    STATE(2325), 1,
      sym_pattern,
    STATE(2759), 1,
      sym_pattern_list,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(1651), 2,
      sym_attribute,
      sym_subscript,
    STATE(1668), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1825), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [52347] = 21,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    ACTIONS(1821), 1,
      sym_identifier,
    ACTIONS(1823), 1,
      anon_sym_LPAREN,
    ACTIONS(1827), 1,
      anon_sym_type,
    ACTIONS(1829), 1,
      anon_sym_LBRACK,
    ACTIONS(1831), 1,
      anon_sym_await,
    STATE(1004), 1,
      sym_string,
    STATE(1620), 1,
      sym_primary_expression,
    STATE(1647), 1,
      sym_list_splat_pattern,
    STATE(2333), 1,
      sym_pattern,
    STATE(2757), 1,
      sym_pattern_list,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(1651), 2,
      sym_attribute,
      sym_subscript,
    STATE(1668), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1825), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [52436] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1869), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1867), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [52489] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1486), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1484), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [52542] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1871), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1873), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [52595] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1877), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1875), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [52648] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1881), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1879), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [52701] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1885), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1883), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [52754] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1889), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1887), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [52807] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1893), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1891), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [52860] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1897), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1895), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [52913] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1901), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1899), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [52966] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1905), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1903), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [53019] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1907), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1909), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [53072] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1911), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1913), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [53125] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1917), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1915), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [53178] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1921), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1919), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [53231] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1925), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1923), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [53284] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1927), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1929), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [53337] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1931), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1933), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [53390] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1935), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1937), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [53443] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1941), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1939), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [53496] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1943), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1945), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [53549] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1911), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1913), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [53602] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1947), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1949), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [53655] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1907), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1909), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [53708] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1951), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1953), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [53761] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1955), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1957), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [53814] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1959), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1961), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [53867] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1779), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1781), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [53920] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1965), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1963), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [53973] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1843), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1845), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [54026] = 21,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(1791), 1,
      sym_identifier,
    ACTIONS(1793), 1,
      anon_sym_LPAREN,
    ACTIONS(1797), 1,
      anon_sym_STAR,
    ACTIONS(1801), 1,
      anon_sym_type,
    ACTIONS(1803), 1,
      anon_sym_LBRACK,
    ACTIONS(1805), 1,
      anon_sym_await,
    ACTIONS(1967), 1,
      anon_sym_RPAREN,
    STATE(1004), 1,
      sym_string,
    STATE(1638), 1,
      sym_list_splat_pattern,
    STATE(1654), 1,
      sym_primary_expression,
    STATE(2576), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(1642), 2,
      sym_attribute,
      sym_subscript,
    STATE(2574), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1799), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [54115] = 21,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    ACTIONS(1821), 1,
      sym_identifier,
    ACTIONS(1823), 1,
      anon_sym_LPAREN,
    ACTIONS(1827), 1,
      anon_sym_type,
    ACTIONS(1829), 1,
      anon_sym_LBRACK,
    ACTIONS(1831), 1,
      anon_sym_await,
    STATE(1004), 1,
      sym_string,
    STATE(1620), 1,
      sym_primary_expression,
    STATE(1647), 1,
      sym_list_splat_pattern,
    STATE(2494), 1,
      sym_pattern,
    STATE(2750), 1,
      sym_pattern_list,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(1651), 2,
      sym_attribute,
      sym_subscript,
    STATE(1668), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1825), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [54204] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1847), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1849), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [54257] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1871), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1873), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [54310] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1927), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1929), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [54363] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1959), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1961), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [54416] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1971), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1969), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [54469] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1869), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1867), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [54522] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1498), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1496), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [54575] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1975), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1973), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [54628] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1979), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1977), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [54681] = 21,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    ACTIONS(1821), 1,
      sym_identifier,
    ACTIONS(1823), 1,
      anon_sym_LPAREN,
    ACTIONS(1827), 1,
      anon_sym_type,
    ACTIONS(1829), 1,
      anon_sym_LBRACK,
    ACTIONS(1831), 1,
      anon_sym_await,
    STATE(1004), 1,
      sym_string,
    STATE(1620), 1,
      sym_primary_expression,
    STATE(1647), 1,
      sym_list_splat_pattern,
    STATE(2446), 1,
      sym_pattern,
    STATE(2653), 1,
      sym_pattern_list,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(1651), 2,
      sym_attribute,
      sym_subscript,
    STATE(1668), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1825), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [54770] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1983), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1981), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [54823] = 21,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(1967), 1,
      anon_sym_RBRACK,
    ACTIONS(1985), 1,
      sym_identifier,
    ACTIONS(1987), 1,
      anon_sym_LPAREN,
    ACTIONS(1989), 1,
      anon_sym_STAR,
    ACTIONS(1993), 1,
      anon_sym_type,
    ACTIONS(1995), 1,
      anon_sym_LBRACK,
    ACTIONS(1997), 1,
      anon_sym_await,
    STATE(1004), 1,
      sym_string,
    STATE(1623), 1,
      sym_primary_expression,
    STATE(1630), 1,
      sym_list_splat_pattern,
    STATE(2585), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(1622), 2,
      sym_attribute,
      sym_subscript,
    STATE(2600), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1991), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [54912] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2001), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1999), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [54965] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1865), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1863), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [55018] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1853), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1851), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [55071] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2003), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(2005), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [55124] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1941), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1939), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [55177] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1979), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1977), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [55230] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2009), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(2007), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [55283] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2013), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(2011), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [55336] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1901), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1899), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [55389] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1897), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1895), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [55442] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2015), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(2017), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [55495] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2021), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(2019), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [55548] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2023), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(2025), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [55601] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2029), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(2027), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [55654] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2003), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(2005), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [55707] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1835), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1837), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [55760] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1839), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1841), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [55813] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1893), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1891), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [55866] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1983), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1981), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [55919] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1931), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1933), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [55972] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1935), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1937), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [56025] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1943), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1945), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [56078] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1947), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1949), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [56131] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1951), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1953), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [56184] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1955), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1957), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [56237] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2015), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(2017), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [56290] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2033), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(2031), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [56343] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2023), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(2025), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [56396] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1889), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1887), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [56449] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2037), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(2035), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [56502] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2041), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(2039), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [56555] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1885), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1883), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [56608] = 21,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    ACTIONS(1821), 1,
      sym_identifier,
    ACTIONS(1823), 1,
      anon_sym_LPAREN,
    ACTIONS(1827), 1,
      anon_sym_type,
    ACTIONS(1829), 1,
      anon_sym_LBRACK,
    ACTIONS(1831), 1,
      anon_sym_await,
    ACTIONS(2043), 1,
      anon_sym_in,
    STATE(1004), 1,
      sym_string,
    STATE(1620), 1,
      sym_primary_expression,
    STATE(1647), 1,
      sym_list_splat_pattern,
    STATE(1664), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(1651), 2,
      sym_attribute,
      sym_subscript,
    STATE(1668), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1825), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [56697] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2041), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(2039), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [56750] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2029), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(2027), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [56803] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2021), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(2019), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [56856] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1779), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1781), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [56909] = 21,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    ACTIONS(1821), 1,
      sym_identifier,
    ACTIONS(1823), 1,
      anon_sym_LPAREN,
    ACTIONS(1827), 1,
      anon_sym_type,
    ACTIONS(1829), 1,
      anon_sym_LBRACK,
    ACTIONS(1831), 1,
      anon_sym_await,
    STATE(1004), 1,
      sym_string,
    STATE(1620), 1,
      sym_primary_expression,
    STATE(1647), 1,
      sym_list_splat_pattern,
    STATE(2350), 1,
      sym_pattern,
    STATE(2732), 1,
      sym_pattern_list,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(1651), 2,
      sym_attribute,
      sym_subscript,
    STATE(1668), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1825), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [56998] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1905), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1903), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [57051] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1975), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1973), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [57104] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1861), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1859), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [57157] = 21,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    ACTIONS(1821), 1,
      sym_identifier,
    ACTIONS(1823), 1,
      anon_sym_LPAREN,
    ACTIONS(1827), 1,
      anon_sym_type,
    ACTIONS(1829), 1,
      anon_sym_LBRACK,
    ACTIONS(1831), 1,
      anon_sym_await,
    STATE(1004), 1,
      sym_string,
    STATE(1620), 1,
      sym_primary_expression,
    STATE(1647), 1,
      sym_list_splat_pattern,
    STATE(2354), 1,
      sym_pattern,
    STATE(2723), 1,
      sym_pattern_list,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(1651), 2,
      sym_attribute,
      sym_subscript,
    STATE(1668), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1825), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [57246] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1881), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1879), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [57299] = 21,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    ACTIONS(1821), 1,
      sym_identifier,
    ACTIONS(1823), 1,
      anon_sym_LPAREN,
    ACTIONS(1827), 1,
      anon_sym_type,
    ACTIONS(1829), 1,
      anon_sym_LBRACK,
    ACTIONS(1831), 1,
      anon_sym_await,
    STATE(1004), 1,
      sym_string,
    STATE(1620), 1,
      sym_primary_expression,
    STATE(1647), 1,
      sym_list_splat_pattern,
    STATE(2270), 1,
      sym_pattern,
    STATE(2827), 1,
      sym_pattern_list,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(1651), 2,
      sym_attribute,
      sym_subscript,
    STATE(1668), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1825), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [57388] = 21,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(1833), 1,
      anon_sym_RBRACK,
    ACTIONS(1985), 1,
      sym_identifier,
    ACTIONS(1987), 1,
      anon_sym_LPAREN,
    ACTIONS(1989), 1,
      anon_sym_STAR,
    ACTIONS(1993), 1,
      anon_sym_type,
    ACTIONS(1995), 1,
      anon_sym_LBRACK,
    ACTIONS(1997), 1,
      anon_sym_await,
    STATE(1004), 1,
      sym_string,
    STATE(1623), 1,
      sym_primary_expression,
    STATE(1630), 1,
      sym_list_splat_pattern,
    STATE(2585), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(1622), 2,
      sym_attribute,
      sym_subscript,
    STATE(2600), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1991), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [57477] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1857), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1855), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [57530] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1965), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1963), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [57583] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2001), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1999), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [57636] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1877), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1875), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [57689] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2047), 12,
      sym__dedent,
      sym_string_start,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(2045), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [57742] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2009), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(2007), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [57795] = 21,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    ACTIONS(1821), 1,
      sym_identifier,
    ACTIONS(1823), 1,
      anon_sym_LPAREN,
    ACTIONS(1827), 1,
      anon_sym_type,
    ACTIONS(1829), 1,
      anon_sym_LBRACK,
    ACTIONS(1831), 1,
      anon_sym_await,
    ACTIONS(2049), 1,
      anon_sym_in,
    STATE(1004), 1,
      sym_string,
    STATE(1620), 1,
      sym_primary_expression,
    STATE(1647), 1,
      sym_list_splat_pattern,
    STATE(1664), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(1651), 2,
      sym_attribute,
      sym_subscript,
    STATE(1668), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1825), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [57884] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2013), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(2011), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [57937] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1921), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1919), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [57990] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1759), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1761), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [58043] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1971), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1969), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [58096] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2047), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(2045), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [58149] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1498), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1496), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [58202] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1925), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1923), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [58255] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1917), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1915), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [58308] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1486), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(1484), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [58361] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2033), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(2031), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [58414] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2037), 12,
      sym_string_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_LBRACE,
      anon_sym_PLUS,
      anon_sym_TILDE,
      sym_ellipsis,
      sym_float,
    ACTIONS(2035), 32,
      anon_sym_import,
      anon_sym_from,
      anon_sym_print,
      anon_sym_assert,
      anon_sym_return,
      anon_sym_del,
      anon_sym_raise,
      anon_sym_pass,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_match,
      anon_sym_async,
      anon_sym_for,
      anon_sym_while,
      anon_sym_try,
      anon_sym_with,
      anon_sym_def,
      anon_sym_global,
      anon_sym_nonlocal,
      anon_sym_exec,
      anon_sym_type,
      anon_sym_class,
      anon_sym_not,
      anon_sym_lambda,
      anon_sym_yield,
      sym_integer,
      sym_identifier,
      anon_sym_await,
      sym_true,
      sym_false,
      sym_none,
  [58467] = 20,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(1088), 1,
      sym_identifier,
    ACTIONS(1090), 1,
      anon_sym_LPAREN,
    ACTIONS(1096), 1,
      anon_sym_type,
    ACTIONS(1098), 1,
      anon_sym_LBRACK,
    ACTIONS(1100), 1,
      anon_sym_await,
    ACTIONS(2051), 1,
      anon_sym_STAR,
    STATE(1004), 1,
      sym_string,
    STATE(1502), 1,
      sym_list_splat_pattern,
    STATE(1650), 1,
      sym_primary_expression,
    STATE(1664), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(1498), 2,
      sym_attribute,
      sym_subscript,
    STATE(1668), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1094), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [58553] = 20,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(1985), 1,
      sym_identifier,
    ACTIONS(1987), 1,
      anon_sym_LPAREN,
    ACTIONS(1989), 1,
      anon_sym_STAR,
    ACTIONS(1993), 1,
      anon_sym_type,
    ACTIONS(1995), 1,
      anon_sym_LBRACK,
    ACTIONS(1997), 1,
      anon_sym_await,
    STATE(1004), 1,
      sym_string,
    STATE(1623), 1,
      sym_primary_expression,
    STATE(1630), 1,
      sym_list_splat_pattern,
    STATE(2585), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(1622), 2,
      sym_attribute,
      sym_subscript,
    STATE(2600), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1991), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [58639] = 20,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(1791), 1,
      sym_identifier,
    ACTIONS(1793), 1,
      anon_sym_LPAREN,
    ACTIONS(1797), 1,
      anon_sym_STAR,
    ACTIONS(1801), 1,
      anon_sym_type,
    ACTIONS(1803), 1,
      anon_sym_LBRACK,
    ACTIONS(1805), 1,
      anon_sym_await,
    STATE(1004), 1,
      sym_string,
    STATE(1638), 1,
      sym_list_splat_pattern,
    STATE(1654), 1,
      sym_primary_expression,
    STATE(2576), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(1642), 2,
      sym_attribute,
      sym_subscript,
    STATE(2574), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1799), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [58725] = 20,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    ACTIONS(1821), 1,
      sym_identifier,
    ACTIONS(1823), 1,
      anon_sym_LPAREN,
    ACTIONS(1827), 1,
      anon_sym_type,
    ACTIONS(1829), 1,
      anon_sym_LBRACK,
    ACTIONS(1831), 1,
      anon_sym_await,
    STATE(1004), 1,
      sym_string,
    STATE(1620), 1,
      sym_primary_expression,
    STATE(1647), 1,
      sym_list_splat_pattern,
    STATE(1664), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(1651), 2,
      sym_attribute,
      sym_subscript,
    STATE(1668), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1825), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [58811] = 20,
    ACTIONS(17), 1,
      anon_sym_STAR,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(954), 1,
      sym_identifier,
    ACTIONS(958), 1,
      anon_sym_LPAREN,
    ACTIONS(964), 1,
      anon_sym_type,
    ACTIONS(966), 1,
      anon_sym_LBRACK,
    ACTIONS(968), 1,
      anon_sym_await,
    STATE(1004), 1,
      sym_string,
    STATE(1401), 1,
      sym_list_splat_pattern,
    STATE(1631), 1,
      sym_primary_expression,
    STATE(1635), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(1400), 2,
      sym_attribute,
      sym_subscript,
    STATE(1628), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(962), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [58897] = 20,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(1733), 1,
      sym_identifier,
    ACTIONS(1735), 1,
      anon_sym_LPAREN,
    ACTIONS(1737), 1,
      anon_sym_STAR,
    ACTIONS(1741), 1,
      anon_sym_type,
    ACTIONS(1743), 1,
      anon_sym_LBRACK,
    ACTIONS(1745), 1,
      anon_sym_await,
    STATE(1004), 1,
      sym_string,
    STATE(1598), 1,
      sym_list_splat_pattern,
    STATE(1621), 1,
      sym_primary_expression,
    STATE(2085), 1,
      sym_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(1599), 2,
      sym_attribute,
      sym_subscript,
    STATE(2024), 2,
      sym_tuple_pattern,
      sym_list_pattern,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(1739), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [58983] = 19,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    ACTIONS(2053), 1,
      sym_identifier,
    ACTIONS(2059), 1,
      anon_sym_type,
    ACTIONS(2061), 1,
      anon_sym_await,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1620), 1,
      sym_primary_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(2055), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
    STATE(1644), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(2057), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [59066] = 19,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    ACTIONS(2063), 1,
      sym_identifier,
    ACTIONS(2067), 1,
      anon_sym_type,
    ACTIONS(2069), 1,
      anon_sym_await,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1654), 1,
      sym_primary_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(2055), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    STATE(1612), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(2065), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [59149] = 17,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(780), 1,
      anon_sym_type,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(790), 1,
      anon_sym_await,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    ACTIONS(2071), 1,
      anon_sym_not,
    STATE(1150), 1,
      sym_string,
    STATE(1216), 1,
      sym_primary_expression,
    STATE(1470), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(778), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(772), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [59227] = 17,
    ACTIONS(752), 1,
      anon_sym_LPAREN,
    ACTIONS(758), 1,
      anon_sym_type,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(768), 1,
      anon_sym_await,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1306), 1,
      anon_sym_STAR,
    ACTIONS(2073), 1,
      anon_sym_not,
    STATE(1032), 1,
      sym_string,
    STATE(1136), 1,
      sym_primary_expression,
    STATE(1432), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(756), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(750), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [59305] = 17,
    ACTIONS(706), 1,
      anon_sym_LPAREN,
    ACTIONS(712), 1,
      anon_sym_type,
    ACTIONS(714), 1,
      anon_sym_LBRACK,
    ACTIONS(718), 1,
      anon_sym_LBRACE,
    ACTIONS(722), 1,
      anon_sym_await,
    ACTIONS(724), 1,
      sym_string_start,
    ACTIONS(1252), 1,
      anon_sym_STAR,
    ACTIONS(2075), 1,
      anon_sym_not,
    STATE(993), 1,
      sym_string,
    STATE(1050), 1,
      sym_primary_expression,
    STATE(1218), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(720), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(716), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(710), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(704), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1169), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [59383] = 17,
    ACTIONS(796), 1,
      anon_sym_LPAREN,
    ACTIONS(802), 1,
      anon_sym_type,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(808), 1,
      anon_sym_LBRACE,
    ACTIONS(812), 1,
      anon_sym_await,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(1286), 1,
      anon_sym_STAR,
    ACTIONS(2077), 1,
      anon_sym_not,
    STATE(1017), 1,
      sym_string,
    STATE(1119), 1,
      sym_primary_expression,
    STATE(1367), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(806), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(800), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(794), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1414), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [59461] = 17,
    ACTIONS(728), 1,
      anon_sym_LPAREN,
    ACTIONS(734), 1,
      anon_sym_type,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(746), 1,
      anon_sym_await,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(1262), 1,
      anon_sym_STAR,
    ACTIONS(2079), 1,
      anon_sym_not,
    STATE(1030), 1,
      sym_string,
    STATE(1155), 1,
      sym_primary_expression,
    STATE(1290), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(732), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(726), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [59539] = 17,
    ACTIONS(684), 1,
      anon_sym_LPAREN,
    ACTIONS(690), 1,
      anon_sym_type,
    ACTIONS(692), 1,
      anon_sym_LBRACK,
    ACTIONS(696), 1,
      anon_sym_LBRACE,
    ACTIONS(700), 1,
      anon_sym_await,
    ACTIONS(702), 1,
      sym_string_start,
    ACTIONS(998), 1,
      anon_sym_STAR,
    ACTIONS(2081), 1,
      anon_sym_not,
    STATE(979), 1,
      sym_string,
    STATE(1003), 1,
      sym_primary_expression,
    STATE(1183), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(698), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(694), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(688), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(682), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1241), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [59617] = 17,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(675), 1,
      anon_sym_type,
    ACTIONS(677), 1,
      anon_sym_await,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    ACTIONS(2083), 1,
      anon_sym_not,
    STATE(1004), 1,
      sym_string,
    STATE(1058), 1,
      sym_primary_expression,
    STATE(1433), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(673), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [59695] = 17,
    ACTIONS(67), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(652), 1,
      anon_sym_LPAREN,
    ACTIONS(658), 1,
      anon_sym_type,
    ACTIONS(660), 1,
      anon_sym_LBRACK,
    ACTIONS(664), 1,
      anon_sym_await,
    ACTIONS(1302), 1,
      anon_sym_STAR,
    ACTIONS(2085), 1,
      anon_sym_not,
    STATE(975), 1,
      sym_string,
    STATE(983), 1,
      sym_primary_expression,
    STATE(1117), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(75), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(65), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(656), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(77), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1057), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [59773] = 18,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    ACTIONS(2087), 1,
      sym_identifier,
    ACTIONS(2091), 1,
      anon_sym_type,
    ACTIONS(2093), 1,
      anon_sym_await,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1620), 1,
      sym_primary_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(1639), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(2089), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [59852] = 18,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    ACTIONS(2095), 1,
      sym_identifier,
    ACTIONS(2099), 1,
      anon_sym_type,
    ACTIONS(2101), 1,
      anon_sym_await,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1621), 1,
      sym_primary_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(1182), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(2097), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [59931] = 16,
    ACTIONS(684), 1,
      anon_sym_LPAREN,
    ACTIONS(690), 1,
      anon_sym_type,
    ACTIONS(692), 1,
      anon_sym_LBRACK,
    ACTIONS(696), 1,
      anon_sym_LBRACE,
    ACTIONS(700), 1,
      anon_sym_await,
    ACTIONS(702), 1,
      sym_string_start,
    ACTIONS(998), 1,
      anon_sym_STAR,
    STATE(979), 1,
      sym_string,
    STATE(1034), 1,
      sym_primary_expression,
    STATE(1183), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(698), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(694), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(688), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(682), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1241), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [60006] = 18,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    ACTIONS(2095), 1,
      sym_identifier,
    ACTIONS(2099), 1,
      anon_sym_type,
    ACTIONS(2101), 1,
      anon_sym_await,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1641), 1,
      sym_primary_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(1182), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(2097), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [60085] = 16,
    ACTIONS(67), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(652), 1,
      anon_sym_LPAREN,
    ACTIONS(658), 1,
      anon_sym_type,
    ACTIONS(660), 1,
      anon_sym_LBRACK,
    ACTIONS(664), 1,
      anon_sym_await,
    ACTIONS(1302), 1,
      anon_sym_STAR,
    STATE(975), 1,
      sym_string,
    STATE(985), 1,
      sym_primary_expression,
    STATE(1117), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(75), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(65), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(656), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(77), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1057), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [60160] = 18,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    ACTIONS(2103), 1,
      sym_identifier,
    ACTIONS(2107), 1,
      anon_sym_type,
    ACTIONS(2109), 1,
      anon_sym_await,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1624), 1,
      sym_primary_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(1490), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(2105), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [60239] = 16,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(675), 1,
      anon_sym_type,
    ACTIONS(677), 1,
      anon_sym_await,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1004), 1,
      sym_string,
    STATE(1104), 1,
      sym_primary_expression,
    STATE(1433), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(673), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [60314] = 18,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    ACTIONS(2111), 1,
      sym_identifier,
    ACTIONS(2115), 1,
      anon_sym_type,
    ACTIONS(2117), 1,
      anon_sym_await,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1631), 1,
      sym_primary_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(645), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(2113), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [60393] = 18,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    ACTIONS(2119), 1,
      sym_identifier,
    ACTIONS(2123), 1,
      anon_sym_type,
    ACTIONS(2125), 1,
      anon_sym_await,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1619), 1,
      sym_primary_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(1094), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(2121), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [60472] = 16,
    ACTIONS(706), 1,
      anon_sym_LPAREN,
    ACTIONS(712), 1,
      anon_sym_type,
    ACTIONS(714), 1,
      anon_sym_LBRACK,
    ACTIONS(718), 1,
      anon_sym_LBRACE,
    ACTIONS(722), 1,
      anon_sym_await,
    ACTIONS(724), 1,
      sym_string_start,
    ACTIONS(1252), 1,
      anon_sym_STAR,
    STATE(993), 1,
      sym_string,
    STATE(1038), 1,
      sym_primary_expression,
    STATE(1218), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(720), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(716), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(710), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(704), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1169), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [60547] = 16,
    ACTIONS(706), 1,
      anon_sym_LPAREN,
    ACTIONS(712), 1,
      anon_sym_type,
    ACTIONS(714), 1,
      anon_sym_LBRACK,
    ACTIONS(718), 1,
      anon_sym_LBRACE,
    ACTIONS(722), 1,
      anon_sym_await,
    ACTIONS(724), 1,
      sym_string_start,
    ACTIONS(1252), 1,
      anon_sym_STAR,
    STATE(993), 1,
      sym_string,
    STATE(1029), 1,
      sym_primary_expression,
    STATE(1218), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(720), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(716), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(710), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(704), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1169), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [60622] = 16,
    ACTIONS(706), 1,
      anon_sym_LPAREN,
    ACTIONS(712), 1,
      anon_sym_type,
    ACTIONS(714), 1,
      anon_sym_LBRACK,
    ACTIONS(718), 1,
      anon_sym_LBRACE,
    ACTIONS(722), 1,
      anon_sym_await,
    ACTIONS(724), 1,
      sym_string_start,
    ACTIONS(1252), 1,
      anon_sym_STAR,
    STATE(993), 1,
      sym_string,
    STATE(1023), 1,
      sym_primary_expression,
    STATE(1218), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(720), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(716), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(710), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(704), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1169), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [60697] = 16,
    ACTIONS(67), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(652), 1,
      anon_sym_LPAREN,
    ACTIONS(658), 1,
      anon_sym_type,
    ACTIONS(660), 1,
      anon_sym_LBRACK,
    ACTIONS(664), 1,
      anon_sym_await,
    ACTIONS(1302), 1,
      anon_sym_STAR,
    STATE(975), 1,
      sym_string,
    STATE(992), 1,
      sym_primary_expression,
    STATE(1117), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(75), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(65), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(656), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(77), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1057), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [60772] = 16,
    ACTIONS(706), 1,
      anon_sym_LPAREN,
    ACTIONS(712), 1,
      anon_sym_type,
    ACTIONS(714), 1,
      anon_sym_LBRACK,
    ACTIONS(718), 1,
      anon_sym_LBRACE,
    ACTIONS(722), 1,
      anon_sym_await,
    ACTIONS(724), 1,
      sym_string_start,
    ACTIONS(1252), 1,
      anon_sym_STAR,
    STATE(993), 1,
      sym_string,
    STATE(1007), 1,
      sym_primary_expression,
    STATE(1218), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(720), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(716), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(710), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(704), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1169), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [60847] = 16,
    ACTIONS(706), 1,
      anon_sym_LPAREN,
    ACTIONS(712), 1,
      anon_sym_type,
    ACTIONS(714), 1,
      anon_sym_LBRACK,
    ACTIONS(718), 1,
      anon_sym_LBRACE,
    ACTIONS(722), 1,
      anon_sym_await,
    ACTIONS(724), 1,
      sym_string_start,
    ACTIONS(1252), 1,
      anon_sym_STAR,
    STATE(993), 1,
      sym_string,
    STATE(1001), 1,
      sym_primary_expression,
    STATE(1218), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(720), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(716), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(710), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(704), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1169), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [60922] = 16,
    ACTIONS(706), 1,
      anon_sym_LPAREN,
    ACTIONS(712), 1,
      anon_sym_type,
    ACTIONS(714), 1,
      anon_sym_LBRACK,
    ACTIONS(718), 1,
      anon_sym_LBRACE,
    ACTIONS(722), 1,
      anon_sym_await,
    ACTIONS(724), 1,
      sym_string_start,
    ACTIONS(1252), 1,
      anon_sym_STAR,
    STATE(993), 1,
      sym_string,
    STATE(1051), 1,
      sym_primary_expression,
    STATE(1218), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(720), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(716), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(710), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(704), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1169), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [60997] = 16,
    ACTIONS(67), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(652), 1,
      anon_sym_LPAREN,
    ACTIONS(658), 1,
      anon_sym_type,
    ACTIONS(660), 1,
      anon_sym_LBRACK,
    ACTIONS(664), 1,
      anon_sym_await,
    ACTIONS(1302), 1,
      anon_sym_STAR,
    STATE(975), 1,
      sym_string,
    STATE(987), 1,
      sym_primary_expression,
    STATE(1117), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(75), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(65), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(656), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(77), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1057), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [61072] = 16,
    ACTIONS(706), 1,
      anon_sym_LPAREN,
    ACTIONS(712), 1,
      anon_sym_type,
    ACTIONS(714), 1,
      anon_sym_LBRACK,
    ACTIONS(718), 1,
      anon_sym_LBRACE,
    ACTIONS(722), 1,
      anon_sym_await,
    ACTIONS(724), 1,
      sym_string_start,
    ACTIONS(1252), 1,
      anon_sym_STAR,
    STATE(993), 1,
      sym_string,
    STATE(1050), 1,
      sym_primary_expression,
    STATE(1218), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(720), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(716), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(710), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(704), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1169), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [61147] = 16,
    ACTIONS(706), 1,
      anon_sym_LPAREN,
    ACTIONS(712), 1,
      anon_sym_type,
    ACTIONS(714), 1,
      anon_sym_LBRACK,
    ACTIONS(718), 1,
      anon_sym_LBRACE,
    ACTIONS(722), 1,
      anon_sym_await,
    ACTIONS(724), 1,
      sym_string_start,
    ACTIONS(1252), 1,
      anon_sym_STAR,
    STATE(993), 1,
      sym_string,
    STATE(1048), 1,
      sym_primary_expression,
    STATE(1218), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(720), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(716), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(710), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(704), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1169), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [61222] = 16,
    ACTIONS(706), 1,
      anon_sym_LPAREN,
    ACTIONS(712), 1,
      anon_sym_type,
    ACTIONS(714), 1,
      anon_sym_LBRACK,
    ACTIONS(718), 1,
      anon_sym_LBRACE,
    ACTIONS(722), 1,
      anon_sym_await,
    ACTIONS(724), 1,
      sym_string_start,
    ACTIONS(1252), 1,
      anon_sym_STAR,
    STATE(993), 1,
      sym_string,
    STATE(1047), 1,
      sym_primary_expression,
    STATE(1218), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(720), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(716), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(710), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(704), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1169), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [61297] = 16,
    ACTIONS(67), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(652), 1,
      anon_sym_LPAREN,
    ACTIONS(658), 1,
      anon_sym_type,
    ACTIONS(660), 1,
      anon_sym_LBRACK,
    ACTIONS(664), 1,
      anon_sym_await,
    ACTIONS(1302), 1,
      anon_sym_STAR,
    STATE(975), 1,
      sym_string,
    STATE(998), 1,
      sym_primary_expression,
    STATE(1117), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(75), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(65), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(656), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(77), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1057), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [61372] = 16,
    ACTIONS(67), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(652), 1,
      anon_sym_LPAREN,
    ACTIONS(658), 1,
      anon_sym_type,
    ACTIONS(660), 1,
      anon_sym_LBRACK,
    ACTIONS(664), 1,
      anon_sym_await,
    ACTIONS(1302), 1,
      anon_sym_STAR,
    STATE(975), 1,
      sym_string,
    STATE(990), 1,
      sym_primary_expression,
    STATE(1117), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(75), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(65), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(656), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(77), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1057), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [61447] = 18,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    ACTIONS(2123), 1,
      anon_sym_type,
    ACTIONS(2125), 1,
      anon_sym_await,
    ACTIONS(2127), 1,
      sym_identifier,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1619), 1,
      sym_primary_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(1094), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(2121), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [61526] = 18,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    ACTIONS(2107), 1,
      anon_sym_type,
    ACTIONS(2109), 1,
      anon_sym_await,
    ACTIONS(2129), 1,
      sym_identifier,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1623), 1,
      sym_primary_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(1490), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(2105), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [61605] = 16,
    ACTIONS(728), 1,
      anon_sym_LPAREN,
    ACTIONS(734), 1,
      anon_sym_type,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(746), 1,
      anon_sym_await,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(1262), 1,
      anon_sym_STAR,
    STATE(1030), 1,
      sym_string,
    STATE(1132), 1,
      sym_primary_expression,
    STATE(1290), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(732), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(726), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [61680] = 18,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    ACTIONS(2131), 1,
      sym_identifier,
    ACTIONS(2135), 1,
      anon_sym_type,
    ACTIONS(2137), 1,
      anon_sym_await,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1654), 1,
      sym_primary_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(1412), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(2133), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [61759] = 18,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    ACTIONS(2139), 1,
      sym_identifier,
    ACTIONS(2143), 1,
      anon_sym_type,
    ACTIONS(2145), 1,
      anon_sym_await,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1620), 1,
      sym_primary_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(1392), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(2141), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [61838] = 16,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(780), 1,
      anon_sym_type,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(790), 1,
      anon_sym_await,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    STATE(1150), 1,
      sym_string,
    STATE(1232), 1,
      sym_primary_expression,
    STATE(1470), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(778), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(772), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [61913] = 16,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(780), 1,
      anon_sym_type,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(790), 1,
      anon_sym_await,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    STATE(1150), 1,
      sym_string,
    STATE(1231), 1,
      sym_primary_expression,
    STATE(1470), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(778), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(772), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [61988] = 16,
    ACTIONS(684), 1,
      anon_sym_LPAREN,
    ACTIONS(690), 1,
      anon_sym_type,
    ACTIONS(692), 1,
      anon_sym_LBRACK,
    ACTIONS(696), 1,
      anon_sym_LBRACE,
    ACTIONS(700), 1,
      anon_sym_await,
    ACTIONS(702), 1,
      sym_string_start,
    ACTIONS(998), 1,
      anon_sym_STAR,
    STATE(979), 1,
      sym_string,
    STATE(1010), 1,
      sym_primary_expression,
    STATE(1183), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(698), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(694), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(688), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(682), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1241), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [62063] = 16,
    ACTIONS(67), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(652), 1,
      anon_sym_LPAREN,
    ACTIONS(658), 1,
      anon_sym_type,
    ACTIONS(660), 1,
      anon_sym_LBRACK,
    ACTIONS(664), 1,
      anon_sym_await,
    ACTIONS(1302), 1,
      anon_sym_STAR,
    STATE(975), 1,
      sym_string,
    STATE(989), 1,
      sym_primary_expression,
    STATE(1117), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(75), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(65), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(656), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(77), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1057), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [62138] = 16,
    ACTIONS(67), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(652), 1,
      anon_sym_LPAREN,
    ACTIONS(658), 1,
      anon_sym_type,
    ACTIONS(660), 1,
      anon_sym_LBRACK,
    ACTIONS(664), 1,
      anon_sym_await,
    ACTIONS(1302), 1,
      anon_sym_STAR,
    STATE(975), 1,
      sym_string,
    STATE(986), 1,
      sym_primary_expression,
    STATE(1117), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(75), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(65), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(656), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(77), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1057), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [62213] = 16,
    ACTIONS(684), 1,
      anon_sym_LPAREN,
    ACTIONS(690), 1,
      anon_sym_type,
    ACTIONS(692), 1,
      anon_sym_LBRACK,
    ACTIONS(696), 1,
      anon_sym_LBRACE,
    ACTIONS(700), 1,
      anon_sym_await,
    ACTIONS(702), 1,
      sym_string_start,
    ACTIONS(998), 1,
      anon_sym_STAR,
    STATE(979), 1,
      sym_string,
    STATE(1005), 1,
      sym_primary_expression,
    STATE(1183), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(698), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(694), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(688), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(682), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1241), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [62288] = 18,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    ACTIONS(2131), 1,
      sym_identifier,
    ACTIONS(2135), 1,
      anon_sym_type,
    ACTIONS(2137), 1,
      anon_sym_await,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1633), 1,
      sym_primary_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(1412), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(2133), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [62367] = 16,
    ACTIONS(728), 1,
      anon_sym_LPAREN,
    ACTIONS(734), 1,
      anon_sym_type,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(746), 1,
      anon_sym_await,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(1262), 1,
      anon_sym_STAR,
    STATE(1030), 1,
      sym_string,
    STATE(1151), 1,
      sym_primary_expression,
    STATE(1290), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(732), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(726), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [62442] = 16,
    ACTIONS(728), 1,
      anon_sym_LPAREN,
    ACTIONS(734), 1,
      anon_sym_type,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(746), 1,
      anon_sym_await,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(1262), 1,
      anon_sym_STAR,
    STATE(1030), 1,
      sym_string,
    STATE(1053), 1,
      sym_primary_expression,
    STATE(1290), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(732), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(726), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [62517] = 16,
    ACTIONS(728), 1,
      anon_sym_LPAREN,
    ACTIONS(734), 1,
      anon_sym_type,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(746), 1,
      anon_sym_await,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(1262), 1,
      anon_sym_STAR,
    STATE(1030), 1,
      sym_string,
    STATE(1155), 1,
      sym_primary_expression,
    STATE(1290), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(732), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(726), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [62592] = 16,
    ACTIONS(728), 1,
      anon_sym_LPAREN,
    ACTIONS(734), 1,
      anon_sym_type,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(746), 1,
      anon_sym_await,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(1262), 1,
      anon_sym_STAR,
    STATE(1030), 1,
      sym_string,
    STATE(1128), 1,
      sym_primary_expression,
    STATE(1290), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(732), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(726), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [62667] = 16,
    ACTIONS(728), 1,
      anon_sym_LPAREN,
    ACTIONS(734), 1,
      anon_sym_type,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(746), 1,
      anon_sym_await,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(1262), 1,
      anon_sym_STAR,
    STATE(1030), 1,
      sym_string,
    STATE(1160), 1,
      sym_primary_expression,
    STATE(1290), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(732), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(726), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [62742] = 16,
    ACTIONS(728), 1,
      anon_sym_LPAREN,
    ACTIONS(734), 1,
      anon_sym_type,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(746), 1,
      anon_sym_await,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(1262), 1,
      anon_sym_STAR,
    STATE(1030), 1,
      sym_string,
    STATE(1159), 1,
      sym_primary_expression,
    STATE(1290), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(732), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(726), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [62817] = 16,
    ACTIONS(728), 1,
      anon_sym_LPAREN,
    ACTIONS(734), 1,
      anon_sym_type,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(746), 1,
      anon_sym_await,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(1262), 1,
      anon_sym_STAR,
    STATE(1030), 1,
      sym_string,
    STATE(1158), 1,
      sym_primary_expression,
    STATE(1290), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(732), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(726), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [62892] = 16,
    ACTIONS(728), 1,
      anon_sym_LPAREN,
    ACTIONS(734), 1,
      anon_sym_type,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(746), 1,
      anon_sym_await,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(1262), 1,
      anon_sym_STAR,
    STATE(1030), 1,
      sym_string,
    STATE(1156), 1,
      sym_primary_expression,
    STATE(1290), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(732), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(726), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [62967] = 16,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(780), 1,
      anon_sym_type,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(790), 1,
      anon_sym_await,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    STATE(1150), 1,
      sym_string,
    STATE(1225), 1,
      sym_primary_expression,
    STATE(1470), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(778), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(772), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [63042] = 16,
    ACTIONS(796), 1,
      anon_sym_LPAREN,
    ACTIONS(802), 1,
      anon_sym_type,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(808), 1,
      anon_sym_LBRACE,
    ACTIONS(812), 1,
      anon_sym_await,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(1286), 1,
      anon_sym_STAR,
    STATE(1017), 1,
      sym_string,
    STATE(1130), 1,
      sym_primary_expression,
    STATE(1367), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(806), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(800), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(794), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1414), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [63117] = 16,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(780), 1,
      anon_sym_type,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(790), 1,
      anon_sym_await,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    STATE(1150), 1,
      sym_string,
    STATE(1162), 1,
      sym_primary_expression,
    STATE(1470), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(778), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(772), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [63192] = 16,
    ACTIONS(796), 1,
      anon_sym_LPAREN,
    ACTIONS(802), 1,
      anon_sym_type,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(808), 1,
      anon_sym_LBRACE,
    ACTIONS(812), 1,
      anon_sym_await,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(1286), 1,
      anon_sym_STAR,
    STATE(1017), 1,
      sym_string,
    STATE(1129), 1,
      sym_primary_expression,
    STATE(1367), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(806), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(800), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(794), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1414), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [63267] = 16,
    ACTIONS(684), 1,
      anon_sym_LPAREN,
    ACTIONS(690), 1,
      anon_sym_type,
    ACTIONS(692), 1,
      anon_sym_LBRACK,
    ACTIONS(696), 1,
      anon_sym_LBRACE,
    ACTIONS(700), 1,
      anon_sym_await,
    ACTIONS(702), 1,
      sym_string_start,
    ACTIONS(998), 1,
      anon_sym_STAR,
    STATE(979), 1,
      sym_string,
    STATE(1003), 1,
      sym_primary_expression,
    STATE(1183), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(698), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(694), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(688), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(682), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1241), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [63342] = 16,
    ACTIONS(684), 1,
      anon_sym_LPAREN,
    ACTIONS(690), 1,
      anon_sym_type,
    ACTIONS(692), 1,
      anon_sym_LBRACK,
    ACTIONS(696), 1,
      anon_sym_LBRACE,
    ACTIONS(700), 1,
      anon_sym_await,
    ACTIONS(702), 1,
      sym_string_start,
    ACTIONS(998), 1,
      anon_sym_STAR,
    STATE(979), 1,
      sym_string,
    STATE(1044), 1,
      sym_primary_expression,
    STATE(1183), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(698), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(694), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(688), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(682), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1241), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [63417] = 16,
    ACTIONS(684), 1,
      anon_sym_LPAREN,
    ACTIONS(690), 1,
      anon_sym_type,
    ACTIONS(692), 1,
      anon_sym_LBRACK,
    ACTIONS(696), 1,
      anon_sym_LBRACE,
    ACTIONS(700), 1,
      anon_sym_await,
    ACTIONS(702), 1,
      sym_string_start,
    ACTIONS(998), 1,
      anon_sym_STAR,
    STATE(979), 1,
      sym_string,
    STATE(1025), 1,
      sym_primary_expression,
    STATE(1183), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(698), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(694), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(688), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(682), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1241), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [63492] = 16,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(780), 1,
      anon_sym_type,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(790), 1,
      anon_sym_await,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    STATE(1150), 1,
      sym_string,
    STATE(1223), 1,
      sym_primary_expression,
    STATE(1470), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(778), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(772), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [63567] = 16,
    ACTIONS(796), 1,
      anon_sym_LPAREN,
    ACTIONS(802), 1,
      anon_sym_type,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(808), 1,
      anon_sym_LBRACE,
    ACTIONS(812), 1,
      anon_sym_await,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(1286), 1,
      anon_sym_STAR,
    STATE(1017), 1,
      sym_string,
    STATE(1126), 1,
      sym_primary_expression,
    STATE(1367), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(806), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(800), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(794), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1414), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [63642] = 16,
    ACTIONS(796), 1,
      anon_sym_LPAREN,
    ACTIONS(802), 1,
      anon_sym_type,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(808), 1,
      anon_sym_LBRACE,
    ACTIONS(812), 1,
      anon_sym_await,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(1286), 1,
      anon_sym_STAR,
    STATE(1017), 1,
      sym_string,
    STATE(1125), 1,
      sym_primary_expression,
    STATE(1367), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(806), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(800), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(794), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1414), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [63717] = 16,
    ACTIONS(796), 1,
      anon_sym_LPAREN,
    ACTIONS(802), 1,
      anon_sym_type,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(808), 1,
      anon_sym_LBRACE,
    ACTIONS(812), 1,
      anon_sym_await,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(1286), 1,
      anon_sym_STAR,
    STATE(1017), 1,
      sym_string,
    STATE(1124), 1,
      sym_primary_expression,
    STATE(1367), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(806), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(800), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(794), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1414), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [63792] = 16,
    ACTIONS(796), 1,
      anon_sym_LPAREN,
    ACTIONS(802), 1,
      anon_sym_type,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(808), 1,
      anon_sym_LBRACE,
    ACTIONS(812), 1,
      anon_sym_await,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(1286), 1,
      anon_sym_STAR,
    STATE(1017), 1,
      sym_string,
    STATE(1123), 1,
      sym_primary_expression,
    STATE(1367), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(806), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(800), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(794), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1414), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [63867] = 16,
    ACTIONS(67), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(652), 1,
      anon_sym_LPAREN,
    ACTIONS(658), 1,
      anon_sym_type,
    ACTIONS(660), 1,
      anon_sym_LBRACK,
    ACTIONS(664), 1,
      anon_sym_await,
    ACTIONS(1302), 1,
      anon_sym_STAR,
    STATE(975), 1,
      sym_string,
    STATE(984), 1,
      sym_primary_expression,
    STATE(1117), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(75), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(65), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(656), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(77), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1057), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [63942] = 16,
    ACTIONS(796), 1,
      anon_sym_LPAREN,
    ACTIONS(802), 1,
      anon_sym_type,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(808), 1,
      anon_sym_LBRACE,
    ACTIONS(812), 1,
      anon_sym_await,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(1286), 1,
      anon_sym_STAR,
    STATE(1017), 1,
      sym_string,
    STATE(1121), 1,
      sym_primary_expression,
    STATE(1367), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(806), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(800), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(794), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1414), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [64017] = 16,
    ACTIONS(684), 1,
      anon_sym_LPAREN,
    ACTIONS(690), 1,
      anon_sym_type,
    ACTIONS(692), 1,
      anon_sym_LBRACK,
    ACTIONS(696), 1,
      anon_sym_LBRACE,
    ACTIONS(700), 1,
      anon_sym_await,
    ACTIONS(702), 1,
      sym_string_start,
    ACTIONS(998), 1,
      anon_sym_STAR,
    STATE(979), 1,
      sym_string,
    STATE(999), 1,
      sym_primary_expression,
    STATE(1183), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(698), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(694), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(688), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(682), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1241), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [64092] = 16,
    ACTIONS(796), 1,
      anon_sym_LPAREN,
    ACTIONS(802), 1,
      anon_sym_type,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(808), 1,
      anon_sym_LBRACE,
    ACTIONS(812), 1,
      anon_sym_await,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(1286), 1,
      anon_sym_STAR,
    STATE(1017), 1,
      sym_string,
    STATE(1119), 1,
      sym_primary_expression,
    STATE(1367), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(806), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(800), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(794), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1414), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [64167] = 16,
    ACTIONS(796), 1,
      anon_sym_LPAREN,
    ACTIONS(802), 1,
      anon_sym_type,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(808), 1,
      anon_sym_LBRACE,
    ACTIONS(812), 1,
      anon_sym_await,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(1286), 1,
      anon_sym_STAR,
    STATE(1017), 1,
      sym_string,
    STATE(1118), 1,
      sym_primary_expression,
    STATE(1367), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(806), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(800), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(794), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1414), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [64242] = 16,
    ACTIONS(684), 1,
      anon_sym_LPAREN,
    ACTIONS(690), 1,
      anon_sym_type,
    ACTIONS(692), 1,
      anon_sym_LBRACK,
    ACTIONS(696), 1,
      anon_sym_LBRACE,
    ACTIONS(700), 1,
      anon_sym_await,
    ACTIONS(702), 1,
      sym_string_start,
    ACTIONS(998), 1,
      anon_sym_STAR,
    STATE(979), 1,
      sym_string,
    STATE(1040), 1,
      sym_primary_expression,
    STATE(1183), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(698), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(694), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(688), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(682), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1241), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [64317] = 16,
    ACTIONS(796), 1,
      anon_sym_LPAREN,
    ACTIONS(802), 1,
      anon_sym_type,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(808), 1,
      anon_sym_LBRACE,
    ACTIONS(812), 1,
      anon_sym_await,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(1286), 1,
      anon_sym_STAR,
    STATE(1017), 1,
      sym_string,
    STATE(1116), 1,
      sym_primary_expression,
    STATE(1367), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(806), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(800), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(794), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1414), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [64392] = 16,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(780), 1,
      anon_sym_type,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(790), 1,
      anon_sym_await,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    STATE(1150), 1,
      sym_string,
    STATE(1222), 1,
      sym_primary_expression,
    STATE(1470), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(778), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(772), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [64467] = 16,
    ACTIONS(684), 1,
      anon_sym_LPAREN,
    ACTIONS(690), 1,
      anon_sym_type,
    ACTIONS(692), 1,
      anon_sym_LBRACK,
    ACTIONS(696), 1,
      anon_sym_LBRACE,
    ACTIONS(700), 1,
      anon_sym_await,
    ACTIONS(702), 1,
      sym_string_start,
    ACTIONS(998), 1,
      anon_sym_STAR,
    STATE(979), 1,
      sym_string,
    STATE(1049), 1,
      sym_primary_expression,
    STATE(1183), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(698), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(694), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(688), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(682), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1241), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [64542] = 16,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(780), 1,
      anon_sym_type,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(790), 1,
      anon_sym_await,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    STATE(1150), 1,
      sym_string,
    STATE(1217), 1,
      sym_primary_expression,
    STATE(1470), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(778), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(772), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [64617] = 16,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(780), 1,
      anon_sym_type,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(790), 1,
      anon_sym_await,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    STATE(1150), 1,
      sym_string,
    STATE(1216), 1,
      sym_primary_expression,
    STATE(1470), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(778), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(772), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [64692] = 16,
    ACTIONS(67), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(652), 1,
      anon_sym_LPAREN,
    ACTIONS(658), 1,
      anon_sym_type,
    ACTIONS(660), 1,
      anon_sym_LBRACK,
    ACTIONS(664), 1,
      anon_sym_await,
    ACTIONS(1302), 1,
      anon_sym_STAR,
    STATE(975), 1,
      sym_string,
    STATE(983), 1,
      sym_primary_expression,
    STATE(1117), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(75), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(65), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(656), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(77), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1057), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [64767] = 16,
    ACTIONS(67), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(652), 1,
      anon_sym_LPAREN,
    ACTIONS(658), 1,
      anon_sym_type,
    ACTIONS(660), 1,
      anon_sym_LBRACK,
    ACTIONS(664), 1,
      anon_sym_await,
    ACTIONS(1302), 1,
      anon_sym_STAR,
    STATE(975), 1,
      sym_string,
    STATE(982), 1,
      sym_primary_expression,
    STATE(1117), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(75), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(65), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(656), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(77), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1057), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [64842] = 16,
    ACTIONS(67), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(652), 1,
      anon_sym_LPAREN,
    ACTIONS(658), 1,
      anon_sym_type,
    ACTIONS(660), 1,
      anon_sym_LBRACK,
    ACTIONS(664), 1,
      anon_sym_await,
    ACTIONS(1302), 1,
      anon_sym_STAR,
    STATE(975), 1,
      sym_string,
    STATE(981), 1,
      sym_primary_expression,
    STATE(1117), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(75), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(65), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(656), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(77), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1057), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [64917] = 16,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(780), 1,
      anon_sym_type,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(790), 1,
      anon_sym_await,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    STATE(1150), 1,
      sym_string,
    STATE(1213), 1,
      sym_primary_expression,
    STATE(1470), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(778), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(772), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [64992] = 16,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(780), 1,
      anon_sym_type,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(790), 1,
      anon_sym_await,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    STATE(1150), 1,
      sym_string,
    STATE(1210), 1,
      sym_primary_expression,
    STATE(1470), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(778), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(772), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [65067] = 16,
    ACTIONS(752), 1,
      anon_sym_LPAREN,
    ACTIONS(758), 1,
      anon_sym_type,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(768), 1,
      anon_sym_await,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1306), 1,
      anon_sym_STAR,
    STATE(1032), 1,
      sym_string,
    STATE(1152), 1,
      sym_primary_expression,
    STATE(1432), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(756), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(750), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [65142] = 16,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(675), 1,
      anon_sym_type,
    ACTIONS(677), 1,
      anon_sym_await,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1004), 1,
      sym_string,
    STATE(1073), 1,
      sym_primary_expression,
    STATE(1433), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(673), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [65217] = 16,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(675), 1,
      anon_sym_type,
    ACTIONS(677), 1,
      anon_sym_await,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1004), 1,
      sym_string,
    STATE(1072), 1,
      sym_primary_expression,
    STATE(1433), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(673), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [65292] = 16,
    ACTIONS(752), 1,
      anon_sym_LPAREN,
    ACTIONS(758), 1,
      anon_sym_type,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(768), 1,
      anon_sym_await,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1306), 1,
      anon_sym_STAR,
    STATE(1032), 1,
      sym_string,
    STATE(1153), 1,
      sym_primary_expression,
    STATE(1432), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(756), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(750), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [65367] = 18,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    ACTIONS(2135), 1,
      anon_sym_type,
    ACTIONS(2137), 1,
      anon_sym_await,
    ACTIONS(2147), 1,
      sym_identifier,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1633), 1,
      sym_primary_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(1412), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(2133), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [65446] = 16,
    ACTIONS(706), 1,
      anon_sym_LPAREN,
    ACTIONS(712), 1,
      anon_sym_type,
    ACTIONS(714), 1,
      anon_sym_LBRACK,
    ACTIONS(718), 1,
      anon_sym_LBRACE,
    ACTIONS(722), 1,
      anon_sym_await,
    ACTIONS(724), 1,
      sym_string_start,
    ACTIONS(1252), 1,
      anon_sym_STAR,
    STATE(993), 1,
      sym_string,
    STATE(1026), 1,
      sym_primary_expression,
    STATE(1218), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(720), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(716), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(710), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(704), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1169), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [65521] = 16,
    ACTIONS(752), 1,
      anon_sym_LPAREN,
    ACTIONS(758), 1,
      anon_sym_type,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(768), 1,
      anon_sym_await,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1306), 1,
      anon_sym_STAR,
    STATE(1032), 1,
      sym_string,
    STATE(1147), 1,
      sym_primary_expression,
    STATE(1432), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(756), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(750), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [65596] = 16,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(675), 1,
      anon_sym_type,
    ACTIONS(677), 1,
      anon_sym_await,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1004), 1,
      sym_string,
    STATE(1061), 1,
      sym_primary_expression,
    STATE(1433), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(673), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [65671] = 16,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(675), 1,
      anon_sym_type,
    ACTIONS(677), 1,
      anon_sym_await,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1004), 1,
      sym_string,
    STATE(1063), 1,
      sym_primary_expression,
    STATE(1433), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(673), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [65746] = 16,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(675), 1,
      anon_sym_type,
    ACTIONS(677), 1,
      anon_sym_await,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1004), 1,
      sym_string,
    STATE(1054), 1,
      sym_primary_expression,
    STATE(1433), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(673), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [65821] = 16,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(675), 1,
      anon_sym_type,
    ACTIONS(677), 1,
      anon_sym_await,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1004), 1,
      sym_string,
    STATE(1055), 1,
      sym_primary_expression,
    STATE(1433), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(673), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [65896] = 16,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(675), 1,
      anon_sym_type,
    ACTIONS(677), 1,
      anon_sym_await,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1004), 1,
      sym_string,
    STATE(1056), 1,
      sym_primary_expression,
    STATE(1433), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(673), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [65971] = 16,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(675), 1,
      anon_sym_type,
    ACTIONS(677), 1,
      anon_sym_await,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1004), 1,
      sym_string,
    STATE(1058), 1,
      sym_primary_expression,
    STATE(1433), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(673), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [66046] = 16,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(675), 1,
      anon_sym_type,
    ACTIONS(677), 1,
      anon_sym_await,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1004), 1,
      sym_string,
    STATE(1059), 1,
      sym_primary_expression,
    STATE(1433), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(673), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [66121] = 16,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(675), 1,
      anon_sym_type,
    ACTIONS(677), 1,
      anon_sym_await,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    STATE(1004), 1,
      sym_string,
    STATE(1060), 1,
      sym_primary_expression,
    STATE(1433), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(673), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(323), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1365), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [66196] = 18,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    ACTIONS(2149), 1,
      sym_identifier,
    ACTIONS(2153), 1,
      anon_sym_type,
    ACTIONS(2155), 1,
      anon_sym_await,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1650), 1,
      sym_primary_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(1512), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(2151), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [66275] = 16,
    ACTIONS(752), 1,
      anon_sym_LPAREN,
    ACTIONS(758), 1,
      anon_sym_type,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(768), 1,
      anon_sym_await,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1306), 1,
      anon_sym_STAR,
    STATE(1032), 1,
      sym_string,
    STATE(1144), 1,
      sym_primary_expression,
    STATE(1432), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(756), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(750), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [66350] = 18,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    ACTIONS(2137), 1,
      anon_sym_await,
    ACTIONS(2157), 1,
      sym_identifier,
    ACTIONS(2161), 1,
      anon_sym_type,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1654), 1,
      sym_primary_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(1396), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(2159), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [66429] = 16,
    ACTIONS(752), 1,
      anon_sym_LPAREN,
    ACTIONS(758), 1,
      anon_sym_type,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(768), 1,
      anon_sym_await,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1306), 1,
      anon_sym_STAR,
    STATE(1032), 1,
      sym_string,
    STATE(1142), 1,
      sym_primary_expression,
    STATE(1432), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(756), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(750), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [66504] = 18,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    ACTIONS(2115), 1,
      anon_sym_type,
    ACTIONS(2117), 1,
      anon_sym_await,
    ACTIONS(2163), 1,
      sym_identifier,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1631), 1,
      sym_primary_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(645), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(2113), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [66583] = 16,
    ACTIONS(752), 1,
      anon_sym_LPAREN,
    ACTIONS(758), 1,
      anon_sym_type,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(768), 1,
      anon_sym_await,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1306), 1,
      anon_sym_STAR,
    STATE(1032), 1,
      sym_string,
    STATE(1140), 1,
      sym_primary_expression,
    STATE(1432), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(756), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(750), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [66658] = 16,
    ACTIONS(752), 1,
      anon_sym_LPAREN,
    ACTIONS(758), 1,
      anon_sym_type,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(768), 1,
      anon_sym_await,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1306), 1,
      anon_sym_STAR,
    STATE(1032), 1,
      sym_string,
    STATE(1139), 1,
      sym_primary_expression,
    STATE(1432), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(756), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(750), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [66733] = 18,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    ACTIONS(2101), 1,
      anon_sym_await,
    ACTIONS(2165), 1,
      sym_identifier,
    ACTIONS(2169), 1,
      anon_sym_type,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1621), 1,
      sym_primary_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(1253), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(2167), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [66812] = 18,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    ACTIONS(2171), 1,
      sym_identifier,
    ACTIONS(2175), 1,
      anon_sym_type,
    ACTIONS(2177), 1,
      anon_sym_await,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1654), 1,
      sym_primary_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(1608), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(2173), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [66891] = 16,
    ACTIONS(752), 1,
      anon_sym_LPAREN,
    ACTIONS(758), 1,
      anon_sym_type,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(768), 1,
      anon_sym_await,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1306), 1,
      anon_sym_STAR,
    STATE(1032), 1,
      sym_string,
    STATE(1136), 1,
      sym_primary_expression,
    STATE(1432), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(756), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(750), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [66966] = 16,
    ACTIONS(752), 1,
      anon_sym_LPAREN,
    ACTIONS(758), 1,
      anon_sym_type,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(768), 1,
      anon_sym_await,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1306), 1,
      anon_sym_STAR,
    STATE(1032), 1,
      sym_string,
    STATE(1135), 1,
      sym_primary_expression,
    STATE(1432), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(756), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(750), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [67041] = 18,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    ACTIONS(2107), 1,
      anon_sym_type,
    ACTIONS(2109), 1,
      anon_sym_await,
    ACTIONS(2129), 1,
      sym_identifier,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1624), 1,
      sym_primary_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(1490), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(2105), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [67120] = 16,
    ACTIONS(752), 1,
      anon_sym_LPAREN,
    ACTIONS(758), 1,
      anon_sym_type,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(768), 1,
      anon_sym_await,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1306), 1,
      anon_sym_STAR,
    STATE(1032), 1,
      sym_string,
    STATE(1086), 1,
      sym_primary_expression,
    STATE(1432), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(756), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(750), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [67195] = 16,
    ACTIONS(752), 1,
      anon_sym_LPAREN,
    ACTIONS(758), 1,
      anon_sym_type,
    ACTIONS(760), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_LBRACE,
    ACTIONS(768), 1,
      anon_sym_await,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(1306), 1,
      anon_sym_STAR,
    STATE(1032), 1,
      sym_string,
    STATE(1134), 1,
      sym_primary_expression,
    STATE(1432), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(766), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(762), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(756), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(750), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1306), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [67270] = 16,
    ACTIONS(684), 1,
      anon_sym_LPAREN,
    ACTIONS(690), 1,
      anon_sym_type,
    ACTIONS(692), 1,
      anon_sym_LBRACK,
    ACTIONS(696), 1,
      anon_sym_LBRACE,
    ACTIONS(700), 1,
      anon_sym_await,
    ACTIONS(702), 1,
      sym_string_start,
    ACTIONS(998), 1,
      anon_sym_STAR,
    STATE(979), 1,
      sym_string,
    STATE(1015), 1,
      sym_primary_expression,
    STATE(1183), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(698), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(694), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(688), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(682), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1241), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [67345] = 16,
    ACTIONS(706), 1,
      anon_sym_LPAREN,
    ACTIONS(712), 1,
      anon_sym_type,
    ACTIONS(714), 1,
      anon_sym_LBRACK,
    ACTIONS(718), 1,
      anon_sym_LBRACE,
    ACTIONS(722), 1,
      anon_sym_await,
    ACTIONS(724), 1,
      sym_string_start,
    ACTIONS(1252), 1,
      anon_sym_STAR,
    STATE(993), 1,
      sym_string,
    STATE(1028), 1,
      sym_primary_expression,
    STATE(1218), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(720), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(716), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(710), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(704), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1169), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [67420] = 18,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    ACTIONS(2143), 1,
      anon_sym_type,
    ACTIONS(2145), 1,
      anon_sym_await,
    ACTIONS(2179), 1,
      sym_identifier,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1620), 1,
      sym_primary_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(1392), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(2141), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [67499] = 16,
    ACTIONS(728), 1,
      anon_sym_LPAREN,
    ACTIONS(734), 1,
      anon_sym_type,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(746), 1,
      anon_sym_await,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(1262), 1,
      anon_sym_STAR,
    STATE(1030), 1,
      sym_string,
    STATE(1064), 1,
      sym_primary_expression,
    STATE(1290), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(732), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(726), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [67574] = 16,
    ACTIONS(684), 1,
      anon_sym_LPAREN,
    ACTIONS(690), 1,
      anon_sym_type,
    ACTIONS(692), 1,
      anon_sym_LBRACK,
    ACTIONS(696), 1,
      anon_sym_LBRACE,
    ACTIONS(700), 1,
      anon_sym_await,
    ACTIONS(702), 1,
      sym_string_start,
    ACTIONS(998), 1,
      anon_sym_STAR,
    STATE(979), 1,
      sym_string,
    STATE(1046), 1,
      sym_primary_expression,
    STATE(1183), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(698), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(694), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(688), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(682), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1241), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [67649] = 16,
    ACTIONS(796), 1,
      anon_sym_LPAREN,
    ACTIONS(802), 1,
      anon_sym_type,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(808), 1,
      anon_sym_LBRACE,
    ACTIONS(812), 1,
      anon_sym_await,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(1286), 1,
      anon_sym_STAR,
    STATE(1017), 1,
      sym_string,
    STATE(1100), 1,
      sym_primary_expression,
    STATE(1367), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(806), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(800), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(794), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1414), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [67724] = 18,
    ACTIONS(310), 1,
      anon_sym_LBRACE,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
    ACTIONS(412), 1,
      anon_sym_LBRACK,
    ACTIONS(1424), 1,
      anon_sym_STAR,
    ACTIONS(2109), 1,
      anon_sym_await,
    ACTIONS(2181), 1,
      sym_identifier,
    ACTIONS(2185), 1,
      anon_sym_type,
    STATE(1004), 1,
      sym_string,
    STATE(1433), 1,
      sym_list_splat_pattern,
    STATE(1623), 1,
      sym_primary_expression,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(321), 2,
      sym_ellipsis,
      sym_float,
    STATE(1381), 2,
      sym_attribute,
      sym_subscript,
    ACTIONS(315), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(323), 4,
      sym_integer,
      sym_true,
      sym_false,
      sym_none,
    ACTIONS(2183), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    STATE(1365), 14,
      sym_binary_operator,
      sym_unary_operator,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [67803] = 16,
    ACTIONS(774), 1,
      anon_sym_LPAREN,
    ACTIONS(780), 1,
      anon_sym_type,
    ACTIONS(782), 1,
      anon_sym_LBRACK,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(790), 1,
      anon_sym_await,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(1336), 1,
      anon_sym_STAR,
    STATE(1150), 1,
      sym_string,
    STATE(1188), 1,
      sym_primary_expression,
    STATE(1470), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(788), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(784), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(778), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(772), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1450), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [67878] = 16,
    ACTIONS(728), 1,
      anon_sym_LPAREN,
    ACTIONS(734), 1,
      anon_sym_type,
    ACTIONS(738), 1,
      anon_sym_LBRACK,
    ACTIONS(742), 1,
      anon_sym_LBRACE,
    ACTIONS(746), 1,
      anon_sym_await,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(1262), 1,
      anon_sym_STAR,
    STATE(1030), 1,
      sym_string,
    STATE(1065), 1,
      sym_primary_expression,
    STATE(1290), 1,
      sym_list_splat_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(744), 2,
      sym_ellipsis,
      sym_float,
    ACTIONS(740), 3,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_TILDE,
    ACTIONS(732), 4,
      anon_sym_print,
      anon_sym_match,
      anon_sym_async,
      anon_sym_exec,
    ACTIONS(726), 5,
      sym_integer,
      sym_identifier,
      sym_true,
      sym_false,
      sym_none,
    STATE(1337), 16,
      sym_binary_operator,
      sym_unary_operator,
      sym_attribute,
      sym_subscript,
      sym_call,
      sym_list,
      sym_set,
      sym_tuple,
      sym_dictionary,
      sym_list_comprehension,
      sym_dictionary_comprehension,
      sym_set_comprehension,
      sym_generator_expression,
      sym_parenthesized_expression,
      sym_concatenated_string,
      sym_await,
  [67953] = 5,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(976), 2,
      sym_string,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(1547), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1542), 31,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [68005] = 5,
    ACTIONS(81), 1,
      sym_string_start,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(978), 2,
      sym_string,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(2189), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2187), 31,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [68057] = 20,
    ACTIONS(2193), 1,
      anon_sym_DOT,
    ACTIONS(2195), 1,
      anon_sym_LPAREN,
    ACTIONS(2203), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2205), 1,
      anon_sym_EQ,
    ACTIONS(2207), 1,
      anon_sym_LBRACK,
    ACTIONS(2213), 1,
      anon_sym_PIPE,
    ACTIONS(2215), 1,
      anon_sym_not,
    ACTIONS(2217), 1,
      anon_sym_AMP,
    ACTIONS(2219), 1,
      anon_sym_CARET,
    ACTIONS(2223), 1,
      anon_sym_is,
    STATE(1589), 1,
      aux_sym_comparison_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2197), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2199), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(2221), 2,
      anon_sym_LT,
      anon_sym_GT,
    STATE(1127), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2209), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2201), 6,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
    ACTIONS(2191), 9,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_and,
      anon_sym_or,
  [68139] = 5,
    ACTIONS(2229), 1,
      sym_string_start,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(978), 2,
      sym_string,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(2227), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2225), 31,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [68191] = 5,
    ACTIONS(702), 1,
      sym_string_start,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(988), 2,
      sym_string,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(1547), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1542), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [68242] = 5,
    ACTIONS(724), 1,
      sym_string_start,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(991), 2,
      sym_string,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(2189), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2187), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [68293] = 8,
    ACTIONS(2193), 1,
      anon_sym_DOT,
    ACTIONS(2195), 1,
      anon_sym_LPAREN,
    ACTIONS(2203), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2207), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1127), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2234), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2232), 27,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [68350] = 11,
    ACTIONS(2193), 1,
      anon_sym_DOT,
    ACTIONS(2195), 1,
      anon_sym_LPAREN,
    ACTIONS(2203), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2207), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2197), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1127), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2209), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2234), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2232), 22,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_PIPE,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [68413] = 15,
    ACTIONS(2193), 1,
      anon_sym_DOT,
    ACTIONS(2195), 1,
      anon_sym_LPAREN,
    ACTIONS(2203), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2207), 1,
      anon_sym_LBRACK,
    ACTIONS(2213), 1,
      anon_sym_PIPE,
    ACTIONS(2217), 1,
      anon_sym_AMP,
    ACTIONS(2219), 1,
      anon_sym_CARET,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2197), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2199), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1127), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2209), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2238), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2236), 17,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [68484] = 8,
    ACTIONS(2193), 1,
      anon_sym_DOT,
    ACTIONS(2195), 1,
      anon_sym_LPAREN,
    ACTIONS(2203), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2207), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1127), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2234), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2232), 27,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [68541] = 10,
    ACTIONS(2193), 1,
      anon_sym_DOT,
    ACTIONS(2195), 1,
      anon_sym_LPAREN,
    ACTIONS(2203), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2207), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2197), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    STATE(1127), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2209), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2234), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2232), 24,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [68602] = 14,
    ACTIONS(2193), 1,
      anon_sym_DOT,
    ACTIONS(2195), 1,
      anon_sym_LPAREN,
    ACTIONS(2203), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2207), 1,
      anon_sym_LBRACK,
    ACTIONS(2217), 1,
      anon_sym_AMP,
    ACTIONS(2219), 1,
      anon_sym_CARET,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2197), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2199), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1127), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2209), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2234), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2232), 18,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_PIPE,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [68671] = 15,
    ACTIONS(2193), 1,
      anon_sym_DOT,
    ACTIONS(2195), 1,
      anon_sym_LPAREN,
    ACTIONS(2203), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2207), 1,
      anon_sym_LBRACK,
    ACTIONS(2213), 1,
      anon_sym_PIPE,
    ACTIONS(2217), 1,
      anon_sym_AMP,
    ACTIONS(2219), 1,
      anon_sym_CARET,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2197), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2199), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1127), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2209), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2242), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2240), 17,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [68742] = 5,
    ACTIONS(702), 1,
      sym_string_start,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(997), 2,
      sym_string,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(2189), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2187), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [68793] = 13,
    ACTIONS(2193), 1,
      anon_sym_DOT,
    ACTIONS(2195), 1,
      anon_sym_LPAREN,
    ACTIONS(2203), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2207), 1,
      anon_sym_LBRACK,
    ACTIONS(2219), 1,
      anon_sym_CARET,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2197), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2199), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1127), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2209), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2234), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2232), 19,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_PIPE,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [68860] = 12,
    ACTIONS(2193), 1,
      anon_sym_DOT,
    ACTIONS(2195), 1,
      anon_sym_LPAREN,
    ACTIONS(2203), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2207), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2197), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2199), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1127), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2209), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2234), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2232), 20,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_PIPE,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [68925] = 5,
    ACTIONS(2244), 1,
      sym_string_start,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(991), 2,
      sym_string,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(2227), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2225), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [68976] = 8,
    ACTIONS(2193), 1,
      anon_sym_DOT,
    ACTIONS(2195), 1,
      anon_sym_LPAREN,
    ACTIONS(2203), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2207), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1127), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2249), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2247), 27,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [69033] = 5,
    ACTIONS(724), 1,
      sym_string_start,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(980), 2,
      sym_string,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(1547), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1542), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [69084] = 20,
    ACTIONS(2205), 1,
      anon_sym_as,
    ACTIONS(2251), 1,
      anon_sym_DOT,
    ACTIONS(2253), 1,
      anon_sym_LPAREN,
    ACTIONS(2261), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2263), 1,
      anon_sym_LBRACK,
    ACTIONS(2269), 1,
      anon_sym_PIPE,
    ACTIONS(2271), 1,
      anon_sym_not,
    ACTIONS(2273), 1,
      anon_sym_AMP,
    ACTIONS(2275), 1,
      anon_sym_CARET,
    ACTIONS(2279), 1,
      anon_sym_is,
    STATE(1602), 1,
      aux_sym_comparison_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2255), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2257), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2267), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(2277), 2,
      anon_sym_LT,
      anon_sym_GT,
    STATE(1193), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2265), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2259), 6,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
    ACTIONS(2191), 8,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
  [69165] = 8,
    ACTIONS(2193), 1,
      anon_sym_DOT,
    ACTIONS(2195), 1,
      anon_sym_LPAREN,
    ACTIONS(2203), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2207), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1127), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2283), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2281), 27,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [69222] = 20,
    ACTIONS(2205), 1,
      anon_sym_EQ,
    ACTIONS(2285), 1,
      anon_sym_DOT,
    ACTIONS(2287), 1,
      anon_sym_LPAREN,
    ACTIONS(2295), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2297), 1,
      anon_sym_LBRACK,
    ACTIONS(2303), 1,
      anon_sym_PIPE,
    ACTIONS(2305), 1,
      anon_sym_not,
    ACTIONS(2307), 1,
      anon_sym_AMP,
    ACTIONS(2309), 1,
      anon_sym_CARET,
    ACTIONS(2313), 1,
      anon_sym_is,
    STATE(1605), 1,
      aux_sym_comparison_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2289), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2291), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2301), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(2311), 2,
      anon_sym_LT,
      anon_sym_GT,
    STATE(1262), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2299), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2293), 6,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
    ACTIONS(2191), 8,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
      sym_type_conversion,
  [69303] = 5,
    ACTIONS(2315), 1,
      sym_string_start,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(997), 2,
      sym_string,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(2227), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2225), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [69354] = 15,
    ACTIONS(2193), 1,
      anon_sym_DOT,
    ACTIONS(2195), 1,
      anon_sym_LPAREN,
    ACTIONS(2203), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2207), 1,
      anon_sym_LBRACK,
    ACTIONS(2213), 1,
      anon_sym_PIPE,
    ACTIONS(2217), 1,
      anon_sym_AMP,
    ACTIONS(2219), 1,
      anon_sym_CARET,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2197), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2199), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1127), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2209), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2320), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2318), 17,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [69425] = 14,
    ACTIONS(2285), 1,
      anon_sym_DOT,
    ACTIONS(2287), 1,
      anon_sym_LPAREN,
    ACTIONS(2295), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2297), 1,
      anon_sym_LBRACK,
    ACTIONS(2307), 1,
      anon_sym_AMP,
    ACTIONS(2309), 1,
      anon_sym_CARET,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2289), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2291), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2301), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1262), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2234), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2299), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2232), 17,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [69493] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1660), 6,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1658), 31,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [69539] = 10,
    ACTIONS(2251), 1,
      anon_sym_DOT,
    ACTIONS(2253), 1,
      anon_sym_LPAREN,
    ACTIONS(2261), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2263), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2255), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    STATE(1193), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2234), 3,
      anon_sym_as,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2265), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2232), 23,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [69599] = 20,
    ACTIONS(2205), 1,
      anon_sym_EQ,
    ACTIONS(2322), 1,
      anon_sym_DOT,
    ACTIONS(2324), 1,
      anon_sym_LPAREN,
    ACTIONS(2332), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2334), 1,
      anon_sym_LBRACK,
    ACTIONS(2340), 1,
      anon_sym_PIPE,
    ACTIONS(2342), 1,
      anon_sym_not,
    ACTIONS(2344), 1,
      anon_sym_AMP,
    ACTIONS(2346), 1,
      anon_sym_CARET,
    ACTIONS(2350), 1,
      anon_sym_is,
    STATE(1595), 1,
      aux_sym_comparison_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2326), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2328), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2338), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(2348), 2,
      anon_sym_LT,
      anon_sym_GT,
    STATE(1362), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2336), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2330), 6,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
    ACTIONS(2191), 7,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_and,
      anon_sym_or,
  [69679] = 15,
    ACTIONS(2285), 1,
      anon_sym_DOT,
    ACTIONS(2287), 1,
      anon_sym_LPAREN,
    ACTIONS(2295), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2297), 1,
      anon_sym_LBRACK,
    ACTIONS(2303), 1,
      anon_sym_PIPE,
    ACTIONS(2307), 1,
      anon_sym_AMP,
    ACTIONS(2309), 1,
      anon_sym_CARET,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2289), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2291), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2301), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1262), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2238), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2299), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2236), 16,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [69749] = 5,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1006), 2,
      sym_string,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(1547), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1542), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [69799] = 11,
    ACTIONS(2285), 1,
      anon_sym_DOT,
    ACTIONS(2287), 1,
      anon_sym_LPAREN,
    ACTIONS(2295), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2297), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2289), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2301), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1262), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2234), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2299), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2232), 21,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [69861] = 5,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1045), 2,
      sym_string,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(2189), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2187), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [69911] = 14,
    ACTIONS(2251), 1,
      anon_sym_DOT,
    ACTIONS(2253), 1,
      anon_sym_LPAREN,
    ACTIONS(2261), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2263), 1,
      anon_sym_LBRACK,
    ACTIONS(2273), 1,
      anon_sym_AMP,
    ACTIONS(2275), 1,
      anon_sym_CARET,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2255), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2257), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2267), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1193), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2234), 3,
      anon_sym_as,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2265), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2232), 17,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [69979] = 20,
    ACTIONS(2205), 1,
      anon_sym_EQ,
    ACTIONS(2352), 1,
      anon_sym_DOT,
    ACTIONS(2354), 1,
      anon_sym_LPAREN,
    ACTIONS(2362), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2364), 1,
      anon_sym_LBRACK,
    ACTIONS(2370), 1,
      anon_sym_PIPE,
    ACTIONS(2372), 1,
      anon_sym_not,
    ACTIONS(2374), 1,
      anon_sym_AMP,
    ACTIONS(2376), 1,
      anon_sym_CARET,
    ACTIONS(2380), 1,
      anon_sym_is,
    STATE(1597), 1,
      aux_sym_comparison_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2356), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2358), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2368), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(2378), 2,
      anon_sym_LT,
      anon_sym_GT,
    STATE(1423), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2366), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2360), 6,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
    ACTIONS(2191), 7,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_and,
      anon_sym_or,
  [70059] = 5,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1018), 2,
      sym_string,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(2189), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2187), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [70109] = 8,
    ACTIONS(2285), 1,
      anon_sym_DOT,
    ACTIONS(2287), 1,
      anon_sym_LPAREN,
    ACTIONS(2295), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2297), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1262), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2234), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2232), 26,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [70165] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1668), 6,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1666), 31,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [70211] = 4,
    ACTIONS(292), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 6,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(277), 30,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [70259] = 19,
    ACTIONS(2195), 1,
      anon_sym_LPAREN,
    ACTIONS(2203), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2213), 1,
      anon_sym_PIPE,
    ACTIONS(2215), 1,
      anon_sym_not,
    ACTIONS(2217), 1,
      anon_sym_AMP,
    ACTIONS(2219), 1,
      anon_sym_CARET,
    ACTIONS(2223), 1,
      anon_sym_is,
    ACTIONS(2382), 1,
      anon_sym_DOT,
    ACTIONS(2384), 1,
      anon_sym_LBRACK,
    STATE(1589), 1,
      aux_sym_comparison_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2197), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2199), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(2221), 2,
      anon_sym_LT,
      anon_sym_GT,
    STATE(1127), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2209), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2201), 6,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
    ACTIONS(2191), 8,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_and,
      anon_sym_or,
  [70337] = 5,
    ACTIONS(2386), 1,
      sym_string_start,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1014), 2,
      sym_string,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(2227), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2225), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [70387] = 15,
    ACTIONS(2285), 1,
      anon_sym_DOT,
    ACTIONS(2287), 1,
      anon_sym_LPAREN,
    ACTIONS(2295), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2297), 1,
      anon_sym_LBRACK,
    ACTIONS(2303), 1,
      anon_sym_PIPE,
    ACTIONS(2307), 1,
      anon_sym_AMP,
    ACTIONS(2309), 1,
      anon_sym_CARET,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2289), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2291), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2301), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1262), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2242), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2299), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2240), 16,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [70457] = 20,
    ACTIONS(2205), 1,
      anon_sym_as,
    ACTIONS(2389), 1,
      anon_sym_DOT,
    ACTIONS(2391), 1,
      anon_sym_LPAREN,
    ACTIONS(2399), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2401), 1,
      anon_sym_LBRACK,
    ACTIONS(2407), 1,
      anon_sym_PIPE,
    ACTIONS(2409), 1,
      anon_sym_not,
    ACTIONS(2411), 1,
      anon_sym_AMP,
    ACTIONS(2413), 1,
      anon_sym_CARET,
    ACTIONS(2417), 1,
      anon_sym_is,
    STATE(1614), 1,
      aux_sym_comparison_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2393), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2395), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2405), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(2415), 2,
      anon_sym_LT,
      anon_sym_GT,
    STATE(1430), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2403), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2397), 6,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
    ACTIONS(2191), 7,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACK,
      anon_sym_and,
      anon_sym_or,
  [70537] = 5,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1019), 2,
      sym_string,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(1547), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1542), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [70587] = 5,
    ACTIONS(2419), 1,
      sym_string_start,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1018), 2,
      sym_string,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(2227), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2225), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [70637] = 5,
    ACTIONS(814), 1,
      sym_string_start,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1022), 2,
      sym_string,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(2189), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2187), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [70687] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2424), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2422), 32,
      sym__newline,
      sym_string_start,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [70733] = 5,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1014), 2,
      sym_string,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(2189), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2187), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [70783] = 5,
    ACTIONS(2426), 1,
      sym_string_start,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1022), 2,
      sym_string,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(2227), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2225), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [70833] = 13,
    ACTIONS(2251), 1,
      anon_sym_DOT,
    ACTIONS(2253), 1,
      anon_sym_LPAREN,
    ACTIONS(2261), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2263), 1,
      anon_sym_LBRACK,
    ACTIONS(2275), 1,
      anon_sym_CARET,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2255), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2257), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2267), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1193), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2234), 3,
      anon_sym_as,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2265), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2232), 18,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [70899] = 20,
    ACTIONS(2205), 1,
      anon_sym_as,
    ACTIONS(2429), 1,
      anon_sym_DOT,
    ACTIONS(2431), 1,
      anon_sym_LPAREN,
    ACTIONS(2439), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2441), 1,
      anon_sym_LBRACK,
    ACTIONS(2447), 1,
      anon_sym_PIPE,
    ACTIONS(2449), 1,
      anon_sym_not,
    ACTIONS(2451), 1,
      anon_sym_AMP,
    ACTIONS(2453), 1,
      anon_sym_CARET,
    ACTIONS(2457), 1,
      anon_sym_is,
    STATE(1613), 1,
      aux_sym_comparison_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2433), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2435), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2445), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(2455), 2,
      anon_sym_LT,
      anon_sym_GT,
    STATE(1366), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2443), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2437), 6,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
    ACTIONS(2191), 7,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_and,
      anon_sym_or,
  [70979] = 10,
    ACTIONS(2285), 1,
      anon_sym_DOT,
    ACTIONS(2287), 1,
      anon_sym_LPAREN,
    ACTIONS(2295), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2297), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2289), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    STATE(1262), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2234), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2299), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2232), 23,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [71039] = 15,
    ACTIONS(2251), 1,
      anon_sym_DOT,
    ACTIONS(2253), 1,
      anon_sym_LPAREN,
    ACTIONS(2261), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2263), 1,
      anon_sym_LBRACK,
    ACTIONS(2269), 1,
      anon_sym_PIPE,
    ACTIONS(2273), 1,
      anon_sym_AMP,
    ACTIONS(2275), 1,
      anon_sym_CARET,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2255), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2257), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2267), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1193), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2242), 3,
      anon_sym_as,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2265), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2240), 16,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [71109] = 8,
    ACTIONS(2285), 1,
      anon_sym_DOT,
    ACTIONS(2287), 1,
      anon_sym_LPAREN,
    ACTIONS(2295), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2297), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1262), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2283), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2281), 26,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [71165] = 8,
    ACTIONS(2251), 1,
      anon_sym_DOT,
    ACTIONS(2253), 1,
      anon_sym_LPAREN,
    ACTIONS(2261), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2263), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1193), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2249), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2247), 26,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [71221] = 12,
    ACTIONS(2251), 1,
      anon_sym_DOT,
    ACTIONS(2253), 1,
      anon_sym_LPAREN,
    ACTIONS(2261), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2263), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2255), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2257), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2267), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1193), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2234), 3,
      anon_sym_as,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2265), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2232), 19,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [71285] = 5,
    ACTIONS(748), 1,
      sym_string_start,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1021), 2,
      sym_string,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(1547), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1542), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [71335] = 8,
    ACTIONS(2251), 1,
      anon_sym_DOT,
    ACTIONS(2253), 1,
      anon_sym_LPAREN,
    ACTIONS(2261), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2263), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1193), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2283), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2281), 26,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [71391] = 5,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1009), 2,
      sym_string,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(1547), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1542), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [71441] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1664), 6,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1662), 31,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [71487] = 8,
    ACTIONS(2285), 1,
      anon_sym_DOT,
    ACTIONS(2287), 1,
      anon_sym_LPAREN,
    ACTIONS(2295), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2297), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1262), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2249), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2247), 26,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [71543] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1664), 6,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1662), 31,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [71589] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1649), 6,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1647), 31,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [71635] = 4,
    ACTIONS(292), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 6,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(277), 30,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [71683] = 15,
    ACTIONS(2251), 1,
      anon_sym_DOT,
    ACTIONS(2253), 1,
      anon_sym_LPAREN,
    ACTIONS(2261), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2263), 1,
      anon_sym_LBRACK,
    ACTIONS(2269), 1,
      anon_sym_PIPE,
    ACTIONS(2273), 1,
      anon_sym_AMP,
    ACTIONS(2275), 1,
      anon_sym_CARET,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2255), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2257), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2267), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1193), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2265), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2320), 3,
      anon_sym_as,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2318), 16,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [71753] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1649), 6,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1647), 31,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [71799] = 13,
    ACTIONS(2285), 1,
      anon_sym_DOT,
    ACTIONS(2287), 1,
      anon_sym_LPAREN,
    ACTIONS(2295), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2297), 1,
      anon_sym_LBRACK,
    ACTIONS(2309), 1,
      anon_sym_CARET,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2289), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2291), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2301), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1262), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2234), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2299), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2232), 18,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [71865] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1602), 6,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1600), 31,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [71911] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2461), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2459), 32,
      sym__newline,
      sym_string_start,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [71957] = 4,
    ACTIONS(1549), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1547), 6,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1542), 30,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [72005] = 8,
    ACTIONS(2285), 1,
      anon_sym_DOT,
    ACTIONS(2287), 1,
      anon_sym_LPAREN,
    ACTIONS(2295), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2297), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1262), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2234), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2232), 26,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [72061] = 5,
    ACTIONS(2463), 1,
      sym_string_start,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1045), 2,
      sym_string,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(2227), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2225), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [72111] = 15,
    ACTIONS(2285), 1,
      anon_sym_DOT,
    ACTIONS(2287), 1,
      anon_sym_LPAREN,
    ACTIONS(2295), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2297), 1,
      anon_sym_LBRACK,
    ACTIONS(2303), 1,
      anon_sym_PIPE,
    ACTIONS(2307), 1,
      anon_sym_AMP,
    ACTIONS(2309), 1,
      anon_sym_CARET,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2289), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2291), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2301), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1262), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2299), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2320), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2318), 16,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [72181] = 8,
    ACTIONS(2251), 1,
      anon_sym_DOT,
    ACTIONS(2253), 1,
      anon_sym_LPAREN,
    ACTIONS(2261), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2263), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1193), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2234), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2232), 26,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [72237] = 11,
    ACTIONS(2251), 1,
      anon_sym_DOT,
    ACTIONS(2253), 1,
      anon_sym_LPAREN,
    ACTIONS(2261), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2263), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2255), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2267), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1193), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2234), 3,
      anon_sym_as,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2265), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2232), 21,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [72299] = 12,
    ACTIONS(2285), 1,
      anon_sym_DOT,
    ACTIONS(2287), 1,
      anon_sym_LPAREN,
    ACTIONS(2295), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2297), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2289), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2291), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2301), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1262), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2234), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2299), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2232), 19,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [72363] = 15,
    ACTIONS(2251), 1,
      anon_sym_DOT,
    ACTIONS(2253), 1,
      anon_sym_LPAREN,
    ACTIONS(2261), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2263), 1,
      anon_sym_LBRACK,
    ACTIONS(2269), 1,
      anon_sym_PIPE,
    ACTIONS(2273), 1,
      anon_sym_AMP,
    ACTIONS(2275), 1,
      anon_sym_CARET,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2255), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2257), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2267), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1193), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2238), 3,
      anon_sym_as,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2265), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2236), 16,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [72433] = 8,
    ACTIONS(2251), 1,
      anon_sym_DOT,
    ACTIONS(2253), 1,
      anon_sym_LPAREN,
    ACTIONS(2261), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2263), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1193), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2234), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2232), 26,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [72489] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2424), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2422), 31,
      sym_string_start,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [72534] = 11,
    ACTIONS(2429), 1,
      anon_sym_DOT,
    ACTIONS(2431), 1,
      anon_sym_LPAREN,
    ACTIONS(2439), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2441), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2433), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2445), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1366), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2234), 3,
      anon_sym_as,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2443), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2232), 20,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_PIPE,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [72595] = 14,
    ACTIONS(2322), 1,
      anon_sym_DOT,
    ACTIONS(2324), 1,
      anon_sym_LPAREN,
    ACTIONS(2332), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2334), 1,
      anon_sym_LBRACK,
    ACTIONS(2344), 1,
      anon_sym_AMP,
    ACTIONS(2346), 1,
      anon_sym_CARET,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2326), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2328), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2338), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1362), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2234), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2336), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2232), 16,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_PIPE,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [72662] = 10,
    ACTIONS(2322), 1,
      anon_sym_DOT,
    ACTIONS(2324), 1,
      anon_sym_LPAREN,
    ACTIONS(2332), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2334), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2326), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    STATE(1362), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2234), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2336), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2232), 22,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [72721] = 8,
    ACTIONS(2322), 1,
      anon_sym_DOT,
    ACTIONS(2324), 1,
      anon_sym_LPAREN,
    ACTIONS(2332), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2334), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1362), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2234), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2232), 25,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [72776] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1547), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1542), 31,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [72821] = 15,
    ACTIONS(2322), 1,
      anon_sym_DOT,
    ACTIONS(2324), 1,
      anon_sym_LPAREN,
    ACTIONS(2332), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2334), 1,
      anon_sym_LBRACK,
    ACTIONS(2340), 1,
      anon_sym_PIPE,
    ACTIONS(2344), 1,
      anon_sym_AMP,
    ACTIONS(2346), 1,
      anon_sym_CARET,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2326), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2328), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2338), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1362), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2238), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2336), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2236), 15,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [72890] = 11,
    ACTIONS(2322), 1,
      anon_sym_DOT,
    ACTIONS(2324), 1,
      anon_sym_LPAREN,
    ACTIONS(2332), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2334), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2326), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2338), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1362), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2234), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2336), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2232), 20,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_PIPE,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [72951] = 8,
    ACTIONS(2322), 1,
      anon_sym_DOT,
    ACTIONS(2324), 1,
      anon_sym_LPAREN,
    ACTIONS(2332), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2334), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1362), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2234), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2232), 25,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [73006] = 12,
    ACTIONS(2322), 1,
      anon_sym_DOT,
    ACTIONS(2324), 1,
      anon_sym_LPAREN,
    ACTIONS(2332), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2334), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2326), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2328), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2338), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1362), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2234), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2336), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2232), 18,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_PIPE,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [73069] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1668), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1666), 31,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [73114] = 13,
    ACTIONS(2322), 1,
      anon_sym_DOT,
    ACTIONS(2324), 1,
      anon_sym_LPAREN,
    ACTIONS(2332), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2334), 1,
      anon_sym_LBRACK,
    ACTIONS(2346), 1,
      anon_sym_CARET,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2326), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2328), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2338), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1362), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2234), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2336), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2232), 17,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_PIPE,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [73179] = 15,
    ACTIONS(2429), 1,
      anon_sym_DOT,
    ACTIONS(2431), 1,
      anon_sym_LPAREN,
    ACTIONS(2439), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2441), 1,
      anon_sym_LBRACK,
    ACTIONS(2447), 1,
      anon_sym_PIPE,
    ACTIONS(2451), 1,
      anon_sym_AMP,
    ACTIONS(2453), 1,
      anon_sym_CARET,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2433), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2435), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2445), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1366), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2320), 3,
      anon_sym_as,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2443), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2318), 15,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [73248] = 15,
    ACTIONS(2429), 1,
      anon_sym_DOT,
    ACTIONS(2431), 1,
      anon_sym_LPAREN,
    ACTIONS(2439), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2441), 1,
      anon_sym_LBRACK,
    ACTIONS(2447), 1,
      anon_sym_PIPE,
    ACTIONS(2451), 1,
      anon_sym_AMP,
    ACTIONS(2453), 1,
      anon_sym_CARET,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2433), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2435), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2445), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1366), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2242), 3,
      anon_sym_as,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2443), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2240), 15,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [73317] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2468), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2466), 31,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [73362] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2472), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2470), 31,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [73407] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2476), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2474), 31,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [73452] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2480), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2478), 31,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [73497] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2484), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2482), 31,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [73542] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1660), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1658), 31,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [73587] = 15,
    ACTIONS(2322), 1,
      anon_sym_DOT,
    ACTIONS(2324), 1,
      anon_sym_LPAREN,
    ACTIONS(2332), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2334), 1,
      anon_sym_LBRACK,
    ACTIONS(2340), 1,
      anon_sym_PIPE,
    ACTIONS(2344), 1,
      anon_sym_AMP,
    ACTIONS(2346), 1,
      anon_sym_CARET,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2326), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2328), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2338), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1362), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2242), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2336), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2240), 15,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [73656] = 15,
    ACTIONS(2322), 1,
      anon_sym_DOT,
    ACTIONS(2324), 1,
      anon_sym_LPAREN,
    ACTIONS(2332), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2334), 1,
      anon_sym_LBRACK,
    ACTIONS(2340), 1,
      anon_sym_PIPE,
    ACTIONS(2344), 1,
      anon_sym_AMP,
    ACTIONS(2346), 1,
      anon_sym_CARET,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2326), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2328), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2338), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1362), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2320), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2336), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2318), 15,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [73725] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1602), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1600), 31,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [73770] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1649), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1647), 31,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [73815] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2424), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2422), 31,
      sym_string_start,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [73860] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1649), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1647), 31,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [73905] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2488), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2486), 31,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [73950] = 5,
    ACTIONS(292), 1,
      anon_sym_COLON_EQ,
    ACTIONS(736), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(277), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [73999] = 6,
    ACTIONS(1549), 1,
      anon_sym_COLON_EQ,
    ACTIONS(1614), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1604), 2,
      anon_sym_async,
      anon_sym_for,
    ACTIONS(1611), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1608), 27,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [74050] = 6,
    ACTIONS(292), 1,
      anon_sym_COLON_EQ,
    ACTIONS(671), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(666), 2,
      anon_sym_async,
      anon_sym_for,
    ACTIONS(668), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(679), 27,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [74101] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2461), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2459), 31,
      sym_string_start,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [74146] = 6,
    ACTIONS(292), 1,
      anon_sym_COLON_EQ,
    ACTIONS(671), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(666), 2,
      anon_sym_async,
      anon_sym_for,
    ACTIONS(668), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(679), 27,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [74197] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2492), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2490), 31,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [74242] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2496), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2494), 31,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [74287] = 8,
    ACTIONS(2352), 1,
      anon_sym_DOT,
    ACTIONS(2354), 1,
      anon_sym_LPAREN,
    ACTIONS(2362), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2364), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1423), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2249), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2247), 25,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [74342] = 5,
    ACTIONS(292), 1,
      anon_sym_COLON_EQ,
    ACTIONS(736), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(277), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [74391] = 5,
    ACTIONS(1549), 1,
      anon_sym_COLON_EQ,
    ACTIONS(2498), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1547), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1542), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [74440] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1664), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1662), 31,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [74485] = 8,
    ACTIONS(2352), 1,
      anon_sym_DOT,
    ACTIONS(2354), 1,
      anon_sym_LPAREN,
    ACTIONS(2362), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2364), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1423), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2283), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2281), 25,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [74540] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1664), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1662), 31,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [74585] = 5,
    ACTIONS(1544), 1,
      anon_sym_COMMA,
    ACTIONS(1549), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1547), 6,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1542), 28,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [74634] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1641), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1636), 31,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [74679] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1611), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1614), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1608), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(1604), 17,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [74728] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2502), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2500), 31,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [74773] = 6,
    ACTIONS(1549), 1,
      anon_sym_COLON_EQ,
    ACTIONS(2504), 1,
      anon_sym_LBRACK,
    STATE(1987), 1,
      sym_type_parameter,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1547), 6,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1542), 27,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [74824] = 8,
    ACTIONS(2322), 1,
      anon_sym_DOT,
    ACTIONS(2324), 1,
      anon_sym_LPAREN,
    ACTIONS(2332), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2334), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1362), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2283), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2281), 25,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [74879] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2508), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2506), 31,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [74924] = 19,
    ACTIONS(2510), 1,
      anon_sym_DOT,
    ACTIONS(2512), 1,
      anon_sym_LPAREN,
    ACTIONS(2520), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2522), 1,
      anon_sym_LBRACK,
    ACTIONS(2528), 1,
      anon_sym_PIPE,
    ACTIONS(2530), 1,
      anon_sym_not,
    ACTIONS(2532), 1,
      anon_sym_AMP,
    ACTIONS(2534), 1,
      anon_sym_CARET,
    ACTIONS(2538), 1,
      anon_sym_is,
    STATE(1604), 1,
      aux_sym_comparison_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2514), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2516), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2526), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(2536), 2,
      anon_sym_LT,
      anon_sym_GT,
    STATE(1469), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2524), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2518), 6,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
    ACTIONS(2191), 7,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_and,
      anon_sym_or,
  [75001] = 8,
    ACTIONS(2389), 1,
      anon_sym_DOT,
    ACTIONS(2391), 1,
      anon_sym_LPAREN,
    ACTIONS(2399), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2401), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1430), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2249), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2247), 25,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [75056] = 8,
    ACTIONS(2389), 1,
      anon_sym_DOT,
    ACTIONS(2391), 1,
      anon_sym_LPAREN,
    ACTIONS(2399), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2401), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1430), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2283), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2281), 25,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [75111] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2542), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2540), 31,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [75156] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2546), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2544), 31,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [75201] = 8,
    ACTIONS(2322), 1,
      anon_sym_DOT,
    ACTIONS(2324), 1,
      anon_sym_LPAREN,
    ACTIONS(2332), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2334), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1362), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2249), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2247), 25,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [75256] = 5,
    ACTIONS(2548), 1,
      sym_string_start,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1105), 2,
      sym_string,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(2227), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2225), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [75305] = 4,
    ACTIONS(1549), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1547), 6,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1542), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [75352] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2461), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2459), 31,
      sym_string_start,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [75397] = 4,
    ACTIONS(292), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 6,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(277), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [75444] = 4,
    ACTIONS(292), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 6,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(277), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [75491] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(668), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(671), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(679), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(666), 17,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [75540] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1623), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1618), 31,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [75585] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(668), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(671), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(679), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(666), 17,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [75634] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2553), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2551), 31,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [75679] = 5,
    ACTIONS(284), 1,
      anon_sym_COMMA,
    ACTIONS(292), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 6,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(277), 28,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [75728] = 5,
    ACTIONS(284), 1,
      anon_sym_COMMA,
    ACTIONS(292), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 6,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(277), 28,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [75777] = 8,
    ACTIONS(2389), 1,
      anon_sym_DOT,
    ACTIONS(2391), 1,
      anon_sym_LPAREN,
    ACTIONS(2399), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2401), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1430), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2234), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2232), 25,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [75832] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1634), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1629), 31,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [75877] = 11,
    ACTIONS(2389), 1,
      anon_sym_DOT,
    ACTIONS(2391), 1,
      anon_sym_LPAREN,
    ACTIONS(2399), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2401), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2393), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2405), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1430), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2234), 3,
      anon_sym_as,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2403), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2232), 20,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_PIPE,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [75938] = 15,
    ACTIONS(2389), 1,
      anon_sym_DOT,
    ACTIONS(2391), 1,
      anon_sym_LPAREN,
    ACTIONS(2399), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2401), 1,
      anon_sym_LBRACK,
    ACTIONS(2407), 1,
      anon_sym_PIPE,
    ACTIONS(2411), 1,
      anon_sym_AMP,
    ACTIONS(2413), 1,
      anon_sym_CARET,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2393), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2395), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2405), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1430), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2238), 3,
      anon_sym_as,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2403), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2236), 15,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [76007] = 6,
    ACTIONS(1549), 1,
      anon_sym_COLON_EQ,
    ACTIONS(2555), 1,
      anon_sym_LBRACK,
    STATE(1959), 1,
      sym_type_parameter,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1547), 6,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1542), 27,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [76058] = 8,
    ACTIONS(2389), 1,
      anon_sym_DOT,
    ACTIONS(2391), 1,
      anon_sym_LPAREN,
    ACTIONS(2399), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2401), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1430), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2234), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2232), 25,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [76113] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2559), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2557), 31,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [76158] = 10,
    ACTIONS(2389), 1,
      anon_sym_DOT,
    ACTIONS(2391), 1,
      anon_sym_LPAREN,
    ACTIONS(2399), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2401), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2393), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    STATE(1430), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2234), 3,
      anon_sym_as,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2403), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2232), 22,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [76217] = 14,
    ACTIONS(2389), 1,
      anon_sym_DOT,
    ACTIONS(2391), 1,
      anon_sym_LPAREN,
    ACTIONS(2399), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2401), 1,
      anon_sym_LBRACK,
    ACTIONS(2411), 1,
      anon_sym_AMP,
    ACTIONS(2413), 1,
      anon_sym_CARET,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2393), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2395), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2405), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1430), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2234), 3,
      anon_sym_as,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2403), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2232), 16,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_PIPE,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [76284] = 13,
    ACTIONS(2389), 1,
      anon_sym_DOT,
    ACTIONS(2391), 1,
      anon_sym_LPAREN,
    ACTIONS(2399), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2401), 1,
      anon_sym_LBRACK,
    ACTIONS(2413), 1,
      anon_sym_CARET,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2393), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2395), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2405), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1430), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2234), 3,
      anon_sym_as,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2403), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2232), 17,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_PIPE,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [76349] = 12,
    ACTIONS(2389), 1,
      anon_sym_DOT,
    ACTIONS(2391), 1,
      anon_sym_LPAREN,
    ACTIONS(2399), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2401), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2393), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2395), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2405), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1430), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2234), 3,
      anon_sym_as,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2403), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2232), 18,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_PIPE,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [76412] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2563), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2561), 31,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [76457] = 8,
    ACTIONS(2429), 1,
      anon_sym_DOT,
    ACTIONS(2431), 1,
      anon_sym_LPAREN,
    ACTIONS(2439), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2441), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1366), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2234), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2232), 25,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [76512] = 15,
    ACTIONS(2389), 1,
      anon_sym_DOT,
    ACTIONS(2391), 1,
      anon_sym_LPAREN,
    ACTIONS(2399), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2401), 1,
      anon_sym_LBRACK,
    ACTIONS(2407), 1,
      anon_sym_PIPE,
    ACTIONS(2411), 1,
      anon_sym_AMP,
    ACTIONS(2413), 1,
      anon_sym_CARET,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2393), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2395), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2405), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1430), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2242), 3,
      anon_sym_as,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2403), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2240), 15,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [76581] = 15,
    ACTIONS(2389), 1,
      anon_sym_DOT,
    ACTIONS(2391), 1,
      anon_sym_LPAREN,
    ACTIONS(2399), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2401), 1,
      anon_sym_LBRACK,
    ACTIONS(2407), 1,
      anon_sym_PIPE,
    ACTIONS(2411), 1,
      anon_sym_AMP,
    ACTIONS(2413), 1,
      anon_sym_CARET,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2393), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2395), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2405), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1430), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2320), 3,
      anon_sym_as,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2403), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2318), 15,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [76650] = 5,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1105), 2,
      sym_string,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(2189), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2187), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [76699] = 8,
    ACTIONS(2429), 1,
      anon_sym_DOT,
    ACTIONS(2431), 1,
      anon_sym_LPAREN,
    ACTIONS(2439), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2441), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1366), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2249), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2247), 25,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [76754] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2567), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2565), 31,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [76799] = 8,
    ACTIONS(2352), 1,
      anon_sym_DOT,
    ACTIONS(2354), 1,
      anon_sym_LPAREN,
    ACTIONS(2362), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2364), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1423), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2234), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2232), 25,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [76854] = 11,
    ACTIONS(2352), 1,
      anon_sym_DOT,
    ACTIONS(2354), 1,
      anon_sym_LPAREN,
    ACTIONS(2362), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2364), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2356), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2368), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1423), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2234), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2366), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2232), 20,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_PIPE,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [76915] = 15,
    ACTIONS(2352), 1,
      anon_sym_DOT,
    ACTIONS(2354), 1,
      anon_sym_LPAREN,
    ACTIONS(2362), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2364), 1,
      anon_sym_LBRACK,
    ACTIONS(2370), 1,
      anon_sym_PIPE,
    ACTIONS(2374), 1,
      anon_sym_AMP,
    ACTIONS(2376), 1,
      anon_sym_CARET,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2356), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2358), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2368), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1423), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2238), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2366), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2236), 15,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [76984] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2571), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2569), 31,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [77029] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2575), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2573), 31,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [77074] = 8,
    ACTIONS(2352), 1,
      anon_sym_DOT,
    ACTIONS(2354), 1,
      anon_sym_LPAREN,
    ACTIONS(2362), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2364), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1423), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2234), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2232), 25,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [77129] = 10,
    ACTIONS(2352), 1,
      anon_sym_DOT,
    ACTIONS(2354), 1,
      anon_sym_LPAREN,
    ACTIONS(2362), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2364), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2356), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    STATE(1423), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2234), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2366), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2232), 22,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [77188] = 4,
    ACTIONS(1549), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1547), 6,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1542), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [77235] = 14,
    ACTIONS(2352), 1,
      anon_sym_DOT,
    ACTIONS(2354), 1,
      anon_sym_LPAREN,
    ACTIONS(2362), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2364), 1,
      anon_sym_LBRACK,
    ACTIONS(2374), 1,
      anon_sym_AMP,
    ACTIONS(2376), 1,
      anon_sym_CARET,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2356), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2358), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2368), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1423), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2234), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2366), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2232), 16,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_PIPE,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [77302] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(277), 31,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [77347] = 13,
    ACTIONS(2352), 1,
      anon_sym_DOT,
    ACTIONS(2354), 1,
      anon_sym_LPAREN,
    ACTIONS(2362), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2364), 1,
      anon_sym_LBRACK,
    ACTIONS(2376), 1,
      anon_sym_CARET,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2356), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2358), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2368), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1423), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2234), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2366), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2232), 17,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_PIPE,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [77412] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(277), 31,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [77457] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2579), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2577), 31,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [77502] = 12,
    ACTIONS(2352), 1,
      anon_sym_DOT,
    ACTIONS(2354), 1,
      anon_sym_LPAREN,
    ACTIONS(2362), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2364), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2356), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2358), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2368), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1423), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2234), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2366), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2232), 18,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_PIPE,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [77565] = 4,
    ACTIONS(292), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 6,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(277), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [77612] = 4,
    ACTIONS(292), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 6,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(277), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [77659] = 5,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1131), 2,
      sym_string,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(1547), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1542), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [77708] = 8,
    ACTIONS(2429), 1,
      anon_sym_DOT,
    ACTIONS(2431), 1,
      anon_sym_LPAREN,
    ACTIONS(2439), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2441), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1366), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2234), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2232), 25,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [77763] = 15,
    ACTIONS(2352), 1,
      anon_sym_DOT,
    ACTIONS(2354), 1,
      anon_sym_LPAREN,
    ACTIONS(2362), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2364), 1,
      anon_sym_LBRACK,
    ACTIONS(2370), 1,
      anon_sym_PIPE,
    ACTIONS(2374), 1,
      anon_sym_AMP,
    ACTIONS(2376), 1,
      anon_sym_CARET,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2356), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2358), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2368), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1423), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2320), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2366), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2318), 15,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [77832] = 15,
    ACTIONS(2352), 1,
      anon_sym_DOT,
    ACTIONS(2354), 1,
      anon_sym_LPAREN,
    ACTIONS(2362), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2364), 1,
      anon_sym_LBRACK,
    ACTIONS(2370), 1,
      anon_sym_PIPE,
    ACTIONS(2374), 1,
      anon_sym_AMP,
    ACTIONS(2376), 1,
      anon_sym_CARET,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2356), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2358), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2368), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1423), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2242), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2366), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2240), 15,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [77901] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2583), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2581), 31,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [77946] = 15,
    ACTIONS(2429), 1,
      anon_sym_DOT,
    ACTIONS(2431), 1,
      anon_sym_LPAREN,
    ACTIONS(2439), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2441), 1,
      anon_sym_LBRACK,
    ACTIONS(2447), 1,
      anon_sym_PIPE,
    ACTIONS(2451), 1,
      anon_sym_AMP,
    ACTIONS(2453), 1,
      anon_sym_CARET,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2433), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2435), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2445), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1366), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2238), 3,
      anon_sym_as,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2443), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2236), 15,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [78015] = 12,
    ACTIONS(2429), 1,
      anon_sym_DOT,
    ACTIONS(2431), 1,
      anon_sym_LPAREN,
    ACTIONS(2439), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2441), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2433), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2435), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2445), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1366), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2234), 3,
      anon_sym_as,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2443), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2232), 18,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_PIPE,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [78078] = 8,
    ACTIONS(2429), 1,
      anon_sym_DOT,
    ACTIONS(2431), 1,
      anon_sym_LPAREN,
    ACTIONS(2439), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2441), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1366), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2283), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2281), 25,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [78133] = 13,
    ACTIONS(2429), 1,
      anon_sym_DOT,
    ACTIONS(2431), 1,
      anon_sym_LPAREN,
    ACTIONS(2439), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2441), 1,
      anon_sym_LBRACK,
    ACTIONS(2453), 1,
      anon_sym_CARET,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2433), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2435), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2445), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1366), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2234), 3,
      anon_sym_as,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2443), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2232), 17,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_PIPE,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [78198] = 14,
    ACTIONS(2429), 1,
      anon_sym_DOT,
    ACTIONS(2431), 1,
      anon_sym_LPAREN,
    ACTIONS(2439), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2441), 1,
      anon_sym_LBRACK,
    ACTIONS(2451), 1,
      anon_sym_AMP,
    ACTIONS(2453), 1,
      anon_sym_CARET,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2433), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2435), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2445), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1366), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2234), 3,
      anon_sym_as,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2443), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2232), 16,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_PIPE,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [78265] = 10,
    ACTIONS(2429), 1,
      anon_sym_DOT,
    ACTIONS(2431), 1,
      anon_sym_LPAREN,
    ACTIONS(2439), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2441), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2433), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    STATE(1366), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2234), 3,
      anon_sym_as,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2443), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2232), 22,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [78324] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1664), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1662), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [78368] = 13,
    ACTIONS(2510), 1,
      anon_sym_DOT,
    ACTIONS(2512), 1,
      anon_sym_LPAREN,
    ACTIONS(2520), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2522), 1,
      anon_sym_LBRACK,
    ACTIONS(2534), 1,
      anon_sym_CARET,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2234), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2514), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2516), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2526), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1469), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2524), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2232), 17,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_PIPE,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [78432] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(668), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(671), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(679), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(666), 16,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [78480] = 4,
    ACTIONS(1620), 1,
      anon_sym_COMMA,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1623), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1618), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [78526] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2424), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2422), 30,
      sym_string_start,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [78570] = 4,
    ACTIONS(1544), 1,
      anon_sym_COMMA,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1547), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1542), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [78616] = 4,
    ACTIONS(1631), 1,
      anon_sym_COMMA,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1634), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1629), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [78662] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1660), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1658), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [78706] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1547), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1542), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [78750] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2583), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2581), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [78794] = 4,
    ACTIONS(292), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 6,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(277), 28,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [78840] = 4,
    ACTIONS(292), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 6,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(277), 28,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [78886] = 4,
    ACTIONS(1549), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1547), 6,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1542), 28,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [78932] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1602), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1600), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [78976] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1649), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1647), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [79020] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1649), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1647), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [79064] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1664), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1662), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [79108] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1664), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1662), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [79152] = 19,
    ACTIONS(2389), 1,
      anon_sym_DOT,
    ACTIONS(2401), 1,
      anon_sym_LBRACK,
    ACTIONS(2512), 1,
      anon_sym_LPAREN,
    ACTIONS(2520), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2528), 1,
      anon_sym_PIPE,
    ACTIONS(2530), 1,
      anon_sym_not,
    ACTIONS(2532), 1,
      anon_sym_AMP,
    ACTIONS(2534), 1,
      anon_sym_CARET,
    ACTIONS(2538), 1,
      anon_sym_is,
    STATE(1604), 1,
      aux_sym_comparison_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2514), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2516), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2526), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(2536), 2,
      anon_sym_LT,
      anon_sym_GT,
    STATE(1469), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2524), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2191), 6,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_RBRACK,
      anon_sym_and,
      anon_sym_or,
    ACTIONS(2518), 6,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
  [79228] = 4,
    ACTIONS(1638), 1,
      anon_sym_COMMA,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1641), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1636), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [79274] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2424), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2422), 30,
      sym_string_start,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [79318] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1611), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1614), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1608), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(1604), 16,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [79366] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1634), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1629), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [79410] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(277), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [79454] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(277), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [79498] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2579), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2577), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [79542] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1668), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1666), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [79586] = 8,
    ACTIONS(2510), 1,
      anon_sym_DOT,
    ACTIONS(2512), 1,
      anon_sym_LPAREN,
    ACTIONS(2520), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2522), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1469), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2249), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2247), 25,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [79640] = 8,
    ACTIONS(2510), 1,
      anon_sym_DOT,
    ACTIONS(2512), 1,
      anon_sym_LPAREN,
    ACTIONS(2520), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2522), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1469), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2283), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2281), 25,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [79694] = 5,
    ACTIONS(292), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(284), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(279), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(277), 27,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [79742] = 6,
    ACTIONS(1549), 1,
      anon_sym_COLON_EQ,
    ACTIONS(1556), 1,
      anon_sym_LBRACK,
    STATE(2052), 1,
      sym_type_parameter,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1547), 6,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1542), 26,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [79792] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1668), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1666), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [79836] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2563), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2561), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [79880] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2461), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2459), 30,
      sym_string_start,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [79924] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2496), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2494), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [79968] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2461), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2459), 30,
      sym_string_start,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [80012] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1623), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1618), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [80056] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1641), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1636), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [80100] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2492), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2490), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [80144] = 5,
    ACTIONS(1549), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1544), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(1547), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1542), 27,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [80192] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2468), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2466), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [80236] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2461), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2459), 30,
      sym_string_start,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [80280] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2472), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2470), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [80324] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2480), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2478), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [80368] = 4,
    ACTIONS(1549), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1547), 6,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1542), 28,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_else,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [80414] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2488), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2486), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [80458] = 4,
    ACTIONS(292), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 6,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(277), 28,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_else,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [80504] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2424), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2422), 30,
      sym_string_start,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [80548] = 4,
    ACTIONS(292), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 6,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(277), 28,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_else,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [80594] = 8,
    ACTIONS(2510), 1,
      anon_sym_DOT,
    ACTIONS(2512), 1,
      anon_sym_LPAREN,
    ACTIONS(2520), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2522), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1469), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2234), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2232), 25,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [80648] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2559), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2557), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [80692] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2546), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2544), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [80736] = 11,
    ACTIONS(2510), 1,
      anon_sym_DOT,
    ACTIONS(2512), 1,
      anon_sym_LPAREN,
    ACTIONS(2520), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2522), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2234), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2514), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2526), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1469), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2524), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2232), 20,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_PIPE,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [80796] = 5,
    ACTIONS(292), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(284), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(279), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(277), 27,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [80844] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2542), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2540), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [80888] = 15,
    ACTIONS(2510), 1,
      anon_sym_DOT,
    ACTIONS(2512), 1,
      anon_sym_LPAREN,
    ACTIONS(2520), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2522), 1,
      anon_sym_LBRACK,
    ACTIONS(2528), 1,
      anon_sym_PIPE,
    ACTIONS(2532), 1,
      anon_sym_AMP,
    ACTIONS(2534), 1,
      anon_sym_CARET,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2238), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2514), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2516), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2526), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1469), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2524), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2236), 15,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [80956] = 8,
    ACTIONS(2510), 1,
      anon_sym_DOT,
    ACTIONS(2512), 1,
      anon_sym_LPAREN,
    ACTIONS(2520), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2522), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1469), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2234), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2232), 25,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [81010] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1634), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1629), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [81054] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1664), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1662), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [81098] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2508), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2506), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [81142] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2502), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2500), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [81186] = 10,
    ACTIONS(2510), 1,
      anon_sym_DOT,
    ACTIONS(2512), 1,
      anon_sym_LPAREN,
    ACTIONS(2520), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2522), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2234), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2514), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    STATE(1469), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2524), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2232), 22,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [81244] = 14,
    ACTIONS(2510), 1,
      anon_sym_DOT,
    ACTIONS(2512), 1,
      anon_sym_LPAREN,
    ACTIONS(2520), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2522), 1,
      anon_sym_LBRACK,
    ACTIONS(2532), 1,
      anon_sym_AMP,
    ACTIONS(2534), 1,
      anon_sym_CARET,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2234), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2514), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2516), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2526), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1469), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2524), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2232), 16,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_PIPE,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [81310] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(668), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(671), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(679), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(666), 16,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [81358] = 12,
    ACTIONS(2510), 1,
      anon_sym_DOT,
    ACTIONS(2512), 1,
      anon_sym_LPAREN,
    ACTIONS(2520), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2522), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2234), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2514), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2516), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2526), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1469), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2524), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2232), 18,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_PIPE,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [81420] = 6,
    ACTIONS(1549), 1,
      anon_sym_COLON_EQ,
    ACTIONS(2585), 1,
      anon_sym_LBRACK,
    STATE(2039), 1,
      sym_type_parameter,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1547), 5,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1542), 27,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [81470] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2484), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2482), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [81514] = 5,
    ACTIONS(292), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(666), 2,
      anon_sym_async,
      anon_sym_for,
    ACTIONS(668), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(679), 27,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [81562] = 5,
    ACTIONS(292), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(666), 2,
      anon_sym_async,
      anon_sym_for,
    ACTIONS(668), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(679), 27,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [81610] = 5,
    ACTIONS(1549), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1604), 2,
      anon_sym_async,
      anon_sym_for,
    ACTIONS(1611), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1608), 27,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [81658] = 15,
    ACTIONS(2510), 1,
      anon_sym_DOT,
    ACTIONS(2512), 1,
      anon_sym_LPAREN,
    ACTIONS(2520), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2522), 1,
      anon_sym_LBRACK,
    ACTIONS(2528), 1,
      anon_sym_PIPE,
    ACTIONS(2532), 1,
      anon_sym_AMP,
    ACTIONS(2534), 1,
      anon_sym_CARET,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2242), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2514), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2516), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2526), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1469), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2524), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2240), 15,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [81726] = 15,
    ACTIONS(2510), 1,
      anon_sym_DOT,
    ACTIONS(2512), 1,
      anon_sym_LPAREN,
    ACTIONS(2520), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2522), 1,
      anon_sym_LBRACK,
    ACTIONS(2528), 1,
      anon_sym_PIPE,
    ACTIONS(2532), 1,
      anon_sym_AMP,
    ACTIONS(2534), 1,
      anon_sym_CARET,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2320), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2514), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2516), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2526), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1469), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2524), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2318), 15,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [81794] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2583), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2581), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [81838] = 5,
    ACTIONS(292), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(284), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(279), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(277), 27,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [81886] = 19,
    ACTIONS(2251), 1,
      anon_sym_DOT,
    ACTIONS(2263), 1,
      anon_sym_LBRACK,
    ACTIONS(2287), 1,
      anon_sym_LPAREN,
    ACTIONS(2295), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2303), 1,
      anon_sym_PIPE,
    ACTIONS(2305), 1,
      anon_sym_not,
    ACTIONS(2307), 1,
      anon_sym_AMP,
    ACTIONS(2309), 1,
      anon_sym_CARET,
    ACTIONS(2313), 1,
      anon_sym_is,
    STATE(1605), 1,
      aux_sym_comparison_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2289), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2291), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2301), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(2311), 2,
      anon_sym_LT,
      anon_sym_GT,
    STATE(1262), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2299), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2191), 6,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
    ACTIONS(2293), 6,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
  [81962] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2476), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2474), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [82006] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2575), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2573), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [82050] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2567), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2565), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [82094] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2571), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2569), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [82138] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2553), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2551), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [82182] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1547), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1542), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [82226] = 4,
    ACTIONS(1549), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1547), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1542), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [82272] = 4,
    ACTIONS(292), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(277), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [82318] = 5,
    ACTIONS(292), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(666), 2,
      anon_sym_async,
      anon_sym_for,
    ACTIONS(668), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(679), 27,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [82366] = 4,
    ACTIONS(292), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(277), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [82412] = 5,
    ACTIONS(292), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(284), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(279), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(277), 27,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [82460] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1604), 3,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
    ACTIONS(1611), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1608), 27,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [82506] = 5,
    ACTIONS(292), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(666), 2,
      anon_sym_async,
      anon_sym_for,
    ACTIONS(668), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(679), 27,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [82554] = 4,
    ACTIONS(292), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(277), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [82600] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(668), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(671), 3,
      anon_sym_as,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(679), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(666), 16,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [82648] = 5,
    ACTIONS(1549), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1604), 2,
      anon_sym_async,
      anon_sym_for,
    ACTIONS(1611), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1608), 27,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [82696] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(668), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(671), 3,
      anon_sym_as,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(679), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(666), 16,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [82744] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1611), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1614), 3,
      anon_sym_as,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1608), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(1604), 16,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_RBRACE,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [82792] = 4,
    ACTIONS(292), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(277), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [82838] = 4,
    ACTIONS(1549), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1547), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1542), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [82884] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(277), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [82928] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(277), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [82972] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2579), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2577), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [83016] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2461), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2459), 30,
      sym_string_start,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [83060] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2424), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2422), 30,
      sym_string_start,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [83104] = 5,
    ACTIONS(1549), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1544), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(1547), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1542), 27,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [83152] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2563), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2561), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [83196] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2496), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2494), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [83240] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2492), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2490), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [83284] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2468), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2466), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [83328] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2472), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2470), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [83372] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2480), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2478), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [83416] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2488), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2486), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [83460] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1649), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1647), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [83504] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1649), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1647), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [83548] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1602), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1600), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [83592] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1623), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1618), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [83636] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1641), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1636), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [83680] = 19,
    ACTIONS(2354), 1,
      anon_sym_LPAREN,
    ACTIONS(2362), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2370), 1,
      anon_sym_PIPE,
    ACTIONS(2372), 1,
      anon_sym_not,
    ACTIONS(2374), 1,
      anon_sym_AMP,
    ACTIONS(2376), 1,
      anon_sym_CARET,
    ACTIONS(2380), 1,
      anon_sym_is,
    ACTIONS(2429), 1,
      anon_sym_DOT,
    ACTIONS(2441), 1,
      anon_sym_LBRACK,
    STATE(1597), 1,
      aux_sym_comparison_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2356), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2358), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2368), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(2378), 2,
      anon_sym_LT,
      anon_sym_GT,
    STATE(1423), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2366), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
    ACTIONS(2191), 6,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_and,
      anon_sym_or,
    ACTIONS(2360), 6,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
  [83756] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2553), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2551), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [83800] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2571), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2569), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [83844] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2567), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2565), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [83888] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1660), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1658), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [83932] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2559), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2557), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [83976] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2575), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2573), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [84020] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2546), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2544), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [84064] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2542), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2540), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [84108] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2508), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2506), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [84152] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2502), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2500), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [84196] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2476), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2474), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [84240] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2484), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2482), 30,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
      sym_type_conversion,
  [84284] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2502), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2500), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [84327] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2496), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2494), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [84370] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2476), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2474), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [84413] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1634), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1629), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [84456] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1604), 2,
      anon_sym_async,
      anon_sym_for,
    ACTIONS(1611), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1608), 27,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [84501] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2484), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2482), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [84544] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2468), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2466), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [84587] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2472), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2470), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [84630] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2480), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2478), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [84673] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2575), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2573), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [84716] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2583), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2581), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [84759] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2468), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2466), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [84802] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2476), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2474), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [84845] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2567), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2565), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [84888] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2575), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2573), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [84931] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2472), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2470), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [84974] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2567), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2565), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [85017] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2571), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2569), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [85060] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2553), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2551), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [85103] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1547), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1542), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [85146] = 5,
    ACTIONS(1549), 1,
      anon_sym_COLON_EQ,
    ACTIONS(2498), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1547), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1542), 28,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [85193] = 5,
    ACTIONS(292), 1,
      anon_sym_COLON_EQ,
    ACTIONS(736), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(277), 28,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [85240] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2488), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2486), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [85283] = 5,
    ACTIONS(292), 1,
      anon_sym_COLON_EQ,
    ACTIONS(736), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(277), 28,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [85330] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2488), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2486), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [85373] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1664), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1662), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [85416] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2583), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2581), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [85459] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1664), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1662), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [85502] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2553), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2551), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [85545] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2571), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2569), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [85588] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1641), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1636), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [85631] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1623), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1618), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [85674] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2484), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2482), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [85717] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1649), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1647), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [85760] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2559), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2557), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [85803] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1649), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1647), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [85846] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2480), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2478), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [85889] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1602), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1600), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [85932] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2567), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2565), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [85975] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2575), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2573), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [86018] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2476), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2474), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [86061] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2546), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2544), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [86104] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2542), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2540), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [86147] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2508), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2506), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [86190] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2502), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2500), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [86233] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(668), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(671), 3,
      anon_sym_as,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(679), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(666), 15,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [86280] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(668), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(671), 3,
      anon_sym_as,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(679), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(666), 15,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [86327] = 7,
    ACTIONS(1616), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1611), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1614), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1606), 5,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_PIPE,
    ACTIONS(1604), 12,
      anon_sym_as,
      anon_sym_if,
      anon_sym_in,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
    ACTIONS(1608), 12,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
  [86378] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2484), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2482), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [86421] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2583), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2581), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [86464] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1547), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1542), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [86507] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2492), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2490), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [86550] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1660), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1658), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [86593] = 4,
    ACTIONS(292), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 5,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(277), 28,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [86638] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1631), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(1634), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1629), 27,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [86683] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1544), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(1547), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1542), 27,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [86728] = 4,
    ACTIONS(292), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 5,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(277), 28,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [86773] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2476), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2474), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [86816] = 4,
    ACTIONS(1549), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1547), 5,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1542), 28,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [86861] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2575), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2573), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [86904] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2567), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2565), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [86947] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2496), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2494), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [86990] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2583), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2581), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [87033] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(277), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [87076] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1641), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1636), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [87119] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(277), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [87162] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1623), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1618), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [87205] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2579), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2577), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [87248] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(277), 3,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
    ACTIONS(279), 13,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(319), 18,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [87293] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2484), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2482), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [87336] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2502), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2500), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [87379] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2508), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2506), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [87422] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2542), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2540), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [87465] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2571), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2569), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [87508] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2553), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2551), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [87551] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2563), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2561), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [87594] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(277), 3,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
    ACTIONS(279), 13,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(319), 18,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [87639] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2546), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2544), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [87682] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1547), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1542), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [87725] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2563), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2561), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [87768] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1634), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1629), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [87811] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2559), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2557), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [87854] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(668), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(671), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(679), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(666), 15,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [87901] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(668), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(671), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(679), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(666), 15,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [87948] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2508), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2506), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [87991] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2542), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2540), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [88034] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2546), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2544), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [88077] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1620), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(1623), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1618), 27,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [88122] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2559), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2557), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [88165] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2488), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2486), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [88208] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2502), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2500), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [88251] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2579), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2577), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [88294] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(277), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [88337] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1664), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1662), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [88380] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1611), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1614), 3,
      anon_sym_as,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1608), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(1604), 15,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [88427] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1664), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1662), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [88470] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2508), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2506), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [88513] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(277), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [88556] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1638), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(1641), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1636), 27,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [88601] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1623), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1618), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [88644] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2488), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2486), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [88687] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1668), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1666), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [88730] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1641), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1636), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [88773] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2559), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2557), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [88816] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1668), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1666), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [88859] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1611), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1614), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1608), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(1604), 15,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [88906] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1668), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1666), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [88949] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1636), 3,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
    ACTIONS(1641), 13,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(1645), 18,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [88994] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2542), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2540), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [89037] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1611), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1614), 3,
      anon_sym_as,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1608), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(1604), 15,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [89084] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1649), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1647), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [89127] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1649), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1647), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [89170] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1618), 3,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
    ACTIONS(1623), 13,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(1625), 18,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [89215] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1542), 3,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
    ACTIONS(1547), 13,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(1558), 18,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [89260] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1629), 3,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
    ACTIONS(1634), 13,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(1558), 18,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [89305] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2480), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2478), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [89348] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2472), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2470), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [89391] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2468), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2466), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [89434] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2480), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2478), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [89477] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2472), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2470), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [89520] = 7,
    ACTIONS(1616), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1611), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1614), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1606), 5,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_PIPE,
    ACTIONS(1604), 12,
      anon_sym_as,
      anon_sym_if,
      anon_sym_in,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
    ACTIONS(1608), 12,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
  [89571] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1641), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1636), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [89614] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1623), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1618), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [89657] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2461), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2459), 30,
      sym_string_start,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [89700] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1602), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1600), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [89743] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1611), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1614), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1608), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(1604), 15,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [89790] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(668), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(671), 3,
      anon_sym_as,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(679), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(666), 15,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [89837] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1547), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1542), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [89880] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2492), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2490), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [89923] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2496), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2494), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [89966] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(668), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(671), 3,
      anon_sym_as,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(679), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(666), 15,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [90013] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2546), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2544), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [90056] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1631), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(1634), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1629), 27,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [90101] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2424), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2422), 30,
      sym_string_start,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [90144] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1544), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(1547), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1542), 27,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [90189] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2468), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2466), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [90232] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2563), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2561), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [90275] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1660), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1658), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [90318] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1620), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(1623), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1618), 27,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [90363] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1664), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1662), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [90406] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2492), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2490), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [90449] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2571), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2569), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [90492] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(668), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(671), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(679), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(666), 15,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [90539] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2563), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2561), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [90582] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1664), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1662), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [90625] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1634), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1629), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [90668] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1634), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1629), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [90711] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(277), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [90754] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2553), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2551), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [90797] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(277), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [90840] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(668), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(671), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(679), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(666), 15,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [90887] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1660), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1658), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [90930] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2579), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2577), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [90973] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2496), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2494), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [91016] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2492), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2490), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [91059] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1604), 2,
      anon_sym_async,
      anon_sym_for,
    ACTIONS(1611), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1608), 27,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [91104] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1638), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(1641), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1636), 27,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [91149] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(277), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [91192] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(277), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [91235] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1602), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1600), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [91278] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1649), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1647), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [91321] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2579), 5,
      anon_sym_as,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2577), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [91364] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1649), 5,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1647), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [91407] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1547), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1542), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [91449] = 4,
    ACTIONS(292), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(668), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(679), 28,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [91493] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1623), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1618), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [91535] = 7,
    ACTIONS(1616), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1611), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1614), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1606), 4,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_PIPE,
    ACTIONS(1604), 12,
      anon_sym_as,
      anon_sym_if,
      anon_sym_in,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
    ACTIONS(1608), 12,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
  [91585] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2567), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2565), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [91627] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2575), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2573), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [91669] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2571), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2569), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [91711] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2476), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2474), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [91753] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(277), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [91795] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1641), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1636), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [91837] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1611), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1614), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1606), 5,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_PIPE,
    ACTIONS(1604), 12,
      anon_sym_as,
      anon_sym_if,
      anon_sym_in,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
    ACTIONS(1608), 12,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
  [91885] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(277), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [91927] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2579), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2577), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [91969] = 4,
    ACTIONS(1549), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1611), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1608), 28,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [92013] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2583), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2581), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [92055] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2553), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2551), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [92097] = 4,
    ACTIONS(292), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(668), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(679), 28,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [92141] = 4,
    ACTIONS(292), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(668), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(679), 28,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [92185] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2484), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2482), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [92227] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2563), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2561), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [92269] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1634), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1629), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [92311] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2488), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2486), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [92353] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2502), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2500), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [92395] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2508), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2506), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [92437] = 4,
    ACTIONS(292), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(668), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(679), 28,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [92481] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2496), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2494), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [92523] = 4,
    ACTIONS(1549), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1611), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1608), 28,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [92567] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2542), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2540), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [92609] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2492), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2490), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [92651] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2468), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2466), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [92693] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1668), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1666), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [92735] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1660), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1658), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [92777] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2546), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2544), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [92819] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2559), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2557), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [92861] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1602), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1600), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [92903] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2472), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2470), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [92945] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2480), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2478), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [92987] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(668), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(671), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(679), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(666), 15,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [93033] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1649), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1647), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [93075] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(668), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(671), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(679), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(666), 15,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [93121] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1611), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1614), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1608), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(1604), 15,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [93167] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1664), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1662), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [93209] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1664), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1662), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [93251] = 4,
    ACTIONS(292), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(668), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(679), 28,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [93295] = 4,
    ACTIONS(292), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(668), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(679), 28,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [93339] = 4,
    ACTIONS(1549), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1611), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1608), 28,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [93383] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1649), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1647), 29,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [93425] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1664), 13,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(1662), 19,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [93466] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1542), 3,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
    ACTIONS(1547), 13,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(1558), 16,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [93509] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1660), 13,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(1658), 19,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [93550] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1618), 3,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
    ACTIONS(1623), 13,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(1625), 16,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [93593] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1636), 3,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
    ACTIONS(1641), 13,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(1645), 16,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [93636] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1629), 3,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
    ACTIONS(1634), 13,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(1558), 16,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [93679] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1649), 13,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(1647), 19,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [93720] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1649), 13,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(1647), 19,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [93761] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1664), 13,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(1662), 19,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [93802] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(679), 3,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
    ACTIONS(668), 13,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(666), 16,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [93845] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1668), 13,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(1666), 19,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [93886] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(277), 3,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
    ACTIONS(279), 13,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(319), 16,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [93929] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(277), 3,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
    ACTIONS(279), 13,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(319), 16,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [93972] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(679), 3,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
    ACTIONS(668), 13,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(666), 16,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [94015] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1602), 13,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(1600), 19,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [94056] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1608), 3,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
    ACTIONS(1611), 13,
      anon_sym_STAR,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
    ACTIONS(1604), 16,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [94099] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1611), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1608), 28,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [94140] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1611), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1608), 28,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [94181] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1611), 4,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1608), 28,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_GT_GT,
      anon_sym_if,
      anon_sym_in,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_PLUS,
      anon_sym_not,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
      anon_sym_is,
  [94222] = 20,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(2587), 1,
      sym_identifier,
    ACTIONS(2589), 1,
      anon_sym_LPAREN,
    ACTIONS(2591), 1,
      anon_sym_STAR,
    ACTIONS(2593), 1,
      anon_sym_if,
    ACTIONS(2595), 1,
      anon_sym_COLON,
    ACTIONS(2597), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2599), 1,
      anon_sym_LBRACK,
    ACTIONS(2601), 1,
      anon_sym_DASH,
    ACTIONS(2605), 1,
      anon_sym_LBRACE,
    ACTIONS(2607), 1,
      sym_integer,
    ACTIONS(2609), 1,
      sym_float,
    STATE(1812), 1,
      sym_string,
    STATE(1917), 1,
      sym_dotted_name,
    STATE(2223), 1,
      sym_case_pattern,
    STATE(2804), 1,
      sym_if_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2236), 2,
      sym__as_pattern,
      sym_keyword_pattern,
    ACTIONS(2603), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2019), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [94296] = 20,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(2587), 1,
      sym_identifier,
    ACTIONS(2589), 1,
      anon_sym_LPAREN,
    ACTIONS(2591), 1,
      anon_sym_STAR,
    ACTIONS(2593), 1,
      anon_sym_if,
    ACTIONS(2597), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2599), 1,
      anon_sym_LBRACK,
    ACTIONS(2601), 1,
      anon_sym_DASH,
    ACTIONS(2605), 1,
      anon_sym_LBRACE,
    ACTIONS(2607), 1,
      sym_integer,
    ACTIONS(2609), 1,
      sym_float,
    ACTIONS(2611), 1,
      anon_sym_COLON,
    STATE(1812), 1,
      sym_string,
    STATE(1917), 1,
      sym_dotted_name,
    STATE(2223), 1,
      sym_case_pattern,
    STATE(2778), 1,
      sym_if_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2236), 2,
      sym__as_pattern,
      sym_keyword_pattern,
    ACTIONS(2603), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2019), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [94370] = 18,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(2613), 1,
      sym_identifier,
    ACTIONS(2615), 1,
      anon_sym_LPAREN,
    ACTIONS(2617), 1,
      anon_sym_RPAREN,
    ACTIONS(2619), 1,
      anon_sym_STAR,
    ACTIONS(2621), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2623), 1,
      anon_sym_LBRACK,
    ACTIONS(2625), 1,
      anon_sym_DASH,
    ACTIONS(2629), 1,
      anon_sym_LBRACE,
    ACTIONS(2631), 1,
      sym_integer,
    ACTIONS(2633), 1,
      sym_float,
    STATE(1898), 1,
      sym_string,
    STATE(2075), 1,
      sym_dotted_name,
    STATE(2515), 1,
      sym_case_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2320), 2,
      sym__as_pattern,
      sym_keyword_pattern,
    ACTIONS(2627), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2076), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [94438] = 18,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(2613), 1,
      sym_identifier,
    ACTIONS(2615), 1,
      anon_sym_LPAREN,
    ACTIONS(2619), 1,
      anon_sym_STAR,
    ACTIONS(2621), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2623), 1,
      anon_sym_LBRACK,
    ACTIONS(2625), 1,
      anon_sym_DASH,
    ACTIONS(2629), 1,
      anon_sym_LBRACE,
    ACTIONS(2631), 1,
      sym_integer,
    ACTIONS(2633), 1,
      sym_float,
    ACTIONS(2635), 1,
      anon_sym_RPAREN,
    STATE(1898), 1,
      sym_string,
    STATE(2075), 1,
      sym_dotted_name,
    STATE(2244), 1,
      sym_case_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2320), 2,
      sym__as_pattern,
      sym_keyword_pattern,
    ACTIONS(2627), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2076), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [94506] = 18,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(2613), 1,
      sym_identifier,
    ACTIONS(2615), 1,
      anon_sym_LPAREN,
    ACTIONS(2619), 1,
      anon_sym_STAR,
    ACTIONS(2621), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2623), 1,
      anon_sym_LBRACK,
    ACTIONS(2625), 1,
      anon_sym_DASH,
    ACTIONS(2629), 1,
      anon_sym_LBRACE,
    ACTIONS(2631), 1,
      sym_integer,
    ACTIONS(2633), 1,
      sym_float,
    ACTIONS(2637), 1,
      anon_sym_RPAREN,
    STATE(1898), 1,
      sym_string,
    STATE(2075), 1,
      sym_dotted_name,
    STATE(2515), 1,
      sym_case_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2320), 2,
      sym__as_pattern,
      sym_keyword_pattern,
    ACTIONS(2627), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2076), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [94574] = 18,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(2613), 1,
      sym_identifier,
    ACTIONS(2615), 1,
      anon_sym_LPAREN,
    ACTIONS(2619), 1,
      anon_sym_STAR,
    ACTIONS(2621), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2623), 1,
      anon_sym_LBRACK,
    ACTIONS(2625), 1,
      anon_sym_DASH,
    ACTIONS(2629), 1,
      anon_sym_LBRACE,
    ACTIONS(2631), 1,
      sym_integer,
    ACTIONS(2633), 1,
      sym_float,
    ACTIONS(2639), 1,
      anon_sym_RPAREN,
    STATE(1898), 1,
      sym_string,
    STATE(2075), 1,
      sym_dotted_name,
    STATE(2515), 1,
      sym_case_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2320), 2,
      sym__as_pattern,
      sym_keyword_pattern,
    ACTIONS(2627), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2076), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [94642] = 18,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(2613), 1,
      sym_identifier,
    ACTIONS(2615), 1,
      anon_sym_LPAREN,
    ACTIONS(2619), 1,
      anon_sym_STAR,
    ACTIONS(2621), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2623), 1,
      anon_sym_LBRACK,
    ACTIONS(2625), 1,
      anon_sym_DASH,
    ACTIONS(2629), 1,
      anon_sym_LBRACE,
    ACTIONS(2631), 1,
      sym_integer,
    ACTIONS(2633), 1,
      sym_float,
    ACTIONS(2641), 1,
      anon_sym_RPAREN,
    STATE(1898), 1,
      sym_string,
    STATE(2075), 1,
      sym_dotted_name,
    STATE(2515), 1,
      sym_case_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2320), 2,
      sym__as_pattern,
      sym_keyword_pattern,
    ACTIONS(2627), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2076), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [94710] = 18,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(2613), 1,
      sym_identifier,
    ACTIONS(2615), 1,
      anon_sym_LPAREN,
    ACTIONS(2619), 1,
      anon_sym_STAR,
    ACTIONS(2621), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2623), 1,
      anon_sym_LBRACK,
    ACTIONS(2625), 1,
      anon_sym_DASH,
    ACTIONS(2629), 1,
      anon_sym_LBRACE,
    ACTIONS(2631), 1,
      sym_integer,
    ACTIONS(2633), 1,
      sym_float,
    ACTIONS(2643), 1,
      anon_sym_RPAREN,
    STATE(1898), 1,
      sym_string,
    STATE(2075), 1,
      sym_dotted_name,
    STATE(2515), 1,
      sym_case_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2320), 2,
      sym__as_pattern,
      sym_keyword_pattern,
    ACTIONS(2627), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2076), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [94778] = 18,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(2645), 1,
      sym_identifier,
    ACTIONS(2647), 1,
      anon_sym_LPAREN,
    ACTIONS(2649), 1,
      anon_sym_STAR,
    ACTIONS(2651), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2653), 1,
      anon_sym_LBRACK,
    ACTIONS(2655), 1,
      anon_sym_RBRACK,
    ACTIONS(2657), 1,
      anon_sym_DASH,
    ACTIONS(2661), 1,
      anon_sym_LBRACE,
    ACTIONS(2663), 1,
      sym_integer,
    ACTIONS(2665), 1,
      sym_float,
    STATE(1887), 1,
      sym_string,
    STATE(2122), 1,
      sym_dotted_name,
    STATE(2280), 1,
      sym_case_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2526), 2,
      sym__as_pattern,
      sym_keyword_pattern,
    ACTIONS(2659), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2129), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [94846] = 18,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(2613), 1,
      sym_identifier,
    ACTIONS(2615), 1,
      anon_sym_LPAREN,
    ACTIONS(2619), 1,
      anon_sym_STAR,
    ACTIONS(2621), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2623), 1,
      anon_sym_LBRACK,
    ACTIONS(2625), 1,
      anon_sym_DASH,
    ACTIONS(2629), 1,
      anon_sym_LBRACE,
    ACTIONS(2631), 1,
      sym_integer,
    ACTIONS(2633), 1,
      sym_float,
    ACTIONS(2667), 1,
      anon_sym_RPAREN,
    STATE(1898), 1,
      sym_string,
    STATE(2075), 1,
      sym_dotted_name,
    STATE(2214), 1,
      sym_case_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2320), 2,
      sym__as_pattern,
      sym_keyword_pattern,
    ACTIONS(2627), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2076), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [94914] = 18,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(2613), 1,
      sym_identifier,
    ACTIONS(2615), 1,
      anon_sym_LPAREN,
    ACTIONS(2619), 1,
      anon_sym_STAR,
    ACTIONS(2621), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2623), 1,
      anon_sym_LBRACK,
    ACTIONS(2625), 1,
      anon_sym_DASH,
    ACTIONS(2629), 1,
      anon_sym_LBRACE,
    ACTIONS(2631), 1,
      sym_integer,
    ACTIONS(2633), 1,
      sym_float,
    ACTIONS(2669), 1,
      anon_sym_RPAREN,
    STATE(1898), 1,
      sym_string,
    STATE(2075), 1,
      sym_dotted_name,
    STATE(2515), 1,
      sym_case_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2320), 2,
      sym__as_pattern,
      sym_keyword_pattern,
    ACTIONS(2627), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2076), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [94982] = 18,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(2645), 1,
      sym_identifier,
    ACTIONS(2647), 1,
      anon_sym_LPAREN,
    ACTIONS(2649), 1,
      anon_sym_STAR,
    ACTIONS(2651), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2653), 1,
      anon_sym_LBRACK,
    ACTIONS(2657), 1,
      anon_sym_DASH,
    ACTIONS(2661), 1,
      anon_sym_LBRACE,
    ACTIONS(2663), 1,
      sym_integer,
    ACTIONS(2665), 1,
      sym_float,
    ACTIONS(2671), 1,
      anon_sym_RBRACK,
    STATE(1887), 1,
      sym_string,
    STATE(2122), 1,
      sym_dotted_name,
    STATE(2172), 1,
      sym_case_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2526), 2,
      sym__as_pattern,
      sym_keyword_pattern,
    ACTIONS(2659), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2129), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [95050] = 18,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(2645), 1,
      sym_identifier,
    ACTIONS(2647), 1,
      anon_sym_LPAREN,
    ACTIONS(2649), 1,
      anon_sym_STAR,
    ACTIONS(2651), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2653), 1,
      anon_sym_LBRACK,
    ACTIONS(2657), 1,
      anon_sym_DASH,
    ACTIONS(2661), 1,
      anon_sym_LBRACE,
    ACTIONS(2663), 1,
      sym_integer,
    ACTIONS(2665), 1,
      sym_float,
    ACTIONS(2673), 1,
      anon_sym_RBRACK,
    STATE(1887), 1,
      sym_string,
    STATE(2122), 1,
      sym_dotted_name,
    STATE(2280), 1,
      sym_case_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2526), 2,
      sym__as_pattern,
      sym_keyword_pattern,
    ACTIONS(2659), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2129), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [95118] = 18,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(2613), 1,
      sym_identifier,
    ACTIONS(2615), 1,
      anon_sym_LPAREN,
    ACTIONS(2619), 1,
      anon_sym_STAR,
    ACTIONS(2621), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2623), 1,
      anon_sym_LBRACK,
    ACTIONS(2625), 1,
      anon_sym_DASH,
    ACTIONS(2629), 1,
      anon_sym_LBRACE,
    ACTIONS(2631), 1,
      sym_integer,
    ACTIONS(2633), 1,
      sym_float,
    ACTIONS(2675), 1,
      anon_sym_RPAREN,
    STATE(1898), 1,
      sym_string,
    STATE(2075), 1,
      sym_dotted_name,
    STATE(2515), 1,
      sym_case_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2320), 2,
      sym__as_pattern,
      sym_keyword_pattern,
    ACTIONS(2627), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2076), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [95186] = 18,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(2645), 1,
      sym_identifier,
    ACTIONS(2647), 1,
      anon_sym_LPAREN,
    ACTIONS(2649), 1,
      anon_sym_STAR,
    ACTIONS(2651), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2653), 1,
      anon_sym_LBRACK,
    ACTIONS(2657), 1,
      anon_sym_DASH,
    ACTIONS(2661), 1,
      anon_sym_LBRACE,
    ACTIONS(2663), 1,
      sym_integer,
    ACTIONS(2665), 1,
      sym_float,
    ACTIONS(2677), 1,
      anon_sym_RBRACK,
    STATE(1887), 1,
      sym_string,
    STATE(2122), 1,
      sym_dotted_name,
    STATE(2280), 1,
      sym_case_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2526), 2,
      sym__as_pattern,
      sym_keyword_pattern,
    ACTIONS(2659), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2129), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [95254] = 18,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(2645), 1,
      sym_identifier,
    ACTIONS(2647), 1,
      anon_sym_LPAREN,
    ACTIONS(2649), 1,
      anon_sym_STAR,
    ACTIONS(2651), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2653), 1,
      anon_sym_LBRACK,
    ACTIONS(2657), 1,
      anon_sym_DASH,
    ACTIONS(2661), 1,
      anon_sym_LBRACE,
    ACTIONS(2663), 1,
      sym_integer,
    ACTIONS(2665), 1,
      sym_float,
    ACTIONS(2679), 1,
      anon_sym_RBRACK,
    STATE(1887), 1,
      sym_string,
    STATE(2122), 1,
      sym_dotted_name,
    STATE(2280), 1,
      sym_case_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2526), 2,
      sym__as_pattern,
      sym_keyword_pattern,
    ACTIONS(2659), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2129), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [95322] = 18,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(2613), 1,
      sym_identifier,
    ACTIONS(2615), 1,
      anon_sym_LPAREN,
    ACTIONS(2619), 1,
      anon_sym_STAR,
    ACTIONS(2621), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2623), 1,
      anon_sym_LBRACK,
    ACTIONS(2625), 1,
      anon_sym_DASH,
    ACTIONS(2629), 1,
      anon_sym_LBRACE,
    ACTIONS(2631), 1,
      sym_integer,
    ACTIONS(2633), 1,
      sym_float,
    ACTIONS(2681), 1,
      anon_sym_RPAREN,
    STATE(1898), 1,
      sym_string,
    STATE(2075), 1,
      sym_dotted_name,
    STATE(2196), 1,
      sym_case_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2320), 2,
      sym__as_pattern,
      sym_keyword_pattern,
    ACTIONS(2627), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2076), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [95390] = 18,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(2645), 1,
      sym_identifier,
    ACTIONS(2647), 1,
      anon_sym_LPAREN,
    ACTIONS(2649), 1,
      anon_sym_STAR,
    ACTIONS(2651), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2653), 1,
      anon_sym_LBRACK,
    ACTIONS(2657), 1,
      anon_sym_DASH,
    ACTIONS(2661), 1,
      anon_sym_LBRACE,
    ACTIONS(2663), 1,
      sym_integer,
    ACTIONS(2665), 1,
      sym_float,
    ACTIONS(2683), 1,
      anon_sym_RBRACK,
    STATE(1887), 1,
      sym_string,
    STATE(2122), 1,
      sym_dotted_name,
    STATE(2195), 1,
      sym_case_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2526), 2,
      sym__as_pattern,
      sym_keyword_pattern,
    ACTIONS(2659), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2129), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [95458] = 18,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(2613), 1,
      sym_identifier,
    ACTIONS(2615), 1,
      anon_sym_LPAREN,
    ACTIONS(2619), 1,
      anon_sym_STAR,
    ACTIONS(2621), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2623), 1,
      anon_sym_LBRACK,
    ACTIONS(2625), 1,
      anon_sym_DASH,
    ACTIONS(2629), 1,
      anon_sym_LBRACE,
    ACTIONS(2631), 1,
      sym_integer,
    ACTIONS(2633), 1,
      sym_float,
    ACTIONS(2685), 1,
      anon_sym_RPAREN,
    STATE(1898), 1,
      sym_string,
    STATE(2075), 1,
      sym_dotted_name,
    STATE(2157), 1,
      sym_case_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2320), 2,
      sym__as_pattern,
      sym_keyword_pattern,
    ACTIONS(2627), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2076), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [95526] = 18,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(2613), 1,
      sym_identifier,
    ACTIONS(2615), 1,
      anon_sym_LPAREN,
    ACTIONS(2619), 1,
      anon_sym_STAR,
    ACTIONS(2621), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2623), 1,
      anon_sym_LBRACK,
    ACTIONS(2625), 1,
      anon_sym_DASH,
    ACTIONS(2629), 1,
      anon_sym_LBRACE,
    ACTIONS(2631), 1,
      sym_integer,
    ACTIONS(2633), 1,
      sym_float,
    ACTIONS(2687), 1,
      anon_sym_RPAREN,
    STATE(1898), 1,
      sym_string,
    STATE(2075), 1,
      sym_dotted_name,
    STATE(2515), 1,
      sym_case_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2320), 2,
      sym__as_pattern,
      sym_keyword_pattern,
    ACTIONS(2627), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2076), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [95594] = 18,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(2645), 1,
      sym_identifier,
    ACTIONS(2647), 1,
      anon_sym_LPAREN,
    ACTIONS(2649), 1,
      anon_sym_STAR,
    ACTIONS(2651), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2653), 1,
      anon_sym_LBRACK,
    ACTIONS(2657), 1,
      anon_sym_DASH,
    ACTIONS(2661), 1,
      anon_sym_LBRACE,
    ACTIONS(2663), 1,
      sym_integer,
    ACTIONS(2665), 1,
      sym_float,
    ACTIONS(2689), 1,
      anon_sym_RBRACK,
    STATE(1887), 1,
      sym_string,
    STATE(2122), 1,
      sym_dotted_name,
    STATE(2243), 1,
      sym_case_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2526), 2,
      sym__as_pattern,
      sym_keyword_pattern,
    ACTIONS(2659), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2129), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [95662] = 18,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(2613), 1,
      sym_identifier,
    ACTIONS(2615), 1,
      anon_sym_LPAREN,
    ACTIONS(2619), 1,
      anon_sym_STAR,
    ACTIONS(2621), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2623), 1,
      anon_sym_LBRACK,
    ACTIONS(2625), 1,
      anon_sym_DASH,
    ACTIONS(2629), 1,
      anon_sym_LBRACE,
    ACTIONS(2631), 1,
      sym_integer,
    ACTIONS(2633), 1,
      sym_float,
    ACTIONS(2691), 1,
      anon_sym_RPAREN,
    STATE(1898), 1,
      sym_string,
    STATE(2075), 1,
      sym_dotted_name,
    STATE(2206), 1,
      sym_case_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2320), 2,
      sym__as_pattern,
      sym_keyword_pattern,
    ACTIONS(2627), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2076), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [95730] = 18,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(2645), 1,
      sym_identifier,
    ACTIONS(2647), 1,
      anon_sym_LPAREN,
    ACTIONS(2649), 1,
      anon_sym_STAR,
    ACTIONS(2651), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2653), 1,
      anon_sym_LBRACK,
    ACTIONS(2657), 1,
      anon_sym_DASH,
    ACTIONS(2661), 1,
      anon_sym_LBRACE,
    ACTIONS(2663), 1,
      sym_integer,
    ACTIONS(2665), 1,
      sym_float,
    ACTIONS(2693), 1,
      anon_sym_RBRACK,
    STATE(1887), 1,
      sym_string,
    STATE(2122), 1,
      sym_dotted_name,
    STATE(2207), 1,
      sym_case_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2526), 2,
      sym__as_pattern,
      sym_keyword_pattern,
    ACTIONS(2659), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2129), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [95798] = 18,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(2613), 1,
      sym_identifier,
    ACTIONS(2615), 1,
      anon_sym_LPAREN,
    ACTIONS(2619), 1,
      anon_sym_STAR,
    ACTIONS(2621), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2623), 1,
      anon_sym_LBRACK,
    ACTIONS(2625), 1,
      anon_sym_DASH,
    ACTIONS(2629), 1,
      anon_sym_LBRACE,
    ACTIONS(2631), 1,
      sym_integer,
    ACTIONS(2633), 1,
      sym_float,
    ACTIONS(2695), 1,
      anon_sym_RPAREN,
    STATE(1898), 1,
      sym_string,
    STATE(2075), 1,
      sym_dotted_name,
    STATE(2515), 1,
      sym_case_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2320), 2,
      sym__as_pattern,
      sym_keyword_pattern,
    ACTIONS(2627), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2076), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [95866] = 18,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(2645), 1,
      sym_identifier,
    ACTIONS(2647), 1,
      anon_sym_LPAREN,
    ACTIONS(2649), 1,
      anon_sym_STAR,
    ACTIONS(2651), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2653), 1,
      anon_sym_LBRACK,
    ACTIONS(2657), 1,
      anon_sym_DASH,
    ACTIONS(2661), 1,
      anon_sym_LBRACE,
    ACTIONS(2663), 1,
      sym_integer,
    ACTIONS(2665), 1,
      sym_float,
    ACTIONS(2697), 1,
      anon_sym_RBRACK,
    STATE(1887), 1,
      sym_string,
    STATE(2122), 1,
      sym_dotted_name,
    STATE(2280), 1,
      sym_case_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2526), 2,
      sym__as_pattern,
      sym_keyword_pattern,
    ACTIONS(2659), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2129), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [95934] = 18,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(2613), 1,
      sym_identifier,
    ACTIONS(2615), 1,
      anon_sym_LPAREN,
    ACTIONS(2619), 1,
      anon_sym_STAR,
    ACTIONS(2621), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2623), 1,
      anon_sym_LBRACK,
    ACTIONS(2625), 1,
      anon_sym_DASH,
    ACTIONS(2629), 1,
      anon_sym_LBRACE,
    ACTIONS(2631), 1,
      sym_integer,
    ACTIONS(2633), 1,
      sym_float,
    ACTIONS(2699), 1,
      anon_sym_RPAREN,
    STATE(1898), 1,
      sym_string,
    STATE(2075), 1,
      sym_dotted_name,
    STATE(2515), 1,
      sym_case_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2320), 2,
      sym__as_pattern,
      sym_keyword_pattern,
    ACTIONS(2627), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2076), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [96002] = 18,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(2613), 1,
      sym_identifier,
    ACTIONS(2615), 1,
      anon_sym_LPAREN,
    ACTIONS(2619), 1,
      anon_sym_STAR,
    ACTIONS(2621), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2623), 1,
      anon_sym_LBRACK,
    ACTIONS(2625), 1,
      anon_sym_DASH,
    ACTIONS(2629), 1,
      anon_sym_LBRACE,
    ACTIONS(2631), 1,
      sym_integer,
    ACTIONS(2633), 1,
      sym_float,
    ACTIONS(2701), 1,
      anon_sym_RPAREN,
    STATE(1898), 1,
      sym_string,
    STATE(2075), 1,
      sym_dotted_name,
    STATE(2515), 1,
      sym_case_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2320), 2,
      sym__as_pattern,
      sym_keyword_pattern,
    ACTIONS(2627), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2076), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [96070] = 18,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(2645), 1,
      sym_identifier,
    ACTIONS(2647), 1,
      anon_sym_LPAREN,
    ACTIONS(2649), 1,
      anon_sym_STAR,
    ACTIONS(2651), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2653), 1,
      anon_sym_LBRACK,
    ACTIONS(2657), 1,
      anon_sym_DASH,
    ACTIONS(2661), 1,
      anon_sym_LBRACE,
    ACTIONS(2663), 1,
      sym_integer,
    ACTIONS(2665), 1,
      sym_float,
    ACTIONS(2703), 1,
      anon_sym_RBRACK,
    STATE(1887), 1,
      sym_string,
    STATE(2122), 1,
      sym_dotted_name,
    STATE(2280), 1,
      sym_case_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2526), 2,
      sym__as_pattern,
      sym_keyword_pattern,
    ACTIONS(2659), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2129), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [96138] = 18,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(2645), 1,
      sym_identifier,
    ACTIONS(2647), 1,
      anon_sym_LPAREN,
    ACTIONS(2649), 1,
      anon_sym_STAR,
    ACTIONS(2651), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2653), 1,
      anon_sym_LBRACK,
    ACTIONS(2657), 1,
      anon_sym_DASH,
    ACTIONS(2661), 1,
      anon_sym_LBRACE,
    ACTIONS(2663), 1,
      sym_integer,
    ACTIONS(2665), 1,
      sym_float,
    ACTIONS(2705), 1,
      anon_sym_RBRACK,
    STATE(1887), 1,
      sym_string,
    STATE(2122), 1,
      sym_dotted_name,
    STATE(2280), 1,
      sym_case_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2526), 2,
      sym__as_pattern,
      sym_keyword_pattern,
    ACTIONS(2659), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2129), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [96206] = 18,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(2613), 1,
      sym_identifier,
    ACTIONS(2615), 1,
      anon_sym_LPAREN,
    ACTIONS(2619), 1,
      anon_sym_STAR,
    ACTIONS(2621), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2623), 1,
      anon_sym_LBRACK,
    ACTIONS(2625), 1,
      anon_sym_DASH,
    ACTIONS(2629), 1,
      anon_sym_LBRACE,
    ACTIONS(2631), 1,
      sym_integer,
    ACTIONS(2633), 1,
      sym_float,
    ACTIONS(2707), 1,
      anon_sym_RPAREN,
    STATE(1898), 1,
      sym_string,
    STATE(2075), 1,
      sym_dotted_name,
    STATE(2238), 1,
      sym_case_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2320), 2,
      sym__as_pattern,
      sym_keyword_pattern,
    ACTIONS(2627), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2076), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [96274] = 18,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(2613), 1,
      sym_identifier,
    ACTIONS(2615), 1,
      anon_sym_LPAREN,
    ACTIONS(2619), 1,
      anon_sym_STAR,
    ACTIONS(2621), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2623), 1,
      anon_sym_LBRACK,
    ACTIONS(2625), 1,
      anon_sym_DASH,
    ACTIONS(2629), 1,
      anon_sym_LBRACE,
    ACTIONS(2631), 1,
      sym_integer,
    ACTIONS(2633), 1,
      sym_float,
    ACTIONS(2709), 1,
      anon_sym_RPAREN,
    STATE(1898), 1,
      sym_string,
    STATE(2075), 1,
      sym_dotted_name,
    STATE(2515), 1,
      sym_case_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2320), 2,
      sym__as_pattern,
      sym_keyword_pattern,
    ACTIONS(2627), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2076), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [96342] = 18,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(2613), 1,
      sym_identifier,
    ACTIONS(2615), 1,
      anon_sym_LPAREN,
    ACTIONS(2619), 1,
      anon_sym_STAR,
    ACTIONS(2621), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2623), 1,
      anon_sym_LBRACK,
    ACTIONS(2625), 1,
      anon_sym_DASH,
    ACTIONS(2629), 1,
      anon_sym_LBRACE,
    ACTIONS(2631), 1,
      sym_integer,
    ACTIONS(2633), 1,
      sym_float,
    ACTIONS(2711), 1,
      anon_sym_RPAREN,
    STATE(1898), 1,
      sym_string,
    STATE(2075), 1,
      sym_dotted_name,
    STATE(2515), 1,
      sym_case_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2320), 2,
      sym__as_pattern,
      sym_keyword_pattern,
    ACTIONS(2627), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2076), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [96410] = 18,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(2613), 1,
      sym_identifier,
    ACTIONS(2615), 1,
      anon_sym_LPAREN,
    ACTIONS(2619), 1,
      anon_sym_STAR,
    ACTIONS(2621), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2623), 1,
      anon_sym_LBRACK,
    ACTIONS(2625), 1,
      anon_sym_DASH,
    ACTIONS(2629), 1,
      anon_sym_LBRACE,
    ACTIONS(2631), 1,
      sym_integer,
    ACTIONS(2633), 1,
      sym_float,
    ACTIONS(2713), 1,
      anon_sym_RPAREN,
    STATE(1898), 1,
      sym_string,
    STATE(2075), 1,
      sym_dotted_name,
    STATE(2231), 1,
      sym_case_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2320), 2,
      sym__as_pattern,
      sym_keyword_pattern,
    ACTIONS(2627), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2076), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [96478] = 18,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(2613), 1,
      sym_identifier,
    ACTIONS(2615), 1,
      anon_sym_LPAREN,
    ACTIONS(2619), 1,
      anon_sym_STAR,
    ACTIONS(2621), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2623), 1,
      anon_sym_LBRACK,
    ACTIONS(2625), 1,
      anon_sym_DASH,
    ACTIONS(2629), 1,
      anon_sym_LBRACE,
    ACTIONS(2631), 1,
      sym_integer,
    ACTIONS(2633), 1,
      sym_float,
    ACTIONS(2715), 1,
      anon_sym_RPAREN,
    STATE(1898), 1,
      sym_string,
    STATE(2075), 1,
      sym_dotted_name,
    STATE(2183), 1,
      sym_case_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2320), 2,
      sym__as_pattern,
      sym_keyword_pattern,
    ACTIONS(2627), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2076), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [96546] = 18,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(2613), 1,
      sym_identifier,
    ACTIONS(2615), 1,
      anon_sym_LPAREN,
    ACTIONS(2619), 1,
      anon_sym_STAR,
    ACTIONS(2621), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2623), 1,
      anon_sym_LBRACK,
    ACTIONS(2625), 1,
      anon_sym_DASH,
    ACTIONS(2629), 1,
      anon_sym_LBRACE,
    ACTIONS(2631), 1,
      sym_integer,
    ACTIONS(2633), 1,
      sym_float,
    ACTIONS(2717), 1,
      anon_sym_RPAREN,
    STATE(1898), 1,
      sym_string,
    STATE(2075), 1,
      sym_dotted_name,
    STATE(2515), 1,
      sym_case_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2320), 2,
      sym__as_pattern,
      sym_keyword_pattern,
    ACTIONS(2627), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2076), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [96614] = 18,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(2645), 1,
      sym_identifier,
    ACTIONS(2647), 1,
      anon_sym_LPAREN,
    ACTIONS(2649), 1,
      anon_sym_STAR,
    ACTIONS(2651), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2653), 1,
      anon_sym_LBRACK,
    ACTIONS(2657), 1,
      anon_sym_DASH,
    ACTIONS(2661), 1,
      anon_sym_LBRACE,
    ACTIONS(2663), 1,
      sym_integer,
    ACTIONS(2665), 1,
      sym_float,
    ACTIONS(2719), 1,
      anon_sym_RBRACK,
    STATE(1887), 1,
      sym_string,
    STATE(2122), 1,
      sym_dotted_name,
    STATE(2280), 1,
      sym_case_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2526), 2,
      sym__as_pattern,
      sym_keyword_pattern,
    ACTIONS(2659), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2129), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [96682] = 18,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(2613), 1,
      sym_identifier,
    ACTIONS(2615), 1,
      anon_sym_LPAREN,
    ACTIONS(2619), 1,
      anon_sym_STAR,
    ACTIONS(2621), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2623), 1,
      anon_sym_LBRACK,
    ACTIONS(2625), 1,
      anon_sym_DASH,
    ACTIONS(2629), 1,
      anon_sym_LBRACE,
    ACTIONS(2631), 1,
      sym_integer,
    ACTIONS(2633), 1,
      sym_float,
    ACTIONS(2721), 1,
      anon_sym_RPAREN,
    STATE(1898), 1,
      sym_string,
    STATE(2075), 1,
      sym_dotted_name,
    STATE(2515), 1,
      sym_case_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2320), 2,
      sym__as_pattern,
      sym_keyword_pattern,
    ACTIONS(2627), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2076), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [96750] = 18,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(2613), 1,
      sym_identifier,
    ACTIONS(2615), 1,
      anon_sym_LPAREN,
    ACTIONS(2619), 1,
      anon_sym_STAR,
    ACTIONS(2621), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2623), 1,
      anon_sym_LBRACK,
    ACTIONS(2625), 1,
      anon_sym_DASH,
    ACTIONS(2629), 1,
      anon_sym_LBRACE,
    ACTIONS(2631), 1,
      sym_integer,
    ACTIONS(2633), 1,
      sym_float,
    ACTIONS(2723), 1,
      anon_sym_RPAREN,
    STATE(1898), 1,
      sym_string,
    STATE(2075), 1,
      sym_dotted_name,
    STATE(2515), 1,
      sym_case_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2320), 2,
      sym__as_pattern,
      sym_keyword_pattern,
    ACTIONS(2627), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2076), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [96818] = 17,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(2645), 1,
      sym_identifier,
    ACTIONS(2647), 1,
      anon_sym_LPAREN,
    ACTIONS(2649), 1,
      anon_sym_STAR,
    ACTIONS(2651), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2653), 1,
      anon_sym_LBRACK,
    ACTIONS(2657), 1,
      anon_sym_DASH,
    ACTIONS(2661), 1,
      anon_sym_LBRACE,
    ACTIONS(2663), 1,
      sym_integer,
    ACTIONS(2665), 1,
      sym_float,
    STATE(1887), 1,
      sym_string,
    STATE(2122), 1,
      sym_dotted_name,
    STATE(2280), 1,
      sym_case_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2526), 2,
      sym__as_pattern,
      sym_keyword_pattern,
    ACTIONS(2659), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2129), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [96883] = 17,
    ACTIONS(702), 1,
      sym_string_start,
    ACTIONS(2725), 1,
      sym_identifier,
    ACTIONS(2727), 1,
      anon_sym_LPAREN,
    ACTIONS(2729), 1,
      anon_sym_STAR,
    ACTIONS(2731), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2733), 1,
      anon_sym_LBRACK,
    ACTIONS(2735), 1,
      anon_sym_DASH,
    ACTIONS(2739), 1,
      anon_sym_LBRACE,
    ACTIONS(2741), 1,
      sym_integer,
    ACTIONS(2743), 1,
      sym_float,
    STATE(1895), 1,
      sym_string,
    STATE(2034), 1,
      sym_dotted_name,
    STATE(2488), 1,
      sym_case_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2271), 2,
      sym__as_pattern,
      sym_keyword_pattern,
    ACTIONS(2737), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2032), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [96948] = 17,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(2587), 1,
      sym_identifier,
    ACTIONS(2589), 1,
      anon_sym_LPAREN,
    ACTIONS(2591), 1,
      anon_sym_STAR,
    ACTIONS(2597), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2599), 1,
      anon_sym_LBRACK,
    ACTIONS(2601), 1,
      anon_sym_DASH,
    ACTIONS(2605), 1,
      anon_sym_LBRACE,
    ACTIONS(2607), 1,
      sym_integer,
    ACTIONS(2609), 1,
      sym_float,
    STATE(1812), 1,
      sym_string,
    STATE(1917), 1,
      sym_dotted_name,
    STATE(2020), 1,
      sym_case_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2236), 2,
      sym__as_pattern,
      sym_keyword_pattern,
    ACTIONS(2603), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2019), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [97013] = 17,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(2587), 1,
      sym_identifier,
    ACTIONS(2589), 1,
      anon_sym_LPAREN,
    ACTIONS(2591), 1,
      anon_sym_STAR,
    ACTIONS(2597), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2599), 1,
      anon_sym_LBRACK,
    ACTIONS(2601), 1,
      anon_sym_DASH,
    ACTIONS(2605), 1,
      anon_sym_LBRACE,
    ACTIONS(2607), 1,
      sym_integer,
    ACTIONS(2609), 1,
      sym_float,
    STATE(1812), 1,
      sym_string,
    STATE(1917), 1,
      sym_dotted_name,
    STATE(2223), 1,
      sym_case_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2236), 2,
      sym__as_pattern,
      sym_keyword_pattern,
    ACTIONS(2603), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2019), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [97078] = 17,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(2613), 1,
      sym_identifier,
    ACTIONS(2615), 1,
      anon_sym_LPAREN,
    ACTIONS(2619), 1,
      anon_sym_STAR,
    ACTIONS(2621), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2623), 1,
      anon_sym_LBRACK,
    ACTIONS(2625), 1,
      anon_sym_DASH,
    ACTIONS(2629), 1,
      anon_sym_LBRACE,
    ACTIONS(2631), 1,
      sym_integer,
    ACTIONS(2633), 1,
      sym_float,
    STATE(1898), 1,
      sym_string,
    STATE(2075), 1,
      sym_dotted_name,
    STATE(2515), 1,
      sym_case_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2320), 2,
      sym__as_pattern,
      sym_keyword_pattern,
    ACTIONS(2627), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2076), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [97143] = 18,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(2589), 1,
      anon_sym_LPAREN,
    ACTIONS(2599), 1,
      anon_sym_LBRACK,
    ACTIONS(2601), 1,
      anon_sym_DASH,
    ACTIONS(2605), 1,
      anon_sym_LBRACE,
    ACTIONS(2607), 1,
      sym_integer,
    ACTIONS(2609), 1,
      sym_float,
    ACTIONS(2729), 1,
      anon_sym_STAR,
    ACTIONS(2731), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2745), 1,
      sym_identifier,
    ACTIONS(2749), 1,
      anon_sym_RBRACE,
    STATE(1812), 1,
      sym_string,
    STATE(1917), 1,
      sym_dotted_name,
    STATE(2142), 1,
      sym_splat_pattern,
    STATE(2535), 1,
      sym__key_value_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2747), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2491), 8,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [97209] = 18,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(2589), 1,
      anon_sym_LPAREN,
    ACTIONS(2599), 1,
      anon_sym_LBRACK,
    ACTIONS(2601), 1,
      anon_sym_DASH,
    ACTIONS(2605), 1,
      anon_sym_LBRACE,
    ACTIONS(2607), 1,
      sym_integer,
    ACTIONS(2609), 1,
      sym_float,
    ACTIONS(2729), 1,
      anon_sym_STAR,
    ACTIONS(2731), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2745), 1,
      sym_identifier,
    ACTIONS(2751), 1,
      anon_sym_RBRACE,
    STATE(1812), 1,
      sym_string,
    STATE(1917), 1,
      sym_dotted_name,
    STATE(2142), 1,
      sym_splat_pattern,
    STATE(2535), 1,
      sym__key_value_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2747), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2491), 8,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [97275] = 18,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(2589), 1,
      anon_sym_LPAREN,
    ACTIONS(2599), 1,
      anon_sym_LBRACK,
    ACTIONS(2601), 1,
      anon_sym_DASH,
    ACTIONS(2605), 1,
      anon_sym_LBRACE,
    ACTIONS(2607), 1,
      sym_integer,
    ACTIONS(2609), 1,
      sym_float,
    ACTIONS(2729), 1,
      anon_sym_STAR,
    ACTIONS(2731), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2745), 1,
      sym_identifier,
    ACTIONS(2753), 1,
      anon_sym_RBRACE,
    STATE(1812), 1,
      sym_string,
    STATE(1917), 1,
      sym_dotted_name,
    STATE(2142), 1,
      sym_splat_pattern,
    STATE(2535), 1,
      sym__key_value_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2747), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2491), 8,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [97341] = 18,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(2589), 1,
      anon_sym_LPAREN,
    ACTIONS(2599), 1,
      anon_sym_LBRACK,
    ACTIONS(2601), 1,
      anon_sym_DASH,
    ACTIONS(2605), 1,
      anon_sym_LBRACE,
    ACTIONS(2607), 1,
      sym_integer,
    ACTIONS(2609), 1,
      sym_float,
    ACTIONS(2729), 1,
      anon_sym_STAR,
    ACTIONS(2731), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2745), 1,
      sym_identifier,
    ACTIONS(2755), 1,
      anon_sym_RBRACE,
    STATE(1812), 1,
      sym_string,
    STATE(1917), 1,
      sym_dotted_name,
    STATE(2142), 1,
      sym_splat_pattern,
    STATE(2535), 1,
      sym__key_value_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2747), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2491), 8,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [97407] = 18,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(2589), 1,
      anon_sym_LPAREN,
    ACTIONS(2599), 1,
      anon_sym_LBRACK,
    ACTIONS(2601), 1,
      anon_sym_DASH,
    ACTIONS(2605), 1,
      anon_sym_LBRACE,
    ACTIONS(2607), 1,
      sym_integer,
    ACTIONS(2609), 1,
      sym_float,
    ACTIONS(2729), 1,
      anon_sym_STAR,
    ACTIONS(2731), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2745), 1,
      sym_identifier,
    ACTIONS(2757), 1,
      anon_sym_RBRACE,
    STATE(1812), 1,
      sym_string,
    STATE(1917), 1,
      sym_dotted_name,
    STATE(2040), 1,
      sym_splat_pattern,
    STATE(2331), 1,
      sym__key_value_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2747), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2491), 8,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [97473] = 18,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(2589), 1,
      anon_sym_LPAREN,
    ACTIONS(2599), 1,
      anon_sym_LBRACK,
    ACTIONS(2601), 1,
      anon_sym_DASH,
    ACTIONS(2605), 1,
      anon_sym_LBRACE,
    ACTIONS(2607), 1,
      sym_integer,
    ACTIONS(2609), 1,
      sym_float,
    ACTIONS(2729), 1,
      anon_sym_STAR,
    ACTIONS(2731), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2745), 1,
      sym_identifier,
    ACTIONS(2759), 1,
      anon_sym_RBRACE,
    STATE(1812), 1,
      sym_string,
    STATE(1917), 1,
      sym_dotted_name,
    STATE(2142), 1,
      sym_splat_pattern,
    STATE(2535), 1,
      sym__key_value_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2747), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2491), 8,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [97539] = 18,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(2589), 1,
      anon_sym_LPAREN,
    ACTIONS(2599), 1,
      anon_sym_LBRACK,
    ACTIONS(2601), 1,
      anon_sym_DASH,
    ACTIONS(2605), 1,
      anon_sym_LBRACE,
    ACTIONS(2607), 1,
      sym_integer,
    ACTIONS(2609), 1,
      sym_float,
    ACTIONS(2729), 1,
      anon_sym_STAR,
    ACTIONS(2731), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2745), 1,
      sym_identifier,
    ACTIONS(2761), 1,
      anon_sym_RBRACE,
    STATE(1812), 1,
      sym_string,
    STATE(1917), 1,
      sym_dotted_name,
    STATE(2127), 1,
      sym_splat_pattern,
    STATE(2511), 1,
      sym__key_value_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2747), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2491), 8,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [97605] = 18,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(2589), 1,
      anon_sym_LPAREN,
    ACTIONS(2599), 1,
      anon_sym_LBRACK,
    ACTIONS(2601), 1,
      anon_sym_DASH,
    ACTIONS(2605), 1,
      anon_sym_LBRACE,
    ACTIONS(2607), 1,
      sym_integer,
    ACTIONS(2609), 1,
      sym_float,
    ACTIONS(2729), 1,
      anon_sym_STAR,
    ACTIONS(2731), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2745), 1,
      sym_identifier,
    ACTIONS(2763), 1,
      anon_sym_RBRACE,
    STATE(1812), 1,
      sym_string,
    STATE(1917), 1,
      sym_dotted_name,
    STATE(2142), 1,
      sym_splat_pattern,
    STATE(2535), 1,
      sym__key_value_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2747), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2491), 8,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [97671] = 18,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(2589), 1,
      anon_sym_LPAREN,
    ACTIONS(2599), 1,
      anon_sym_LBRACK,
    ACTIONS(2601), 1,
      anon_sym_DASH,
    ACTIONS(2605), 1,
      anon_sym_LBRACE,
    ACTIONS(2607), 1,
      sym_integer,
    ACTIONS(2609), 1,
      sym_float,
    ACTIONS(2729), 1,
      anon_sym_STAR,
    ACTIONS(2731), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2745), 1,
      sym_identifier,
    ACTIONS(2765), 1,
      anon_sym_RBRACE,
    STATE(1812), 1,
      sym_string,
    STATE(1917), 1,
      sym_dotted_name,
    STATE(2070), 1,
      sym_splat_pattern,
    STATE(2432), 1,
      sym__key_value_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2747), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2491), 8,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [97737] = 18,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(2589), 1,
      anon_sym_LPAREN,
    ACTIONS(2599), 1,
      anon_sym_LBRACK,
    ACTIONS(2601), 1,
      anon_sym_DASH,
    ACTIONS(2605), 1,
      anon_sym_LBRACE,
    ACTIONS(2607), 1,
      sym_integer,
    ACTIONS(2609), 1,
      sym_float,
    ACTIONS(2729), 1,
      anon_sym_STAR,
    ACTIONS(2731), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2745), 1,
      sym_identifier,
    ACTIONS(2767), 1,
      anon_sym_RBRACE,
    STATE(1812), 1,
      sym_string,
    STATE(1917), 1,
      sym_dotted_name,
    STATE(2142), 1,
      sym_splat_pattern,
    STATE(2535), 1,
      sym__key_value_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2747), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2491), 8,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [97803] = 18,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(2589), 1,
      anon_sym_LPAREN,
    ACTIONS(2599), 1,
      anon_sym_LBRACK,
    ACTIONS(2601), 1,
      anon_sym_DASH,
    ACTIONS(2605), 1,
      anon_sym_LBRACE,
    ACTIONS(2607), 1,
      sym_integer,
    ACTIONS(2609), 1,
      sym_float,
    ACTIONS(2729), 1,
      anon_sym_STAR,
    ACTIONS(2731), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2745), 1,
      sym_identifier,
    ACTIONS(2769), 1,
      anon_sym_RBRACE,
    STATE(1812), 1,
      sym_string,
    STATE(1917), 1,
      sym_dotted_name,
    STATE(2142), 1,
      sym_splat_pattern,
    STATE(2535), 1,
      sym__key_value_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2747), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2491), 8,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [97869] = 18,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(2589), 1,
      anon_sym_LPAREN,
    ACTIONS(2599), 1,
      anon_sym_LBRACK,
    ACTIONS(2601), 1,
      anon_sym_DASH,
    ACTIONS(2605), 1,
      anon_sym_LBRACE,
    ACTIONS(2607), 1,
      sym_integer,
    ACTIONS(2609), 1,
      sym_float,
    ACTIONS(2729), 1,
      anon_sym_STAR,
    ACTIONS(2731), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2745), 1,
      sym_identifier,
    ACTIONS(2771), 1,
      anon_sym_RBRACE,
    STATE(1812), 1,
      sym_string,
    STATE(1917), 1,
      sym_dotted_name,
    STATE(2142), 1,
      sym_splat_pattern,
    STATE(2535), 1,
      sym__key_value_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2747), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2491), 8,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [97935] = 18,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(2589), 1,
      anon_sym_LPAREN,
    ACTIONS(2599), 1,
      anon_sym_LBRACK,
    ACTIONS(2601), 1,
      anon_sym_DASH,
    ACTIONS(2605), 1,
      anon_sym_LBRACE,
    ACTIONS(2607), 1,
      sym_integer,
    ACTIONS(2609), 1,
      sym_float,
    ACTIONS(2729), 1,
      anon_sym_STAR,
    ACTIONS(2731), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2745), 1,
      sym_identifier,
    ACTIONS(2773), 1,
      anon_sym_RBRACE,
    STATE(1812), 1,
      sym_string,
    STATE(1917), 1,
      sym_dotted_name,
    STATE(2142), 1,
      sym_splat_pattern,
    STATE(2535), 1,
      sym__key_value_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2747), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2491), 8,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [98001] = 18,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(2589), 1,
      anon_sym_LPAREN,
    ACTIONS(2599), 1,
      anon_sym_LBRACK,
    ACTIONS(2601), 1,
      anon_sym_DASH,
    ACTIONS(2605), 1,
      anon_sym_LBRACE,
    ACTIONS(2607), 1,
      sym_integer,
    ACTIONS(2609), 1,
      sym_float,
    ACTIONS(2729), 1,
      anon_sym_STAR,
    ACTIONS(2731), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2745), 1,
      sym_identifier,
    ACTIONS(2775), 1,
      anon_sym_RBRACE,
    STATE(1812), 1,
      sym_string,
    STATE(1917), 1,
      sym_dotted_name,
    STATE(2055), 1,
      sym_splat_pattern,
    STATE(2413), 1,
      sym__key_value_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2747), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2491), 8,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [98067] = 18,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(2589), 1,
      anon_sym_LPAREN,
    ACTIONS(2599), 1,
      anon_sym_LBRACK,
    ACTIONS(2601), 1,
      anon_sym_DASH,
    ACTIONS(2605), 1,
      anon_sym_LBRACE,
    ACTIONS(2607), 1,
      sym_integer,
    ACTIONS(2609), 1,
      sym_float,
    ACTIONS(2729), 1,
      anon_sym_STAR,
    ACTIONS(2731), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2745), 1,
      sym_identifier,
    ACTIONS(2777), 1,
      anon_sym_RBRACE,
    STATE(1812), 1,
      sym_string,
    STATE(1917), 1,
      sym_dotted_name,
    STATE(2142), 1,
      sym_splat_pattern,
    STATE(2535), 1,
      sym__key_value_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2747), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2491), 8,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [98133] = 18,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(2589), 1,
      anon_sym_LPAREN,
    ACTIONS(2599), 1,
      anon_sym_LBRACK,
    ACTIONS(2601), 1,
      anon_sym_DASH,
    ACTIONS(2605), 1,
      anon_sym_LBRACE,
    ACTIONS(2607), 1,
      sym_integer,
    ACTIONS(2609), 1,
      sym_float,
    ACTIONS(2729), 1,
      anon_sym_STAR,
    ACTIONS(2731), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2745), 1,
      sym_identifier,
    ACTIONS(2779), 1,
      anon_sym_RBRACE,
    STATE(1812), 1,
      sym_string,
    STATE(1917), 1,
      sym_dotted_name,
    STATE(2142), 1,
      sym_splat_pattern,
    STATE(2535), 1,
      sym__key_value_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2747), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2491), 8,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [98199] = 18,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(2589), 1,
      anon_sym_LPAREN,
    ACTIONS(2599), 1,
      anon_sym_LBRACK,
    ACTIONS(2601), 1,
      anon_sym_DASH,
    ACTIONS(2605), 1,
      anon_sym_LBRACE,
    ACTIONS(2607), 1,
      sym_integer,
    ACTIONS(2609), 1,
      sym_float,
    ACTIONS(2729), 1,
      anon_sym_STAR,
    ACTIONS(2731), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2745), 1,
      sym_identifier,
    ACTIONS(2781), 1,
      anon_sym_RBRACE,
    STATE(1812), 1,
      sym_string,
    STATE(1917), 1,
      sym_dotted_name,
    STATE(2142), 1,
      sym_splat_pattern,
    STATE(2535), 1,
      sym__key_value_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2747), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2491), 8,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [98265] = 18,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(2589), 1,
      anon_sym_LPAREN,
    ACTIONS(2599), 1,
      anon_sym_LBRACK,
    ACTIONS(2601), 1,
      anon_sym_DASH,
    ACTIONS(2605), 1,
      anon_sym_LBRACE,
    ACTIONS(2607), 1,
      sym_integer,
    ACTIONS(2609), 1,
      sym_float,
    ACTIONS(2729), 1,
      anon_sym_STAR,
    ACTIONS(2731), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2745), 1,
      sym_identifier,
    ACTIONS(2783), 1,
      anon_sym_RBRACE,
    STATE(1812), 1,
      sym_string,
    STATE(1917), 1,
      sym_dotted_name,
    STATE(2142), 1,
      sym_splat_pattern,
    STATE(2535), 1,
      sym__key_value_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2747), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2491), 8,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [98331] = 18,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(2589), 1,
      anon_sym_LPAREN,
    ACTIONS(2599), 1,
      anon_sym_LBRACK,
    ACTIONS(2601), 1,
      anon_sym_DASH,
    ACTIONS(2605), 1,
      anon_sym_LBRACE,
    ACTIONS(2607), 1,
      sym_integer,
    ACTIONS(2609), 1,
      sym_float,
    ACTIONS(2729), 1,
      anon_sym_STAR,
    ACTIONS(2731), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2745), 1,
      sym_identifier,
    ACTIONS(2785), 1,
      anon_sym_RBRACE,
    STATE(1812), 1,
      sym_string,
    STATE(1917), 1,
      sym_dotted_name,
    STATE(2142), 1,
      sym_splat_pattern,
    STATE(2535), 1,
      sym__key_value_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2747), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2491), 8,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [98397] = 18,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(2589), 1,
      anon_sym_LPAREN,
    ACTIONS(2599), 1,
      anon_sym_LBRACK,
    ACTIONS(2601), 1,
      anon_sym_DASH,
    ACTIONS(2605), 1,
      anon_sym_LBRACE,
    ACTIONS(2607), 1,
      sym_integer,
    ACTIONS(2609), 1,
      sym_float,
    ACTIONS(2729), 1,
      anon_sym_STAR,
    ACTIONS(2731), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2745), 1,
      sym_identifier,
    ACTIONS(2787), 1,
      anon_sym_RBRACE,
    STATE(1812), 1,
      sym_string,
    STATE(1917), 1,
      sym_dotted_name,
    STATE(2142), 1,
      sym_splat_pattern,
    STATE(2535), 1,
      sym__key_value_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2747), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2491), 8,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [98463] = 17,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(2589), 1,
      anon_sym_LPAREN,
    ACTIONS(2599), 1,
      anon_sym_LBRACK,
    ACTIONS(2601), 1,
      anon_sym_DASH,
    ACTIONS(2605), 1,
      anon_sym_LBRACE,
    ACTIONS(2607), 1,
      sym_integer,
    ACTIONS(2609), 1,
      sym_float,
    ACTIONS(2729), 1,
      anon_sym_STAR,
    ACTIONS(2731), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2745), 1,
      sym_identifier,
    STATE(1812), 1,
      sym_string,
    STATE(1917), 1,
      sym_dotted_name,
    STATE(2142), 1,
      sym_splat_pattern,
    STATE(2535), 1,
      sym__key_value_pattern,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2747), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2491), 8,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [98526] = 15,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(2615), 1,
      anon_sym_LPAREN,
    ACTIONS(2619), 1,
      anon_sym_STAR,
    ACTIONS(2621), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2623), 1,
      anon_sym_LBRACK,
    ACTIONS(2625), 1,
      anon_sym_DASH,
    ACTIONS(2629), 1,
      anon_sym_LBRACE,
    ACTIONS(2631), 1,
      sym_integer,
    ACTIONS(2633), 1,
      sym_float,
    ACTIONS(2789), 1,
      sym_identifier,
    STATE(1898), 1,
      sym_string,
    STATE(2075), 1,
      sym_dotted_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2791), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2118), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [98584] = 15,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(2615), 1,
      anon_sym_LPAREN,
    ACTIONS(2619), 1,
      anon_sym_STAR,
    ACTIONS(2621), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2623), 1,
      anon_sym_LBRACK,
    ACTIONS(2625), 1,
      anon_sym_DASH,
    ACTIONS(2629), 1,
      anon_sym_LBRACE,
    ACTIONS(2631), 1,
      sym_integer,
    ACTIONS(2633), 1,
      sym_float,
    ACTIONS(2789), 1,
      sym_identifier,
    STATE(1898), 1,
      sym_string,
    STATE(2075), 1,
      sym_dotted_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2793), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2111), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [98642] = 15,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(2589), 1,
      anon_sym_LPAREN,
    ACTIONS(2591), 1,
      anon_sym_STAR,
    ACTIONS(2597), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2599), 1,
      anon_sym_LBRACK,
    ACTIONS(2601), 1,
      anon_sym_DASH,
    ACTIONS(2605), 1,
      anon_sym_LBRACE,
    ACTIONS(2607), 1,
      sym_integer,
    ACTIONS(2609), 1,
      sym_float,
    ACTIONS(2745), 1,
      sym_identifier,
    STATE(1812), 1,
      sym_string,
    STATE(1917), 1,
      sym_dotted_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2795), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(1969), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [98700] = 15,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(2647), 1,
      anon_sym_LPAREN,
    ACTIONS(2649), 1,
      anon_sym_STAR,
    ACTIONS(2651), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2653), 1,
      anon_sym_LBRACK,
    ACTIONS(2657), 1,
      anon_sym_DASH,
    ACTIONS(2661), 1,
      anon_sym_LBRACE,
    ACTIONS(2663), 1,
      sym_integer,
    ACTIONS(2665), 1,
      sym_float,
    ACTIONS(2797), 1,
      sym_identifier,
    STATE(1887), 1,
      sym_string,
    STATE(2122), 1,
      sym_dotted_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2799), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2028), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [98758] = 15,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(2647), 1,
      anon_sym_LPAREN,
    ACTIONS(2649), 1,
      anon_sym_STAR,
    ACTIONS(2651), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2653), 1,
      anon_sym_LBRACK,
    ACTIONS(2657), 1,
      anon_sym_DASH,
    ACTIONS(2661), 1,
      anon_sym_LBRACE,
    ACTIONS(2663), 1,
      sym_integer,
    ACTIONS(2665), 1,
      sym_float,
    ACTIONS(2797), 1,
      sym_identifier,
    STATE(1887), 1,
      sym_string,
    STATE(2122), 1,
      sym_dotted_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2801), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2048), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [98816] = 15,
    ACTIONS(702), 1,
      sym_string_start,
    ACTIONS(2727), 1,
      anon_sym_LPAREN,
    ACTIONS(2729), 1,
      anon_sym_STAR,
    ACTIONS(2731), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2733), 1,
      anon_sym_LBRACK,
    ACTIONS(2735), 1,
      anon_sym_DASH,
    ACTIONS(2739), 1,
      anon_sym_LBRACE,
    ACTIONS(2741), 1,
      sym_integer,
    ACTIONS(2743), 1,
      sym_float,
    ACTIONS(2803), 1,
      sym_identifier,
    STATE(1895), 1,
      sym_string,
    STATE(2034), 1,
      sym_dotted_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2805), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2042), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [98874] = 15,
    ACTIONS(702), 1,
      sym_string_start,
    ACTIONS(2727), 1,
      anon_sym_LPAREN,
    ACTIONS(2729), 1,
      anon_sym_STAR,
    ACTIONS(2731), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2733), 1,
      anon_sym_LBRACK,
    ACTIONS(2735), 1,
      anon_sym_DASH,
    ACTIONS(2739), 1,
      anon_sym_LBRACE,
    ACTIONS(2741), 1,
      sym_integer,
    ACTIONS(2743), 1,
      sym_float,
    ACTIONS(2803), 1,
      sym_identifier,
    STATE(1895), 1,
      sym_string,
    STATE(2034), 1,
      sym_dotted_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2807), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2036), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [98932] = 15,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(2589), 1,
      anon_sym_LPAREN,
    ACTIONS(2591), 1,
      anon_sym_STAR,
    ACTIONS(2597), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2599), 1,
      anon_sym_LBRACK,
    ACTIONS(2601), 1,
      anon_sym_DASH,
    ACTIONS(2605), 1,
      anon_sym_LBRACE,
    ACTIONS(2607), 1,
      sym_integer,
    ACTIONS(2609), 1,
      sym_float,
    ACTIONS(2745), 1,
      sym_identifier,
    STATE(1812), 1,
      sym_string,
    STATE(1917), 1,
      sym_dotted_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2809), 4,
      anon_sym__,
      sym_true,
      sym_false,
      sym_none,
    STATE(2008), 9,
      sym__simple_pattern,
      sym_union_pattern,
      sym__list_pattern,
      sym__tuple_pattern,
      sym_dict_pattern,
      sym_splat_pattern,
      sym_class_pattern,
      sym_complex_pattern,
      sym_concatenated_string,
  [98990] = 8,
    ACTIONS(2816), 1,
      anon_sym_EQ,
    ACTIONS(2818), 1,
      anon_sym_not,
    ACTIONS(2824), 1,
      anon_sym_is,
    STATE(1588), 1,
      aux_sym_comparison_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2821), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2813), 6,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
    ACTIONS(2811), 11,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_and,
      anon_sym_or,
  [99032] = 8,
    ACTIONS(2215), 1,
      anon_sym_not,
    ACTIONS(2223), 1,
      anon_sym_is,
    ACTIONS(2829), 1,
      anon_sym_EQ,
    STATE(1588), 1,
      aux_sym_comparison_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2221), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2201), 6,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
    ACTIONS(2827), 11,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_and,
      anon_sym_or,
  [99074] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1623), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1625), 5,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACE,
      sym_type_conversion,
    ACTIONS(1618), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
  [99106] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1641), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1645), 5,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACE,
      sym_type_conversion,
    ACTIONS(1636), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
  [99138] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(319), 5,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACE,
      sym_type_conversion,
    ACTIONS(277), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
  [99170] = 8,
    ACTIONS(2816), 1,
      anon_sym_EQ,
    ACTIONS(2834), 1,
      anon_sym_not,
    ACTIONS(2840), 1,
      anon_sym_is,
    STATE(1593), 1,
      aux_sym_comparison_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2837), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2831), 6,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
    ACTIONS(2811), 9,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_PIPE,
      anon_sym_and,
      anon_sym_or,
  [99210] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(319), 5,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACE,
      sym_type_conversion,
    ACTIONS(277), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
  [99242] = 8,
    ACTIONS(2342), 1,
      anon_sym_not,
    ACTIONS(2350), 1,
      anon_sym_is,
    ACTIONS(2829), 1,
      anon_sym_EQ,
    STATE(1593), 1,
      aux_sym_comparison_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2348), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2330), 6,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
    ACTIONS(2827), 9,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_PIPE,
      anon_sym_and,
      anon_sym_or,
  [99282] = 8,
    ACTIONS(2816), 1,
      anon_sym_EQ,
    ACTIONS(2846), 1,
      anon_sym_not,
    ACTIONS(2852), 1,
      anon_sym_is,
    STATE(1596), 1,
      aux_sym_comparison_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2849), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2843), 6,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
    ACTIONS(2811), 9,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_and,
      anon_sym_or,
  [99322] = 8,
    ACTIONS(2372), 1,
      anon_sym_not,
    ACTIONS(2380), 1,
      anon_sym_is,
    ACTIONS(2829), 1,
      anon_sym_EQ,
    STATE(1596), 1,
      aux_sym_comparison_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2378), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2360), 6,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
    ACTIONS(2827), 9,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_and,
      anon_sym_or,
  [99362] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1634), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1558), 5,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACE,
      sym_type_conversion,
    ACTIONS(1629), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
  [99394] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1547), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1558), 5,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACE,
      sym_type_conversion,
    ACTIONS(1542), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
  [99426] = 7,
    ACTIONS(2858), 1,
      anon_sym_not,
    ACTIONS(2864), 1,
      anon_sym_is,
    STATE(1600), 1,
      aux_sym_comparison_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2861), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2855), 6,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
    ACTIONS(2811), 9,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_PIPE,
      anon_sym_and,
      anon_sym_or,
  [99463] = 8,
    ACTIONS(2816), 1,
      anon_sym_EQ,
    ACTIONS(2870), 1,
      anon_sym_not,
    ACTIONS(2876), 1,
      anon_sym_is,
    STATE(1601), 1,
      aux_sym_comparison_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2873), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2867), 6,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
    ACTIONS(2811), 8,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
      sym_type_conversion,
  [99502] = 8,
    ACTIONS(2271), 1,
      anon_sym_not,
    ACTIONS(2279), 1,
      anon_sym_is,
    ACTIONS(2829), 1,
      anon_sym_as,
    STATE(1603), 1,
      aux_sym_comparison_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2277), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2259), 6,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
    ACTIONS(2827), 8,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
  [99541] = 8,
    ACTIONS(2816), 1,
      anon_sym_as,
    ACTIONS(2882), 1,
      anon_sym_not,
    ACTIONS(2888), 1,
      anon_sym_is,
    STATE(1603), 1,
      aux_sym_comparison_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2885), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2879), 6,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
    ACTIONS(2811), 8,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
  [99580] = 7,
    ACTIONS(2530), 1,
      anon_sym_not,
    ACTIONS(2538), 1,
      anon_sym_is,
    STATE(1600), 1,
      aux_sym_comparison_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2536), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2518), 6,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
    ACTIONS(2827), 9,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_PIPE,
      anon_sym_and,
      anon_sym_or,
  [99617] = 8,
    ACTIONS(2305), 1,
      anon_sym_not,
    ACTIONS(2313), 1,
      anon_sym_is,
    ACTIONS(2829), 1,
      anon_sym_EQ,
    STATE(1601), 1,
      aux_sym_comparison_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2311), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2293), 6,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
    ACTIONS(2827), 8,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
      sym_type_conversion,
  [99656] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(666), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(277), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
  [99686] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(666), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(277), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
  [99716] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1547), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2891), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(1542), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
  [99746] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1404), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(277), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
  [99776] = 8,
    ACTIONS(2816), 1,
      anon_sym_as,
    ACTIONS(2896), 1,
      anon_sym_not,
    ACTIONS(2902), 1,
      anon_sym_is,
    STATE(1610), 1,
      aux_sym_comparison_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2899), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2893), 6,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
    ACTIONS(2811), 7,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_and,
      anon_sym_or,
  [99814] = 4,
    ACTIONS(2905), 1,
      anon_sym_COMMA,
    STATE(1615), 1,
      aux_sym__patterns_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(970), 17,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [99844] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1547), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1604), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(1542), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
  [99874] = 8,
    ACTIONS(2449), 1,
      anon_sym_not,
    ACTIONS(2457), 1,
      anon_sym_is,
    ACTIONS(2829), 1,
      anon_sym_as,
    STATE(1610), 1,
      aux_sym_comparison_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2455), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2437), 6,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
    ACTIONS(2827), 7,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_and,
      anon_sym_or,
  [99912] = 8,
    ACTIONS(2409), 1,
      anon_sym_not,
    ACTIONS(2417), 1,
      anon_sym_is,
    ACTIONS(2829), 1,
      anon_sym_as,
    STATE(1617), 1,
      aux_sym_comparison_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2415), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2397), 6,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
    ACTIONS(2827), 7,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACK,
      anon_sym_and,
      anon_sym_or,
  [99950] = 4,
    ACTIONS(2909), 1,
      anon_sym_COMMA,
    STATE(1615), 1,
      aux_sym__patterns_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2907), 17,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [99980] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1404), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(277), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
  [100010] = 8,
    ACTIONS(2816), 1,
      anon_sym_as,
    ACTIONS(2915), 1,
      anon_sym_not,
    ACTIONS(2921), 1,
      anon_sym_is,
    STATE(1617), 1,
      aux_sym_comparison_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2918), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2912), 6,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_GT,
    ACTIONS(2811), 7,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACK,
      anon_sym_and,
      anon_sym_or,
  [100048] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(666), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(277), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
  [100077] = 13,
    ACTIONS(2193), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_LBRACK,
    ACTIONS(2324), 1,
      anon_sym_LPAREN,
    ACTIONS(2332), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2340), 1,
      anon_sym_PIPE,
    ACTIONS(2344), 1,
      anon_sym_AMP,
    ACTIONS(2346), 1,
      anon_sym_CARET,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2326), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2328), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2338), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1362), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2336), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
  [100124] = 13,
    ACTIONS(2322), 1,
      anon_sym_DOT,
    ACTIONS(2324), 1,
      anon_sym_LPAREN,
    ACTIONS(2332), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2334), 1,
      anon_sym_LBRACK,
    ACTIONS(2340), 1,
      anon_sym_PIPE,
    ACTIONS(2344), 1,
      anon_sym_AMP,
    ACTIONS(2346), 1,
      anon_sym_CARET,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2326), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2328), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2338), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1362), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2336), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
  [100171] = 13,
    ACTIONS(2251), 1,
      anon_sym_DOT,
    ACTIONS(2263), 1,
      anon_sym_LBRACK,
    ACTIONS(2324), 1,
      anon_sym_LPAREN,
    ACTIONS(2332), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2340), 1,
      anon_sym_PIPE,
    ACTIONS(2344), 1,
      anon_sym_AMP,
    ACTIONS(2346), 1,
      anon_sym_CARET,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2326), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2328), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2338), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1362), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2336), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
  [100218] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1547), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1558), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(1542), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
  [100247] = 13,
    ACTIONS(2324), 1,
      anon_sym_LPAREN,
    ACTIONS(2332), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2340), 1,
      anon_sym_PIPE,
    ACTIONS(2344), 1,
      anon_sym_AMP,
    ACTIONS(2346), 1,
      anon_sym_CARET,
    ACTIONS(2389), 1,
      anon_sym_DOT,
    ACTIONS(2401), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2326), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2328), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2338), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1362), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2336), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
  [100294] = 13,
    ACTIONS(2324), 1,
      anon_sym_LPAREN,
    ACTIONS(2332), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2340), 1,
      anon_sym_PIPE,
    ACTIONS(2344), 1,
      anon_sym_AMP,
    ACTIONS(2346), 1,
      anon_sym_CARET,
    ACTIONS(2510), 1,
      anon_sym_DOT,
    ACTIONS(2522), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2326), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2328), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2338), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1362), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2336), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
  [100341] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(666), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(277), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
  [100370] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(319), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(277), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
  [100399] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(319), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(277), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
  [100428] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1558), 18,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [100453] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(319), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(277), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
  [100482] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1558), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(1634), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1629), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
  [100511] = 13,
    ACTIONS(2324), 1,
      anon_sym_LPAREN,
    ACTIONS(2332), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2340), 1,
      anon_sym_PIPE,
    ACTIONS(2344), 1,
      anon_sym_AMP,
    ACTIONS(2346), 1,
      anon_sym_CARET,
    ACTIONS(2382), 1,
      anon_sym_DOT,
    ACTIONS(2384), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2326), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2328), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2338), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1362), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2336), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
  [100558] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(319), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(277), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
  [100587] = 13,
    ACTIONS(2324), 1,
      anon_sym_LPAREN,
    ACTIONS(2332), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2340), 1,
      anon_sym_PIPE,
    ACTIONS(2344), 1,
      anon_sym_AMP,
    ACTIONS(2346), 1,
      anon_sym_CARET,
    ACTIONS(2352), 1,
      anon_sym_DOT,
    ACTIONS(2364), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2326), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2328), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2338), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1362), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2336), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
  [100634] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1623), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1625), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(1618), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
  [100663] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2907), 18,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [100688] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1404), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(277), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
  [100717] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1404), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(277), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
  [100746] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1558), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(1634), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1629), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
  [100775] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1547), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2891), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(1542), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
  [100804] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1641), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1645), 2,
      anon_sym_COMMA,
      anon_sym_in,
    ACTIONS(1636), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
  [100833] = 13,
    ACTIONS(2285), 1,
      anon_sym_DOT,
    ACTIONS(2297), 1,
      anon_sym_LBRACK,
    ACTIONS(2324), 1,
      anon_sym_LPAREN,
    ACTIONS(2332), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2340), 1,
      anon_sym_PIPE,
    ACTIONS(2344), 1,
      anon_sym_AMP,
    ACTIONS(2346), 1,
      anon_sym_CARET,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2326), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2328), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2338), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1362), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2336), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
  [100880] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1547), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1558), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(1542), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
  [100909] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1641), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1645), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(1636), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
  [100938] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1547), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1604), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(1542), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
  [100967] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1623), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1625), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(1618), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
  [100996] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(319), 2,
      anon_sym_COMMA,
      anon_sym_in,
    ACTIONS(277), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
  [101025] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1558), 2,
      anon_sym_COMMA,
      anon_sym_in,
    ACTIONS(1634), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1629), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
  [101054] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(279), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(319), 2,
      anon_sym_COMMA,
      anon_sym_in,
    ACTIONS(277), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
  [101083] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2924), 18,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [101108] = 13,
    ACTIONS(2324), 1,
      anon_sym_LPAREN,
    ACTIONS(2332), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2340), 1,
      anon_sym_PIPE,
    ACTIONS(2344), 1,
      anon_sym_AMP,
    ACTIONS(2346), 1,
      anon_sym_CARET,
    ACTIONS(2926), 1,
      anon_sym_DOT,
    ACTIONS(2928), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2326), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2328), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2338), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1362), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2336), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
  [101155] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1547), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1558), 2,
      anon_sym_COMMA,
      anon_sym_in,
    ACTIONS(1542), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
  [101184] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1623), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1625), 2,
      anon_sym_COMMA,
      anon_sym_in,
    ACTIONS(1618), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
  [101213] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2930), 18,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [101238] = 13,
    ACTIONS(2324), 1,
      anon_sym_LPAREN,
    ACTIONS(2332), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2340), 1,
      anon_sym_PIPE,
    ACTIONS(2344), 1,
      anon_sym_AMP,
    ACTIONS(2346), 1,
      anon_sym_CARET,
    ACTIONS(2429), 1,
      anon_sym_DOT,
    ACTIONS(2441), 1,
      anon_sym_LBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2326), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(2328), 2,
      anon_sym_GT_GT,
      anon_sym_LT_LT,
    ACTIONS(2338), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    STATE(1362), 2,
      sym_argument_list,
      sym_generator_expression,
    ACTIONS(2336), 3,
      anon_sym_AT,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
  [101285] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1641), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1645), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(1636), 14,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_GT_GT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_PERCENT,
      anon_sym_SLASH_SLASH,
      anon_sym_AMP,
      anon_sym_CARET,
      anon_sym_LT_LT,
  [101314] = 13,
    ACTIONS(2932), 1,
      sym_identifier,
    ACTIONS(2934), 1,
      anon_sym_LPAREN,
    ACTIONS(2936), 1,
      anon_sym_STAR,
    ACTIONS(2938), 1,
      anon_sym_COLON,
    ACTIONS(2940), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2942), 1,
      anon_sym_SLASH,
    STATE(2505), 1,
      sym_tuple_pattern,
    STATE(2507), 1,
      sym_parameter,
    STATE(2745), 1,
      sym_lambda_parameters,
    STATE(2787), 1,
      sym__parameters,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2552), 2,
      sym_list_splat_pattern,
      sym_dictionary_splat_pattern,
    STATE(2549), 5,
      sym_default_parameter,
      sym_typed_default_parameter,
      sym_typed_parameter,
      sym_positional_separator,
      sym_keyword_separator,
  [101360] = 13,
    ACTIONS(2932), 1,
      sym_identifier,
    ACTIONS(2934), 1,
      anon_sym_LPAREN,
    ACTIONS(2936), 1,
      anon_sym_STAR,
    ACTIONS(2940), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2942), 1,
      anon_sym_SLASH,
    ACTIONS(2944), 1,
      anon_sym_COLON,
    STATE(2505), 1,
      sym_tuple_pattern,
    STATE(2507), 1,
      sym_parameter,
    STATE(2787), 1,
      sym__parameters,
    STATE(2811), 1,
      sym_lambda_parameters,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2552), 2,
      sym_list_splat_pattern,
      sym_dictionary_splat_pattern,
    STATE(2549), 5,
      sym_default_parameter,
      sym_typed_default_parameter,
      sym_typed_parameter,
      sym_positional_separator,
      sym_keyword_separator,
  [101406] = 13,
    ACTIONS(2932), 1,
      sym_identifier,
    ACTIONS(2934), 1,
      anon_sym_LPAREN,
    ACTIONS(2936), 1,
      anon_sym_STAR,
    ACTIONS(2940), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2942), 1,
      anon_sym_SLASH,
    ACTIONS(2946), 1,
      anon_sym_COLON,
    STATE(2505), 1,
      sym_tuple_pattern,
    STATE(2507), 1,
      sym_parameter,
    STATE(2761), 1,
      sym_lambda_parameters,
    STATE(2787), 1,
      sym__parameters,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2552), 2,
      sym_list_splat_pattern,
      sym_dictionary_splat_pattern,
    STATE(2549), 5,
      sym_default_parameter,
      sym_typed_default_parameter,
      sym_typed_parameter,
      sym_positional_separator,
      sym_keyword_separator,
  [101452] = 13,
    ACTIONS(2932), 1,
      sym_identifier,
    ACTIONS(2934), 1,
      anon_sym_LPAREN,
    ACTIONS(2936), 1,
      anon_sym_STAR,
    ACTIONS(2940), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2942), 1,
      anon_sym_SLASH,
    ACTIONS(2948), 1,
      anon_sym_COLON,
    STATE(2505), 1,
      sym_tuple_pattern,
    STATE(2507), 1,
      sym_parameter,
    STATE(2787), 1,
      sym__parameters,
    STATE(2790), 1,
      sym_lambda_parameters,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2552), 2,
      sym_list_splat_pattern,
      sym_dictionary_splat_pattern,
    STATE(2549), 5,
      sym_default_parameter,
      sym_typed_default_parameter,
      sym_typed_parameter,
      sym_positional_separator,
      sym_keyword_separator,
  [101498] = 13,
    ACTIONS(2932), 1,
      sym_identifier,
    ACTIONS(2934), 1,
      anon_sym_LPAREN,
    ACTIONS(2936), 1,
      anon_sym_STAR,
    ACTIONS(2940), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2942), 1,
      anon_sym_SLASH,
    ACTIONS(2950), 1,
      anon_sym_COLON,
    STATE(2505), 1,
      sym_tuple_pattern,
    STATE(2507), 1,
      sym_parameter,
    STATE(2686), 1,
      sym_lambda_parameters,
    STATE(2787), 1,
      sym__parameters,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2552), 2,
      sym_list_splat_pattern,
      sym_dictionary_splat_pattern,
    STATE(2549), 5,
      sym_default_parameter,
      sym_typed_default_parameter,
      sym_typed_parameter,
      sym_positional_separator,
      sym_keyword_separator,
  [101544] = 4,
    ACTIONS(2952), 1,
      anon_sym_COMMA,
    STATE(1661), 1,
      aux_sym__patterns_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2907), 15,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [101572] = 13,
    ACTIONS(2932), 1,
      sym_identifier,
    ACTIONS(2934), 1,
      anon_sym_LPAREN,
    ACTIONS(2936), 1,
      anon_sym_STAR,
    ACTIONS(2940), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2942), 1,
      anon_sym_SLASH,
    ACTIONS(2955), 1,
      anon_sym_COLON,
    STATE(2505), 1,
      sym_tuple_pattern,
    STATE(2507), 1,
      sym_parameter,
    STATE(2756), 1,
      sym_lambda_parameters,
    STATE(2787), 1,
      sym__parameters,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2552), 2,
      sym_list_splat_pattern,
      sym_dictionary_splat_pattern,
    STATE(2549), 5,
      sym_default_parameter,
      sym_typed_default_parameter,
      sym_typed_parameter,
      sym_positional_separator,
      sym_keyword_separator,
  [101618] = 13,
    ACTIONS(2932), 1,
      sym_identifier,
    ACTIONS(2934), 1,
      anon_sym_LPAREN,
    ACTIONS(2936), 1,
      anon_sym_STAR,
    ACTIONS(2940), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2942), 1,
      anon_sym_SLASH,
    ACTIONS(2957), 1,
      anon_sym_COLON,
    STATE(2505), 1,
      sym_tuple_pattern,
    STATE(2507), 1,
      sym_parameter,
    STATE(2645), 1,
      sym_lambda_parameters,
    STATE(2787), 1,
      sym__parameters,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2552), 2,
      sym_list_splat_pattern,
      sym_dictionary_splat_pattern,
    STATE(2549), 5,
      sym_default_parameter,
      sym_typed_default_parameter,
      sym_typed_parameter,
      sym_positional_separator,
      sym_keyword_separator,
  [101664] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2907), 17,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [101688] = 13,
    ACTIONS(2932), 1,
      sym_identifier,
    ACTIONS(2934), 1,
      anon_sym_LPAREN,
    ACTIONS(2936), 1,
      anon_sym_STAR,
    ACTIONS(2940), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2942), 1,
      anon_sym_SLASH,
    ACTIONS(2959), 1,
      anon_sym_COLON,
    STATE(2505), 1,
      sym_tuple_pattern,
    STATE(2507), 1,
      sym_parameter,
    STATE(2787), 1,
      sym__parameters,
    STATE(2812), 1,
      sym_lambda_parameters,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2552), 2,
      sym_list_splat_pattern,
      sym_dictionary_splat_pattern,
    STATE(2549), 5,
      sym_default_parameter,
      sym_typed_default_parameter,
      sym_typed_parameter,
      sym_positional_separator,
      sym_keyword_separator,
  [101734] = 5,
    ACTIONS(2963), 1,
      anon_sym_COLON,
    ACTIONS(2965), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2961), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(2967), 13,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [101764] = 13,
    ACTIONS(2932), 1,
      sym_identifier,
    ACTIONS(2934), 1,
      anon_sym_LPAREN,
    ACTIONS(2936), 1,
      anon_sym_STAR,
    ACTIONS(2940), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2942), 1,
      anon_sym_SLASH,
    ACTIONS(2969), 1,
      anon_sym_COLON,
    STATE(2505), 1,
      sym_tuple_pattern,
    STATE(2507), 1,
      sym_parameter,
    STATE(2744), 1,
      sym_lambda_parameters,
    STATE(2787), 1,
      sym__parameters,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2552), 2,
      sym_list_splat_pattern,
      sym_dictionary_splat_pattern,
    STATE(2549), 5,
      sym_default_parameter,
      sym_typed_default_parameter,
      sym_typed_parameter,
      sym_positional_separator,
      sym_keyword_separator,
  [101810] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1558), 17,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [101834] = 13,
    ACTIONS(2932), 1,
      sym_identifier,
    ACTIONS(2934), 1,
      anon_sym_LPAREN,
    ACTIONS(2936), 1,
      anon_sym_STAR,
    ACTIONS(2940), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2942), 1,
      anon_sym_SLASH,
    ACTIONS(2971), 1,
      anon_sym_COLON,
    STATE(2505), 1,
      sym_tuple_pattern,
    STATE(2507), 1,
      sym_parameter,
    STATE(2718), 1,
      sym_lambda_parameters,
    STATE(2787), 1,
      sym__parameters,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2552), 2,
      sym_list_splat_pattern,
      sym_dictionary_splat_pattern,
    STATE(2549), 5,
      sym_default_parameter,
      sym_typed_default_parameter,
      sym_typed_parameter,
      sym_positional_separator,
      sym_keyword_separator,
  [101880] = 6,
    ACTIONS(2963), 1,
      anon_sym_COLON,
    ACTIONS(2965), 1,
      anon_sym_EQ,
    ACTIONS(2973), 1,
      anon_sym_COMMA,
    STATE(1611), 1,
      aux_sym__patterns_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2967), 13,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [101912] = 6,
    ACTIONS(2963), 1,
      anon_sym_COLON,
    ACTIONS(2965), 1,
      anon_sym_EQ,
    ACTIONS(2975), 1,
      anon_sym_COMMA,
    STATE(1675), 1,
      aux_sym__patterns_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2967), 13,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [101944] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2930), 17,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [101968] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2924), 17,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_in,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [101992] = 13,
    ACTIONS(2932), 1,
      sym_identifier,
    ACTIONS(2934), 1,
      anon_sym_LPAREN,
    ACTIONS(2936), 1,
      anon_sym_STAR,
    ACTIONS(2940), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2942), 1,
      anon_sym_SLASH,
    ACTIONS(2977), 1,
      anon_sym_COLON,
    STATE(2505), 1,
      sym_tuple_pattern,
    STATE(2507), 1,
      sym_parameter,
    STATE(2675), 1,
      sym_lambda_parameters,
    STATE(2787), 1,
      sym__parameters,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2552), 2,
      sym_list_splat_pattern,
      sym_dictionary_splat_pattern,
    STATE(2549), 5,
      sym_default_parameter,
      sym_typed_default_parameter,
      sym_typed_parameter,
      sym_positional_separator,
      sym_keyword_separator,
  [102038] = 4,
    ACTIONS(2979), 1,
      anon_sym_COMMA,
    STATE(1661), 1,
      aux_sym__patterns_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(970), 15,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [102066] = 12,
    ACTIONS(2981), 1,
      sym_identifier,
    ACTIONS(2983), 1,
      anon_sym_LPAREN,
    ACTIONS(2985), 1,
      anon_sym_RPAREN,
    ACTIONS(2987), 1,
      anon_sym_STAR,
    ACTIONS(2989), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2991), 1,
      anon_sym_SLASH,
    STATE(2459), 1,
      sym_tuple_pattern,
    STATE(2479), 1,
      sym_parameter,
    STATE(2742), 1,
      sym__parameters,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2525), 2,
      sym_list_splat_pattern,
      sym_dictionary_splat_pattern,
    STATE(2570), 5,
      sym_default_parameter,
      sym_typed_default_parameter,
      sym_typed_parameter,
      sym_positional_separator,
      sym_keyword_separator,
  [102109] = 11,
    ACTIONS(2932), 1,
      sym_identifier,
    ACTIONS(2934), 1,
      anon_sym_LPAREN,
    ACTIONS(2936), 1,
      anon_sym_STAR,
    ACTIONS(2940), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2942), 1,
      anon_sym_SLASH,
    ACTIONS(2993), 1,
      anon_sym_COLON,
    STATE(2505), 1,
      sym_tuple_pattern,
    STATE(2577), 1,
      sym_parameter,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2552), 2,
      sym_list_splat_pattern,
      sym_dictionary_splat_pattern,
    STATE(2549), 5,
      sym_default_parameter,
      sym_typed_default_parameter,
      sym_typed_parameter,
      sym_positional_separator,
      sym_keyword_separator,
  [102149] = 11,
    ACTIONS(2981), 1,
      sym_identifier,
    ACTIONS(2983), 1,
      anon_sym_LPAREN,
    ACTIONS(2987), 1,
      anon_sym_STAR,
    ACTIONS(2989), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2991), 1,
      anon_sym_SLASH,
    ACTIONS(2995), 1,
      anon_sym_RPAREN,
    STATE(2459), 1,
      sym_tuple_pattern,
    STATE(2564), 1,
      sym_parameter,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2525), 2,
      sym_list_splat_pattern,
      sym_dictionary_splat_pattern,
    STATE(2570), 5,
      sym_default_parameter,
      sym_typed_default_parameter,
      sym_typed_parameter,
      sym_positional_separator,
      sym_keyword_separator,
  [102189] = 4,
    ACTIONS(2963), 1,
      anon_sym_COLON,
    ACTIONS(2965), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2967), 13,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_AT_EQ,
      anon_sym_SLASH_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_STAR_STAR_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [102215] = 11,
    ACTIONS(2932), 1,
      sym_identifier,
    ACTIONS(2934), 1,
      anon_sym_LPAREN,
    ACTIONS(2936), 1,
      anon_sym_STAR,
    ACTIONS(2940), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2942), 1,
      anon_sym_SLASH,
    ACTIONS(2995), 1,
      anon_sym_COLON,
    STATE(2505), 1,
      sym_tuple_pattern,
    STATE(2577), 1,
      sym_parameter,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2552), 2,
      sym_list_splat_pattern,
      sym_dictionary_splat_pattern,
    STATE(2549), 5,
      sym_default_parameter,
      sym_typed_default_parameter,
      sym_typed_parameter,
      sym_positional_separator,
      sym_keyword_separator,
  [102255] = 11,
    ACTIONS(2981), 1,
      sym_identifier,
    ACTIONS(2983), 1,
      anon_sym_LPAREN,
    ACTIONS(2987), 1,
      anon_sym_STAR,
    ACTIONS(2989), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2991), 1,
      anon_sym_SLASH,
    ACTIONS(2993), 1,
      anon_sym_RPAREN,
    STATE(2459), 1,
      sym_tuple_pattern,
    STATE(2564), 1,
      sym_parameter,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2525), 2,
      sym_list_splat_pattern,
      sym_dictionary_splat_pattern,
    STATE(2570), 5,
      sym_default_parameter,
      sym_typed_default_parameter,
      sym_typed_parameter,
      sym_positional_separator,
      sym_keyword_separator,
  [102295] = 10,
    ACTIONS(2932), 1,
      sym_identifier,
    ACTIONS(2934), 1,
      anon_sym_LPAREN,
    ACTIONS(2936), 1,
      anon_sym_STAR,
    ACTIONS(2940), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2942), 1,
      anon_sym_SLASH,
    STATE(2505), 1,
      sym_tuple_pattern,
    STATE(2577), 1,
      sym_parameter,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2552), 2,
      sym_list_splat_pattern,
      sym_dictionary_splat_pattern,
    STATE(2549), 5,
      sym_default_parameter,
      sym_typed_default_parameter,
      sym_typed_parameter,
      sym_positional_separator,
      sym_keyword_separator,
  [102332] = 10,
    ACTIONS(2981), 1,
      sym_identifier,
    ACTIONS(2983), 1,
      anon_sym_LPAREN,
    ACTIONS(2987), 1,
      anon_sym_STAR,
    ACTIONS(2989), 1,
      anon_sym_STAR_STAR,
    ACTIONS(2991), 1,
      anon_sym_SLASH,
    STATE(2459), 1,
      sym_tuple_pattern,
    STATE(2564), 1,
      sym_parameter,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2525), 2,
      sym_list_splat_pattern,
      sym_dictionary_splat_pattern,
    STATE(2570), 5,
      sym_default_parameter,
      sym_typed_default_parameter,
      sym_typed_parameter,
      sym_positional_separator,
      sym_keyword_separator,
  [102369] = 13,
    ACTIONS(2997), 1,
      anon_sym_COMMA,
    ACTIONS(2999), 1,
      anon_sym_as,
    ACTIONS(3001), 1,
      anon_sym_if,
    ACTIONS(3003), 1,
      anon_sym_COLON,
    ACTIONS(3005), 1,
      anon_sym_async,
    ACTIONS(3007), 1,
      anon_sym_for,
    ACTIONS(3009), 1,
      anon_sym_RBRACE,
    ACTIONS(3011), 1,
      anon_sym_and,
    ACTIONS(3013), 1,
      anon_sym_or,
    STATE(1891), 1,
      sym_for_in_clause,
    STATE(2293), 1,
      aux_sym__collection_elements_repeat1,
    STATE(2765), 1,
      sym__comprehension_clauses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [102410] = 4,
    ACTIONS(3017), 1,
      anon_sym_and,
    ACTIONS(3019), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3015), 10,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PIPE,
  [102433] = 13,
    ACTIONS(2997), 1,
      anon_sym_COMMA,
    ACTIONS(2999), 1,
      anon_sym_as,
    ACTIONS(3001), 1,
      anon_sym_if,
    ACTIONS(3003), 1,
      anon_sym_COLON,
    ACTIONS(3005), 1,
      anon_sym_async,
    ACTIONS(3007), 1,
      anon_sym_for,
    ACTIONS(3009), 1,
      anon_sym_RBRACE,
    ACTIONS(3011), 1,
      anon_sym_and,
    ACTIONS(3013), 1,
      anon_sym_or,
    STATE(1891), 1,
      sym_for_in_clause,
    STATE(2293), 1,
      aux_sym__collection_elements_repeat1,
    STATE(2786), 1,
      sym__comprehension_clauses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [102474] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2191), 12,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_and,
      anon_sym_or,
  [102493] = 3,
    ACTIONS(3017), 1,
      anon_sym_and,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3021), 11,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_or,
  [102514] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3021), 12,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_and,
      anon_sym_or,
  [102533] = 13,
    ACTIONS(2997), 1,
      anon_sym_COMMA,
    ACTIONS(2999), 1,
      anon_sym_as,
    ACTIONS(3001), 1,
      anon_sym_if,
    ACTIONS(3003), 1,
      anon_sym_COLON,
    ACTIONS(3005), 1,
      anon_sym_async,
    ACTIONS(3007), 1,
      anon_sym_for,
    ACTIONS(3009), 1,
      anon_sym_RBRACE,
    ACTIONS(3011), 1,
      anon_sym_and,
    ACTIONS(3013), 1,
      anon_sym_or,
    STATE(1891), 1,
      sym_for_in_clause,
    STATE(2293), 1,
      aux_sym__collection_elements_repeat1,
    STATE(2655), 1,
      sym__comprehension_clauses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [102574] = 13,
    ACTIONS(2997), 1,
      anon_sym_COMMA,
    ACTIONS(2999), 1,
      anon_sym_as,
    ACTIONS(3001), 1,
      anon_sym_if,
    ACTIONS(3003), 1,
      anon_sym_COLON,
    ACTIONS(3005), 1,
      anon_sym_async,
    ACTIONS(3007), 1,
      anon_sym_for,
    ACTIONS(3009), 1,
      anon_sym_RBRACE,
    ACTIONS(3011), 1,
      anon_sym_and,
    ACTIONS(3013), 1,
      anon_sym_or,
    STATE(1891), 1,
      sym_for_in_clause,
    STATE(2293), 1,
      aux_sym__collection_elements_repeat1,
    STATE(2668), 1,
      sym__comprehension_clauses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [102615] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3023), 12,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_and,
      anon_sym_or,
  [102634] = 6,
    ACTIONS(3017), 1,
      anon_sym_and,
    ACTIONS(3019), 1,
      anon_sym_or,
    ACTIONS(3027), 1,
      anon_sym_as,
    ACTIONS(3029), 1,
      anon_sym_if,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3025), 8,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PIPE,
  [102661] = 13,
    ACTIONS(2997), 1,
      anon_sym_COMMA,
    ACTIONS(2999), 1,
      anon_sym_as,
    ACTIONS(3001), 1,
      anon_sym_if,
    ACTIONS(3003), 1,
      anon_sym_COLON,
    ACTIONS(3005), 1,
      anon_sym_async,
    ACTIONS(3007), 1,
      anon_sym_for,
    ACTIONS(3009), 1,
      anon_sym_RBRACE,
    ACTIONS(3011), 1,
      anon_sym_and,
    ACTIONS(3013), 1,
      anon_sym_or,
    STATE(1891), 1,
      sym_for_in_clause,
    STATE(2293), 1,
      aux_sym__collection_elements_repeat1,
    STATE(2643), 1,
      sym__comprehension_clauses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [102702] = 13,
    ACTIONS(2997), 1,
      anon_sym_COMMA,
    ACTIONS(2999), 1,
      anon_sym_as,
    ACTIONS(3001), 1,
      anon_sym_if,
    ACTIONS(3003), 1,
      anon_sym_COLON,
    ACTIONS(3005), 1,
      anon_sym_async,
    ACTIONS(3007), 1,
      anon_sym_for,
    ACTIONS(3009), 1,
      anon_sym_RBRACE,
    ACTIONS(3011), 1,
      anon_sym_and,
    ACTIONS(3013), 1,
      anon_sym_or,
    STATE(1891), 1,
      sym_for_in_clause,
    STATE(2293), 1,
      aux_sym__collection_elements_repeat1,
    STATE(2669), 1,
      sym__comprehension_clauses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [102743] = 6,
    ACTIONS(3017), 1,
      anon_sym_and,
    ACTIONS(3019), 1,
      anon_sym_or,
    ACTIONS(3027), 1,
      anon_sym_as,
    ACTIONS(3029), 1,
      anon_sym_if,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3031), 8,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PIPE,
  [102770] = 5,
    ACTIONS(3017), 1,
      anon_sym_and,
    ACTIONS(3019), 1,
      anon_sym_or,
    ACTIONS(3035), 1,
      anon_sym_as,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3033), 9,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PIPE,
  [102795] = 13,
    ACTIONS(2997), 1,
      anon_sym_COMMA,
    ACTIONS(2999), 1,
      anon_sym_as,
    ACTIONS(3001), 1,
      anon_sym_if,
    ACTIONS(3003), 1,
      anon_sym_COLON,
    ACTIONS(3005), 1,
      anon_sym_async,
    ACTIONS(3007), 1,
      anon_sym_for,
    ACTIONS(3009), 1,
      anon_sym_RBRACE,
    ACTIONS(3011), 1,
      anon_sym_and,
    ACTIONS(3013), 1,
      anon_sym_or,
    STATE(1891), 1,
      sym_for_in_clause,
    STATE(2293), 1,
      aux_sym__collection_elements_repeat1,
    STATE(2766), 1,
      sym__comprehension_clauses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [102836] = 6,
    ACTIONS(3017), 1,
      anon_sym_and,
    ACTIONS(3019), 1,
      anon_sym_or,
    ACTIONS(3027), 1,
      anon_sym_as,
    ACTIONS(3029), 1,
      anon_sym_if,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3038), 8,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_from,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PIPE,
  [102863] = 13,
    ACTIONS(2997), 1,
      anon_sym_COMMA,
    ACTIONS(2999), 1,
      anon_sym_as,
    ACTIONS(3001), 1,
      anon_sym_if,
    ACTIONS(3003), 1,
      anon_sym_COLON,
    ACTIONS(3005), 1,
      anon_sym_async,
    ACTIONS(3007), 1,
      anon_sym_for,
    ACTIONS(3009), 1,
      anon_sym_RBRACE,
    ACTIONS(3011), 1,
      anon_sym_and,
    ACTIONS(3013), 1,
      anon_sym_or,
    STATE(1891), 1,
      sym_for_in_clause,
    STATE(2293), 1,
      aux_sym__collection_elements_repeat1,
    STATE(2785), 1,
      sym__comprehension_clauses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [102904] = 12,
    ACTIONS(3009), 1,
      anon_sym_RBRACK,
    ACTIONS(3040), 1,
      anon_sym_COMMA,
    ACTIONS(3042), 1,
      anon_sym_as,
    ACTIONS(3044), 1,
      anon_sym_if,
    ACTIONS(3046), 1,
      anon_sym_async,
    ACTIONS(3048), 1,
      anon_sym_for,
    ACTIONS(3050), 1,
      anon_sym_and,
    ACTIONS(3052), 1,
      anon_sym_or,
    STATE(1897), 1,
      sym_for_in_clause,
    STATE(2434), 1,
      aux_sym__collection_elements_repeat1,
    STATE(2661), 1,
      sym__comprehension_clauses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [102942] = 12,
    ACTIONS(3009), 1,
      anon_sym_RBRACK,
    ACTIONS(3040), 1,
      anon_sym_COMMA,
    ACTIONS(3042), 1,
      anon_sym_as,
    ACTIONS(3044), 1,
      anon_sym_if,
    ACTIONS(3046), 1,
      anon_sym_async,
    ACTIONS(3048), 1,
      anon_sym_for,
    ACTIONS(3050), 1,
      anon_sym_and,
    ACTIONS(3052), 1,
      anon_sym_or,
    STATE(1897), 1,
      sym_for_in_clause,
    STATE(2434), 1,
      aux_sym__collection_elements_repeat1,
    STATE(2799), 1,
      sym__comprehension_clauses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [102980] = 12,
    ACTIONS(3009), 1,
      anon_sym_RBRACK,
    ACTIONS(3040), 1,
      anon_sym_COMMA,
    ACTIONS(3042), 1,
      anon_sym_as,
    ACTIONS(3044), 1,
      anon_sym_if,
    ACTIONS(3046), 1,
      anon_sym_async,
    ACTIONS(3048), 1,
      anon_sym_for,
    ACTIONS(3050), 1,
      anon_sym_and,
    ACTIONS(3052), 1,
      anon_sym_or,
    STATE(1897), 1,
      sym_for_in_clause,
    STATE(2434), 1,
      aux_sym__collection_elements_repeat1,
    STATE(2634), 1,
      sym__comprehension_clauses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [103018] = 12,
    ACTIONS(3054), 1,
      anon_sym_RPAREN,
    ACTIONS(3056), 1,
      anon_sym_COMMA,
    ACTIONS(3058), 1,
      anon_sym_as,
    ACTIONS(3060), 1,
      anon_sym_if,
    ACTIONS(3062), 1,
      anon_sym_async,
    ACTIONS(3064), 1,
      anon_sym_for,
    ACTIONS(3066), 1,
      anon_sym_and,
    ACTIONS(3068), 1,
      anon_sym_or,
    STATE(1904), 1,
      sym_for_in_clause,
    STATE(2490), 1,
      aux_sym_argument_list_repeat1,
    STATE(2630), 1,
      sym__comprehension_clauses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [103056] = 12,
    ACTIONS(3058), 1,
      anon_sym_as,
    ACTIONS(3060), 1,
      anon_sym_if,
    ACTIONS(3062), 1,
      anon_sym_async,
    ACTIONS(3064), 1,
      anon_sym_for,
    ACTIONS(3066), 1,
      anon_sym_and,
    ACTIONS(3068), 1,
      anon_sym_or,
    ACTIONS(3070), 1,
      anon_sym_RPAREN,
    ACTIONS(3072), 1,
      anon_sym_COMMA,
    STATE(1904), 1,
      sym_for_in_clause,
    STATE(2504), 1,
      aux_sym_argument_list_repeat1,
    STATE(2760), 1,
      sym__comprehension_clauses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [103094] = 12,
    ACTIONS(3058), 1,
      anon_sym_as,
    ACTIONS(3060), 1,
      anon_sym_if,
    ACTIONS(3062), 1,
      anon_sym_async,
    ACTIONS(3064), 1,
      anon_sym_for,
    ACTIONS(3066), 1,
      anon_sym_and,
    ACTIONS(3068), 1,
      anon_sym_or,
    ACTIONS(3074), 1,
      anon_sym_RPAREN,
    ACTIONS(3076), 1,
      anon_sym_COMMA,
    STATE(1904), 1,
      sym_for_in_clause,
    STATE(2318), 1,
      aux_sym__collection_elements_repeat1,
    STATE(2703), 1,
      sym__comprehension_clauses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [103132] = 12,
    ACTIONS(3058), 1,
      anon_sym_as,
    ACTIONS(3060), 1,
      anon_sym_if,
    ACTIONS(3062), 1,
      anon_sym_async,
    ACTIONS(3064), 1,
      anon_sym_for,
    ACTIONS(3066), 1,
      anon_sym_and,
    ACTIONS(3068), 1,
      anon_sym_or,
    ACTIONS(3076), 1,
      anon_sym_COMMA,
    ACTIONS(3078), 1,
      anon_sym_RPAREN,
    STATE(1904), 1,
      sym_for_in_clause,
    STATE(2318), 1,
      aux_sym__collection_elements_repeat1,
    STATE(2773), 1,
      sym__comprehension_clauses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [103170] = 12,
    ACTIONS(3058), 1,
      anon_sym_as,
    ACTIONS(3060), 1,
      anon_sym_if,
    ACTIONS(3062), 1,
      anon_sym_async,
    ACTIONS(3064), 1,
      anon_sym_for,
    ACTIONS(3066), 1,
      anon_sym_and,
    ACTIONS(3068), 1,
      anon_sym_or,
    ACTIONS(3076), 1,
      anon_sym_COMMA,
    ACTIONS(3080), 1,
      anon_sym_RPAREN,
    STATE(1904), 1,
      sym_for_in_clause,
    STATE(2318), 1,
      aux_sym__collection_elements_repeat1,
    STATE(2760), 1,
      sym__comprehension_clauses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [103208] = 9,
    ACTIONS(3017), 1,
      anon_sym_and,
    ACTIONS(3019), 1,
      anon_sym_or,
    ACTIONS(3027), 1,
      anon_sym_as,
    ACTIONS(3029), 1,
      anon_sym_if,
    ACTIONS(3086), 1,
      anon_sym_COMMA,
    STATE(2160), 1,
      aux_sym_assert_statement_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3082), 2,
      sym__newline,
      anon_sym_SEMI,
    ACTIONS(3084), 3,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_PIPE,
  [103240] = 12,
    ACTIONS(3009), 1,
      anon_sym_RBRACK,
    ACTIONS(3040), 1,
      anon_sym_COMMA,
    ACTIONS(3042), 1,
      anon_sym_as,
    ACTIONS(3044), 1,
      anon_sym_if,
    ACTIONS(3046), 1,
      anon_sym_async,
    ACTIONS(3048), 1,
      anon_sym_for,
    ACTIONS(3050), 1,
      anon_sym_and,
    ACTIONS(3052), 1,
      anon_sym_or,
    STATE(1897), 1,
      sym_for_in_clause,
    STATE(2434), 1,
      aux_sym__collection_elements_repeat1,
    STATE(2699), 1,
      sym__comprehension_clauses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [103278] = 12,
    ACTIONS(3058), 1,
      anon_sym_as,
    ACTIONS(3060), 1,
      anon_sym_if,
    ACTIONS(3062), 1,
      anon_sym_async,
    ACTIONS(3064), 1,
      anon_sym_for,
    ACTIONS(3066), 1,
      anon_sym_and,
    ACTIONS(3068), 1,
      anon_sym_or,
    ACTIONS(3088), 1,
      anon_sym_RPAREN,
    ACTIONS(3090), 1,
      anon_sym_COMMA,
    STATE(1904), 1,
      sym_for_in_clause,
    STATE(2448), 1,
      aux_sym_argument_list_repeat1,
    STATE(2703), 1,
      sym__comprehension_clauses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [103316] = 12,
    ACTIONS(3058), 1,
      anon_sym_as,
    ACTIONS(3060), 1,
      anon_sym_if,
    ACTIONS(3062), 1,
      anon_sym_async,
    ACTIONS(3064), 1,
      anon_sym_for,
    ACTIONS(3066), 1,
      anon_sym_and,
    ACTIONS(3068), 1,
      anon_sym_or,
    ACTIONS(3076), 1,
      anon_sym_COMMA,
    ACTIONS(3092), 1,
      anon_sym_RPAREN,
    STATE(1904), 1,
      sym_for_in_clause,
    STATE(2318), 1,
      aux_sym__collection_elements_repeat1,
    STATE(2674), 1,
      sym__comprehension_clauses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [103354] = 12,
    ACTIONS(3058), 1,
      anon_sym_as,
    ACTIONS(3060), 1,
      anon_sym_if,
    ACTIONS(3062), 1,
      anon_sym_async,
    ACTIONS(3064), 1,
      anon_sym_for,
    ACTIONS(3066), 1,
      anon_sym_and,
    ACTIONS(3068), 1,
      anon_sym_or,
    ACTIONS(3076), 1,
      anon_sym_COMMA,
    ACTIONS(3094), 1,
      anon_sym_RPAREN,
    STATE(1904), 1,
      sym_for_in_clause,
    STATE(2318), 1,
      aux_sym__collection_elements_repeat1,
    STATE(2630), 1,
      sym__comprehension_clauses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [103392] = 12,
    ACTIONS(3009), 1,
      anon_sym_RBRACK,
    ACTIONS(3040), 1,
      anon_sym_COMMA,
    ACTIONS(3042), 1,
      anon_sym_as,
    ACTIONS(3044), 1,
      anon_sym_if,
    ACTIONS(3046), 1,
      anon_sym_async,
    ACTIONS(3048), 1,
      anon_sym_for,
    ACTIONS(3050), 1,
      anon_sym_and,
    ACTIONS(3052), 1,
      anon_sym_or,
    STATE(1897), 1,
      sym_for_in_clause,
    STATE(2434), 1,
      aux_sym__collection_elements_repeat1,
    STATE(2764), 1,
      sym__comprehension_clauses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [103430] = 12,
    ACTIONS(3009), 1,
      anon_sym_RBRACK,
    ACTIONS(3040), 1,
      anon_sym_COMMA,
    ACTIONS(3042), 1,
      anon_sym_as,
    ACTIONS(3044), 1,
      anon_sym_if,
    ACTIONS(3046), 1,
      anon_sym_async,
    ACTIONS(3048), 1,
      anon_sym_for,
    ACTIONS(3050), 1,
      anon_sym_and,
    ACTIONS(3052), 1,
      anon_sym_or,
    STATE(1897), 1,
      sym_for_in_clause,
    STATE(2434), 1,
      aux_sym__collection_elements_repeat1,
    STATE(2652), 1,
      sym__comprehension_clauses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [103468] = 12,
    ACTIONS(3058), 1,
      anon_sym_as,
    ACTIONS(3060), 1,
      anon_sym_if,
    ACTIONS(3062), 1,
      anon_sym_async,
    ACTIONS(3064), 1,
      anon_sym_for,
    ACTIONS(3066), 1,
      anon_sym_and,
    ACTIONS(3068), 1,
      anon_sym_or,
    ACTIONS(3096), 1,
      anon_sym_RPAREN,
    ACTIONS(3098), 1,
      anon_sym_COMMA,
    STATE(1904), 1,
      sym_for_in_clause,
    STATE(2396), 1,
      aux_sym_argument_list_repeat1,
    STATE(2651), 1,
      sym__comprehension_clauses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [103506] = 12,
    ACTIONS(3058), 1,
      anon_sym_as,
    ACTIONS(3060), 1,
      anon_sym_if,
    ACTIONS(3062), 1,
      anon_sym_async,
    ACTIONS(3064), 1,
      anon_sym_for,
    ACTIONS(3066), 1,
      anon_sym_and,
    ACTIONS(3068), 1,
      anon_sym_or,
    ACTIONS(3100), 1,
      anon_sym_RPAREN,
    ACTIONS(3102), 1,
      anon_sym_COMMA,
    STATE(1904), 1,
      sym_for_in_clause,
    STATE(2318), 1,
      aux_sym__collection_elements_repeat1,
    STATE(2793), 1,
      sym__comprehension_clauses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [103544] = 12,
    ACTIONS(3058), 1,
      anon_sym_as,
    ACTIONS(3060), 1,
      anon_sym_if,
    ACTIONS(3062), 1,
      anon_sym_async,
    ACTIONS(3064), 1,
      anon_sym_for,
    ACTIONS(3066), 1,
      anon_sym_and,
    ACTIONS(3068), 1,
      anon_sym_or,
    ACTIONS(3076), 1,
      anon_sym_COMMA,
    ACTIONS(3105), 1,
      anon_sym_RPAREN,
    STATE(1904), 1,
      sym_for_in_clause,
    STATE(2318), 1,
      aux_sym__collection_elements_repeat1,
    STATE(2651), 1,
      sym__comprehension_clauses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [103582] = 12,
    ACTIONS(3058), 1,
      anon_sym_as,
    ACTIONS(3060), 1,
      anon_sym_if,
    ACTIONS(3062), 1,
      anon_sym_async,
    ACTIONS(3064), 1,
      anon_sym_for,
    ACTIONS(3066), 1,
      anon_sym_and,
    ACTIONS(3068), 1,
      anon_sym_or,
    ACTIONS(3076), 1,
      anon_sym_COMMA,
    ACTIONS(3100), 1,
      anon_sym_RPAREN,
    STATE(1904), 1,
      sym_for_in_clause,
    STATE(2318), 1,
      aux_sym__collection_elements_repeat1,
    STATE(2793), 1,
      sym__comprehension_clauses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [103620] = 12,
    ACTIONS(3058), 1,
      anon_sym_as,
    ACTIONS(3060), 1,
      anon_sym_if,
    ACTIONS(3062), 1,
      anon_sym_async,
    ACTIONS(3064), 1,
      anon_sym_for,
    ACTIONS(3066), 1,
      anon_sym_and,
    ACTIONS(3068), 1,
      anon_sym_or,
    ACTIONS(3107), 1,
      anon_sym_RPAREN,
    ACTIONS(3109), 1,
      anon_sym_COMMA,
    STATE(1904), 1,
      sym_for_in_clause,
    STATE(2307), 1,
      aux_sym_argument_list_repeat1,
    STATE(2793), 1,
      sym__comprehension_clauses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [103658] = 12,
    ACTIONS(3058), 1,
      anon_sym_as,
    ACTIONS(3060), 1,
      anon_sym_if,
    ACTIONS(3062), 1,
      anon_sym_async,
    ACTIONS(3064), 1,
      anon_sym_for,
    ACTIONS(3066), 1,
      anon_sym_and,
    ACTIONS(3068), 1,
      anon_sym_or,
    ACTIONS(3111), 1,
      anon_sym_RPAREN,
    ACTIONS(3113), 1,
      anon_sym_COMMA,
    STATE(1904), 1,
      sym_for_in_clause,
    STATE(2412), 1,
      aux_sym_argument_list_repeat1,
    STATE(2674), 1,
      sym__comprehension_clauses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [103696] = 12,
    ACTIONS(3058), 1,
      anon_sym_as,
    ACTIONS(3060), 1,
      anon_sym_if,
    ACTIONS(3062), 1,
      anon_sym_async,
    ACTIONS(3064), 1,
      anon_sym_for,
    ACTIONS(3066), 1,
      anon_sym_and,
    ACTIONS(3068), 1,
      anon_sym_or,
    ACTIONS(3076), 1,
      anon_sym_COMMA,
    ACTIONS(3115), 1,
      anon_sym_RPAREN,
    STATE(1904), 1,
      sym_for_in_clause,
    STATE(2318), 1,
      aux_sym__collection_elements_repeat1,
    STATE(2663), 1,
      sym__comprehension_clauses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [103734] = 12,
    ACTIONS(3009), 1,
      anon_sym_RBRACK,
    ACTIONS(3040), 1,
      anon_sym_COMMA,
    ACTIONS(3042), 1,
      anon_sym_as,
    ACTIONS(3044), 1,
      anon_sym_if,
    ACTIONS(3046), 1,
      anon_sym_async,
    ACTIONS(3048), 1,
      anon_sym_for,
    ACTIONS(3050), 1,
      anon_sym_and,
    ACTIONS(3052), 1,
      anon_sym_or,
    STATE(1897), 1,
      sym_for_in_clause,
    STATE(2434), 1,
      aux_sym__collection_elements_repeat1,
    STATE(2672), 1,
      sym__comprehension_clauses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [103772] = 12,
    ACTIONS(3058), 1,
      anon_sym_as,
    ACTIONS(3060), 1,
      anon_sym_if,
    ACTIONS(3062), 1,
      anon_sym_async,
    ACTIONS(3064), 1,
      anon_sym_for,
    ACTIONS(3066), 1,
      anon_sym_and,
    ACTIONS(3068), 1,
      anon_sym_or,
    ACTIONS(3117), 1,
      anon_sym_RPAREN,
    ACTIONS(3119), 1,
      anon_sym_COMMA,
    STATE(1904), 1,
      sym_for_in_clause,
    STATE(2431), 1,
      aux_sym_argument_list_repeat1,
    STATE(2773), 1,
      sym__comprehension_clauses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [103810] = 12,
    ACTIONS(3009), 1,
      anon_sym_RBRACK,
    ACTIONS(3040), 1,
      anon_sym_COMMA,
    ACTIONS(3042), 1,
      anon_sym_as,
    ACTIONS(3044), 1,
      anon_sym_if,
    ACTIONS(3046), 1,
      anon_sym_async,
    ACTIONS(3048), 1,
      anon_sym_for,
    ACTIONS(3050), 1,
      anon_sym_and,
    ACTIONS(3052), 1,
      anon_sym_or,
    STATE(1897), 1,
      sym_for_in_clause,
    STATE(2434), 1,
      aux_sym__collection_elements_repeat1,
    STATE(2788), 1,
      sym__comprehension_clauses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [103848] = 12,
    ACTIONS(3058), 1,
      anon_sym_as,
    ACTIONS(3060), 1,
      anon_sym_if,
    ACTIONS(3062), 1,
      anon_sym_async,
    ACTIONS(3064), 1,
      anon_sym_for,
    ACTIONS(3066), 1,
      anon_sym_and,
    ACTIONS(3068), 1,
      anon_sym_or,
    ACTIONS(3121), 1,
      anon_sym_RPAREN,
    ACTIONS(3123), 1,
      anon_sym_COMMA,
    STATE(1904), 1,
      sym_for_in_clause,
    STATE(2520), 1,
      aux_sym_argument_list_repeat1,
    STATE(2663), 1,
      sym__comprehension_clauses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [103886] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_line_continuation,
    ACTIONS(3125), 1,
      anon_sym_LBRACE,
    ACTIONS(3129), 1,
      sym__not_escape_sequence,
    ACTIONS(3131), 1,
      sym_string_end,
    STATE(1883), 1,
      aux_sym_string_content_repeat1,
    ACTIONS(3127), 3,
      sym__string_content,
      sym_escape_interpolation,
      sym_escape_sequence,
    STATE(1728), 3,
      sym_string_content,
      sym_interpolation,
      aux_sym_string_repeat1,
  [103915] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_line_continuation,
    ACTIONS(3125), 1,
      anon_sym_LBRACE,
    ACTIONS(3129), 1,
      sym__not_escape_sequence,
    ACTIONS(3133), 1,
      sym_string_end,
    STATE(1883), 1,
      aux_sym_string_content_repeat1,
    ACTIONS(3127), 3,
      sym__string_content,
      sym_escape_interpolation,
      sym_escape_sequence,
    STATE(1761), 3,
      sym_string_content,
      sym_interpolation,
      aux_sym_string_repeat1,
  [103944] = 6,
    ACTIONS(3135), 1,
      anon_sym_as,
    ACTIONS(3137), 1,
      anon_sym_if,
    ACTIONS(3139), 1,
      anon_sym_and,
    ACTIONS(3141), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3025), 6,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PIPE,
  [103969] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_line_continuation,
    ACTIONS(3125), 1,
      anon_sym_LBRACE,
    ACTIONS(3129), 1,
      sym__not_escape_sequence,
    ACTIONS(3143), 1,
      sym_string_end,
    STATE(1883), 1,
      aux_sym_string_content_repeat1,
    ACTIONS(3127), 3,
      sym__string_content,
      sym_escape_interpolation,
      sym_escape_sequence,
    STATE(1743), 3,
      sym_string_content,
      sym_interpolation,
      aux_sym_string_repeat1,
  [103998] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_line_continuation,
    ACTIONS(3125), 1,
      anon_sym_LBRACE,
    ACTIONS(3129), 1,
      sym__not_escape_sequence,
    ACTIONS(3145), 1,
      sym_string_end,
    STATE(1883), 1,
      aux_sym_string_content_repeat1,
    ACTIONS(3127), 3,
      sym__string_content,
      sym_escape_interpolation,
      sym_escape_sequence,
    STATE(1761), 3,
      sym_string_content,
      sym_interpolation,
      aux_sym_string_repeat1,
  [104027] = 8,
    ACTIONS(3147), 1,
      anon_sym_COMMA,
    ACTIONS(3149), 1,
      anon_sym_as,
    ACTIONS(3151), 1,
      anon_sym_if,
    ACTIONS(3155), 1,
      anon_sym_and,
    ACTIONS(3157), 1,
      anon_sym_or,
    STATE(1981), 1,
      aux_sym_assert_statement_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3153), 4,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACE,
      sym_type_conversion,
  [104056] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_line_continuation,
    ACTIONS(3125), 1,
      anon_sym_LBRACE,
    ACTIONS(3129), 1,
      sym__not_escape_sequence,
    ACTIONS(3159), 1,
      sym_string_end,
    STATE(1883), 1,
      aux_sym_string_content_repeat1,
    ACTIONS(3127), 3,
      sym__string_content,
      sym_escape_interpolation,
      sym_escape_sequence,
    STATE(1761), 3,
      sym_string_content,
      sym_interpolation,
      aux_sym_string_repeat1,
  [104085] = 5,
    ACTIONS(3139), 1,
      anon_sym_and,
    ACTIONS(3141), 1,
      anon_sym_or,
    ACTIONS(3161), 1,
      anon_sym_as,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3033), 7,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PIPE,
  [104108] = 4,
    ACTIONS(3139), 1,
      anon_sym_and,
    ACTIONS(3141), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3015), 8,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PIPE,
  [104129] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_line_continuation,
    ACTIONS(3125), 1,
      anon_sym_LBRACE,
    ACTIONS(3129), 1,
      sym__not_escape_sequence,
    ACTIONS(3164), 1,
      sym_string_end,
    STATE(1883), 1,
      aux_sym_string_content_repeat1,
    ACTIONS(3127), 3,
      sym__string_content,
      sym_escape_interpolation,
      sym_escape_sequence,
    STATE(1756), 3,
      sym_string_content,
      sym_interpolation,
      aux_sym_string_repeat1,
  [104158] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3023), 10,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_and,
      anon_sym_or,
  [104175] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3021), 10,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_and,
      anon_sym_or,
  [104192] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_line_continuation,
    ACTIONS(3125), 1,
      anon_sym_LBRACE,
    ACTIONS(3129), 1,
      sym__not_escape_sequence,
    ACTIONS(3166), 1,
      sym_string_end,
    STATE(1883), 1,
      aux_sym_string_content_repeat1,
    ACTIONS(3127), 3,
      sym__string_content,
      sym_escape_interpolation,
      sym_escape_sequence,
    STATE(1761), 3,
      sym_string_content,
      sym_interpolation,
      aux_sym_string_repeat1,
  [104221] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3023), 10,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_and,
      anon_sym_or,
  [104238] = 6,
    ACTIONS(3168), 1,
      anon_sym_as,
    ACTIONS(3170), 1,
      anon_sym_if,
    ACTIONS(3172), 1,
      anon_sym_and,
    ACTIONS(3174), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3038), 6,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_EQ,
      anon_sym_PIPE,
  [104263] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_line_continuation,
    ACTIONS(3125), 1,
      anon_sym_LBRACE,
    ACTIONS(3129), 1,
      sym__not_escape_sequence,
    ACTIONS(3176), 1,
      sym_string_end,
    STATE(1883), 1,
      aux_sym_string_content_repeat1,
    ACTIONS(3127), 3,
      sym__string_content,
      sym_escape_interpolation,
      sym_escape_sequence,
    STATE(1731), 3,
      sym_string_content,
      sym_interpolation,
      aux_sym_string_repeat1,
  [104292] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_line_continuation,
    ACTIONS(3125), 1,
      anon_sym_LBRACE,
    ACTIONS(3129), 1,
      sym__not_escape_sequence,
    ACTIONS(3178), 1,
      sym_string_end,
    STATE(1883), 1,
      aux_sym_string_content_repeat1,
    ACTIONS(3127), 3,
      sym__string_content,
      sym_escape_interpolation,
      sym_escape_sequence,
    STATE(1761), 3,
      sym_string_content,
      sym_interpolation,
      aux_sym_string_repeat1,
  [104321] = 5,
    ACTIONS(3172), 1,
      anon_sym_and,
    ACTIONS(3174), 1,
      anon_sym_or,
    ACTIONS(3180), 1,
      anon_sym_as,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3033), 7,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_EQ,
      anon_sym_PIPE,
  [104344] = 6,
    ACTIONS(3135), 1,
      anon_sym_as,
    ACTIONS(3137), 1,
      anon_sym_if,
    ACTIONS(3139), 1,
      anon_sym_and,
    ACTIONS(3141), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3038), 6,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PIPE,
  [104369] = 4,
    ACTIONS(3172), 1,
      anon_sym_and,
    ACTIONS(3174), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3015), 8,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_EQ,
      anon_sym_PIPE,
  [104390] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_line_continuation,
    ACTIONS(3125), 1,
      anon_sym_LBRACE,
    ACTIONS(3129), 1,
      sym__not_escape_sequence,
    ACTIONS(3183), 1,
      sym_string_end,
    STATE(1883), 1,
      aux_sym_string_content_repeat1,
    ACTIONS(3127), 3,
      sym__string_content,
      sym_escape_interpolation,
      sym_escape_sequence,
    STATE(1761), 3,
      sym_string_content,
      sym_interpolation,
      aux_sym_string_repeat1,
  [104419] = 6,
    ACTIONS(3168), 1,
      anon_sym_as,
    ACTIONS(3170), 1,
      anon_sym_if,
    ACTIONS(3172), 1,
      anon_sym_and,
    ACTIONS(3174), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3025), 6,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_EQ,
      anon_sym_PIPE,
  [104444] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3021), 10,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_and,
      anon_sym_or,
  [104461] = 3,
    ACTIONS(3172), 1,
      anon_sym_and,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3021), 9,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_or,
  [104480] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2191), 10,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_and,
      anon_sym_or,
  [104497] = 8,
    ACTIONS(3147), 1,
      anon_sym_COMMA,
    ACTIONS(3149), 1,
      anon_sym_as,
    ACTIONS(3151), 1,
      anon_sym_if,
    ACTIONS(3155), 1,
      anon_sym_and,
    ACTIONS(3157), 1,
      anon_sym_or,
    STATE(1981), 1,
      aux_sym_assert_statement_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3185), 4,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACE,
      sym_type_conversion,
  [104526] = 6,
    ACTIONS(3017), 1,
      anon_sym_and,
    ACTIONS(3019), 1,
      anon_sym_or,
    ACTIONS(3027), 1,
      anon_sym_as,
    ACTIONS(3029), 1,
      anon_sym_if,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3084), 6,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PIPE,
  [104551] = 3,
    ACTIONS(3139), 1,
      anon_sym_and,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3021), 9,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_or,
  [104570] = 6,
    ACTIONS(3135), 1,
      anon_sym_as,
    ACTIONS(3137), 1,
      anon_sym_if,
    ACTIONS(3139), 1,
      anon_sym_and,
    ACTIONS(3141), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3084), 6,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PIPE,
  [104595] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_line_continuation,
    ACTIONS(3125), 1,
      anon_sym_LBRACE,
    ACTIONS(3129), 1,
      sym__not_escape_sequence,
    ACTIONS(3187), 1,
      sym_string_end,
    STATE(1883), 1,
      aux_sym_string_content_repeat1,
    ACTIONS(3127), 3,
      sym__string_content,
      sym_escape_interpolation,
      sym_escape_sequence,
    STATE(1761), 3,
      sym_string_content,
      sym_interpolation,
      aux_sym_string_repeat1,
  [104624] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_line_continuation,
    ACTIONS(3125), 1,
      anon_sym_LBRACE,
    ACTIONS(3129), 1,
      sym__not_escape_sequence,
    ACTIONS(3189), 1,
      sym_string_end,
    STATE(1883), 1,
      aux_sym_string_content_repeat1,
    ACTIONS(3127), 3,
      sym__string_content,
      sym_escape_interpolation,
      sym_escape_sequence,
    STATE(1747), 3,
      sym_string_content,
      sym_interpolation,
      aux_sym_string_repeat1,
  [104653] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2191), 10,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_and,
      anon_sym_or,
  [104670] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_line_continuation,
    ACTIONS(3125), 1,
      anon_sym_LBRACE,
    ACTIONS(3129), 1,
      sym__not_escape_sequence,
    ACTIONS(3191), 1,
      sym_string_end,
    STATE(1883), 1,
      aux_sym_string_content_repeat1,
    ACTIONS(3127), 3,
      sym__string_content,
      sym_escape_interpolation,
      sym_escape_sequence,
    STATE(1763), 3,
      sym_string_content,
      sym_interpolation,
      aux_sym_string_repeat1,
  [104699] = 6,
    ACTIONS(3135), 1,
      anon_sym_as,
    ACTIONS(3137), 1,
      anon_sym_if,
    ACTIONS(3139), 1,
      anon_sym_and,
    ACTIONS(3141), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3031), 6,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PIPE,
  [104724] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_line_continuation,
    ACTIONS(3193), 1,
      anon_sym_LBRACE,
    ACTIONS(3199), 1,
      sym__not_escape_sequence,
    ACTIONS(3202), 1,
      sym_string_end,
    STATE(1883), 1,
      aux_sym_string_content_repeat1,
    ACTIONS(3196), 3,
      sym__string_content,
      sym_escape_interpolation,
      sym_escape_sequence,
    STATE(1761), 3,
      sym_string_content,
      sym_interpolation,
      aux_sym_string_repeat1,
  [104753] = 6,
    ACTIONS(3168), 1,
      anon_sym_as,
    ACTIONS(3170), 1,
      anon_sym_if,
    ACTIONS(3172), 1,
      anon_sym_and,
    ACTIONS(3174), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3031), 6,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_else,
      anon_sym_EQ,
      anon_sym_PIPE,
  [104778] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_line_continuation,
    ACTIONS(3125), 1,
      anon_sym_LBRACE,
    ACTIONS(3129), 1,
      sym__not_escape_sequence,
    ACTIONS(3204), 1,
      sym_string_end,
    STATE(1883), 1,
      aux_sym_string_content_repeat1,
    ACTIONS(3127), 3,
      sym__string_content,
      sym_escape_interpolation,
      sym_escape_sequence,
    STATE(1761), 3,
      sym_string_content,
      sym_interpolation,
      aux_sym_string_repeat1,
  [104807] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_line_continuation,
    ACTIONS(3125), 1,
      anon_sym_LBRACE,
    ACTIONS(3129), 1,
      sym__not_escape_sequence,
    ACTIONS(3206), 1,
      sym_string_end,
    STATE(1883), 1,
      aux_sym_string_content_repeat1,
    ACTIONS(3127), 3,
      sym__string_content,
      sym_escape_interpolation,
      sym_escape_sequence,
    STATE(1765), 3,
      sym_string_content,
      sym_interpolation,
      aux_sym_string_repeat1,
  [104836] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_line_continuation,
    ACTIONS(3125), 1,
      anon_sym_LBRACE,
    ACTIONS(3129), 1,
      sym__not_escape_sequence,
    ACTIONS(3208), 1,
      sym_string_end,
    STATE(1883), 1,
      aux_sym_string_content_repeat1,
    ACTIONS(3127), 3,
      sym__string_content,
      sym_escape_interpolation,
      sym_escape_sequence,
    STATE(1761), 3,
      sym_string_content,
      sym_interpolation,
      aux_sym_string_repeat1,
  [104865] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_line_continuation,
    ACTIONS(3125), 1,
      anon_sym_LBRACE,
    ACTIONS(3129), 1,
      sym__not_escape_sequence,
    ACTIONS(3210), 1,
      sym_string_end,
    STATE(1883), 1,
      aux_sym_string_content_repeat1,
    ACTIONS(3127), 3,
      sym__string_content,
      sym_escape_interpolation,
      sym_escape_sequence,
    STATE(1739), 3,
      sym_string_content,
      sym_interpolation,
      aux_sym_string_repeat1,
  [104894] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_line_continuation,
    ACTIONS(3125), 1,
      anon_sym_LBRACE,
    ACTIONS(3129), 1,
      sym__not_escape_sequence,
    ACTIONS(3212), 1,
      sym_string_end,
    STATE(1883), 1,
      aux_sym_string_content_repeat1,
    ACTIONS(3127), 3,
      sym__string_content,
      sym_escape_interpolation,
      sym_escape_sequence,
    STATE(1733), 3,
      sym_string_content,
      sym_interpolation,
      aux_sym_string_repeat1,
  [104923] = 3,
    ACTIONS(2205), 1,
      anon_sym_as,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2191), 8,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
  [104941] = 5,
    ACTIONS(3214), 1,
      anon_sym_as,
    ACTIONS(3217), 1,
      anon_sym_and,
    ACTIONS(3219), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3033), 6,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [104963] = 6,
    ACTIONS(2999), 1,
      anon_sym_as,
    ACTIONS(3001), 1,
      anon_sym_if,
    ACTIONS(3011), 1,
      anon_sym_and,
    ACTIONS(3013), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3031), 5,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACE,
  [104987] = 4,
    ACTIONS(3011), 1,
      anon_sym_and,
    ACTIONS(3221), 1,
      anon_sym_as,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3021), 7,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACE,
      anon_sym_or,
  [105007] = 6,
    ACTIONS(3149), 1,
      anon_sym_as,
    ACTIONS(3151), 1,
      anon_sym_if,
    ACTIONS(3155), 1,
      anon_sym_and,
    ACTIONS(3157), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3038), 5,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACE,
      sym_type_conversion,
  [105031] = 6,
    ACTIONS(2999), 1,
      anon_sym_as,
    ACTIONS(3001), 1,
      anon_sym_if,
    ACTIONS(3011), 1,
      anon_sym_and,
    ACTIONS(3013), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3025), 5,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACE,
  [105055] = 3,
    ACTIONS(3221), 1,
      anon_sym_as,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3021), 8,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
  [105073] = 5,
    ACTIONS(3155), 1,
      anon_sym_and,
    ACTIONS(3157), 1,
      anon_sym_or,
    ACTIONS(3223), 1,
      anon_sym_as,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3033), 6,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACE,
      sym_type_conversion,
  [105095] = 4,
    ACTIONS(3155), 1,
      anon_sym_and,
    ACTIONS(3157), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3015), 7,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACE,
      sym_type_conversion,
  [105115] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3021), 9,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
      sym_type_conversion,
  [105131] = 3,
    ACTIONS(3155), 1,
      anon_sym_and,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3021), 8,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACE,
      anon_sym_or,
      sym_type_conversion,
  [105149] = 4,
    ACTIONS(3228), 1,
      anon_sym_DOT,
    STATE(1779), 1,
      aux_sym_dotted_name_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3226), 7,
      anon_sym_import,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_PIPE,
  [105169] = 5,
    ACTIONS(3011), 1,
      anon_sym_and,
    ACTIONS(3013), 1,
      anon_sym_or,
    ACTIONS(3231), 1,
      anon_sym_as,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3015), 6,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACE,
  [105191] = 6,
    ACTIONS(3149), 1,
      anon_sym_as,
    ACTIONS(3151), 1,
      anon_sym_if,
    ACTIONS(3155), 1,
      anon_sym_and,
    ACTIONS(3157), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3233), 5,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACE,
      sym_type_conversion,
  [105215] = 6,
    ACTIONS(3217), 1,
      anon_sym_and,
    ACTIONS(3219), 1,
      anon_sym_or,
    ACTIONS(3235), 1,
      anon_sym_as,
    ACTIONS(3237), 1,
      anon_sym_if,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3025), 5,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [105239] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2191), 9,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
      sym_type_conversion,
  [105255] = 3,
    ACTIONS(3217), 1,
      anon_sym_and,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3021), 8,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_PIPE,
      anon_sym_or,
  [105273] = 5,
    ACTIONS(3011), 1,
      anon_sym_and,
    ACTIONS(3013), 1,
      anon_sym_or,
    ACTIONS(3239), 1,
      anon_sym_as,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3033), 6,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACE,
  [105295] = 6,
    ACTIONS(3217), 1,
      anon_sym_and,
    ACTIONS(3219), 1,
      anon_sym_or,
    ACTIONS(3235), 1,
      anon_sym_as,
    ACTIONS(3237), 1,
      anon_sym_if,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3084), 5,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [105319] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3023), 9,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_PIPE,
      anon_sym_and,
      anon_sym_or,
  [105335] = 3,
    ACTIONS(3242), 1,
      anon_sym_as,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3023), 8,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
  [105353] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3023), 9,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
      sym_type_conversion,
  [105369] = 4,
    ACTIONS(3246), 1,
      anon_sym_DOT,
    STATE(1798), 1,
      aux_sym_dotted_name_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3244), 7,
      anon_sym_import,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_PIPE,
  [105389] = 6,
    ACTIONS(3217), 1,
      anon_sym_and,
    ACTIONS(3219), 1,
      anon_sym_or,
    ACTIONS(3235), 1,
      anon_sym_as,
    ACTIONS(3237), 1,
      anon_sym_if,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3038), 5,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [105413] = 9,
    ACTIONS(3017), 1,
      anon_sym_and,
    ACTIONS(3019), 1,
      anon_sym_or,
    ACTIONS(3027), 1,
      anon_sym_as,
    ACTIONS(3029), 1,
      anon_sym_if,
    ACTIONS(3250), 1,
      anon_sym_from,
    ACTIONS(3252), 1,
      anon_sym_COMMA,
    STATE(2029), 1,
      aux_sym_assert_statement_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3248), 2,
      sym__newline,
      anon_sym_SEMI,
  [105443] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2191), 9,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_PIPE,
      anon_sym_and,
      anon_sym_or,
  [105459] = 4,
    ACTIONS(3217), 1,
      anon_sym_and,
    ACTIONS(3219), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3015), 7,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [105479] = 6,
    ACTIONS(3217), 1,
      anon_sym_and,
    ACTIONS(3219), 1,
      anon_sym_or,
    ACTIONS(3235), 1,
      anon_sym_as,
    ACTIONS(3237), 1,
      anon_sym_if,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3031), 5,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [105503] = 6,
    ACTIONS(3168), 1,
      anon_sym_as,
    ACTIONS(3170), 1,
      anon_sym_if,
    ACTIONS(3172), 1,
      anon_sym_and,
    ACTIONS(3174), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3084), 5,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PIPE,
  [105527] = 6,
    ACTIONS(3149), 1,
      anon_sym_as,
    ACTIONS(3151), 1,
      anon_sym_if,
    ACTIONS(3155), 1,
      anon_sym_and,
    ACTIONS(3157), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3254), 5,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACE,
      sym_type_conversion,
  [105551] = 4,
    ACTIONS(3246), 1,
      anon_sym_DOT,
    STATE(1779), 1,
      aux_sym_dotted_name_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3256), 7,
      anon_sym_import,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_PIPE,
  [105571] = 6,
    ACTIONS(3149), 1,
      anon_sym_as,
    ACTIONS(3151), 1,
      anon_sym_if,
    ACTIONS(3155), 1,
      anon_sym_and,
    ACTIONS(3157), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3031), 5,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACE,
      sym_type_conversion,
  [105595] = 6,
    ACTIONS(3149), 1,
      anon_sym_as,
    ACTIONS(3151), 1,
      anon_sym_if,
    ACTIONS(3155), 1,
      anon_sym_and,
    ACTIONS(3157), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3025), 5,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACE,
      sym_type_conversion,
  [105619] = 6,
    ACTIONS(2999), 1,
      anon_sym_as,
    ACTIONS(3001), 1,
      anon_sym_if,
    ACTIONS(3011), 1,
      anon_sym_and,
    ACTIONS(3013), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3038), 5,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACE,
  [105643] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3021), 9,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_PIPE,
      anon_sym_and,
      anon_sym_or,
  [105659] = 5,
    ACTIONS(3246), 1,
      anon_sym_DOT,
    ACTIONS(3258), 1,
      anon_sym_EQ,
    STATE(1798), 1,
      aux_sym_dotted_name_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3244), 6,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_PIPE,
  [105681] = 5,
    ACTIONS(3050), 1,
      anon_sym_and,
    ACTIONS(3052), 1,
      anon_sym_or,
    ACTIONS(3260), 1,
      anon_sym_as,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3033), 5,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACK,
  [105702] = 5,
    ACTIONS(3058), 1,
      anon_sym_as,
    ACTIONS(3066), 1,
      anon_sym_and,
    ACTIONS(3068), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3263), 5,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
  [105723] = 5,
    ACTIONS(2999), 1,
      anon_sym_as,
    ACTIONS(3011), 1,
      anon_sym_and,
    ACTIONS(3013), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3263), 5,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACE,
  [105744] = 9,
    ACTIONS(3217), 1,
      anon_sym_and,
    ACTIONS(3219), 1,
      anon_sym_or,
    ACTIONS(3235), 1,
      anon_sym_as,
    ACTIONS(3237), 1,
      anon_sym_if,
    ACTIONS(3265), 1,
      anon_sym_COMMA,
    ACTIONS(3267), 1,
      anon_sym_COLON,
    ACTIONS(3269), 1,
      anon_sym_RBRACK,
    STATE(2416), 1,
      aux_sym_subscript_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [105773] = 8,
    ACTIONS(3017), 1,
      anon_sym_and,
    ACTIONS(3019), 1,
      anon_sym_or,
    ACTIONS(3027), 1,
      anon_sym_as,
    ACTIONS(3029), 1,
      anon_sym_if,
    ACTIONS(3273), 1,
      anon_sym_COMMA,
    STATE(2192), 1,
      aux_sym_assert_statement_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3271), 2,
      sym__newline,
      anon_sym_SEMI,
  [105800] = 3,
    ACTIONS(2205), 1,
      anon_sym_as,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2191), 7,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACK,
      anon_sym_and,
      anon_sym_or,
  [105817] = 5,
    ACTIONS(3066), 1,
      anon_sym_and,
    ACTIONS(3068), 1,
      anon_sym_or,
    ACTIONS(3275), 1,
      anon_sym_as,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3033), 5,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
  [105838] = 6,
    ACTIONS(3058), 1,
      anon_sym_as,
    ACTIONS(3060), 1,
      anon_sym_if,
    ACTIONS(3066), 1,
      anon_sym_and,
    ACTIONS(3068), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3038), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_async,
      anon_sym_for,
  [105861] = 4,
    ACTIONS(327), 1,
      sym_string_start,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1006), 2,
      sym_string,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(3278), 5,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_PIPE,
  [105880] = 7,
    ACTIONS(1522), 1,
      anon_sym_except,
    ACTIONS(1526), 1,
      anon_sym_except_STAR,
    ACTIONS(3280), 1,
      anon_sym_finally,
    STATE(848), 1,
      sym_finally_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(527), 2,
      sym_except_clause,
      aux_sym_try_statement_repeat1,
    STATE(528), 2,
      sym_except_group_clause,
      aux_sym_try_statement_repeat2,
  [105905] = 5,
    ACTIONS(3066), 1,
      anon_sym_and,
    ACTIONS(3068), 1,
      anon_sym_or,
    ACTIONS(3231), 1,
      anon_sym_as,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3015), 5,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
  [105926] = 9,
    ACTIONS(3217), 1,
      anon_sym_and,
    ACTIONS(3219), 1,
      anon_sym_or,
    ACTIONS(3235), 1,
      anon_sym_as,
    ACTIONS(3237), 1,
      anon_sym_if,
    ACTIONS(3267), 1,
      anon_sym_COLON,
    ACTIONS(3282), 1,
      anon_sym_COMMA,
    ACTIONS(3284), 1,
      anon_sym_RBRACK,
    STATE(2311), 1,
      aux_sym_subscript_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [105955] = 6,
    ACTIONS(3058), 1,
      anon_sym_as,
    ACTIONS(3060), 1,
      anon_sym_if,
    ACTIONS(3066), 1,
      anon_sym_and,
    ACTIONS(3068), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3025), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_async,
      anon_sym_for,
  [105978] = 5,
    ACTIONS(2999), 1,
      anon_sym_as,
    ACTIONS(3011), 1,
      anon_sym_and,
    ACTIONS(3013), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3263), 5,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACE,
  [105999] = 5,
    ACTIONS(3042), 1,
      anon_sym_as,
    ACTIONS(3050), 1,
      anon_sym_and,
    ACTIONS(3052), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3263), 5,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACK,
  [106020] = 3,
    ACTIONS(3242), 1,
      anon_sym_as,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3023), 7,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACK,
      anon_sym_and,
      anon_sym_or,
  [106037] = 8,
    ACTIONS(3017), 1,
      anon_sym_and,
    ACTIONS(3019), 1,
      anon_sym_or,
    ACTIONS(3027), 1,
      anon_sym_as,
    ACTIONS(3029), 1,
      anon_sym_if,
    ACTIONS(3086), 1,
      anon_sym_COMMA,
    STATE(2160), 1,
      aux_sym_assert_statement_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3082), 2,
      sym__newline,
      anon_sym_SEMI,
  [106064] = 5,
    ACTIONS(3286), 1,
      anon_sym_DOT,
    ACTIONS(3288), 1,
      anon_sym_EQ,
    STATE(1863), 1,
      aux_sym_dotted_name_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3244), 5,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
  [106085] = 3,
    ACTIONS(3221), 1,
      anon_sym_as,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3021), 7,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_and,
      anon_sym_or,
  [106102] = 6,
    ACTIONS(3058), 1,
      anon_sym_as,
    ACTIONS(3060), 1,
      anon_sym_if,
    ACTIONS(3066), 1,
      anon_sym_and,
    ACTIONS(3068), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3031), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_async,
      anon_sym_for,
  [106125] = 7,
    ACTIONS(63), 1,
      anon_sym_AT,
    ACTIONS(3290), 1,
      anon_sym_async,
    ACTIONS(3292), 1,
      anon_sym_def,
    ACTIONS(3294), 1,
      anon_sym_class,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(844), 2,
      sym_function_definition,
      sym_class_definition,
    STATE(1923), 2,
      sym_decorator,
      aux_sym_decorated_definition_repeat1,
  [106150] = 6,
    ACTIONS(2999), 1,
      anon_sym_as,
    ACTIONS(3001), 1,
      anon_sym_if,
    ACTIONS(3011), 1,
      anon_sym_and,
    ACTIONS(3013), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3296), 4,
      anon_sym_COMMA,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACE,
  [106173] = 4,
    ACTIONS(3066), 1,
      anon_sym_and,
    ACTIONS(3221), 1,
      anon_sym_as,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3021), 6,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_or,
  [106192] = 5,
    ACTIONS(3042), 1,
      anon_sym_as,
    ACTIONS(3050), 1,
      anon_sym_and,
    ACTIONS(3052), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3263), 5,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACK,
  [106213] = 7,
    ACTIONS(63), 1,
      anon_sym_AT,
    ACTIONS(3298), 1,
      anon_sym_async,
    ACTIONS(3300), 1,
      anon_sym_def,
    ACTIONS(3302), 1,
      anon_sym_class,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(837), 2,
      sym_function_definition,
      sym_class_definition,
    STATE(1923), 2,
      sym_decorator,
      aux_sym_decorated_definition_repeat1,
  [106238] = 8,
    ACTIONS(3017), 1,
      anon_sym_and,
    ACTIONS(3019), 1,
      anon_sym_or,
    ACTIONS(3027), 1,
      anon_sym_as,
    ACTIONS(3029), 1,
      anon_sym_if,
    ACTIONS(3252), 1,
      anon_sym_COMMA,
    STATE(2029), 1,
      aux_sym_assert_statement_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3185), 2,
      sym__newline,
      anon_sym_SEMI,
  [106265] = 7,
    ACTIONS(1490), 1,
      anon_sym_except_STAR,
    ACTIONS(1494), 1,
      anon_sym_except,
    ACTIONS(3304), 1,
      anon_sym_finally,
    STATE(782), 1,
      sym_finally_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(497), 2,
      sym_except_group_clause,
      aux_sym_try_statement_repeat2,
    STATE(498), 2,
      sym_except_clause,
      aux_sym_try_statement_repeat1,
  [106290] = 9,
    ACTIONS(3217), 1,
      anon_sym_and,
    ACTIONS(3219), 1,
      anon_sym_or,
    ACTIONS(3235), 1,
      anon_sym_as,
    ACTIONS(3237), 1,
      anon_sym_if,
    ACTIONS(3267), 1,
      anon_sym_COLON,
    ACTIONS(3306), 1,
      anon_sym_COMMA,
    ACTIONS(3308), 1,
      anon_sym_RBRACK,
    STATE(2516), 1,
      aux_sym_subscript_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [106319] = 3,
    ACTIONS(2205), 1,
      anon_sym_as,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2191), 7,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_and,
      anon_sym_or,
  [106336] = 7,
    ACTIONS(1490), 1,
      anon_sym_except_STAR,
    ACTIONS(1494), 1,
      anon_sym_except,
    ACTIONS(3304), 1,
      anon_sym_finally,
    STATE(745), 1,
      sym_finally_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(492), 2,
      sym_except_group_clause,
      aux_sym_try_statement_repeat2,
    STATE(493), 2,
      sym_except_clause,
      aux_sym_try_statement_repeat1,
  [106361] = 9,
    ACTIONS(3217), 1,
      anon_sym_and,
    ACTIONS(3219), 1,
      anon_sym_or,
    ACTIONS(3235), 1,
      anon_sym_as,
    ACTIONS(3237), 1,
      anon_sym_if,
    ACTIONS(3267), 1,
      anon_sym_COLON,
    ACTIONS(3310), 1,
      anon_sym_COMMA,
    ACTIONS(3312), 1,
      anon_sym_RBRACK,
    STATE(2305), 1,
      aux_sym_subscript_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [106390] = 9,
    ACTIONS(3217), 1,
      anon_sym_and,
    ACTIONS(3219), 1,
      anon_sym_or,
    ACTIONS(3235), 1,
      anon_sym_as,
    ACTIONS(3237), 1,
      anon_sym_if,
    ACTIONS(3267), 1,
      anon_sym_COLON,
    ACTIONS(3314), 1,
      anon_sym_COMMA,
    ACTIONS(3316), 1,
      anon_sym_RBRACK,
    STATE(2508), 1,
      aux_sym_subscript_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [106419] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3226), 8,
      anon_sym_import,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_PIPE,
  [106434] = 5,
    ACTIONS(3058), 1,
      anon_sym_as,
    ACTIONS(3066), 1,
      anon_sym_and,
    ACTIONS(3068), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3263), 5,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
  [106455] = 9,
    ACTIONS(3217), 1,
      anon_sym_and,
    ACTIONS(3219), 1,
      anon_sym_or,
    ACTIONS(3235), 1,
      anon_sym_as,
    ACTIONS(3237), 1,
      anon_sym_if,
    ACTIONS(3267), 1,
      anon_sym_COLON,
    ACTIONS(3318), 1,
      anon_sym_COMMA,
    ACTIONS(3320), 1,
      anon_sym_RBRACK,
    STATE(2486), 1,
      aux_sym_subscript_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [106484] = 5,
    ACTIONS(3042), 1,
      anon_sym_as,
    ACTIONS(3050), 1,
      anon_sym_and,
    ACTIONS(3052), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3263), 5,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACK,
  [106505] = 5,
    ACTIONS(3322), 1,
      anon_sym_DOT,
    ACTIONS(3324), 1,
      anon_sym_EQ,
    STATE(1889), 1,
      aux_sym_dotted_name_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3244), 5,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [106526] = 7,
    ACTIONS(1522), 1,
      anon_sym_except,
    ACTIONS(1526), 1,
      anon_sym_except_STAR,
    ACTIONS(3280), 1,
      anon_sym_finally,
    STATE(845), 1,
      sym_finally_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(592), 2,
      sym_except_group_clause,
      aux_sym_try_statement_repeat2,
    STATE(593), 2,
      sym_except_clause,
      aux_sym_try_statement_repeat1,
  [106551] = 5,
    ACTIONS(3326), 1,
      anon_sym_DOT,
    ACTIONS(3328), 1,
      anon_sym_EQ,
    STATE(1877), 1,
      aux_sym_dotted_name_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3244), 5,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_RBRACE,
  [106572] = 3,
    ACTIONS(3242), 1,
      anon_sym_as,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3023), 7,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_and,
      anon_sym_or,
  [106589] = 5,
    ACTIONS(3058), 1,
      anon_sym_as,
    ACTIONS(3066), 1,
      anon_sym_and,
    ACTIONS(3068), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3263), 5,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
  [106610] = 5,
    ACTIONS(2999), 1,
      anon_sym_as,
    ACTIONS(3011), 1,
      anon_sym_and,
    ACTIONS(3013), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3263), 5,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACE,
  [106631] = 6,
    ACTIONS(3042), 1,
      anon_sym_as,
    ACTIONS(3044), 1,
      anon_sym_if,
    ACTIONS(3050), 1,
      anon_sym_and,
    ACTIONS(3052), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3038), 4,
      anon_sym_COMMA,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACK,
  [106654] = 9,
    ACTIONS(3217), 1,
      anon_sym_and,
    ACTIONS(3219), 1,
      anon_sym_or,
    ACTIONS(3235), 1,
      anon_sym_as,
    ACTIONS(3237), 1,
      anon_sym_if,
    ACTIONS(3267), 1,
      anon_sym_COLON,
    ACTIONS(3330), 1,
      anon_sym_COMMA,
    ACTIONS(3332), 1,
      anon_sym_RBRACK,
    STATE(2441), 1,
      aux_sym_subscript_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [106683] = 6,
    ACTIONS(3042), 1,
      anon_sym_as,
    ACTIONS(3044), 1,
      anon_sym_if,
    ACTIONS(3050), 1,
      anon_sym_and,
    ACTIONS(3052), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3025), 4,
      anon_sym_COMMA,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACK,
  [106706] = 8,
    ACTIONS(3017), 1,
      anon_sym_and,
    ACTIONS(3019), 1,
      anon_sym_or,
    ACTIONS(3027), 1,
      anon_sym_as,
    ACTIONS(3029), 1,
      anon_sym_if,
    ACTIONS(3252), 1,
      anon_sym_COMMA,
    STATE(2029), 1,
      aux_sym_assert_statement_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3334), 2,
      sym__newline,
      anon_sym_SEMI,
  [106733] = 6,
    ACTIONS(3017), 1,
      anon_sym_and,
    ACTIONS(3019), 1,
      anon_sym_or,
    ACTIONS(3027), 1,
      anon_sym_as,
    ACTIONS(3029), 1,
      anon_sym_if,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3233), 4,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_from,
      anon_sym_COMMA,
  [106756] = 6,
    ACTIONS(3042), 1,
      anon_sym_as,
    ACTIONS(3044), 1,
      anon_sym_if,
    ACTIONS(3050), 1,
      anon_sym_and,
    ACTIONS(3052), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3031), 4,
      anon_sym_COMMA,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACK,
  [106779] = 9,
    ACTIONS(3217), 1,
      anon_sym_and,
    ACTIONS(3219), 1,
      anon_sym_or,
    ACTIONS(3235), 1,
      anon_sym_as,
    ACTIONS(3237), 1,
      anon_sym_if,
    ACTIONS(3267), 1,
      anon_sym_COLON,
    ACTIONS(3336), 1,
      anon_sym_COMMA,
    ACTIONS(3338), 1,
      anon_sym_RBRACK,
    STATE(2374), 1,
      aux_sym_subscript_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [106808] = 8,
    ACTIONS(3017), 1,
      anon_sym_and,
    ACTIONS(3019), 1,
      anon_sym_or,
    ACTIONS(3027), 1,
      anon_sym_as,
    ACTIONS(3029), 1,
      anon_sym_if,
    ACTIONS(3252), 1,
      anon_sym_COMMA,
    STATE(2029), 1,
      aux_sym_assert_statement_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3340), 2,
      sym__newline,
      anon_sym_SEMI,
  [106835] = 9,
    ACTIONS(3217), 1,
      anon_sym_and,
    ACTIONS(3219), 1,
      anon_sym_or,
    ACTIONS(3235), 1,
      anon_sym_as,
    ACTIONS(3237), 1,
      anon_sym_if,
    ACTIONS(3267), 1,
      anon_sym_COLON,
    ACTIONS(3342), 1,
      anon_sym_COMMA,
    ACTIONS(3344), 1,
      anon_sym_RBRACK,
    STATE(2383), 1,
      aux_sym_subscript_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [106864] = 5,
    ACTIONS(3050), 1,
      anon_sym_and,
    ACTIONS(3052), 1,
      anon_sym_or,
    ACTIONS(3231), 1,
      anon_sym_as,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3015), 5,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACK,
  [106885] = 3,
    ACTIONS(3221), 1,
      anon_sym_as,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3021), 7,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACK,
      anon_sym_and,
      anon_sym_or,
  [106902] = 4,
    ACTIONS(3050), 1,
      anon_sym_and,
    ACTIONS(3221), 1,
      anon_sym_as,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3021), 6,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACK,
      anon_sym_or,
  [106921] = 8,
    ACTIONS(3017), 1,
      anon_sym_and,
    ACTIONS(3019), 1,
      anon_sym_or,
    ACTIONS(3027), 1,
      anon_sym_as,
    ACTIONS(3029), 1,
      anon_sym_if,
    ACTIONS(3252), 1,
      anon_sym_COMMA,
    STATE(2029), 1,
      aux_sym_assert_statement_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2961), 2,
      sym__newline,
      anon_sym_SEMI,
  [106948] = 8,
    ACTIONS(3017), 1,
      anon_sym_and,
    ACTIONS(3019), 1,
      anon_sym_or,
    ACTIONS(3027), 1,
      anon_sym_as,
    ACTIONS(3029), 1,
      anon_sym_if,
    ACTIONS(3273), 1,
      anon_sym_COMMA,
    STATE(2264), 1,
      aux_sym_assert_statement_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3346), 2,
      sym__newline,
      anon_sym_SEMI,
  [106975] = 9,
    ACTIONS(3217), 1,
      anon_sym_and,
    ACTIONS(3219), 1,
      anon_sym_or,
    ACTIONS(3235), 1,
      anon_sym_as,
    ACTIONS(3237), 1,
      anon_sym_if,
    ACTIONS(3267), 1,
      anon_sym_COLON,
    ACTIONS(3348), 1,
      anon_sym_COMMA,
    ACTIONS(3350), 1,
      anon_sym_RBRACK,
    STATE(2393), 1,
      aux_sym_subscript_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [107004] = 8,
    ACTIONS(3017), 1,
      anon_sym_and,
    ACTIONS(3019), 1,
      anon_sym_or,
    ACTIONS(3027), 1,
      anon_sym_as,
    ACTIONS(3029), 1,
      anon_sym_if,
    ACTIONS(3354), 1,
      anon_sym_COMMA,
    STATE(2266), 1,
      aux_sym_print_statement_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3352), 2,
      sym__newline,
      anon_sym_SEMI,
  [107031] = 8,
    ACTIONS(3005), 1,
      anon_sym_async,
    ACTIONS(3007), 1,
      anon_sym_for,
    ACTIONS(3356), 1,
      anon_sym_COMMA,
    ACTIONS(3358), 1,
      anon_sym_RBRACE,
    STATE(1891), 1,
      sym_for_in_clause,
    STATE(2421), 1,
      aux_sym_dictionary_repeat1,
    STATE(2631), 1,
      sym__comprehension_clauses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [107057] = 4,
    ACTIONS(3286), 1,
      anon_sym_DOT,
    STATE(1888), 1,
      aux_sym_dotted_name_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3256), 5,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
  [107075] = 5,
    ACTIONS(2999), 1,
      anon_sym_as,
    ACTIONS(3011), 1,
      anon_sym_and,
    ACTIONS(3013), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3360), 4,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACE,
  [107095] = 4,
    ACTIONS(3362), 1,
      anon_sym_DOT,
    STATE(1865), 1,
      aux_sym_dotted_name_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3226), 5,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_RBRACE,
  [107113] = 4,
    ACTIONS(3365), 1,
      anon_sym_DOT,
    STATE(1866), 1,
      aux_sym_dotted_name_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3226), 5,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [107131] = 6,
    ACTIONS(3046), 1,
      anon_sym_async,
    ACTIONS(3048), 1,
      anon_sym_for,
    ACTIONS(3368), 1,
      anon_sym_if,
    ACTIONS(3370), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1912), 3,
      sym_for_in_clause,
      sym_if_clause,
      aux_sym__comprehension_clauses_repeat1,
  [107153] = 6,
    ACTIONS(3372), 1,
      anon_sym_if,
    ACTIONS(3375), 1,
      anon_sym_async,
    ACTIONS(3378), 1,
      anon_sym_for,
    ACTIONS(3381), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1868), 3,
      sym_for_in_clause,
      sym_if_clause,
      aux_sym__comprehension_clauses_repeat1,
  [107175] = 6,
    ACTIONS(3062), 1,
      anon_sym_async,
    ACTIONS(3064), 1,
      anon_sym_for,
    ACTIONS(3370), 1,
      anon_sym_RPAREN,
    ACTIONS(3383), 1,
      anon_sym_if,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1902), 3,
      sym_for_in_clause,
      sym_if_clause,
      aux_sym__comprehension_clauses_repeat1,
  [107197] = 6,
    ACTIONS(3005), 1,
      anon_sym_async,
    ACTIONS(3007), 1,
      anon_sym_for,
    ACTIONS(3370), 1,
      anon_sym_RBRACE,
    ACTIONS(3385), 1,
      anon_sym_if,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1868), 3,
      sym_for_in_clause,
      sym_if_clause,
      aux_sym__comprehension_clauses_repeat1,
  [107219] = 8,
    ACTIONS(3168), 1,
      anon_sym_as,
    ACTIONS(3170), 1,
      anon_sym_if,
    ACTIONS(3172), 1,
      anon_sym_and,
    ACTIONS(3174), 1,
      anon_sym_or,
    ACTIONS(3387), 1,
      anon_sym_COMMA,
    ACTIONS(3389), 1,
      anon_sym_COLON,
    STATE(2281), 1,
      aux_sym_match_statement_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [107245] = 6,
    ACTIONS(3017), 1,
      anon_sym_and,
    ACTIONS(3019), 1,
      anon_sym_or,
    ACTIONS(3027), 1,
      anon_sym_as,
    ACTIONS(3029), 1,
      anon_sym_if,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3391), 3,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [107267] = 5,
    ACTIONS(3058), 1,
      anon_sym_as,
    ACTIONS(3066), 1,
      anon_sym_and,
    ACTIONS(3068), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3360), 4,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
  [107287] = 8,
    ACTIONS(3393), 1,
      sym_identifier,
    ACTIONS(3395), 1,
      anon_sym_LPAREN,
    ACTIONS(3397), 1,
      anon_sym_STAR,
    STATE(2087), 1,
      sym_dotted_name,
    STATE(2177), 1,
      sym_aliased_import,
    STATE(2533), 1,
      sym__import_list,
    STATE(2557), 1,
      sym_wildcard_import,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [107313] = 5,
    ACTIONS(3042), 1,
      anon_sym_as,
    ACTIONS(3050), 1,
      anon_sym_and,
    ACTIONS(3052), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3360), 4,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACK,
  [107333] = 8,
    ACTIONS(3005), 1,
      anon_sym_async,
    ACTIONS(3007), 1,
      anon_sym_for,
    ACTIONS(3399), 1,
      anon_sym_COMMA,
    ACTIONS(3401), 1,
      anon_sym_RBRACE,
    STATE(1891), 1,
      sym_for_in_clause,
    STATE(2463), 1,
      aux_sym_dictionary_repeat1,
    STATE(2666), 1,
      sym__comprehension_clauses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [107359] = 4,
    ACTIONS(3326), 1,
      anon_sym_DOT,
    STATE(1865), 1,
      aux_sym_dotted_name_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3256), 5,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_RBRACE,
  [107377] = 8,
    ACTIONS(3168), 1,
      anon_sym_as,
    ACTIONS(3170), 1,
      anon_sym_if,
    ACTIONS(3172), 1,
      anon_sym_and,
    ACTIONS(3174), 1,
      anon_sym_or,
    ACTIONS(3403), 1,
      anon_sym_COMMA,
    ACTIONS(3405), 1,
      anon_sym_COLON,
    STATE(2408), 1,
      aux_sym_match_statement_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [107403] = 8,
    ACTIONS(3168), 1,
      anon_sym_as,
    ACTIONS(3170), 1,
      anon_sym_if,
    ACTIONS(3172), 1,
      anon_sym_and,
    ACTIONS(3174), 1,
      anon_sym_or,
    ACTIONS(3407), 1,
      anon_sym_COMMA,
    ACTIONS(3409), 1,
      anon_sym_COLON,
    STATE(2454), 1,
      aux_sym_assert_statement_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [107429] = 7,
    ACTIONS(1352), 1,
      anon_sym_COLON,
    ACTIONS(3217), 1,
      anon_sym_and,
    ACTIONS(3219), 1,
      anon_sym_or,
    ACTIONS(3235), 1,
      anon_sym_as,
    ACTIONS(3237), 1,
      anon_sym_if,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1350), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [107453] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3413), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3411), 5,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_PIPE,
  [107469] = 8,
    ACTIONS(3107), 1,
      anon_sym_RPAREN,
    ACTIONS(3109), 1,
      anon_sym_COMMA,
    ACTIONS(3135), 1,
      anon_sym_as,
    ACTIONS(3137), 1,
      anon_sym_if,
    ACTIONS(3139), 1,
      anon_sym_and,
    ACTIONS(3141), 1,
      anon_sym_or,
    STATE(2307), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [107495] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_line_continuation,
    ACTIONS(3419), 1,
      sym__not_escape_sequence,
    STATE(1910), 1,
      aux_sym_string_content_repeat1,
    ACTIONS(3415), 2,
      sym_string_end,
      anon_sym_LBRACE,
    ACTIONS(3417), 3,
      sym__string_content,
      sym_escape_interpolation,
      sym_escape_sequence,
  [107517] = 8,
    ACTIONS(3168), 1,
      anon_sym_as,
    ACTIONS(3170), 1,
      anon_sym_if,
    ACTIONS(3172), 1,
      anon_sym_and,
    ACTIONS(3174), 1,
      anon_sym_or,
    ACTIONS(3407), 1,
      anon_sym_COMMA,
    ACTIONS(3421), 1,
      anon_sym_COLON,
    STATE(2454), 1,
      aux_sym_assert_statement_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [107543] = 8,
    ACTIONS(3168), 1,
      anon_sym_as,
    ACTIONS(3170), 1,
      anon_sym_if,
    ACTIONS(3172), 1,
      anon_sym_and,
    ACTIONS(3174), 1,
      anon_sym_or,
    ACTIONS(3407), 1,
      anon_sym_COMMA,
    ACTIONS(3423), 1,
      anon_sym_COLON,
    STATE(2454), 1,
      aux_sym_assert_statement_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [107569] = 8,
    ACTIONS(3005), 1,
      anon_sym_async,
    ACTIONS(3007), 1,
      anon_sym_for,
    ACTIONS(3425), 1,
      anon_sym_COMMA,
    ACTIONS(3427), 1,
      anon_sym_RBRACE,
    STATE(1891), 1,
      sym_for_in_clause,
    STATE(2409), 1,
      aux_sym_dictionary_repeat1,
    STATE(2656), 1,
      sym__comprehension_clauses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [107595] = 4,
    ACTIONS(792), 1,
      sym_string_start,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1131), 2,
      sym_string,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(3278), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [107613] = 4,
    ACTIONS(3429), 1,
      anon_sym_DOT,
    STATE(1888), 1,
      aux_sym_dotted_name_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3226), 5,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
  [107631] = 4,
    ACTIONS(3322), 1,
      anon_sym_DOT,
    STATE(1866), 1,
      aux_sym_dotted_name_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3256), 5,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [107649] = 8,
    ACTIONS(3005), 1,
      anon_sym_async,
    ACTIONS(3007), 1,
      anon_sym_for,
    ACTIONS(3432), 1,
      anon_sym_COMMA,
    ACTIONS(3434), 1,
      anon_sym_RBRACE,
    STATE(1891), 1,
      sym_for_in_clause,
    STATE(2428), 1,
      aux_sym_dictionary_repeat1,
    STATE(2730), 1,
      sym__comprehension_clauses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [107675] = 6,
    ACTIONS(3005), 1,
      anon_sym_async,
    ACTIONS(3007), 1,
      anon_sym_for,
    ACTIONS(3385), 1,
      anon_sym_if,
    ACTIONS(3436), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1870), 3,
      sym_for_in_clause,
      sym_if_clause,
      aux_sym__comprehension_clauses_repeat1,
  [107697] = 8,
    ACTIONS(3005), 1,
      anon_sym_async,
    ACTIONS(3007), 1,
      anon_sym_for,
    ACTIONS(3438), 1,
      anon_sym_COMMA,
    ACTIONS(3440), 1,
      anon_sym_RBRACE,
    STATE(1891), 1,
      sym_for_in_clause,
    STATE(2489), 1,
      aux_sym_dictionary_repeat1,
    STATE(2770), 1,
      sym__comprehension_clauses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [107723] = 7,
    ACTIONS(3217), 1,
      anon_sym_and,
    ACTIONS(3219), 1,
      anon_sym_or,
    ACTIONS(3235), 1,
      anon_sym_as,
    ACTIONS(3237), 1,
      anon_sym_if,
    ACTIONS(3442), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1434), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [107747] = 8,
    ACTIONS(3135), 1,
      anon_sym_as,
    ACTIONS(3137), 1,
      anon_sym_if,
    ACTIONS(3139), 1,
      anon_sym_and,
    ACTIONS(3141), 1,
      anon_sym_or,
    ACTIONS(3185), 1,
      anon_sym_RPAREN,
    ACTIONS(3444), 1,
      anon_sym_COMMA,
    STATE(2324), 1,
      aux_sym_assert_statement_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [107773] = 4,
    ACTIONS(702), 1,
      sym_string_start,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(988), 2,
      sym_string,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(3278), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_RBRACE,
  [107791] = 8,
    ACTIONS(3005), 1,
      anon_sym_async,
    ACTIONS(3007), 1,
      anon_sym_for,
    ACTIONS(3446), 1,
      anon_sym_COMMA,
    ACTIONS(3448), 1,
      anon_sym_RBRACE,
    STATE(1891), 1,
      sym_for_in_clause,
    STATE(2290), 1,
      aux_sym_dictionary_repeat1,
    STATE(2784), 1,
      sym__comprehension_clauses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [107817] = 6,
    ACTIONS(3046), 1,
      anon_sym_async,
    ACTIONS(3048), 1,
      anon_sym_for,
    ACTIONS(3368), 1,
      anon_sym_if,
    ACTIONS(3436), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1867), 3,
      sym_for_in_clause,
      sym_if_clause,
      aux_sym__comprehension_clauses_repeat1,
  [107839] = 4,
    ACTIONS(770), 1,
      sym_string_start,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1009), 2,
      sym_string,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(3278), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
  [107857] = 6,
    ACTIONS(3017), 1,
      anon_sym_and,
    ACTIONS(3019), 1,
      anon_sym_or,
    ACTIONS(3027), 1,
      anon_sym_as,
    ACTIONS(3029), 1,
      anon_sym_if,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3450), 3,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [107879] = 4,
    ACTIONS(3322), 1,
      anon_sym_DOT,
    STATE(1889), 1,
      aux_sym_dotted_name_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3244), 5,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [107897] = 4,
    ACTIONS(3326), 1,
      anon_sym_DOT,
    STATE(1877), 1,
      aux_sym_dotted_name_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3244), 5,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_RBRACE,
  [107915] = 6,
    ACTIONS(3381), 1,
      anon_sym_RPAREN,
    ACTIONS(3452), 1,
      anon_sym_if,
    ACTIONS(3455), 1,
      anon_sym_async,
    ACTIONS(3458), 1,
      anon_sym_for,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1902), 3,
      sym_for_in_clause,
      sym_if_clause,
      aux_sym__comprehension_clauses_repeat1,
  [107937] = 7,
    ACTIONS(3217), 1,
      anon_sym_and,
    ACTIONS(3219), 1,
      anon_sym_or,
    ACTIONS(3235), 1,
      anon_sym_as,
    ACTIONS(3237), 1,
      anon_sym_if,
    ACTIONS(3267), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3461), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [107961] = 6,
    ACTIONS(3062), 1,
      anon_sym_async,
    ACTIONS(3064), 1,
      anon_sym_for,
    ACTIONS(3383), 1,
      anon_sym_if,
    ACTIONS(3436), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1869), 3,
      sym_for_in_clause,
      sym_if_clause,
      aux_sym__comprehension_clauses_repeat1,
  [107983] = 8,
    ACTIONS(3005), 1,
      anon_sym_async,
    ACTIONS(3007), 1,
      anon_sym_for,
    ACTIONS(3463), 1,
      anon_sym_COMMA,
    ACTIONS(3465), 1,
      anon_sym_RBRACE,
    STATE(1891), 1,
      sym_for_in_clause,
    STATE(2510), 1,
      aux_sym_dictionary_repeat1,
    STATE(2783), 1,
      sym__comprehension_clauses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [108009] = 7,
    ACTIONS(2745), 1,
      sym_identifier,
    ACTIONS(3467), 1,
      anon_sym_DOT,
    ACTIONS(3469), 1,
      anon_sym___future__,
    STATE(2173), 1,
      aux_sym_import_prefix_repeat1,
    STATE(2363), 1,
      sym_import_prefix,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(2678), 2,
      sym_relative_import,
      sym_dotted_name,
  [108033] = 8,
    ACTIONS(3168), 1,
      anon_sym_as,
    ACTIONS(3170), 1,
      anon_sym_if,
    ACTIONS(3172), 1,
      anon_sym_and,
    ACTIONS(3174), 1,
      anon_sym_or,
    ACTIONS(3407), 1,
      anon_sym_COMMA,
    ACTIONS(3471), 1,
      anon_sym_COLON,
    STATE(2454), 1,
      aux_sym_assert_statement_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [108059] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3473), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3278), 5,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_PIPE,
  [108075] = 8,
    ACTIONS(3005), 1,
      anon_sym_async,
    ACTIONS(3007), 1,
      anon_sym_for,
    ACTIONS(3475), 1,
      anon_sym_COMMA,
    ACTIONS(3477), 1,
      anon_sym_RBRACE,
    STATE(1891), 1,
      sym_for_in_clause,
    STATE(2395), 1,
      aux_sym_dictionary_repeat1,
    STATE(2667), 1,
      sym__comprehension_clauses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [108101] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_line_continuation,
    ACTIONS(3484), 1,
      sym__not_escape_sequence,
    STATE(1910), 1,
      aux_sym_string_content_repeat1,
    ACTIONS(3479), 2,
      sym_string_end,
      anon_sym_LBRACE,
    ACTIONS(3481), 3,
      sym__string_content,
      sym_escape_interpolation,
      sym_escape_sequence,
  [108123] = 8,
    ACTIONS(3185), 1,
      anon_sym_RBRACK,
    ACTIONS(3217), 1,
      anon_sym_and,
    ACTIONS(3219), 1,
      anon_sym_or,
    ACTIONS(3235), 1,
      anon_sym_as,
    ACTIONS(3237), 1,
      anon_sym_if,
    ACTIONS(3487), 1,
      anon_sym_COMMA,
    STATE(2467), 1,
      aux_sym_assert_statement_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [108149] = 6,
    ACTIONS(3381), 1,
      anon_sym_RBRACK,
    ACTIONS(3489), 1,
      anon_sym_if,
    ACTIONS(3492), 1,
      anon_sym_async,
    ACTIONS(3495), 1,
      anon_sym_for,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1912), 3,
      sym_for_in_clause,
      sym_if_clause,
      aux_sym__comprehension_clauses_repeat1,
  [108171] = 4,
    ACTIONS(3286), 1,
      anon_sym_DOT,
    STATE(1863), 1,
      aux_sym_dotted_name_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3244), 5,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
  [108189] = 4,
    ACTIONS(3498), 1,
      anon_sym_DOT,
    STATE(2002), 1,
      aux_sym_dotted_name_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3256), 4,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_as,
  [108206] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_line_continuation,
    ACTIONS(3502), 1,
      sym__not_escape_sequence,
    ACTIONS(3500), 5,
      sym__string_content,
      sym_escape_interpolation,
      sym_string_end,
      anon_sym_LBRACE,
      sym_escape_sequence,
  [108223] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_line_continuation,
    ACTIONS(3506), 1,
      sym__not_escape_sequence,
    ACTIONS(3504), 5,
      sym__string_content,
      sym_escape_interpolation,
      sym_string_end,
      anon_sym_LBRACE,
      sym_escape_sequence,
  [108240] = 3,
    ACTIONS(3508), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3278), 5,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_PIPE,
  [108255] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_line_continuation,
    ACTIONS(3512), 1,
      sym__not_escape_sequence,
    ACTIONS(3510), 5,
      sym__string_content,
      sym_escape_interpolation,
      sym_string_end,
      anon_sym_LBRACE,
      sym_escape_sequence,
  [108272] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_line_continuation,
    ACTIONS(3516), 1,
      sym__not_escape_sequence,
    ACTIONS(3514), 5,
      sym__string_content,
      sym_escape_interpolation,
      sym_string_end,
      anon_sym_LBRACE,
      sym_escape_sequence,
  [108289] = 6,
    ACTIONS(3135), 1,
      anon_sym_as,
    ACTIONS(3137), 1,
      anon_sym_if,
    ACTIONS(3139), 1,
      anon_sym_and,
    ACTIONS(3141), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3254), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [108310] = 4,
    ACTIONS(3518), 1,
      anon_sym_COMMA,
    STATE(1921), 1,
      aux_sym_assert_statement_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3233), 4,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACE,
      sym_type_conversion,
  [108327] = 6,
    ACTIONS(3135), 1,
      anon_sym_as,
    ACTIONS(3137), 1,
      anon_sym_if,
    ACTIONS(3139), 1,
      anon_sym_and,
    ACTIONS(3141), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3521), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [108348] = 4,
    ACTIONS(3525), 1,
      anon_sym_AT,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1923), 2,
      sym_decorator,
      aux_sym_decorated_definition_repeat1,
    ACTIONS(3523), 3,
      anon_sym_async,
      anon_sym_def,
      anon_sym_class,
  [108365] = 6,
    ACTIONS(3217), 1,
      anon_sym_and,
    ACTIONS(3219), 1,
      anon_sym_or,
    ACTIONS(3235), 1,
      anon_sym_as,
    ACTIONS(3237), 1,
      anon_sym_if,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3528), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [108386] = 7,
    ACTIONS(3530), 1,
      anon_sym_DOT,
    ACTIONS(3532), 1,
      anon_sym_COMMA,
    ACTIONS(3534), 1,
      anon_sym_COLON,
    ACTIONS(3536), 1,
      anon_sym_RBRACK,
    ACTIONS(3538), 1,
      anon_sym_PIPE,
    STATE(2419), 1,
      aux_sym_type_parameter_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [108409] = 4,
    ACTIONS(3542), 1,
      anon_sym_COMMA,
    STATE(1966), 1,
      aux_sym_for_in_clause_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3540), 4,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
  [108426] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3544), 6,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PIPE,
  [108439] = 7,
    ACTIONS(3530), 1,
      anon_sym_DOT,
    ACTIONS(3534), 1,
      anon_sym_COLON,
    ACTIONS(3538), 1,
      anon_sym_PIPE,
    ACTIONS(3546), 1,
      anon_sym_COMMA,
    ACTIONS(3548), 1,
      anon_sym_RBRACK,
    STATE(2316), 1,
      aux_sym_type_parameter_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [108462] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3544), 6,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PIPE,
  [108475] = 6,
    ACTIONS(3149), 1,
      anon_sym_as,
    ACTIONS(3151), 1,
      anon_sym_if,
    ACTIONS(3155), 1,
      anon_sym_and,
    ACTIONS(3157), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3521), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [108496] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_line_continuation,
    ACTIONS(3552), 1,
      sym__not_escape_sequence,
    ACTIONS(3550), 5,
      sym__string_content,
      sym_escape_interpolation,
      sym_string_end,
      anon_sym_LBRACE,
      sym_escape_sequence,
  [108513] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3554), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3411), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_RBRACE,
  [108528] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_line_continuation,
    ACTIONS(3558), 1,
      sym__not_escape_sequence,
    ACTIONS(3556), 5,
      sym__string_content,
      sym_escape_interpolation,
      sym_string_end,
      anon_sym_LBRACE,
      sym_escape_sequence,
  [108545] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3084), 6,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PIPE,
  [108558] = 4,
    ACTIONS(3172), 1,
      anon_sym_and,
    ACTIONS(3174), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3015), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
  [108575] = 6,
    ACTIONS(3017), 1,
      anon_sym_and,
    ACTIONS(3019), 1,
      anon_sym_or,
    ACTIONS(3027), 1,
      anon_sym_as,
    ACTIONS(3029), 1,
      anon_sym_if,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3560), 2,
      sym__newline,
      anon_sym_SEMI,
  [108596] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3562), 6,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PIPE,
  [108609] = 4,
    ACTIONS(3566), 1,
      anon_sym_PIPE,
    STATE(1955), 1,
      aux_sym_union_pattern_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3564), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
  [108626] = 7,
    ACTIONS(3530), 1,
      anon_sym_DOT,
    ACTIONS(3534), 1,
      anon_sym_COLON,
    ACTIONS(3538), 1,
      anon_sym_PIPE,
    ACTIONS(3568), 1,
      anon_sym_COMMA,
    ACTIONS(3570), 1,
      anon_sym_RBRACK,
    STATE(2339), 1,
      aux_sym_type_parameter_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [108649] = 4,
    ACTIONS(3574), 1,
      anon_sym_COMMA,
    STATE(1974), 1,
      aux_sym_for_in_clause_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3572), 4,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
  [108666] = 4,
    ACTIONS(3576), 1,
      anon_sym_COMMA,
    STATE(1941), 1,
      aux_sym_for_in_clause_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3579), 4,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACK,
  [108683] = 4,
    ACTIONS(3581), 1,
      anon_sym_COMMA,
    STATE(1941), 1,
      aux_sym_for_in_clause_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3540), 4,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACK,
  [108700] = 6,
    ACTIONS(3217), 1,
      anon_sym_and,
    ACTIONS(3219), 1,
      anon_sym_or,
    ACTIONS(3235), 1,
      anon_sym_as,
    ACTIONS(3237), 1,
      anon_sym_if,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3254), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [108721] = 6,
    ACTIONS(3135), 1,
      anon_sym_as,
    ACTIONS(3137), 1,
      anon_sym_if,
    ACTIONS(3139), 1,
      anon_sym_and,
    ACTIONS(3141), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3583), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [108742] = 6,
    ACTIONS(3135), 1,
      anon_sym_as,
    ACTIONS(3137), 1,
      anon_sym_if,
    ACTIONS(3139), 1,
      anon_sym_and,
    ACTIONS(3141), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3585), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [108763] = 6,
    ACTIONS(3135), 1,
      anon_sym_as,
    ACTIONS(3137), 1,
      anon_sym_if,
    ACTIONS(3139), 1,
      anon_sym_and,
    ACTIONS(3141), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3233), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [108784] = 4,
    ACTIONS(3587), 1,
      anon_sym_COMMA,
    STATE(1942), 1,
      aux_sym_for_in_clause_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3589), 4,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACK,
  [108801] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3544), 6,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PIPE,
  [108814] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3226), 6,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
  [108827] = 6,
    ACTIONS(3168), 1,
      anon_sym_as,
    ACTIONS(3170), 1,
      anon_sym_if,
    ACTIONS(3172), 1,
      anon_sym_and,
    ACTIONS(3174), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3591), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
  [108848] = 6,
    ACTIONS(3149), 1,
      anon_sym_as,
    ACTIONS(3151), 1,
      anon_sym_if,
    ACTIONS(3155), 1,
      anon_sym_and,
    ACTIONS(3157), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3585), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [108869] = 6,
    ACTIONS(3135), 1,
      anon_sym_as,
    ACTIONS(3137), 1,
      anon_sym_if,
    ACTIONS(3139), 1,
      anon_sym_and,
    ACTIONS(3141), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3593), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [108890] = 6,
    ACTIONS(3149), 1,
      anon_sym_as,
    ACTIONS(3151), 1,
      anon_sym_if,
    ACTIONS(3155), 1,
      anon_sym_and,
    ACTIONS(3157), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3583), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [108911] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3595), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3278), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_RBRACE,
  [108926] = 4,
    ACTIONS(3599), 1,
      anon_sym_PIPE,
    STATE(1955), 1,
      aux_sym_union_pattern_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3597), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
  [108943] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3084), 6,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PIPE,
  [108956] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3602), 6,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PIPE,
  [108969] = 6,
    ACTIONS(3168), 1,
      anon_sym_as,
    ACTIONS(3170), 1,
      anon_sym_if,
    ACTIONS(3172), 1,
      anon_sym_and,
    ACTIONS(3174), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3233), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
  [108990] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3604), 6,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PIPE,
  [109003] = 6,
    ACTIONS(3017), 1,
      anon_sym_and,
    ACTIONS(3019), 1,
      anon_sym_or,
    ACTIONS(3027), 1,
      anon_sym_as,
    ACTIONS(3029), 1,
      anon_sym_if,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3254), 2,
      sym__newline,
      anon_sym_SEMI,
  [109024] = 7,
    ACTIONS(3170), 1,
      anon_sym_if,
    ACTIONS(3172), 1,
      anon_sym_and,
    ACTIONS(3174), 1,
      anon_sym_or,
    ACTIONS(3606), 1,
      anon_sym_COMMA,
    ACTIONS(3608), 1,
      anon_sym_as,
    ACTIONS(3610), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [109047] = 6,
    ACTIONS(3135), 1,
      anon_sym_as,
    ACTIONS(3137), 1,
      anon_sym_if,
    ACTIONS(3139), 1,
      anon_sym_and,
    ACTIONS(3141), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3591), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [109068] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3612), 6,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PIPE,
  [109081] = 5,
    ACTIONS(3614), 1,
      anon_sym_DOT,
    ACTIONS(3618), 1,
      anon_sym_COLON,
    ACTIONS(3620), 1,
      anon_sym_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3616), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
  [109100] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3622), 6,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PIPE,
  [109113] = 4,
    ACTIONS(3624), 1,
      anon_sym_COMMA,
    STATE(1966), 1,
      aux_sym_for_in_clause_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3579), 4,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
  [109130] = 6,
    ACTIONS(3217), 1,
      anon_sym_and,
    ACTIONS(3219), 1,
      anon_sym_or,
    ACTIONS(3235), 1,
      anon_sym_as,
    ACTIONS(3237), 1,
      anon_sym_if,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3583), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [109151] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1606), 6,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PIPE,
  [109164] = 3,
    STATE(1938), 1,
      aux_sym_union_pattern_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3597), 5,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_PIPE,
  [109179] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3226), 6,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [109192] = 6,
    ACTIONS(3629), 1,
      anon_sym_DOT,
    ACTIONS(3631), 1,
      anon_sym_COLON,
    ACTIONS(3633), 1,
      anon_sym_EQ,
    ACTIONS(3635), 1,
      anon_sym_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3627), 2,
      sym__newline,
      anon_sym_SEMI,
  [109213] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3226), 6,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_RBRACE,
  [109226] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3637), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3411), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
  [109241] = 4,
    ACTIONS(3641), 1,
      anon_sym_COMMA,
    STATE(1966), 1,
      aux_sym_for_in_clause_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3639), 4,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
  [109258] = 4,
    ACTIONS(3643), 1,
      anon_sym_COMMA,
    STATE(1926), 1,
      aux_sym_for_in_clause_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3589), 4,
      anon_sym_RPAREN,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
  [109275] = 6,
    ACTIONS(3217), 1,
      anon_sym_and,
    ACTIONS(3219), 1,
      anon_sym_or,
    ACTIONS(3235), 1,
      anon_sym_as,
    ACTIONS(3237), 1,
      anon_sym_if,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3233), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [109296] = 4,
    ACTIONS(3645), 1,
      anon_sym_COMMA,
    STATE(1977), 1,
      aux_sym__patterns_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2907), 4,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACE,
      sym_type_conversion,
  [109313] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_line_continuation,
    ACTIONS(3650), 1,
      sym__not_escape_sequence,
    ACTIONS(3648), 5,
      sym__string_content,
      sym_escape_interpolation,
      sym_string_end,
      anon_sym_LBRACE,
      sym_escape_sequence,
  [109330] = 6,
    ACTIONS(3217), 1,
      anon_sym_and,
    ACTIONS(3219), 1,
      anon_sym_or,
    ACTIONS(3235), 1,
      anon_sym_as,
    ACTIONS(3237), 1,
      anon_sym_if,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1430), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [109351] = 4,
    ACTIONS(3652), 1,
      anon_sym_COMMA,
    STATE(1941), 1,
      aux_sym_for_in_clause_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3639), 4,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACK,
  [109368] = 4,
    ACTIONS(3654), 1,
      anon_sym_COMMA,
    STATE(1921), 1,
      aux_sym_assert_statement_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1290), 4,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACE,
      sym_type_conversion,
  [109385] = 4,
    ACTIONS(3656), 1,
      anon_sym_COMMA,
    STATE(1998), 1,
      aux_sym_for_in_clause_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3572), 4,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACE,
  [109402] = 6,
    ACTIONS(3135), 1,
      anon_sym_as,
    ACTIONS(3137), 1,
      anon_sym_if,
    ACTIONS(3139), 1,
      anon_sym_and,
    ACTIONS(3141), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3658), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [109423] = 6,
    ACTIONS(3017), 1,
      anon_sym_and,
    ACTIONS(3019), 1,
      anon_sym_or,
    ACTIONS(3027), 1,
      anon_sym_as,
    ACTIONS(3029), 1,
      anon_sym_if,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3660), 2,
      sym__newline,
      anon_sym_SEMI,
  [109444] = 6,
    ACTIONS(3135), 1,
      anon_sym_as,
    ACTIONS(3137), 1,
      anon_sym_if,
    ACTIONS(3139), 1,
      anon_sym_and,
    ACTIONS(3141), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3662), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [109465] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3664), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3278), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [109480] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3604), 6,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PIPE,
  [109493] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1606), 6,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PIPE,
  [109506] = 6,
    ACTIONS(3217), 1,
      anon_sym_and,
    ACTIONS(3219), 1,
      anon_sym_or,
    ACTIONS(3235), 1,
      anon_sym_as,
    ACTIONS(3237), 1,
      anon_sym_if,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1434), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [109527] = 6,
    ACTIONS(3135), 1,
      anon_sym_as,
    ACTIONS(3137), 1,
      anon_sym_if,
    ACTIONS(3139), 1,
      anon_sym_and,
    ACTIONS(3141), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3666), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [109548] = 4,
    ACTIONS(3498), 1,
      anon_sym_DOT,
    STATE(1914), 1,
      aux_sym_dotted_name_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3244), 4,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_as,
  [109565] = 7,
    ACTIONS(3530), 1,
      anon_sym_DOT,
    ACTIONS(3534), 1,
      anon_sym_COLON,
    ACTIONS(3538), 1,
      anon_sym_PIPE,
    ACTIONS(3668), 1,
      anon_sym_COMMA,
    ACTIONS(3670), 1,
      anon_sym_RBRACK,
    STATE(2458), 1,
      aux_sym_type_parameter_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [109588] = 7,
    ACTIONS(3170), 1,
      anon_sym_if,
    ACTIONS(3172), 1,
      anon_sym_and,
    ACTIONS(3174), 1,
      anon_sym_or,
    ACTIONS(3608), 1,
      anon_sym_as,
    ACTIONS(3672), 1,
      anon_sym_COMMA,
    ACTIONS(3674), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [109611] = 6,
    ACTIONS(3168), 1,
      anon_sym_as,
    ACTIONS(3170), 1,
      anon_sym_if,
    ACTIONS(3172), 1,
      anon_sym_and,
    ACTIONS(3174), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3676), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
  [109632] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3622), 6,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PIPE,
  [109645] = 4,
    ACTIONS(3678), 1,
      anon_sym_COMMA,
    STATE(2012), 1,
      aux_sym_for_in_clause_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3589), 4,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACE,
  [109662] = 5,
    ACTIONS(3629), 1,
      anon_sym_DOT,
    ACTIONS(3631), 1,
      anon_sym_COLON,
    ACTIONS(3635), 1,
      anon_sym_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3616), 3,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_EQ,
  [109681] = 4,
    ACTIONS(3680), 1,
      anon_sym_COMMA,
    STATE(2018), 1,
      aux_sym_for_in_clause_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3639), 4,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACE,
  [109698] = 6,
    ACTIONS(3217), 1,
      anon_sym_and,
    ACTIONS(3219), 1,
      anon_sym_or,
    ACTIONS(3235), 1,
      anon_sym_as,
    ACTIONS(3237), 1,
      anon_sym_if,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3521), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [109719] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5), 1,
      sym_line_continuation,
    ACTIONS(3684), 1,
      sym__not_escape_sequence,
    ACTIONS(3682), 5,
      sym__string_content,
      sym_escape_interpolation,
      sym_string_end,
      anon_sym_LBRACE,
      sym_escape_sequence,
  [109736] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3612), 6,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PIPE,
  [109749] = 4,
    ACTIONS(3686), 1,
      anon_sym_DOT,
    STATE(2002), 1,
      aux_sym_dotted_name_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3226), 4,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_as,
  [109766] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3602), 6,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PIPE,
  [109779] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3562), 6,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PIPE,
  [109792] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3689), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3411), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [109807] = 6,
    ACTIONS(3149), 1,
      anon_sym_as,
    ACTIONS(3151), 1,
      anon_sym_if,
    ACTIONS(3155), 1,
      anon_sym_and,
    ACTIONS(3157), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3296), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [109828] = 6,
    ACTIONS(3614), 1,
      anon_sym_DOT,
    ACTIONS(3618), 1,
      anon_sym_COLON,
    ACTIONS(3620), 1,
      anon_sym_PIPE,
    ACTIONS(3693), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3691), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [109849] = 4,
    ACTIONS(3566), 1,
      anon_sym_PIPE,
    STATE(1938), 1,
      aux_sym_union_pattern_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3695), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
  [109866] = 6,
    ACTIONS(3135), 1,
      anon_sym_as,
    ACTIONS(3137), 1,
      anon_sym_if,
    ACTIONS(3139), 1,
      anon_sym_and,
    ACTIONS(3141), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3697), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [109887] = 6,
    ACTIONS(3168), 1,
      anon_sym_as,
    ACTIONS(3170), 1,
      anon_sym_if,
    ACTIONS(3172), 1,
      anon_sym_and,
    ACTIONS(3174), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3666), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
  [109908] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3699), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3278), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
  [109923] = 4,
    ACTIONS(3701), 1,
      anon_sym_COMMA,
    STATE(2018), 1,
      aux_sym_for_in_clause_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3540), 4,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACE,
  [109940] = 6,
    ACTIONS(3168), 1,
      anon_sym_as,
    ACTIONS(3170), 1,
      anon_sym_if,
    ACTIONS(3172), 1,
      anon_sym_and,
    ACTIONS(3174), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3697), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
  [109961] = 4,
    ACTIONS(3703), 1,
      anon_sym_COMMA,
    STATE(1977), 1,
      aux_sym__patterns_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(970), 4,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACE,
      sym_type_conversion,
  [109978] = 4,
    ACTIONS(3705), 1,
      anon_sym_COMMA,
    STATE(1980), 1,
      aux_sym_for_in_clause_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3572), 4,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACK,
  [109995] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3602), 6,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PIPE,
  [110008] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3562), 6,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PIPE,
  [110021] = 4,
    ACTIONS(3707), 1,
      anon_sym_COMMA,
    STATE(2018), 1,
      aux_sym_for_in_clause_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3579), 4,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACE,
  [110038] = 4,
    ACTIONS(3566), 1,
      anon_sym_PIPE,
    STATE(1938), 1,
      aux_sym_union_pattern_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3710), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
  [110055] = 7,
    ACTIONS(3712), 1,
      anon_sym_COMMA,
    ACTIONS(3714), 1,
      anon_sym_as,
    ACTIONS(3716), 1,
      anon_sym_if,
    ACTIONS(3718), 1,
      anon_sym_COLON,
    STATE(2108), 1,
      aux_sym_case_clause_repeat1,
    STATE(2751), 1,
      sym_if_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [110078] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3720), 5,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_PIPE,
  [110090] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3722), 5,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_PIPE,
  [110102] = 6,
    ACTIONS(3691), 1,
      anon_sym_COMMA,
    ACTIONS(3724), 1,
      anon_sym_DOT,
    ACTIONS(3726), 1,
      anon_sym_COLON,
    ACTIONS(3728), 1,
      anon_sym_EQ,
    ACTIONS(3730), 1,
      anon_sym_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [110122] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1558), 5,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACE,
      sym_type_conversion,
  [110134] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3732), 5,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_PIPE,
  [110146] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3734), 5,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACE,
  [110158] = 4,
    ACTIONS(3736), 1,
      anon_sym_PIPE,
    STATE(2027), 1,
      aux_sym_union_pattern_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3597), 3,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_RBRACK,
  [110174] = 3,
    STATE(2115), 1,
      aux_sym_union_pattern_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3597), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [110188] = 4,
    ACTIONS(3739), 1,
      anon_sym_COMMA,
    STATE(2102), 1,
      aux_sym_assert_statement_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1290), 3,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_from,
  [110204] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3741), 5,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_PIPE,
  [110216] = 6,
    ACTIONS(3168), 1,
      anon_sym_as,
    ACTIONS(3170), 1,
      anon_sym_if,
    ACTIONS(3172), 1,
      anon_sym_and,
    ACTIONS(3174), 1,
      anon_sym_or,
    ACTIONS(3743), 1,
      anon_sym_else,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [110236] = 4,
    ACTIONS(3745), 1,
      anon_sym_PIPE,
    STATE(2109), 1,
      aux_sym_union_pattern_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3710), 3,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_RBRACE,
  [110252] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3747), 5,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_RBRACE,
  [110264] = 3,
    ACTIONS(3749), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3278), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_RBRACE,
  [110278] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3579), 5,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
  [110290] = 4,
    ACTIONS(3745), 1,
      anon_sym_PIPE,
    STATE(2109), 1,
      aux_sym_union_pattern_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3695), 3,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_RBRACE,
  [110306] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3751), 5,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_PIPE,
  [110318] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1606), 5,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [110330] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3604), 5,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [110342] = 5,
    ACTIONS(3753), 1,
      anon_sym_COMMA,
    ACTIONS(3755), 1,
      anon_sym_RBRACE,
    STATE(2345), 1,
      aux_sym_dict_pattern_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3278), 2,
      anon_sym_COLON,
      anon_sym_PIPE,
  [110360] = 6,
    ACTIONS(3757), 1,
      anon_sym_LBRACE,
    ACTIONS(3759), 1,
      anon_sym_RBRACE,
    ACTIONS(3761), 1,
      aux_sym_format_specifier_token1,
    STATE(2049), 1,
      aux_sym_format_specifier_repeat1,
    STATE(2327), 1,
      sym_interpolation,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_continuation,
  [110380] = 3,
    STATE(2109), 1,
      aux_sym_union_pattern_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3597), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_RBRACE,
  [110394] = 4,
    ACTIONS(3763), 1,
      anon_sym_PIPE,
    STATE(2043), 1,
      aux_sym_union_pattern_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3597), 3,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_RBRACE,
  [110410] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3084), 5,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [110422] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3766), 5,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_PIPE,
  [110434] = 6,
    ACTIONS(3393), 1,
      sym_identifier,
    ACTIONS(3768), 1,
      anon_sym_LPAREN,
    STATE(2087), 1,
      sym_dotted_name,
    STATE(2177), 1,
      sym_aliased_import,
    STATE(2544), 1,
      sym__import_list,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [110454] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3734), 5,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
  [110466] = 4,
    ACTIONS(3770), 1,
      anon_sym_PIPE,
    STATE(2115), 1,
      aux_sym_union_pattern_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3695), 3,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_RBRACK,
  [110482] = 6,
    ACTIONS(3772), 1,
      anon_sym_LBRACE,
    ACTIONS(3775), 1,
      anon_sym_RBRACE,
    ACTIONS(3777), 1,
      aux_sym_format_specifier_token1,
    STATE(2049), 1,
      aux_sym_format_specifier_repeat1,
    STATE(2327), 1,
      sym_interpolation,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_continuation,
  [110502] = 5,
    ACTIONS(3393), 1,
      sym_identifier,
    STATE(2174), 1,
      sym_dotted_name,
    STATE(2356), 1,
      sym_aliased_import,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3780), 2,
      sym__newline,
      anon_sym_SEMI,
  [110520] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1606), 5,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PIPE,
  [110532] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3604), 5,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PIPE,
  [110544] = 6,
    ACTIONS(3782), 1,
      anon_sym_COLON,
    ACTIONS(3784), 1,
      anon_sym_EQ,
    ACTIONS(3786), 1,
      anon_sym_RBRACE,
    ACTIONS(3788), 1,
      sym_type_conversion,
    STATE(2662), 1,
      sym_format_specifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [110564] = 6,
    ACTIONS(3168), 1,
      anon_sym_as,
    ACTIONS(3170), 1,
      anon_sym_if,
    ACTIONS(3172), 1,
      anon_sym_and,
    ACTIONS(3174), 1,
      anon_sym_or,
    ACTIONS(3790), 1,
      anon_sym_else,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [110584] = 5,
    ACTIONS(3792), 1,
      anon_sym_COMMA,
    ACTIONS(3794), 1,
      anon_sym_RBRACE,
    STATE(2358), 1,
      aux_sym_dict_pattern_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3278), 2,
      anon_sym_COLON,
      anon_sym_PIPE,
  [110602] = 4,
    ACTIONS(3172), 1,
      anon_sym_and,
    ACTIONS(3174), 1,
      anon_sym_or,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3015), 3,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
  [110618] = 6,
    ACTIONS(3168), 1,
      anon_sym_as,
    ACTIONS(3170), 1,
      anon_sym_if,
    ACTIONS(3172), 1,
      anon_sym_and,
    ACTIONS(3174), 1,
      anon_sym_or,
    ACTIONS(3796), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [110638] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3579), 5,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACE,
  [110650] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3798), 5,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACE,
  [110662] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3800), 5,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_PIPE,
  [110674] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3544), 5,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [110686] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3622), 5,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [110698] = 5,
    ACTIONS(3724), 1,
      anon_sym_DOT,
    ACTIONS(3726), 1,
      anon_sym_COLON,
    ACTIONS(3730), 1,
      anon_sym_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3616), 2,
      anon_sym_COMMA,
      anon_sym_EQ,
  [110716] = 6,
    ACTIONS(3170), 1,
      anon_sym_if,
    ACTIONS(3172), 1,
      anon_sym_and,
    ACTIONS(3174), 1,
      anon_sym_or,
    ACTIONS(3802), 1,
      anon_sym_as,
    ACTIONS(3804), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [110736] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3185), 5,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACE,
      sym_type_conversion,
  [110748] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3806), 5,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_PIPE,
  [110760] = 6,
    ACTIONS(3168), 1,
      anon_sym_as,
    ACTIONS(3170), 1,
      anon_sym_if,
    ACTIONS(3172), 1,
      anon_sym_and,
    ACTIONS(3174), 1,
      anon_sym_or,
    ACTIONS(3360), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [110780] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3622), 5,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PIPE,
  [110792] = 5,
    ACTIONS(3530), 1,
      anon_sym_DOT,
    ACTIONS(3534), 1,
      anon_sym_COLON,
    ACTIONS(3538), 1,
      anon_sym_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3808), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [110810] = 5,
    ACTIONS(3810), 1,
      anon_sym_COMMA,
    ACTIONS(3812), 1,
      anon_sym_RBRACE,
    STATE(2445), 1,
      aux_sym_dict_pattern_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3278), 2,
      anon_sym_COLON,
      anon_sym_PIPE,
  [110828] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3814), 5,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_PIPE,
  [110840] = 6,
    ACTIONS(3168), 1,
      anon_sym_as,
    ACTIONS(3170), 1,
      anon_sym_if,
    ACTIONS(3172), 1,
      anon_sym_and,
    ACTIONS(3174), 1,
      anon_sym_or,
    ACTIONS(3816), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [110860] = 5,
    ACTIONS(3530), 1,
      anon_sym_DOT,
    ACTIONS(3534), 1,
      anon_sym_COLON,
    ACTIONS(3538), 1,
      anon_sym_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3616), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [110878] = 5,
    ACTIONS(3393), 1,
      sym_identifier,
    STATE(2174), 1,
      sym_dotted_name,
    STATE(2356), 1,
      sym_aliased_import,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3818), 2,
      sym__newline,
      anon_sym_SEMI,
  [110896] = 3,
    ACTIONS(3820), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3278), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
  [110910] = 4,
    ACTIONS(3822), 1,
      anon_sym_PIPE,
    STATE(2112), 1,
      aux_sym_union_pattern_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3710), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
  [110926] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3612), 5,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [110938] = 5,
    ACTIONS(3614), 1,
      anon_sym_DOT,
    ACTIONS(3618), 1,
      anon_sym_COLON,
    ACTIONS(3620), 1,
      anon_sym_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3691), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [110956] = 6,
    ACTIONS(3168), 1,
      anon_sym_as,
    ACTIONS(3170), 1,
      anon_sym_if,
    ACTIONS(3172), 1,
      anon_sym_and,
    ACTIONS(3174), 1,
      anon_sym_or,
    ACTIONS(3824), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [110976] = 5,
    ACTIONS(3629), 1,
      anon_sym_DOT,
    ACTIONS(3631), 1,
      anon_sym_COLON,
    ACTIONS(3635), 1,
      anon_sym_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3826), 2,
      sym__newline,
      anon_sym_SEMI,
  [110994] = 5,
    ACTIONS(3393), 1,
      sym_identifier,
    STATE(2174), 1,
      sym_dotted_name,
    STATE(2356), 1,
      sym_aliased_import,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3818), 2,
      sym__newline,
      anon_sym_SEMI,
  [111012] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3828), 5,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_PIPE,
  [111024] = 6,
    ACTIONS(3168), 1,
      anon_sym_as,
    ACTIONS(3170), 1,
      anon_sym_if,
    ACTIONS(3172), 1,
      anon_sym_and,
    ACTIONS(3174), 1,
      anon_sym_or,
    ACTIONS(3830), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [111044] = 6,
    ACTIONS(3170), 1,
      anon_sym_if,
    ACTIONS(3172), 1,
      anon_sym_and,
    ACTIONS(3174), 1,
      anon_sym_or,
    ACTIONS(3802), 1,
      anon_sym_as,
    ACTIONS(3832), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [111064] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2907), 5,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACE,
      sym_type_conversion,
  [111076] = 6,
    ACTIONS(3017), 1,
      anon_sym_and,
    ACTIONS(3019), 1,
      anon_sym_or,
    ACTIONS(3027), 1,
      anon_sym_as,
    ACTIONS(3029), 1,
      anon_sym_if,
    ACTIONS(3834), 1,
      sym__newline,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [111096] = 5,
    ACTIONS(3838), 1,
      anon_sym_COMMA,
    ACTIONS(3840), 1,
      anon_sym_as,
    STATE(2228), 1,
      aux_sym__import_list_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3836), 2,
      sym__newline,
      anon_sym_SEMI,
  [111114] = 6,
    ACTIONS(1556), 1,
      anon_sym_LBRACK,
    ACTIONS(3842), 1,
      anon_sym_LPAREN,
    ACTIONS(3844), 1,
      anon_sym_COLON,
    STATE(2355), 1,
      sym_type_parameter,
    STATE(2721), 1,
      sym_argument_list,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [111134] = 6,
    ACTIONS(3168), 1,
      anon_sym_as,
    ACTIONS(3170), 1,
      anon_sym_if,
    ACTIONS(3172), 1,
      anon_sym_and,
    ACTIONS(3174), 1,
      anon_sym_or,
    ACTIONS(3846), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [111154] = 6,
    ACTIONS(3168), 1,
      anon_sym_as,
    ACTIONS(3170), 1,
      anon_sym_if,
    ACTIONS(3172), 1,
      anon_sym_and,
    ACTIONS(3174), 1,
      anon_sym_or,
    ACTIONS(3848), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [111174] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3850), 5,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_PIPE,
  [111186] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3612), 5,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PIPE,
  [111198] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3852), 5,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_PIPE,
  [111210] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3854), 5,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_PIPE,
  [111222] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3856), 5,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_PIPE,
  [111234] = 6,
    ACTIONS(3168), 1,
      anon_sym_as,
    ACTIONS(3170), 1,
      anon_sym_if,
    ACTIONS(3172), 1,
      anon_sym_and,
    ACTIONS(3174), 1,
      anon_sym_or,
    ACTIONS(3858), 1,
      anon_sym_else,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [111254] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3602), 5,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [111266] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2924), 5,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACE,
      sym_type_conversion,
  [111278] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3226), 5,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_as,
  [111290] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3860), 5,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_PIPE,
  [111302] = 6,
    ACTIONS(3782), 1,
      anon_sym_COLON,
    ACTIONS(3862), 1,
      anon_sym_EQ,
    ACTIONS(3864), 1,
      anon_sym_RBRACE,
    ACTIONS(3866), 1,
      sym_type_conversion,
    STATE(2748), 1,
      sym_format_specifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [111322] = 4,
    ACTIONS(3868), 1,
      anon_sym_COMMA,
    STATE(2102), 1,
      aux_sym_assert_statement_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3233), 3,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_from,
  [111338] = 6,
    ACTIONS(3168), 1,
      anon_sym_as,
    ACTIONS(3170), 1,
      anon_sym_if,
    ACTIONS(3172), 1,
      anon_sym_and,
    ACTIONS(3174), 1,
      anon_sym_or,
    ACTIONS(3871), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [111358] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3873), 5,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_PIPE,
  [111370] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3875), 5,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_PIPE,
  [111382] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3734), 5,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACK,
  [111394] = 6,
    ACTIONS(3168), 1,
      anon_sym_as,
    ACTIONS(3170), 1,
      anon_sym_if,
    ACTIONS(3172), 1,
      anon_sym_and,
    ACTIONS(3174), 1,
      anon_sym_or,
    ACTIONS(3877), 1,
      anon_sym_else,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [111414] = 6,
    ACTIONS(2595), 1,
      anon_sym_COLON,
    ACTIONS(3716), 1,
      anon_sym_if,
    ACTIONS(3879), 1,
      anon_sym_COMMA,
    STATE(2171), 1,
      aux_sym_case_clause_repeat1,
    STATE(2804), 1,
      sym_if_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [111434] = 4,
    ACTIONS(3745), 1,
      anon_sym_PIPE,
    STATE(2043), 1,
      aux_sym_union_pattern_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3564), 3,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_RBRACE,
  [111450] = 4,
    ACTIONS(3881), 1,
      anon_sym_PIPE,
    STATE(2110), 1,
      aux_sym_union_pattern_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3597), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
  [111466] = 3,
    STATE(2112), 1,
      aux_sym_union_pattern_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3597), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
  [111480] = 4,
    ACTIONS(3822), 1,
      anon_sym_PIPE,
    STATE(2110), 1,
      aux_sym_union_pattern_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3564), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
  [111496] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3884), 5,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_PIPE,
  [111508] = 6,
    ACTIONS(3168), 1,
      anon_sym_as,
    ACTIONS(3170), 1,
      anon_sym_if,
    ACTIONS(3172), 1,
      anon_sym_and,
    ACTIONS(3174), 1,
      anon_sym_or,
    ACTIONS(3886), 1,
      anon_sym_else,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [111528] = 4,
    ACTIONS(3770), 1,
      anon_sym_PIPE,
    STATE(2027), 1,
      aux_sym_union_pattern_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3564), 3,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_RBRACK,
  [111544] = 6,
    ACTIONS(3757), 1,
      anon_sym_LBRACE,
    ACTIONS(3888), 1,
      anon_sym_RBRACE,
    ACTIONS(3890), 1,
      aux_sym_format_specifier_token1,
    STATE(2041), 1,
      aux_sym_format_specifier_repeat1,
    STATE(2327), 1,
      sym_interpolation,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_continuation,
  [111564] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3892), 5,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_PIPE,
  [111576] = 4,
    ACTIONS(3822), 1,
      anon_sym_PIPE,
    STATE(2112), 1,
      aux_sym_union_pattern_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3695), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
  [111592] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3747), 5,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_PIPE,
  [111604] = 6,
    ACTIONS(3168), 1,
      anon_sym_as,
    ACTIONS(3170), 1,
      anon_sym_if,
    ACTIONS(3172), 1,
      anon_sym_and,
    ACTIONS(3174), 1,
      anon_sym_or,
    ACTIONS(3894), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [111624] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3896), 5,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_PIPE,
  [111636] = 3,
    ACTIONS(3898), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3278), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [111650] = 6,
    ACTIONS(3168), 1,
      anon_sym_as,
    ACTIONS(3170), 1,
      anon_sym_if,
    ACTIONS(3172), 1,
      anon_sym_and,
    ACTIONS(3174), 1,
      anon_sym_or,
    ACTIONS(3900), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [111670] = 6,
    ACTIONS(3168), 1,
      anon_sym_as,
    ACTIONS(3170), 1,
      anon_sym_if,
    ACTIONS(3172), 1,
      anon_sym_and,
    ACTIONS(3174), 1,
      anon_sym_or,
    ACTIONS(3902), 1,
      anon_sym_else,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [111690] = 6,
    ACTIONS(3168), 1,
      anon_sym_as,
    ACTIONS(3170), 1,
      anon_sym_if,
    ACTIONS(3172), 1,
      anon_sym_and,
    ACTIONS(3174), 1,
      anon_sym_or,
    ACTIONS(3904), 1,
      anon_sym_else,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [111710] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3906), 5,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_PIPE,
  [111722] = 5,
    ACTIONS(3908), 1,
      anon_sym_COMMA,
    ACTIONS(3910), 1,
      anon_sym_RBRACE,
    STATE(2366), 1,
      aux_sym_dict_pattern_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3278), 2,
      anon_sym_COLON,
      anon_sym_PIPE,
  [111740] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3912), 5,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_PIPE,
  [111752] = 4,
    ACTIONS(3770), 1,
      anon_sym_PIPE,
    STATE(2115), 1,
      aux_sym_union_pattern_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3710), 3,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_RBRACK,
  [111768] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2930), 5,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACE,
      sym_type_conversion,
  [111780] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3798), 5,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
  [111792] = 6,
    ACTIONS(3168), 1,
      anon_sym_as,
    ACTIONS(3170), 1,
      anon_sym_if,
    ACTIONS(3172), 1,
      anon_sym_and,
    ACTIONS(3174), 1,
      anon_sym_or,
    ACTIONS(3914), 1,
      anon_sym_else,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [111812] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3579), 5,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACK,
  [111824] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3916), 5,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
      anon_sym_PIPE,
  [111836] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3798), 5,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_async,
      anon_sym_for,
      anon_sym_RBRACK,
  [111848] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3562), 5,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [111860] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3084), 5,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_PIPE,
  [111872] = 6,
    ACTIONS(1556), 1,
      anon_sym_LBRACK,
    ACTIONS(3842), 1,
      anon_sym_LPAREN,
    ACTIONS(3918), 1,
      anon_sym_COLON,
    STATE(2382), 1,
      sym_type_parameter,
    STATE(2670), 1,
      sym_argument_list,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [111892] = 5,
    ACTIONS(3920), 1,
      anon_sym_case,
    ACTIONS(3922), 1,
      sym__dedent,
    STATE(2164), 1,
      aux_sym__match_block_repeat1,
    STATE(2560), 1,
      sym_case_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [111909] = 5,
    ACTIONS(3724), 1,
      anon_sym_DOT,
    ACTIONS(3726), 1,
      anon_sym_COLON,
    ACTIONS(3730), 1,
      anon_sym_PIPE,
    ACTIONS(3924), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [111926] = 4,
    ACTIONS(3928), 1,
      anon_sym_COMMA,
    STATE(2141), 1,
      aux_sym_print_statement_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3926), 2,
      sym__newline,
      anon_sym_SEMI,
  [111941] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3278), 2,
      anon_sym_COLON,
      anon_sym_PIPE,
    ACTIONS(3931), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [111954] = 5,
    ACTIONS(3782), 1,
      anon_sym_COLON,
    ACTIONS(3933), 1,
      anon_sym_RBRACE,
    ACTIONS(3935), 1,
      sym_type_conversion,
    STATE(2737), 1,
      sym_format_specifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [111971] = 5,
    ACTIONS(3818), 1,
      anon_sym_RPAREN,
    ACTIONS(3937), 1,
      sym_identifier,
    STATE(2447), 1,
      sym_dotted_name,
    STATE(2573), 1,
      sym_aliased_import,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [111988] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3912), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
  [111999] = 4,
    ACTIONS(3941), 1,
      anon_sym_COLON,
    ACTIONS(3943), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3939), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [112014] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3722), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
  [112025] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3906), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
  [112036] = 4,
    ACTIONS(3947), 1,
      anon_sym_COMMA,
    STATE(2232), 1,
      aux_sym_global_statement_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3945), 2,
      sym__newline,
      anon_sym_SEMI,
  [112051] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3852), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
  [112062] = 4,
    ACTIONS(3947), 1,
      anon_sym_COMMA,
    STATE(2233), 1,
      aux_sym_global_statement_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3949), 2,
      sym__newline,
      anon_sym_SEMI,
  [112077] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3828), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
  [112088] = 5,
    ACTIONS(1556), 1,
      anon_sym_LBRACK,
    ACTIONS(3951), 1,
      anon_sym_LPAREN,
    STATE(2586), 1,
      sym_parameters,
    STATE(2588), 1,
      sym_type_parameter,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [112105] = 5,
    ACTIONS(3818), 1,
      anon_sym_RPAREN,
    ACTIONS(3937), 1,
      sym_identifier,
    STATE(2447), 1,
      sym_dotted_name,
    STATE(2573), 1,
      sym_aliased_import,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [112122] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3873), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [112133] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3741), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
  [112144] = 5,
    ACTIONS(3953), 1,
      anon_sym_RPAREN,
    ACTIONS(3955), 1,
      anon_sym_COMMA,
    ACTIONS(3957), 1,
      anon_sym_as,
    STATE(2523), 1,
      aux_sym_case_clause_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [112161] = 5,
    ACTIONS(3782), 1,
      anon_sym_COLON,
    ACTIONS(3959), 1,
      anon_sym_RBRACE,
    ACTIONS(3961), 1,
      sym_type_conversion,
    STATE(2798), 1,
      sym_format_specifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [112178] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3963), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
  [112189] = 4,
    ACTIONS(3965), 1,
      anon_sym_COMMA,
    STATE(2102), 1,
      aux_sym_assert_statement_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1440), 2,
      sym__newline,
      anon_sym_SEMI,
  [112204] = 5,
    ACTIONS(3920), 1,
      anon_sym_case,
    ACTIONS(3967), 1,
      sym__dedent,
    STATE(2222), 1,
      aux_sym__match_block_repeat1,
    STATE(2560), 1,
      sym_case_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [112221] = 4,
    ACTIONS(3971), 1,
      anon_sym_COMMA,
    STATE(2263), 1,
      aux_sym_print_statement_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3969), 2,
      sym__newline,
      anon_sym_SEMI,
  [112236] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3720), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
  [112247] = 5,
    ACTIONS(3920), 1,
      anon_sym_case,
    ACTIONS(3973), 1,
      sym__dedent,
    STATE(2229), 1,
      aux_sym__match_block_repeat1,
    STATE(2560), 1,
      sym_case_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [112264] = 5,
    ACTIONS(3780), 1,
      anon_sym_RPAREN,
    ACTIONS(3937), 1,
      sym_identifier,
    STATE(2447), 1,
      sym_dotted_name,
    STATE(2573), 1,
      sym_aliased_import,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [112281] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3751), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
  [112292] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3896), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
  [112303] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3747), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
  [112314] = 5,
    ACTIONS(3836), 1,
      anon_sym_RPAREN,
    ACTIONS(3975), 1,
      anon_sym_COMMA,
    ACTIONS(3977), 1,
      anon_sym_as,
    STATE(2471), 1,
      aux_sym__import_list_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [112331] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3873), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
  [112342] = 4,
    ACTIONS(3979), 1,
      anon_sym_COMMA,
    STATE(2171), 1,
      aux_sym_case_clause_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3982), 2,
      anon_sym_if,
      anon_sym_COLON,
  [112357] = 5,
    ACTIONS(3984), 1,
      anon_sym_COMMA,
    ACTIONS(3986), 1,
      anon_sym_as,
    ACTIONS(3988), 1,
      anon_sym_RBRACK,
    STATE(2484), 1,
      aux_sym_case_clause_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [112374] = 4,
    ACTIONS(3992), 1,
      anon_sym_DOT,
    STATE(2237), 1,
      aux_sym_import_prefix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3990), 2,
      anon_sym_import,
      sym_identifier,
  [112389] = 3,
    ACTIONS(3840), 1,
      anon_sym_as,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3994), 3,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [112402] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3732), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
  [112413] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3800), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
  [112424] = 4,
    ACTIONS(3838), 1,
      anon_sym_COMMA,
    STATE(2225), 1,
      aux_sym__import_list_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3836), 2,
      sym__newline,
      anon_sym_SEMI,
  [112439] = 4,
    ACTIONS(3998), 1,
      anon_sym_COMMA,
    STATE(2178), 1,
      aux_sym__import_list_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3996), 2,
      sym__newline,
      anon_sym_SEMI,
  [112454] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3892), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
  [112465] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3875), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
  [112476] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3860), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
  [112487] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3856), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
  [112498] = 5,
    ACTIONS(3957), 1,
      anon_sym_as,
    ACTIONS(4001), 1,
      anon_sym_RPAREN,
    ACTIONS(4003), 1,
      anon_sym_COMMA,
    STATE(2452), 1,
      aux_sym_case_clause_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [112515] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3854), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
  [112526] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3884), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
  [112537] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3747), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [112548] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3850), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
  [112559] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3896), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [112570] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3916), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
  [112581] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3766), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
  [112592] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3873), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_RBRACE,
  [112603] = 4,
    ACTIONS(3273), 1,
      anon_sym_COMMA,
    STATE(2102), 1,
      aux_sym_assert_statement_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4005), 2,
      sym__newline,
      anon_sym_SEMI,
  [112618] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3720), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [112629] = 5,
    ACTIONS(3937), 1,
      sym_identifier,
    STATE(2169), 1,
      sym_dotted_name,
    STATE(2362), 1,
      sym_aliased_import,
    STATE(2664), 1,
      sym__import_list,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [112646] = 5,
    ACTIONS(3986), 1,
      anon_sym_as,
    ACTIONS(4007), 1,
      anon_sym_COMMA,
    ACTIONS(4009), 1,
      anon_sym_RBRACK,
    STATE(2440), 1,
      aux_sym_case_clause_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [112663] = 5,
    ACTIONS(3957), 1,
      anon_sym_as,
    ACTIONS(4011), 1,
      anon_sym_RPAREN,
    ACTIONS(4013), 1,
      anon_sym_COMMA,
    STATE(2438), 1,
      aux_sym_case_clause_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [112680] = 5,
    ACTIONS(3937), 1,
      sym_identifier,
    STATE(2169), 1,
      sym_dotted_name,
    STATE(2362), 1,
      sym_aliased_import,
    STATE(2775), 1,
      sym__import_list,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [112697] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3806), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
  [112708] = 5,
    ACTIONS(3691), 1,
      anon_sym_COMMA,
    ACTIONS(3724), 1,
      anon_sym_DOT,
    ACTIONS(3726), 1,
      anon_sym_COLON,
    ACTIONS(3730), 1,
      anon_sym_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [112725] = 5,
    ACTIONS(1556), 1,
      anon_sym_LBRACK,
    ACTIONS(3951), 1,
      anon_sym_LPAREN,
    STATE(2543), 1,
      sym_type_parameter,
    STATE(2590), 1,
      sym_parameters,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [112742] = 4,
    ACTIONS(4017), 1,
      anon_sym_COMMA,
    STATE(2201), 1,
      aux_sym_global_statement_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4015), 2,
      sym__newline,
      anon_sym_SEMI,
  [112757] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3814), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_RBRACE,
  [112768] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3814), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
  [112779] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3912), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [112790] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4020), 4,
      anon_sym_async,
      anon_sym_def,
      anon_sym_class,
      anon_sym_AT,
  [112801] = 5,
    ACTIONS(3957), 1,
      anon_sym_as,
    ACTIONS(4022), 1,
      anon_sym_RPAREN,
    ACTIONS(4024), 1,
      anon_sym_COMMA,
    STATE(2373), 1,
      aux_sym_case_clause_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [112818] = 5,
    ACTIONS(3986), 1,
      anon_sym_as,
    ACTIONS(4026), 1,
      anon_sym_COMMA,
    ACTIONS(4028), 1,
      anon_sym_RBRACK,
    STATE(2367), 1,
      aux_sym_case_clause_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [112835] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3806), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_RBRACE,
  [112846] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3722), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [112857] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3766), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_RBRACE,
  [112868] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3916), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_RBRACE,
  [112879] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3850), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_RBRACE,
  [112890] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3884), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_RBRACE,
  [112901] = 5,
    ACTIONS(3957), 1,
      anon_sym_as,
    ACTIONS(4030), 1,
      anon_sym_RPAREN,
    ACTIONS(4032), 1,
      anon_sym_COMMA,
    STATE(2376), 1,
      aux_sym_case_clause_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [112918] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3906), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [112929] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3854), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_RBRACE,
  [112940] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3856), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_RBRACE,
  [112951] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3860), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_RBRACE,
  [112962] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3852), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [112973] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3828), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [112984] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3875), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_RBRACE,
  [112995] = 5,
    ACTIONS(3920), 1,
      anon_sym_case,
    ACTIONS(4034), 1,
      sym__dedent,
    STATE(2229), 1,
      aux_sym__match_block_repeat1,
    STATE(2560), 1,
      sym_case_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [113012] = 3,
    ACTIONS(3714), 1,
      anon_sym_as,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3982), 3,
      anon_sym_COMMA,
      anon_sym_if,
      anon_sym_COLON,
  [113025] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3892), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_RBRACE,
  [113036] = 4,
    ACTIONS(4038), 1,
      anon_sym_COMMA,
    STATE(2178), 1,
      aux_sym__import_list_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4036), 2,
      sym__newline,
      anon_sym_SEMI,
  [113051] = 5,
    ACTIONS(1556), 1,
      anon_sym_LBRACK,
    ACTIONS(3951), 1,
      anon_sym_LPAREN,
    STATE(2542), 1,
      sym_type_parameter,
    STATE(2587), 1,
      sym_parameters,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [113068] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3741), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [113079] = 4,
    ACTIONS(4040), 1,
      anon_sym_COMMA,
    STATE(2178), 1,
      aux_sym__import_list_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4036), 2,
      sym__newline,
      anon_sym_SEMI,
  [113094] = 5,
    ACTIONS(4042), 1,
      anon_sym_case,
    ACTIONS(4045), 1,
      sym__dedent,
    STATE(2229), 1,
      aux_sym__match_block_repeat1,
    STATE(2560), 1,
      sym_case_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [113111] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3800), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_RBRACE,
  [113122] = 5,
    ACTIONS(3957), 1,
      anon_sym_as,
    ACTIONS(4047), 1,
      anon_sym_RPAREN,
    ACTIONS(4049), 1,
      anon_sym_COMMA,
    STATE(2334), 1,
      aux_sym_case_clause_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [113139] = 4,
    ACTIONS(3947), 1,
      anon_sym_COMMA,
    STATE(2201), 1,
      aux_sym_global_statement_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4051), 2,
      sym__newline,
      anon_sym_SEMI,
  [113154] = 4,
    ACTIONS(3947), 1,
      anon_sym_COMMA,
    STATE(2201), 1,
      aux_sym_global_statement_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4053), 2,
      sym__newline,
      anon_sym_SEMI,
  [113169] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3732), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_RBRACE,
  [113180] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3751), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_RBRACE,
  [113191] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3710), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_if,
      anon_sym_COLON,
  [113202] = 4,
    ACTIONS(4057), 1,
      anon_sym_DOT,
    STATE(2237), 1,
      aux_sym_import_prefix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4055), 2,
      anon_sym_import,
      sym_identifier,
  [113217] = 5,
    ACTIONS(3957), 1,
      anon_sym_as,
    ACTIONS(4060), 1,
      anon_sym_RPAREN,
    ACTIONS(4062), 1,
      anon_sym_COMMA,
    STATE(2353), 1,
      aux_sym_case_clause_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [113234] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3751), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [113245] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3732), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [113256] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3800), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [113267] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3892), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [113278] = 5,
    ACTIONS(3986), 1,
      anon_sym_as,
    ACTIONS(4064), 1,
      anon_sym_COMMA,
    ACTIONS(4066), 1,
      anon_sym_RBRACK,
    STATE(2340), 1,
      aux_sym_case_clause_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [113295] = 5,
    ACTIONS(3957), 1,
      anon_sym_as,
    ACTIONS(4068), 1,
      anon_sym_RPAREN,
    ACTIONS(4070), 1,
      anon_sym_COMMA,
    STATE(2338), 1,
      aux_sym_case_clause_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [113312] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3875), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [113323] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3860), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [113334] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3741), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_RBRACE,
  [113345] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3856), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [113356] = 5,
    ACTIONS(1556), 1,
      anon_sym_LBRACK,
    ACTIONS(3951), 1,
      anon_sym_LPAREN,
    STATE(2581), 1,
      sym_parameters,
    STATE(2583), 1,
      sym_type_parameter,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [113373] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3854), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [113384] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3852), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_RBRACE,
  [113395] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3884), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [113406] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3906), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_RBRACE,
  [113417] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3850), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [113428] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3722), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_RBRACE,
  [113439] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3912), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_RBRACE,
  [113450] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3916), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [113461] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3720), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_RBRACE,
  [113472] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3896), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_RBRACE,
  [113483] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3766), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [113494] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3806), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [113505] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3828), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_RBRACE,
  [113516] = 4,
    ACTIONS(4074), 1,
      anon_sym_COMMA,
    STATE(2141), 1,
      aux_sym_print_statement_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4072), 2,
      sym__newline,
      anon_sym_SEMI,
  [113531] = 4,
    ACTIONS(3273), 1,
      anon_sym_COMMA,
    STATE(2102), 1,
      aux_sym_assert_statement_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4076), 2,
      sym__newline,
      anon_sym_SEMI,
  [113546] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3814), 4,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [113557] = 4,
    ACTIONS(4080), 1,
      anon_sym_COMMA,
    STATE(2141), 1,
      aux_sym_print_statement_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4078), 2,
      sym__newline,
      anon_sym_SEMI,
  [113572] = 5,
    ACTIONS(3393), 1,
      sym_identifier,
    STATE(2087), 1,
      sym_dotted_name,
    STATE(2177), 1,
      sym_aliased_import,
    STATE(2592), 1,
      sym__import_list,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [113589] = 3,
    ACTIONS(3250), 1,
      anon_sym_from,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3248), 2,
      sym__newline,
      anon_sym_SEMI,
  [113601] = 4,
    ACTIONS(3009), 1,
      anon_sym_RPAREN,
    ACTIONS(3076), 1,
      anon_sym_COMMA,
    STATE(2318), 1,
      aux_sym__collection_elements_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [113615] = 4,
    ACTIONS(4082), 1,
      anon_sym_COMMA,
    ACTIONS(4084), 1,
      anon_sym_in,
    STATE(2389), 1,
      aux_sym__patterns_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [113629] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3710), 3,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_RBRACE,
  [113639] = 4,
    ACTIONS(4082), 1,
      anon_sym_COMMA,
    ACTIONS(4086), 1,
      anon_sym_in,
    STATE(2389), 1,
      aux_sym__patterns_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [113653] = 3,
    ACTIONS(1693), 1,
      anon_sym_except,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1695), 2,
      anon_sym_except_STAR,
      anon_sym_finally,
  [113665] = 4,
    ACTIONS(4088), 1,
      sym__newline,
    ACTIONS(4090), 1,
      sym__indent,
    STATE(757), 1,
      sym__match_block,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [113679] = 4,
    ACTIONS(4092), 1,
      sym__newline,
    ACTIONS(4094), 1,
      sym__indent,
    STATE(789), 1,
      sym__match_block,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [113693] = 4,
    ACTIONS(3446), 1,
      anon_sym_COMMA,
    ACTIONS(3448), 1,
      anon_sym_RBRACE,
    STATE(2290), 1,
      aux_sym_dictionary_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [113707] = 4,
    ACTIONS(3982), 1,
      anon_sym_RBRACK,
    ACTIONS(4096), 1,
      anon_sym_COMMA,
    STATE(2277), 1,
      aux_sym_case_clause_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [113721] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3963), 3,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_RBRACK,
  [113731] = 4,
    ACTIONS(642), 1,
      sym__newline,
    ACTIONS(4099), 1,
      anon_sym_SEMI,
    STATE(2449), 1,
      aux_sym__simple_statements_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [113745] = 3,
    ACTIONS(3986), 1,
      anon_sym_as,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3982), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [113757] = 4,
    ACTIONS(4101), 1,
      anon_sym_COMMA,
    ACTIONS(4103), 1,
      anon_sym_COLON,
    STATE(2347), 1,
      aux_sym_match_statement_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [113771] = 4,
    ACTIONS(4105), 1,
      anon_sym_COMMA,
    ACTIONS(4108), 1,
      anon_sym_COLON,
    STATE(2282), 1,
      aux_sym__parameters_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [113785] = 4,
    ACTIONS(3724), 1,
      anon_sym_DOT,
    ACTIONS(3730), 1,
      anon_sym_PIPE,
    ACTIONS(4110), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [113799] = 4,
    ACTIONS(3076), 1,
      anon_sym_COMMA,
    ACTIONS(4112), 1,
      anon_sym_RPAREN,
    STATE(2318), 1,
      aux_sym__collection_elements_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [113813] = 4,
    ACTIONS(3076), 1,
      anon_sym_COMMA,
    ACTIONS(4114), 1,
      anon_sym_RPAREN,
    STATE(2318), 1,
      aux_sym__collection_elements_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [113827] = 4,
    ACTIONS(3583), 1,
      anon_sym_RBRACK,
    ACTIONS(4116), 1,
      anon_sym_COMMA,
    STATE(2286), 1,
      aux_sym__collection_elements_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [113841] = 4,
    ACTIONS(4119), 1,
      anon_sym_SEMI,
    ACTIONS(4121), 1,
      sym__newline,
    STATE(2387), 1,
      aux_sym__simple_statements_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [113855] = 3,
    ACTIONS(3500), 1,
      aux_sym_format_specifier_token1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3502), 2,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [113867] = 4,
    ACTIONS(4123), 1,
      anon_sym_SEMI,
    ACTIONS(4125), 1,
      sym__newline,
    STATE(2480), 1,
      aux_sym__simple_statements_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [113881] = 4,
    ACTIONS(1318), 1,
      anon_sym_RBRACE,
    ACTIONS(4127), 1,
      anon_sym_COMMA,
    STATE(2306), 1,
      aux_sym_dictionary_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [113895] = 3,
    ACTIONS(3504), 1,
      aux_sym_format_specifier_token1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3506), 2,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [113907] = 3,
    ACTIONS(3510), 1,
      aux_sym_format_specifier_token1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3512), 2,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [113919] = 4,
    ACTIONS(1250), 1,
      anon_sym_RBRACE,
    ACTIONS(4129), 1,
      anon_sym_COMMA,
    STATE(2433), 1,
      aux_sym__collection_elements_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [113933] = 3,
    ACTIONS(3514), 1,
      aux_sym_format_specifier_token1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3516), 2,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [113945] = 3,
    ACTIONS(3550), 1,
      aux_sym_format_specifier_token1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3552), 2,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [113957] = 4,
    ACTIONS(3107), 1,
      anon_sym_RPAREN,
    ACTIONS(3109), 1,
      anon_sym_COMMA,
    STATE(2307), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [113971] = 4,
    ACTIONS(4131), 1,
      anon_sym_RPAREN,
    ACTIONS(4133), 1,
      anon_sym_COMMA,
    STATE(2309), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [113985] = 4,
    ACTIONS(4135), 1,
      anon_sym_COMMA,
    ACTIONS(4137), 1,
      anon_sym_RBRACK,
    STATE(2308), 1,
      aux_sym_subscript_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [113999] = 4,
    ACTIONS(4092), 1,
      sym__newline,
    ACTIONS(4094), 1,
      sym__indent,
    STATE(827), 1,
      sym__match_block,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114013] = 4,
    ACTIONS(3282), 1,
      anon_sym_COMMA,
    ACTIONS(3284), 1,
      anon_sym_RBRACK,
    STATE(2312), 1,
      aux_sym_subscript_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114027] = 3,
    ACTIONS(3556), 1,
      aux_sym_format_specifier_token1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3558), 2,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [114039] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1625), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
  [114049] = 4,
    ACTIONS(4139), 1,
      anon_sym_SEMI,
    ACTIONS(4141), 1,
      sym__newline,
    STATE(2279), 1,
      aux_sym__simple_statements_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114063] = 3,
    ACTIONS(1701), 1,
      anon_sym_except,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1703), 2,
      anon_sym_except_STAR,
      anon_sym_finally,
  [114075] = 4,
    ACTIONS(4143), 1,
      anon_sym_COMMA,
    ACTIONS(4145), 1,
      anon_sym_RBRACK,
    STATE(2308), 1,
      aux_sym_subscript_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114089] = 4,
    ACTIONS(4147), 1,
      anon_sym_COMMA,
    ACTIONS(4150), 1,
      anon_sym_RBRACE,
    STATE(2306), 1,
      aux_sym_dictionary_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114103] = 4,
    ACTIONS(1208), 1,
      anon_sym_RPAREN,
    ACTIONS(4152), 1,
      anon_sym_COMMA,
    STATE(2418), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114117] = 4,
    ACTIONS(4154), 1,
      anon_sym_COMMA,
    ACTIONS(4157), 1,
      anon_sym_RBRACK,
    STATE(2308), 1,
      aux_sym_subscript_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114131] = 4,
    ACTIONS(1216), 1,
      anon_sym_RPAREN,
    ACTIONS(4159), 1,
      anon_sym_COMMA,
    STATE(2418), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114145] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4161), 3,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [114155] = 4,
    ACTIONS(4163), 1,
      anon_sym_COMMA,
    ACTIONS(4165), 1,
      anon_sym_RBRACK,
    STATE(2308), 1,
      aux_sym_subscript_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114169] = 4,
    ACTIONS(4167), 1,
      anon_sym_COMMA,
    ACTIONS(4169), 1,
      anon_sym_RBRACK,
    STATE(2308), 1,
      aux_sym_subscript_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114183] = 4,
    ACTIONS(3808), 1,
      anon_sym_RBRACK,
    ACTIONS(4171), 1,
      anon_sym_COMMA,
    STATE(2313), 1,
      aux_sym_type_parameter_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114197] = 4,
    ACTIONS(1833), 1,
      anon_sym_RPAREN,
    ACTIONS(4174), 1,
      anon_sym_COMMA,
    STATE(2370), 1,
      aux_sym__patterns_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114211] = 4,
    ACTIONS(4082), 1,
      anon_sym_COMMA,
    ACTIONS(4176), 1,
      anon_sym_in,
    STATE(2389), 1,
      aux_sym__patterns_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114225] = 4,
    ACTIONS(990), 1,
      anon_sym_RBRACK,
    ACTIONS(4178), 1,
      anon_sym_COMMA,
    STATE(2313), 1,
      aux_sym_type_parameter_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114239] = 4,
    ACTIONS(3076), 1,
      anon_sym_COMMA,
    ACTIONS(3115), 1,
      anon_sym_RPAREN,
    STATE(2318), 1,
      aux_sym__collection_elements_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114253] = 4,
    ACTIONS(1250), 1,
      anon_sym_RPAREN,
    ACTIONS(4180), 1,
      anon_sym_COMMA,
    STATE(2330), 1,
      aux_sym__collection_elements_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114267] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4015), 3,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [114277] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3710), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
  [114287] = 4,
    ACTIONS(3724), 1,
      anon_sym_DOT,
    ACTIONS(3730), 1,
      anon_sym_PIPE,
    ACTIONS(4182), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114301] = 4,
    ACTIONS(2995), 1,
      anon_sym_RPAREN,
    ACTIONS(4184), 1,
      anon_sym_COMMA,
    STATE(2323), 1,
      aux_sym__parameters_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114315] = 4,
    ACTIONS(4108), 1,
      anon_sym_RPAREN,
    ACTIONS(4186), 1,
      anon_sym_COMMA,
    STATE(2323), 1,
      aux_sym__parameters_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114329] = 4,
    ACTIONS(1290), 1,
      anon_sym_RPAREN,
    ACTIONS(4189), 1,
      anon_sym_COMMA,
    STATE(2368), 1,
      aux_sym_assert_statement_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114343] = 4,
    ACTIONS(4082), 1,
      anon_sym_COMMA,
    ACTIONS(4191), 1,
      anon_sym_in,
    STATE(2389), 1,
      aux_sym__patterns_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114357] = 3,
    ACTIONS(1673), 1,
      anon_sym_except,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1675), 2,
      anon_sym_except_STAR,
      anon_sym_finally,
  [114369] = 3,
    ACTIONS(4195), 1,
      aux_sym_format_specifier_token1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4193), 2,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [114381] = 4,
    ACTIONS(3076), 1,
      anon_sym_COMMA,
    ACTIONS(4197), 1,
      anon_sym_RPAREN,
    STATE(2318), 1,
      aux_sym__collection_elements_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114395] = 4,
    ACTIONS(4199), 1,
      anon_sym_RPAREN,
    ACTIONS(4201), 1,
      anon_sym_COMMA,
    STATE(2465), 1,
      aux_sym_with_clause_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114409] = 4,
    ACTIONS(3583), 1,
      anon_sym_RPAREN,
    ACTIONS(4203), 1,
      anon_sym_COMMA,
    STATE(2330), 1,
      aux_sym__collection_elements_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114423] = 4,
    ACTIONS(4206), 1,
      anon_sym_COMMA,
    ACTIONS(4208), 1,
      anon_sym_RBRACE,
    STATE(2343), 1,
      aux_sym_dict_pattern_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114437] = 4,
    ACTIONS(1188), 1,
      anon_sym_RPAREN,
    ACTIONS(4210), 1,
      anon_sym_COMMA,
    STATE(2418), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114451] = 4,
    ACTIONS(4082), 1,
      anon_sym_COMMA,
    ACTIONS(4212), 1,
      anon_sym_in,
    STATE(2389), 1,
      aux_sym__patterns_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114465] = 4,
    ACTIONS(2695), 1,
      anon_sym_RPAREN,
    ACTIONS(4214), 1,
      anon_sym_COMMA,
    STATE(2497), 1,
      aux_sym_case_clause_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114479] = 4,
    ACTIONS(3724), 1,
      anon_sym_DOT,
    ACTIONS(3730), 1,
      anon_sym_PIPE,
    ACTIONS(4216), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114493] = 4,
    ACTIONS(3076), 1,
      anon_sym_COMMA,
    ACTIONS(4218), 1,
      anon_sym_RPAREN,
    STATE(2318), 1,
      aux_sym__collection_elements_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114507] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3963), 3,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_RBRACE,
  [114517] = 4,
    ACTIONS(2711), 1,
      anon_sym_RPAREN,
    ACTIONS(4220), 1,
      anon_sym_COMMA,
    STATE(2497), 1,
      aux_sym_case_clause_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114531] = 4,
    ACTIONS(1018), 1,
      anon_sym_RBRACK,
    ACTIONS(4222), 1,
      anon_sym_COMMA,
    STATE(2313), 1,
      aux_sym_type_parameter_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114545] = 4,
    ACTIONS(2697), 1,
      anon_sym_RBRACK,
    ACTIONS(4224), 1,
      anon_sym_COMMA,
    STATE(2277), 1,
      aux_sym_case_clause_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114559] = 4,
    ACTIONS(4092), 1,
      sym__newline,
    ACTIONS(4094), 1,
      sym__indent,
    STATE(828), 1,
      sym__match_block,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114573] = 4,
    ACTIONS(3724), 1,
      anon_sym_DOT,
    ACTIONS(3730), 1,
      anon_sym_PIPE,
    ACTIONS(4226), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114587] = 4,
    ACTIONS(4228), 1,
      anon_sym_COMMA,
    ACTIONS(4230), 1,
      anon_sym_RBRACE,
    STATE(2391), 1,
      aux_sym_dict_pattern_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114601] = 4,
    ACTIONS(3724), 1,
      anon_sym_DOT,
    ACTIONS(3730), 1,
      anon_sym_PIPE,
    ACTIONS(4232), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114615] = 4,
    ACTIONS(4234), 1,
      anon_sym_COMMA,
    ACTIONS(4236), 1,
      anon_sym_RBRACE,
    STATE(2391), 1,
      aux_sym_dict_pattern_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114629] = 4,
    ACTIONS(3724), 1,
      anon_sym_DOT,
    ACTIONS(3730), 1,
      anon_sym_PIPE,
    ACTIONS(4238), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114643] = 4,
    ACTIONS(4240), 1,
      anon_sym_COMMA,
    ACTIONS(4243), 1,
      anon_sym_COLON,
    STATE(2347), 1,
      aux_sym_match_statement_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114657] = 4,
    ACTIONS(3724), 1,
      anon_sym_DOT,
    ACTIONS(3730), 1,
      anon_sym_PIPE,
    ACTIONS(4245), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114671] = 4,
    ACTIONS(3782), 1,
      anon_sym_COLON,
    ACTIONS(4247), 1,
      anon_sym_RBRACE,
    STATE(2682), 1,
      sym_format_specifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114685] = 4,
    ACTIONS(4082), 1,
      anon_sym_COMMA,
    ACTIONS(4249), 1,
      anon_sym_in,
    STATE(2389), 1,
      aux_sym__patterns_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114699] = 4,
    ACTIONS(4251), 1,
      anon_sym_RPAREN,
    ACTIONS(4253), 1,
      anon_sym_COMMA,
    STATE(2351), 1,
      aux_sym_with_clause_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114713] = 4,
    ACTIONS(4082), 1,
      anon_sym_COMMA,
    ACTIONS(4256), 1,
      anon_sym_in,
    STATE(2389), 1,
      aux_sym__patterns_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114727] = 4,
    ACTIONS(2617), 1,
      anon_sym_RPAREN,
    ACTIONS(4258), 1,
      anon_sym_COMMA,
    STATE(2497), 1,
      aux_sym_case_clause_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114741] = 4,
    ACTIONS(4082), 1,
      anon_sym_COMMA,
    ACTIONS(4260), 1,
      anon_sym_in,
    STATE(2389), 1,
      aux_sym__patterns_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114755] = 4,
    ACTIONS(3842), 1,
      anon_sym_LPAREN,
    ACTIONS(4262), 1,
      anon_sym_COLON,
    STATE(2776), 1,
      sym_argument_list,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114769] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3994), 3,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [114779] = 3,
    ACTIONS(3648), 1,
      aux_sym_format_specifier_token1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3650), 2,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [114791] = 4,
    ACTIONS(4264), 1,
      anon_sym_COMMA,
    ACTIONS(4266), 1,
      anon_sym_RBRACE,
    STATE(2391), 1,
      aux_sym_dict_pattern_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114805] = 4,
    ACTIONS(3432), 1,
      anon_sym_COMMA,
    ACTIONS(3434), 1,
      anon_sym_RBRACE,
    STATE(2428), 1,
      aux_sym_dictionary_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114819] = 4,
    ACTIONS(2907), 1,
      anon_sym_RBRACK,
    ACTIONS(4268), 1,
      anon_sym_COMMA,
    STATE(2360), 1,
      aux_sym__patterns_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114833] = 4,
    ACTIONS(4271), 1,
      anon_sym_COMMA,
    ACTIONS(4273), 1,
      anon_sym_RBRACE,
    STATE(2391), 1,
      aux_sym_dict_pattern_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114847] = 4,
    ACTIONS(3836), 1,
      anon_sym_RPAREN,
    ACTIONS(3975), 1,
      anon_sym_COMMA,
    STATE(2482), 1,
      aux_sym__import_list_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114861] = 4,
    ACTIONS(2745), 1,
      sym_identifier,
    ACTIONS(4275), 1,
      anon_sym_import,
    STATE(2713), 1,
      sym_dotted_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114875] = 4,
    ACTIONS(2997), 1,
      anon_sym_COMMA,
    ACTIONS(3009), 1,
      anon_sym_RBRACE,
    STATE(2293), 1,
      aux_sym__collection_elements_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114889] = 4,
    ACTIONS(4277), 1,
      anon_sym_SEMI,
    ACTIONS(4279), 1,
      sym__newline,
    STATE(2386), 1,
      aux_sym__simple_statements_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114903] = 4,
    ACTIONS(4281), 1,
      anon_sym_COMMA,
    ACTIONS(4283), 1,
      anon_sym_RBRACE,
    STATE(2391), 1,
      aux_sym_dict_pattern_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114917] = 4,
    ACTIONS(2719), 1,
      anon_sym_RBRACK,
    ACTIONS(4285), 1,
      anon_sym_COMMA,
    STATE(2277), 1,
      aux_sym_case_clause_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114931] = 4,
    ACTIONS(3233), 1,
      anon_sym_RPAREN,
    ACTIONS(4287), 1,
      anon_sym_COMMA,
    STATE(2368), 1,
      aux_sym_assert_statement_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114945] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2422), 3,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_in,
  [114955] = 4,
    ACTIONS(2907), 1,
      anon_sym_RPAREN,
    ACTIONS(4290), 1,
      anon_sym_COMMA,
    STATE(2370), 1,
      aux_sym__patterns_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114969] = 4,
    ACTIONS(3076), 1,
      anon_sym_COMMA,
    ACTIONS(3092), 1,
      anon_sym_RPAREN,
    STATE(2318), 1,
      aux_sym__collection_elements_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114983] = 4,
    ACTIONS(4293), 1,
      anon_sym_COMMA,
    ACTIONS(4295), 1,
      anon_sym_RBRACK,
    STATE(2308), 1,
      aux_sym_subscript_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [114997] = 4,
    ACTIONS(2723), 1,
      anon_sym_RPAREN,
    ACTIONS(4297), 1,
      anon_sym_COMMA,
    STATE(2497), 1,
      aux_sym_case_clause_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115011] = 4,
    ACTIONS(4299), 1,
      anon_sym_COMMA,
    ACTIONS(4301), 1,
      anon_sym_RBRACK,
    STATE(2308), 1,
      aux_sym_subscript_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115025] = 4,
    ACTIONS(4092), 1,
      sym__newline,
    ACTIONS(4094), 1,
      sym__indent,
    STATE(847), 1,
      sym__match_block,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115039] = 4,
    ACTIONS(2641), 1,
      anon_sym_RPAREN,
    ACTIONS(4303), 1,
      anon_sym_COMMA,
    STATE(2497), 1,
      aux_sym_case_clause_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115053] = 4,
    ACTIONS(3336), 1,
      anon_sym_COMMA,
    ACTIONS(3338), 1,
      anon_sym_RBRACK,
    STATE(2372), 1,
      aux_sym_subscript_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115067] = 4,
    ACTIONS(1833), 1,
      anon_sym_RBRACK,
    ACTIONS(4305), 1,
      anon_sym_COMMA,
    STATE(2360), 1,
      aux_sym__patterns_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115081] = 4,
    ACTIONS(3076), 1,
      anon_sym_COMMA,
    ACTIONS(3100), 1,
      anon_sym_RPAREN,
    STATE(2318), 1,
      aux_sym__collection_elements_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115095] = 4,
    ACTIONS(4307), 1,
      anon_sym_COMMA,
    ACTIONS(4309), 1,
      anon_sym_RBRACK,
    STATE(2308), 1,
      aux_sym_subscript_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115109] = 4,
    ACTIONS(3475), 1,
      anon_sym_COMMA,
    ACTIONS(3477), 1,
      anon_sym_RBRACE,
    STATE(2395), 1,
      aux_sym_dictionary_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115123] = 4,
    ACTIONS(3842), 1,
      anon_sym_LPAREN,
    ACTIONS(4311), 1,
      anon_sym_COLON,
    STATE(2815), 1,
      sym_argument_list,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115137] = 4,
    ACTIONS(4313), 1,
      anon_sym_COMMA,
    ACTIONS(4315), 1,
      anon_sym_RBRACK,
    STATE(2308), 1,
      aux_sym_subscript_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115151] = 4,
    ACTIONS(4317), 1,
      anon_sym_RPAREN,
    ACTIONS(4319), 1,
      anon_sym_COMMA,
    STATE(2314), 1,
      aux_sym__patterns_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115165] = 4,
    ACTIONS(3342), 1,
      anon_sym_COMMA,
    ACTIONS(3344), 1,
      anon_sym_RBRACK,
    STATE(2380), 1,
      aux_sym_subscript_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115179] = 4,
    ACTIONS(630), 1,
      sym__newline,
    ACTIONS(4321), 1,
      anon_sym_SEMI,
    STATE(2449), 1,
      aux_sym__simple_statements_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115193] = 4,
    ACTIONS(626), 1,
      sym__newline,
    ACTIONS(4323), 1,
      anon_sym_SEMI,
    STATE(2449), 1,
      aux_sym__simple_statements_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115207] = 4,
    ACTIONS(4088), 1,
      sym__newline,
    ACTIONS(4090), 1,
      sym__indent,
    STATE(739), 1,
      sym__match_block,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115221] = 4,
    ACTIONS(970), 1,
      anon_sym_in,
    ACTIONS(4325), 1,
      anon_sym_COMMA,
    STATE(2442), 1,
      aux_sym__patterns_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115235] = 4,
    ACTIONS(3076), 1,
      anon_sym_COMMA,
    ACTIONS(3078), 1,
      anon_sym_RPAREN,
    STATE(2318), 1,
      aux_sym__collection_elements_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115249] = 4,
    ACTIONS(4327), 1,
      anon_sym_COMMA,
    ACTIONS(4330), 1,
      anon_sym_RBRACE,
    STATE(2391), 1,
      aux_sym_dict_pattern_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115263] = 4,
    ACTIONS(4332), 1,
      anon_sym_COMMA,
    ACTIONS(4334), 1,
      anon_sym_RBRACK,
    STATE(2308), 1,
      aux_sym_subscript_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115277] = 4,
    ACTIONS(4336), 1,
      anon_sym_COMMA,
    ACTIONS(4338), 1,
      anon_sym_RBRACK,
    STATE(2308), 1,
      aux_sym_subscript_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115291] = 4,
    ACTIONS(1238), 1,
      anon_sym_RPAREN,
    ACTIONS(4340), 1,
      anon_sym_COMMA,
    STATE(2418), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115305] = 4,
    ACTIONS(1338), 1,
      anon_sym_RBRACE,
    ACTIONS(4342), 1,
      anon_sym_COMMA,
    STATE(2306), 1,
      aux_sym_dictionary_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115319] = 4,
    ACTIONS(1240), 1,
      anon_sym_RPAREN,
    ACTIONS(4344), 1,
      anon_sym_COMMA,
    STATE(2418), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115333] = 4,
    ACTIONS(3076), 1,
      anon_sym_COMMA,
    ACTIONS(4346), 1,
      anon_sym_RPAREN,
    STATE(2318), 1,
      aux_sym__collection_elements_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115347] = 4,
    ACTIONS(3393), 1,
      sym_identifier,
    STATE(2174), 1,
      sym_dotted_name,
    STATE(2356), 1,
      sym_aliased_import,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115361] = 4,
    ACTIONS(3009), 1,
      anon_sym_RBRACK,
    ACTIONS(3040), 1,
      anon_sym_COMMA,
    STATE(2434), 1,
      aux_sym__collection_elements_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115375] = 4,
    ACTIONS(3076), 1,
      anon_sym_COMMA,
    ACTIONS(4348), 1,
      anon_sym_RPAREN,
    STATE(2318), 1,
      aux_sym__collection_elements_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115389] = 4,
    ACTIONS(3111), 1,
      anon_sym_RPAREN,
    ACTIONS(3113), 1,
      anon_sym_COMMA,
    STATE(2412), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115403] = 4,
    ACTIONS(4350), 1,
      anon_sym_RPAREN,
    ACTIONS(4352), 1,
      anon_sym_COMMA,
    STATE(2414), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115417] = 4,
    ACTIONS(3348), 1,
      anon_sym_COMMA,
    ACTIONS(3350), 1,
      anon_sym_RBRACK,
    STATE(2392), 1,
      aux_sym_subscript_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115431] = 4,
    ACTIONS(4354), 1,
      anon_sym_RPAREN,
    ACTIONS(4356), 1,
      anon_sym_COMMA,
    STATE(2394), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115445] = 4,
    ACTIONS(3265), 1,
      anon_sym_COMMA,
    ACTIONS(3269), 1,
      anon_sym_RBRACK,
    STATE(2417), 1,
      aux_sym_subscript_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115459] = 4,
    ACTIONS(3096), 1,
      anon_sym_RPAREN,
    ACTIONS(3098), 1,
      anon_sym_COMMA,
    STATE(2396), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115473] = 4,
    ACTIONS(4088), 1,
      sym__newline,
    ACTIONS(4090), 1,
      sym__indent,
    STATE(783), 1,
      sym__match_block,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115487] = 4,
    ACTIONS(4358), 1,
      anon_sym_COMMA,
    ACTIONS(4360), 1,
      anon_sym_COLON,
    STATE(2347), 1,
      aux_sym_match_statement_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115501] = 4,
    ACTIONS(1332), 1,
      anon_sym_RBRACE,
    ACTIONS(4362), 1,
      anon_sym_COMMA,
    STATE(2306), 1,
      aux_sym_dictionary_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115515] = 4,
    ACTIONS(4317), 1,
      anon_sym_RBRACK,
    ACTIONS(4364), 1,
      anon_sym_COMMA,
    STATE(2378), 1,
      aux_sym__patterns_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115529] = 4,
    ACTIONS(3782), 1,
      anon_sym_COLON,
    ACTIONS(4366), 1,
      anon_sym_RBRACE,
    STATE(2722), 1,
      sym_format_specifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115543] = 4,
    ACTIONS(1220), 1,
      anon_sym_RPAREN,
    ACTIONS(4368), 1,
      anon_sym_COMMA,
    STATE(2418), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115557] = 4,
    ACTIONS(4370), 1,
      anon_sym_COMMA,
    ACTIONS(4372), 1,
      anon_sym_RBRACE,
    STATE(2361), 1,
      aux_sym_dict_pattern_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115571] = 4,
    ACTIONS(1210), 1,
      anon_sym_RPAREN,
    ACTIONS(4374), 1,
      anon_sym_COMMA,
    STATE(2418), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115585] = 4,
    ACTIONS(640), 1,
      sym__newline,
    ACTIONS(4376), 1,
      anon_sym_SEMI,
    STATE(2449), 1,
      aux_sym__simple_statements_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115599] = 4,
    ACTIONS(4378), 1,
      anon_sym_COMMA,
    ACTIONS(4380), 1,
      anon_sym_RBRACK,
    STATE(2308), 1,
      aux_sym_subscript_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115613] = 4,
    ACTIONS(4382), 1,
      anon_sym_COMMA,
    ACTIONS(4384), 1,
      anon_sym_RBRACK,
    STATE(2308), 1,
      aux_sym_subscript_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115627] = 4,
    ACTIONS(3593), 1,
      anon_sym_RPAREN,
    ACTIONS(4386), 1,
      anon_sym_COMMA,
    STATE(2418), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115641] = 4,
    ACTIONS(992), 1,
      anon_sym_RBRACK,
    ACTIONS(4389), 1,
      anon_sym_COMMA,
    STATE(2313), 1,
      aux_sym_type_parameter_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115655] = 3,
    ACTIONS(1705), 1,
      anon_sym_except,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1707), 2,
      anon_sym_except_STAR,
      anon_sym_finally,
  [115667] = 4,
    ACTIONS(1322), 1,
      anon_sym_RBRACE,
    ACTIONS(4391), 1,
      anon_sym_COMMA,
    STATE(2306), 1,
      aux_sym_dictionary_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115681] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2930), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
  [115691] = 4,
    ACTIONS(3425), 1,
      anon_sym_COMMA,
    ACTIONS(3427), 1,
      anon_sym_RBRACE,
    STATE(2409), 1,
      aux_sym_dictionary_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115705] = 4,
    ACTIONS(3076), 1,
      anon_sym_COMMA,
    ACTIONS(3105), 1,
      anon_sym_RPAREN,
    STATE(2318), 1,
      aux_sym__collection_elements_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115719] = 4,
    ACTIONS(4393), 1,
      anon_sym_SEMI,
    ACTIONS(4395), 1,
      sym__newline,
    STATE(2415), 1,
      aux_sym__simple_statements_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115733] = 3,
    ACTIONS(1691), 1,
      anon_sym_except,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1689), 2,
      anon_sym_except_STAR,
      anon_sym_finally,
  [115745] = 4,
    ACTIONS(3233), 1,
      anon_sym_COLON,
    ACTIONS(4397), 1,
      anon_sym_COMMA,
    STATE(2427), 1,
      aux_sym_assert_statement_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115759] = 4,
    ACTIONS(1328), 1,
      anon_sym_RBRACE,
    ACTIONS(4400), 1,
      anon_sym_COMMA,
    STATE(2306), 1,
      aux_sym_dictionary_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115773] = 4,
    ACTIONS(3724), 1,
      anon_sym_DOT,
    ACTIONS(3730), 1,
      anon_sym_PIPE,
    ACTIONS(4402), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115787] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1625), 3,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_EQ,
  [115797] = 4,
    ACTIONS(1184), 1,
      anon_sym_RPAREN,
    ACTIONS(4404), 1,
      anon_sym_COMMA,
    STATE(2418), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115811] = 4,
    ACTIONS(4406), 1,
      anon_sym_COMMA,
    ACTIONS(4408), 1,
      anon_sym_RBRACE,
    STATE(2443), 1,
      aux_sym_dict_pattern_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115825] = 4,
    ACTIONS(3583), 1,
      anon_sym_RBRACE,
    ACTIONS(4410), 1,
      anon_sym_COMMA,
    STATE(2433), 1,
      aux_sym__collection_elements_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115839] = 4,
    ACTIONS(1250), 1,
      anon_sym_RBRACK,
    ACTIONS(4413), 1,
      anon_sym_COMMA,
    STATE(2286), 1,
      aux_sym__collection_elements_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115853] = 4,
    ACTIONS(2995), 1,
      anon_sym_COLON,
    ACTIONS(4415), 1,
      anon_sym_COMMA,
    STATE(2282), 1,
      aux_sym__parameters_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115867] = 4,
    ACTIONS(4417), 1,
      anon_sym_COMMA,
    ACTIONS(4419), 1,
      anon_sym_RBRACE,
    STATE(2391), 1,
      aux_sym_dict_pattern_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115881] = 4,
    ACTIONS(3117), 1,
      anon_sym_RPAREN,
    ACTIONS(3119), 1,
      anon_sym_COMMA,
    STATE(2431), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115895] = 4,
    ACTIONS(2699), 1,
      anon_sym_RPAREN,
    ACTIONS(4421), 1,
      anon_sym_COMMA,
    STATE(2497), 1,
      aux_sym_case_clause_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115909] = 4,
    ACTIONS(4423), 1,
      anon_sym_COMMA,
    ACTIONS(4425), 1,
      anon_sym_RBRACK,
    STATE(2308), 1,
      aux_sym_subscript_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115923] = 4,
    ACTIONS(2705), 1,
      anon_sym_RBRACK,
    ACTIONS(4427), 1,
      anon_sym_COMMA,
    STATE(2277), 1,
      aux_sym_case_clause_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115937] = 4,
    ACTIONS(4429), 1,
      anon_sym_COMMA,
    ACTIONS(4431), 1,
      anon_sym_RBRACK,
    STATE(2308), 1,
      aux_sym_subscript_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115951] = 4,
    ACTIONS(2907), 1,
      anon_sym_in,
    ACTIONS(4433), 1,
      anon_sym_COMMA,
    STATE(2442), 1,
      aux_sym__patterns_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115965] = 4,
    ACTIONS(4436), 1,
      anon_sym_COMMA,
    ACTIONS(4438), 1,
      anon_sym_RBRACE,
    STATE(2391), 1,
      aux_sym_dict_pattern_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115979] = 4,
    ACTIONS(1196), 1,
      anon_sym_RPAREN,
    ACTIONS(4440), 1,
      anon_sym_COMMA,
    STATE(2418), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [115993] = 4,
    ACTIONS(4442), 1,
      anon_sym_COMMA,
    ACTIONS(4444), 1,
      anon_sym_RBRACE,
    STATE(2391), 1,
      aux_sym_dict_pattern_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116007] = 4,
    ACTIONS(4082), 1,
      anon_sym_COMMA,
    ACTIONS(4446), 1,
      anon_sym_in,
    STATE(2389), 1,
      aux_sym__patterns_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116021] = 3,
    ACTIONS(3977), 1,
      anon_sym_as,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3994), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [116033] = 4,
    ACTIONS(1194), 1,
      anon_sym_RPAREN,
    ACTIONS(4448), 1,
      anon_sym_COMMA,
    STATE(2418), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116047] = 4,
    ACTIONS(4450), 1,
      anon_sym_SEMI,
    ACTIONS(4453), 1,
      sym__newline,
    STATE(2449), 1,
      aux_sym__simple_statements_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116061] = 4,
    ACTIONS(3330), 1,
      anon_sym_COMMA,
    ACTIONS(3332), 1,
      anon_sym_RBRACK,
    STATE(2439), 1,
      aux_sym_subscript_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116075] = 4,
    ACTIONS(1428), 1,
      anon_sym_COLON,
    ACTIONS(4455), 1,
      anon_sym_COMMA,
    STATE(2503), 1,
      aux_sym_with_clause_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116089] = 4,
    ACTIONS(2637), 1,
      anon_sym_RPAREN,
    ACTIONS(4457), 1,
      anon_sym_COMMA,
    STATE(2497), 1,
      aux_sym_case_clause_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116103] = 4,
    ACTIONS(3233), 1,
      anon_sym_RBRACK,
    ACTIONS(4459), 1,
      anon_sym_COMMA,
    STATE(2453), 1,
      aux_sym_assert_statement_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116117] = 4,
    ACTIONS(1290), 1,
      anon_sym_COLON,
    ACTIONS(4462), 1,
      anon_sym_COMMA,
    STATE(2427), 1,
      aux_sym_assert_statement_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116131] = 4,
    ACTIONS(4464), 1,
      anon_sym_RPAREN,
    ACTIONS(4466), 1,
      anon_sym_COMMA,
    STATE(2444), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116145] = 4,
    ACTIONS(3937), 1,
      sym_identifier,
    STATE(2447), 1,
      sym_dotted_name,
    STATE(2573), 1,
      sym_aliased_import,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116159] = 4,
    ACTIONS(3088), 1,
      anon_sym_RPAREN,
    ACTIONS(3090), 1,
      anon_sym_COMMA,
    STATE(2448), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116173] = 4,
    ACTIONS(982), 1,
      anon_sym_RBRACK,
    ACTIONS(4468), 1,
      anon_sym_COMMA,
    STATE(2313), 1,
      aux_sym_type_parameter_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116187] = 3,
    ACTIONS(3943), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3939), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [116199] = 4,
    ACTIONS(3121), 1,
      anon_sym_RPAREN,
    ACTIONS(3123), 1,
      anon_sym_COMMA,
    STATE(2520), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116213] = 4,
    ACTIONS(4470), 1,
      anon_sym_COMMA,
    ACTIONS(4472), 1,
      anon_sym_COLON,
    STATE(2451), 1,
      aux_sym_with_clause_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116227] = 4,
    ACTIONS(4474), 1,
      anon_sym_SEMI,
    ACTIONS(4476), 1,
      sym__newline,
    STATE(2481), 1,
      aux_sym__simple_statements_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116241] = 4,
    ACTIONS(1340), 1,
      anon_sym_RBRACE,
    ACTIONS(4478), 1,
      anon_sym_COMMA,
    STATE(2306), 1,
      aux_sym_dictionary_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116255] = 3,
    ACTIONS(3682), 1,
      aux_sym_format_specifier_token1,
    ACTIONS(5), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3684), 2,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [116267] = 4,
    ACTIONS(1420), 1,
      anon_sym_RPAREN,
    ACTIONS(4480), 1,
      anon_sym_COMMA,
    STATE(2351), 1,
      aux_sym_with_clause_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116281] = 4,
    ACTIONS(4482), 1,
      anon_sym_RPAREN,
    ACTIONS(4484), 1,
      anon_sym_COMMA,
    STATE(2519), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116295] = 4,
    ACTIONS(1290), 1,
      anon_sym_RBRACK,
    ACTIONS(4486), 1,
      anon_sym_COMMA,
    STATE(2453), 1,
      aux_sym_assert_statement_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116309] = 4,
    ACTIONS(3076), 1,
      anon_sym_COMMA,
    ACTIONS(3080), 1,
      anon_sym_RPAREN,
    STATE(2318), 1,
      aux_sym__collection_elements_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116323] = 4,
    ACTIONS(632), 1,
      sym__newline,
    ACTIONS(4488), 1,
      anon_sym_SEMI,
    STATE(2449), 1,
      aux_sym__simple_statements_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116337] = 4,
    ACTIONS(3399), 1,
      anon_sym_COMMA,
    ACTIONS(3401), 1,
      anon_sym_RBRACE,
    STATE(2463), 1,
      aux_sym_dictionary_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116351] = 4,
    ACTIONS(4036), 1,
      anon_sym_RPAREN,
    ACTIONS(4490), 1,
      anon_sym_COMMA,
    STATE(2474), 1,
      aux_sym__import_list_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116365] = 3,
    ACTIONS(4494), 1,
      anon_sym_in,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4492), 2,
      sym__newline,
      anon_sym_SEMI,
  [116377] = 4,
    ACTIONS(3074), 1,
      anon_sym_RPAREN,
    ACTIONS(3076), 1,
      anon_sym_COMMA,
    STATE(2318), 1,
      aux_sym__collection_elements_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116391] = 4,
    ACTIONS(3996), 1,
      anon_sym_RPAREN,
    ACTIONS(4496), 1,
      anon_sym_COMMA,
    STATE(2474), 1,
      aux_sym__import_list_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116405] = 4,
    ACTIONS(3306), 1,
      anon_sym_COMMA,
    ACTIONS(3308), 1,
      anon_sym_RBRACK,
    STATE(2498), 1,
      aux_sym_subscript_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116419] = 4,
    ACTIONS(3438), 1,
      anon_sym_COMMA,
    ACTIONS(3440), 1,
      anon_sym_RBRACE,
    STATE(2489), 1,
      aux_sym_dictionary_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116433] = 4,
    ACTIONS(4499), 1,
      anon_sym_SEMI,
    ACTIONS(4501), 1,
      sym__newline,
    STATE(2469), 1,
      aux_sym__simple_statements_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116447] = 4,
    ACTIONS(3782), 1,
      anon_sym_COLON,
    ACTIONS(4503), 1,
      anon_sym_RBRACE,
    STATE(2727), 1,
      sym_format_specifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116461] = 4,
    ACTIONS(4505), 1,
      anon_sym_RPAREN,
    ACTIONS(4507), 1,
      anon_sym_COMMA,
    STATE(2322), 1,
      aux_sym__parameters_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116475] = 4,
    ACTIONS(622), 1,
      sym__newline,
    ACTIONS(4509), 1,
      anon_sym_SEMI,
    STATE(2449), 1,
      aux_sym__simple_statements_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116489] = 4,
    ACTIONS(648), 1,
      sym__newline,
    ACTIONS(4511), 1,
      anon_sym_SEMI,
    STATE(2449), 1,
      aux_sym__simple_statements_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116503] = 4,
    ACTIONS(4036), 1,
      anon_sym_RPAREN,
    ACTIONS(4513), 1,
      anon_sym_COMMA,
    STATE(2474), 1,
      aux_sym__import_list_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116517] = 4,
    ACTIONS(4088), 1,
      sym__newline,
    ACTIONS(4090), 1,
      sym__indent,
    STATE(741), 1,
      sym__match_block,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116531] = 4,
    ACTIONS(2673), 1,
      anon_sym_RBRACK,
    ACTIONS(4515), 1,
      anon_sym_COMMA,
    STATE(2277), 1,
      aux_sym_case_clause_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116545] = 4,
    ACTIONS(4517), 1,
      anon_sym_COMMA,
    ACTIONS(4519), 1,
      anon_sym_RBRACK,
    STATE(2308), 1,
      aux_sym_subscript_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116559] = 4,
    ACTIONS(4521), 1,
      anon_sym_COMMA,
    ACTIONS(4523), 1,
      anon_sym_RBRACK,
    STATE(2308), 1,
      aux_sym_subscript_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116573] = 4,
    ACTIONS(1170), 1,
      anon_sym_RPAREN,
    ACTIONS(4525), 1,
      anon_sym_COMMA,
    STATE(2418), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116587] = 3,
    ACTIONS(4529), 1,
      anon_sym_as,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4527), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [116599] = 4,
    ACTIONS(1314), 1,
      anon_sym_RBRACE,
    ACTIONS(4531), 1,
      anon_sym_COMMA,
    STATE(2306), 1,
      aux_sym_dictionary_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116613] = 4,
    ACTIONS(1168), 1,
      anon_sym_RPAREN,
    ACTIONS(4533), 1,
      anon_sym_COMMA,
    STATE(2418), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116627] = 4,
    ACTIONS(3566), 1,
      anon_sym_PIPE,
    ACTIONS(4535), 1,
      anon_sym_COLON,
    STATE(1938), 1,
      aux_sym_union_pattern_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116641] = 4,
    ACTIONS(3318), 1,
      anon_sym_COMMA,
    ACTIONS(3320), 1,
      anon_sym_RBRACK,
    STATE(2485), 1,
      aux_sym_subscript_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116655] = 4,
    ACTIONS(3782), 1,
      anon_sym_COLON,
    ACTIONS(4537), 1,
      anon_sym_RBRACE,
    STATE(2647), 1,
      sym_format_specifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116669] = 4,
    ACTIONS(4082), 1,
      anon_sym_COMMA,
    ACTIONS(4539), 1,
      anon_sym_in,
    STATE(2389), 1,
      aux_sym__patterns_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116683] = 4,
    ACTIONS(3070), 1,
      anon_sym_RPAREN,
    ACTIONS(3072), 1,
      anon_sym_COMMA,
    STATE(2504), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116697] = 4,
    ACTIONS(4541), 1,
      anon_sym_RPAREN,
    ACTIONS(4543), 1,
      anon_sym_COMMA,
    STATE(2506), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116711] = 4,
    ACTIONS(3982), 1,
      anon_sym_RPAREN,
    ACTIONS(4545), 1,
      anon_sym_COMMA,
    STATE(2497), 1,
      aux_sym_case_clause_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116725] = 4,
    ACTIONS(4548), 1,
      anon_sym_COMMA,
    ACTIONS(4550), 1,
      anon_sym_RBRACK,
    STATE(2308), 1,
      aux_sym_subscript_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116739] = 4,
    ACTIONS(3314), 1,
      anon_sym_COMMA,
    ACTIONS(3316), 1,
      anon_sym_RBRACK,
    STATE(2509), 1,
      aux_sym_subscript_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116753] = 4,
    ACTIONS(4552), 1,
      anon_sym_RPAREN,
    ACTIONS(4554), 1,
      anon_sym_COMMA,
    STATE(2487), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116767] = 4,
    ACTIONS(3054), 1,
      anon_sym_RPAREN,
    ACTIONS(3056), 1,
      anon_sym_COMMA,
    STATE(2490), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116781] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2459), 3,
      sym__newline,
      anon_sym_SEMI,
      anon_sym_in,
  [116791] = 4,
    ACTIONS(4251), 1,
      anon_sym_COLON,
    ACTIONS(4556), 1,
      anon_sym_COMMA,
    STATE(2503), 1,
      aux_sym_with_clause_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116805] = 4,
    ACTIONS(1140), 1,
      anon_sym_RPAREN,
    ACTIONS(4559), 1,
      anon_sym_COMMA,
    STATE(2418), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116819] = 3,
    ACTIONS(4561), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3939), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
  [116831] = 4,
    ACTIONS(1148), 1,
      anon_sym_RPAREN,
    ACTIONS(4563), 1,
      anon_sym_COMMA,
    STATE(2418), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116845] = 4,
    ACTIONS(4505), 1,
      anon_sym_COLON,
    ACTIONS(4565), 1,
      anon_sym_COMMA,
    STATE(2435), 1,
      aux_sym__parameters_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116859] = 4,
    ACTIONS(4567), 1,
      anon_sym_COMMA,
    ACTIONS(4569), 1,
      anon_sym_RBRACK,
    STATE(2308), 1,
      aux_sym_subscript_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116873] = 4,
    ACTIONS(4571), 1,
      anon_sym_COMMA,
    ACTIONS(4573), 1,
      anon_sym_RBRACK,
    STATE(2308), 1,
      aux_sym_subscript_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116887] = 4,
    ACTIONS(1316), 1,
      anon_sym_RBRACE,
    ACTIONS(4575), 1,
      anon_sym_COMMA,
    STATE(2306), 1,
      aux_sym_dictionary_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116901] = 4,
    ACTIONS(4577), 1,
      anon_sym_COMMA,
    ACTIONS(4579), 1,
      anon_sym_RBRACE,
    STATE(2436), 1,
      aux_sym_dict_pattern_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116915] = 3,
    ACTIONS(4561), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3939), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
  [116927] = 4,
    ACTIONS(620), 1,
      sym__newline,
    ACTIONS(4581), 1,
      anon_sym_SEMI,
    STATE(2449), 1,
      aux_sym__simple_statements_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116941] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3963), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_as,
  [116951] = 3,
    ACTIONS(3957), 1,
      anon_sym_as,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3982), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [116963] = 4,
    ACTIONS(4583), 1,
      anon_sym_COMMA,
    ACTIONS(4585), 1,
      anon_sym_RBRACK,
    STATE(2308), 1,
      aux_sym_subscript_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116977] = 4,
    ACTIONS(3463), 1,
      anon_sym_COMMA,
    ACTIONS(3465), 1,
      anon_sym_RBRACE,
    STATE(2510), 1,
      aux_sym_dictionary_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [116991] = 4,
    ACTIONS(3356), 1,
      anon_sym_COMMA,
    ACTIONS(3358), 1,
      anon_sym_RBRACE,
    STATE(2421), 1,
      aux_sym_dictionary_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [117005] = 4,
    ACTIONS(1242), 1,
      anon_sym_RPAREN,
    ACTIONS(4587), 1,
      anon_sym_COMMA,
    STATE(2418), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [117019] = 4,
    ACTIONS(1142), 1,
      anon_sym_RPAREN,
    ACTIONS(4589), 1,
      anon_sym_COMMA,
    STATE(2418), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [117033] = 4,
    ACTIONS(3310), 1,
      anon_sym_COMMA,
    ACTIONS(3312), 1,
      anon_sym_RBRACK,
    STATE(2298), 1,
      aux_sym_subscript_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [117047] = 4,
    ACTIONS(4591), 1,
      anon_sym_SEMI,
    ACTIONS(4593), 1,
      sym__newline,
    STATE(2513), 1,
      aux_sym__simple_statements_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [117061] = 4,
    ACTIONS(2675), 1,
      anon_sym_RPAREN,
    ACTIONS(4595), 1,
      anon_sym_COMMA,
    STATE(2497), 1,
      aux_sym_case_clause_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [117075] = 4,
    ACTIONS(4597), 1,
      anon_sym_RPAREN,
    ACTIONS(4599), 1,
      anon_sym_COMMA,
    STATE(2332), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [117089] = 3,
    ACTIONS(4601), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3939), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [117101] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3710), 3,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_RBRACK,
  [117111] = 4,
    ACTIONS(3076), 1,
      anon_sym_COMMA,
    ACTIONS(3094), 1,
      anon_sym_RPAREN,
    STATE(2318), 1,
      aux_sym__collection_elements_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [117125] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4603), 2,
      sym__dedent,
      anon_sym_case,
  [117134] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4605), 2,
      sym__newline,
      anon_sym_SEMI,
  [117143] = 3,
    ACTIONS(4607), 1,
      sym_integer,
    ACTIONS(4609), 1,
      sym_float,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [117154] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1689), 2,
      sym__dedent,
      anon_sym_case,
  [117163] = 3,
    ACTIONS(4611), 1,
      sym_integer,
    ACTIONS(4613), 1,
      sym_float,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [117174] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4615), 2,
      sym__newline,
      anon_sym_SEMI,
  [117183] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1703), 2,
      sym__dedent,
      anon_sym_case,
  [117192] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4617), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [117201] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1695), 2,
      sym__dedent,
      anon_sym_case,
  [117210] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4619), 2,
      sym__newline,
      anon_sym_SEMI,
  [117219] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4621), 2,
      anon_sym_COLON,
      anon_sym_DASH_GT,
  [117228] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4623), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
  [117237] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4625), 2,
      sym__newline,
      anon_sym_SEMI,
  [117246] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4627), 2,
      sym__newline,
      anon_sym_SEMI,
  [117255] = 3,
    ACTIONS(3951), 1,
      anon_sym_LPAREN,
    STATE(2582), 1,
      sym_parameters,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [117266] = 3,
    ACTIONS(3951), 1,
      anon_sym_LPAREN,
    STATE(2584), 1,
      sym_parameters,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [117277] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4629), 2,
      sym__newline,
      anon_sym_SEMI,
  [117286] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4631), 2,
      sym__dedent,
      anon_sym_case,
  [117295] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2930), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [117304] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4633), 2,
      sym__dedent,
      anon_sym_case,
  [117313] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4635), 2,
      sym__dedent,
      anon_sym_case,
  [117322] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3939), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
  [117331] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4637), 2,
      sym__dedent,
      anon_sym_case,
  [117340] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4639), 2,
      sym__newline,
      anon_sym_SEMI,
  [117349] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3939), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
  [117358] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3185), 2,
      sym__newline,
      anon_sym_SEMI,
  [117367] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2924), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [117376] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4641), 2,
      sym__dedent,
      anon_sym_case,
  [117385] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3185), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [117394] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4643), 2,
      sym__newline,
      anon_sym_SEMI,
  [117403] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4645), 2,
      sym__dedent,
      anon_sym_case,
  [117412] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3082), 2,
      sym__newline,
      anon_sym_SEMI,
  [117421] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4647), 2,
      sym__dedent,
      anon_sym_case,
  [117430] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4251), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
  [117439] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4649), 2,
      sym__dedent,
      anon_sym_case,
  [117448] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4651), 2,
      anon_sym__,
      sym_identifier,
  [117457] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4108), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [117466] = 3,
    ACTIONS(4653), 1,
      sym_integer,
    ACTIONS(4655), 1,
      sym_float,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [117477] = 3,
    ACTIONS(4657), 1,
      sym_integer,
    ACTIONS(4659), 1,
      sym_float,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [117488] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1675), 2,
      sym__dedent,
      anon_sym_case,
  [117497] = 3,
    ACTIONS(4661), 1,
      sym_integer,
    ACTIONS(4663), 1,
      sym_float,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [117508] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4665), 2,
      sym__dedent,
      anon_sym_case,
  [117517] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3939), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [117526] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2924), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [117535] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4667), 2,
      anon_sym_COLON,
      anon_sym_DASH_GT,
  [117544] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3994), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [117553] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1558), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [117562] = 3,
    ACTIONS(4669), 1,
      sym_integer,
    ACTIONS(4671), 1,
      sym_float,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [117573] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2907), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [117582] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4108), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
  [117591] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3583), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [117600] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4673), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [117609] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3185), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [117618] = 3,
    ACTIONS(4675), 1,
      anon_sym_COLON,
    ACTIONS(4677), 1,
      anon_sym_DASH_GT,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [117629] = 3,
    ACTIONS(4679), 1,
      anon_sym_COLON,
    ACTIONS(4681), 1,
      anon_sym_DASH_GT,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [117640] = 3,
    ACTIONS(3951), 1,
      anon_sym_LPAREN,
    STATE(2610), 1,
      sym_parameters,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [117651] = 3,
    ACTIONS(4683), 1,
      anon_sym_COLON,
    ACTIONS(4685), 1,
      anon_sym_DASH_GT,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [117662] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2907), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [117671] = 3,
    ACTIONS(4687), 1,
      anon_sym_COLON,
    ACTIONS(4689), 1,
      anon_sym_DASH_GT,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [117682] = 3,
    ACTIONS(4691), 1,
      anon_sym_COLON,
    ACTIONS(4693), 1,
      anon_sym_DASH_GT,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [117693] = 3,
    ACTIONS(3951), 1,
      anon_sym_LPAREN,
    STATE(2604), 1,
      sym_parameters,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [117704] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4623), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [117713] = 3,
    ACTIONS(4695), 1,
      anon_sym_COLON,
    ACTIONS(4697), 1,
      anon_sym_DASH_GT,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [117724] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1707), 2,
      sym__dedent,
      anon_sym_case,
  [117733] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4699), 2,
      sym__newline,
      anon_sym_SEMI,
  [117742] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4701), 2,
      sym__dedent,
      anon_sym_case,
  [117751] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4703), 2,
      sym__newline,
      anon_sym_SEMI,
  [117760] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4150), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [117769] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4705), 2,
      sym__dedent,
      anon_sym_case,
  [117778] = 3,
    ACTIONS(4707), 1,
      sym_integer,
    ACTIONS(4709), 1,
      sym_float,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [117789] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4711), 2,
      sym__dedent,
      anon_sym_case,
  [117798] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4251), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [117807] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1558), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [117816] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4713), 2,
      anon_sym__,
      sym_identifier,
  [117825] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3593), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [117834] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3461), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [117843] = 3,
    ACTIONS(4715), 1,
      anon_sym_COLON,
    ACTIONS(4717), 1,
      anon_sym_DASH_GT,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [117854] = 3,
    ACTIONS(4719), 1,
      anon_sym_COMMA,
    STATE(2014), 1,
      aux_sym__patterns_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [117865] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4721), 2,
      sym__newline,
      anon_sym_SEMI,
  [117874] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4723), 2,
      sym__newline,
      anon_sym_SEMI,
  [117883] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4161), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [117892] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4725), 2,
      sym__newline,
      anon_sym_SEMI,
  [117901] = 3,
    ACTIONS(4727), 1,
      anon_sym_COLON,
    ACTIONS(4729), 1,
      anon_sym_DASH_GT,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [117912] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4731), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [117921] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4733), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [117930] = 3,
    ACTIONS(4735), 1,
      sym_integer,
    ACTIONS(4737), 1,
      sym_float,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [117941] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4673), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [117950] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4453), 2,
      sym__newline,
      anon_sym_SEMI,
  [117959] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4733), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [117968] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4739), 2,
      anon_sym__,
      sym_identifier,
  [117977] = 3,
    ACTIONS(4741), 1,
      sym_integer,
    ACTIONS(4743), 1,
      sym_float,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [117988] = 3,
    ACTIONS(4745), 1,
      sym_integer,
    ACTIONS(4747), 1,
      sym_float,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [117999] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4733), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [118008] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3340), 2,
      sym__newline,
      anon_sym_SEMI,
  [118017] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3334), 2,
      sym__newline,
      anon_sym_SEMI,
  [118026] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4749), 2,
      anon_sym__,
      sym_identifier,
  [118035] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(4673), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [118044] = 3,
    ACTIONS(4751), 1,
      sym_integer,
    ACTIONS(4753), 1,
      sym_float,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118055] = 3,
    ACTIONS(4755), 1,
      sym_integer,
    ACTIONS(4757), 1,
      sym_float,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118066] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3583), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [118075] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(3583), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [118084] = 2,
    ACTIONS(4759), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118092] = 2,
    ACTIONS(4761), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118100] = 2,
    ACTIONS(4763), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118108] = 2,
    ACTIONS(1426), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118116] = 2,
    ACTIONS(4765), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118124] = 2,
    ACTIONS(4767), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118132] = 2,
    ACTIONS(4769), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118140] = 2,
    ACTIONS(4256), 1,
      anon_sym_in,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118148] = 2,
    ACTIONS(4771), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118156] = 2,
    ACTIONS(4773), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118164] = 2,
    ACTIONS(4775), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118172] = 2,
    ACTIONS(4777), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118180] = 2,
    ACTIONS(3427), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118188] = 2,
    ACTIONS(4779), 1,
      anon_sym_in,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118196] = 2,
    ACTIONS(4781), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118204] = 2,
    ACTIONS(4783), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118212] = 2,
    ACTIONS(4785), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118220] = 2,
    ACTIONS(4787), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118228] = 2,
    ACTIONS(4789), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118236] = 2,
    ACTIONS(4791), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118244] = 2,
    ACTIONS(1464), 1,
      anon_sym_def,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118252] = 2,
    ACTIONS(4793), 1,
      anon_sym_in,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118260] = 2,
    ACTIONS(4795), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118268] = 2,
    ACTIONS(4797), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118276] = 2,
    ACTIONS(4446), 1,
      anon_sym_in,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118284] = 2,
    ACTIONS(3121), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118292] = 2,
    ACTIONS(4799), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118300] = 2,
    ACTIONS(4801), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118308] = 2,
    ACTIONS(4803), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118316] = 2,
    ACTIONS(4805), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118324] = 2,
    ACTIONS(3096), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118332] = 2,
    ACTIONS(4807), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118340] = 2,
    ACTIONS(4809), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118348] = 2,
    ACTIONS(4811), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118356] = 2,
    ACTIONS(4813), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118364] = 2,
    ACTIONS(4815), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118372] = 2,
    ACTIONS(3111), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118380] = 2,
    ACTIONS(4817), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118388] = 2,
    ACTIONS(4819), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118396] = 2,
    ACTIONS(4821), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118404] = 2,
    ACTIONS(4823), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118412] = 2,
    ACTIONS(4825), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118420] = 2,
    ACTIONS(4827), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118428] = 2,
    ACTIONS(4829), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118436] = 2,
    ACTIONS(4831), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118444] = 2,
    ACTIONS(4833), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118452] = 2,
    ACTIONS(4835), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118460] = 2,
    ACTIONS(4837), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118468] = 2,
    ACTIONS(4839), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118476] = 2,
    ACTIONS(4841), 1,
      anon_sym_import,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118484] = 2,
    ACTIONS(3434), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118492] = 2,
    ACTIONS(3088), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118500] = 2,
    ACTIONS(4843), 1,
      anon_sym_in,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118508] = 2,
    ACTIONS(4845), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118516] = 2,
    ACTIONS(4847), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118524] = 2,
    ACTIONS(4849), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118532] = 2,
    ACTIONS(4851), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118540] = 2,
    ACTIONS(4853), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118548] = 2,
    ACTIONS(4855), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118556] = 2,
    ACTIONS(3477), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118564] = 2,
    ACTIONS(4857), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118572] = 2,
    ACTIONS(4859), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118580] = 2,
    ACTIONS(4861), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118588] = 2,
    ACTIONS(3117), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118596] = 2,
    ACTIONS(4863), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118604] = 2,
    ACTIONS(4865), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118612] = 2,
    ACTIONS(4867), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118620] = 2,
    ACTIONS(4869), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118628] = 2,
    ACTIONS(4871), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118636] = 2,
    ACTIONS(4873), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118644] = 2,
    ACTIONS(4875), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118652] = 2,
    ACTIONS(4877), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118660] = 2,
    ACTIONS(4879), 1,
      anon_sym_in,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118668] = 2,
    ACTIONS(4881), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118676] = 2,
    ACTIONS(4883), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118684] = 2,
    ACTIONS(4885), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118692] = 2,
    ACTIONS(4887), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118700] = 2,
    ACTIONS(4889), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118708] = 2,
    ACTIONS(4891), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118716] = 2,
    ACTIONS(4893), 1,
      anon_sym_import,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118724] = 2,
    ACTIONS(4895), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118732] = 2,
    ACTIONS(4897), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118740] = 2,
    ACTIONS(4899), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118748] = 2,
    ACTIONS(4901), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118756] = 2,
    ACTIONS(4903), 1,
      anon_sym_import,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118764] = 2,
    ACTIONS(4905), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118772] = 2,
    ACTIONS(3471), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118780] = 2,
    ACTIONS(4907), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118788] = 2,
    ACTIONS(3409), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118796] = 2,
    ACTIONS(4909), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118804] = 2,
    ACTIONS(4911), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118812] = 2,
    ACTIONS(4913), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118820] = 2,
    ACTIONS(4915), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118828] = 2,
    ACTIONS(4917), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118836] = 2,
    ACTIONS(4260), 1,
      anon_sym_in,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118844] = 2,
    ACTIONS(3401), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118852] = 2,
    ACTIONS(3421), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118860] = 2,
    ACTIONS(4919), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118868] = 2,
    ACTIONS(4921), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118876] = 2,
    ACTIONS(4923), 1,
      anon_sym_in,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118884] = 2,
    ACTIONS(4925), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118892] = 2,
    ACTIONS(4927), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118900] = 2,
    ACTIONS(4929), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118908] = 2,
    ACTIONS(4249), 1,
      anon_sym_in,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118916] = 2,
    ACTIONS(4931), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118924] = 2,
    ACTIONS(3423), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118932] = 2,
    ACTIONS(4933), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118940] = 2,
    ACTIONS(4935), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118948] = 2,
    ACTIONS(4937), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118956] = 2,
    ACTIONS(4939), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118964] = 2,
    ACTIONS(3440), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118972] = 2,
    ACTIONS(4941), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118980] = 2,
    ACTIONS(4943), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118988] = 2,
    ACTIONS(4945), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [118996] = 2,
    ACTIONS(4947), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119004] = 2,
    ACTIONS(4949), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119012] = 2,
    ACTIONS(4951), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119020] = 2,
    ACTIONS(4953), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119028] = 2,
    ACTIONS(4955), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119036] = 2,
    ACTIONS(4957), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119044] = 2,
    ACTIONS(4959), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119052] = 2,
    ACTIONS(4539), 1,
      anon_sym_in,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119060] = 2,
    ACTIONS(4961), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119068] = 2,
    ACTIONS(4963), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119076] = 2,
    ACTIONS(4965), 1,
      anon_sym_in,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119084] = 2,
    ACTIONS(4967), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119092] = 2,
    ACTIONS(4969), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119100] = 2,
    ACTIONS(4971), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119108] = 2,
    ACTIONS(4212), 1,
      anon_sym_in,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119116] = 2,
    ACTIONS(4973), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119124] = 2,
    ACTIONS(4191), 1,
      anon_sym_in,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119132] = 2,
    ACTIONS(4975), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119140] = 2,
    ACTIONS(4977), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119148] = 2,
    ACTIONS(4979), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119156] = 2,
    ACTIONS(4981), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119164] = 2,
    ACTIONS(4983), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119172] = 2,
    ACTIONS(4985), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119180] = 2,
    ACTIONS(4987), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119188] = 2,
    ACTIONS(4989), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119196] = 2,
    ACTIONS(4176), 1,
      anon_sym_in,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119204] = 2,
    ACTIONS(4991), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119212] = 2,
    ACTIONS(4993), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119220] = 2,
    ACTIONS(3070), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119228] = 2,
    ACTIONS(4995), 1,
      anon_sym_for,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119236] = 2,
    ACTIONS(4997), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119244] = 2,
    ACTIONS(3054), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119252] = 2,
    ACTIONS(4999), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119260] = 2,
    ACTIONS(5001), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119268] = 2,
    ACTIONS(5003), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119276] = 2,
    ACTIONS(5005), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119284] = 2,
    ACTIONS(5007), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119292] = 2,
    ACTIONS(3107), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119300] = 2,
    ACTIONS(5009), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119308] = 2,
    ACTIONS(5011), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119316] = 2,
    ACTIONS(5013), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119324] = 2,
    ACTIONS(5015), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119332] = 2,
    ACTIONS(5017), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119340] = 2,
    ACTIONS(5019), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119348] = 2,
    ACTIONS(5021), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119356] = 2,
    ACTIONS(5023), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119364] = 2,
    ACTIONS(5025), 1,
      ts_builtin_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119372] = 2,
    ACTIONS(5027), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119380] = 2,
    ACTIONS(5029), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119388] = 2,
    ACTIONS(5031), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119396] = 2,
    ACTIONS(5033), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119404] = 2,
    ACTIONS(5035), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119412] = 2,
    ACTIONS(5037), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119420] = 2,
    ACTIONS(5039), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119428] = 2,
    ACTIONS(5041), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119436] = 2,
    ACTIONS(5043), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119444] = 2,
    ACTIONS(5045), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119452] = 2,
    ACTIONS(5047), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119460] = 2,
    ACTIONS(5049), 1,
      anon_sym_in,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119468] = 2,
    ACTIONS(5051), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119476] = 2,
    ACTIONS(5053), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119484] = 2,
    ACTIONS(5055), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119492] = 2,
    ACTIONS(5057), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119500] = 2,
    ACTIONS(5059), 1,
      anon_sym_in,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119508] = 2,
    ACTIONS(5061), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119516] = 2,
    ACTIONS(5063), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119524] = 2,
    ACTIONS(3358), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119532] = 2,
    ACTIONS(5065), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119540] = 2,
    ACTIONS(5067), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119548] = 2,
    ACTIONS(5069), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119556] = 2,
    ACTIONS(5071), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119564] = 2,
    ACTIONS(5073), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119572] = 2,
    ACTIONS(5075), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119580] = 2,
    ACTIONS(3448), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119588] = 2,
    ACTIONS(5077), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119596] = 2,
    ACTIONS(5079), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119604] = 2,
    ACTIONS(3465), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119612] = 2,
    ACTIONS(5081), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119620] = 2,
    ACTIONS(5083), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119628] = 2,
    ACTIONS(5085), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119636] = 2,
    ACTIONS(4086), 1,
      anon_sym_in,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119644] = 2,
    ACTIONS(1472), 1,
      anon_sym_def,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119652] = 2,
    ACTIONS(5087), 1,
      anon_sym_for,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119660] = 2,
    ACTIONS(5089), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119668] = 2,
    ACTIONS(4084), 1,
      anon_sym_in,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119676] = 2,
    ACTIONS(5091), 1,
      anon_sym_for,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119684] = 2,
    ACTIONS(5093), 1,
      anon_sym_RBRACK,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [119692] = 2,
    ACTIONS(5095), 1,
      anon_sym_COLON_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(189)] = 0,
  [SMALL_STATE(190)] = 124,
  [SMALL_STATE(191)] = 252,
  [SMALL_STATE(192)] = 378,
  [SMALL_STATE(193)] = 498,
  [SMALL_STATE(194)] = 624,
  [SMALL_STATE(195)] = 748,
  [SMALL_STATE(196)] = 872,
  [SMALL_STATE(197)] = 996,
  [SMALL_STATE(198)] = 1120,
  [SMALL_STATE(199)] = 1244,
  [SMALL_STATE(200)] = 1368,
  [SMALL_STATE(201)] = 1492,
  [SMALL_STATE(202)] = 1620,
  [SMALL_STATE(203)] = 1744,
  [SMALL_STATE(204)] = 1868,
  [SMALL_STATE(205)] = 1992,
  [SMALL_STATE(206)] = 2116,
  [SMALL_STATE(207)] = 2240,
  [SMALL_STATE(208)] = 2366,
  [SMALL_STATE(209)] = 2492,
  [SMALL_STATE(210)] = 2616,
  [SMALL_STATE(211)] = 2742,
  [SMALL_STATE(212)] = 2866,
  [SMALL_STATE(213)] = 2990,
  [SMALL_STATE(214)] = 3116,
  [SMALL_STATE(215)] = 3240,
  [SMALL_STATE(216)] = 3366,
  [SMALL_STATE(217)] = 3486,
  [SMALL_STATE(218)] = 3612,
  [SMALL_STATE(219)] = 3736,
  [SMALL_STATE(220)] = 3860,
  [SMALL_STATE(221)] = 3986,
  [SMALL_STATE(222)] = 4106,
  [SMALL_STATE(223)] = 4213,
  [SMALL_STATE(224)] = 4320,
  [SMALL_STATE(225)] = 4434,
  [SMALL_STATE(226)] = 4548,
  [SMALL_STATE(227)] = 4662,
  [SMALL_STATE(228)] = 4778,
  [SMALL_STATE(229)] = 4894,
  [SMALL_STATE(230)] = 5008,
  [SMALL_STATE(231)] = 5122,
  [SMALL_STATE(232)] = 5236,
  [SMALL_STATE(233)] = 5350,
  [SMALL_STATE(234)] = 5464,
  [SMALL_STATE(235)] = 5575,
  [SMALL_STATE(236)] = 5686,
  [SMALL_STATE(237)] = 5801,
  [SMALL_STATE(238)] = 5912,
  [SMALL_STATE(239)] = 6027,
  [SMALL_STATE(240)] = 6138,
  [SMALL_STATE(241)] = 6253,
  [SMALL_STATE(242)] = 6364,
  [SMALL_STATE(243)] = 6475,
  [SMALL_STATE(244)] = 6586,
  [SMALL_STATE(245)] = 6697,
  [SMALL_STATE(246)] = 6808,
  [SMALL_STATE(247)] = 6919,
  [SMALL_STATE(248)] = 7034,
  [SMALL_STATE(249)] = 7149,
  [SMALL_STATE(250)] = 7264,
  [SMALL_STATE(251)] = 7379,
  [SMALL_STATE(252)] = 7484,
  [SMALL_STATE(253)] = 7595,
  [SMALL_STATE(254)] = 7706,
  [SMALL_STATE(255)] = 7811,
  [SMALL_STATE(256)] = 7922,
  [SMALL_STATE(257)] = 8039,
  [SMALL_STATE(258)] = 8154,
  [SMALL_STATE(259)] = 8265,
  [SMALL_STATE(260)] = 8376,
  [SMALL_STATE(261)] = 8487,
  [SMALL_STATE(262)] = 8598,
  [SMALL_STATE(263)] = 8709,
  [SMALL_STATE(264)] = 8820,
  [SMALL_STATE(265)] = 8931,
  [SMALL_STATE(266)] = 9042,
  [SMALL_STATE(267)] = 9153,
  [SMALL_STATE(268)] = 9264,
  [SMALL_STATE(269)] = 9375,
  [SMALL_STATE(270)] = 9486,
  [SMALL_STATE(271)] = 9597,
  [SMALL_STATE(272)] = 9712,
  [SMALL_STATE(273)] = 9824,
  [SMALL_STATE(274)] = 9936,
  [SMALL_STATE(275)] = 10048,
  [SMALL_STATE(276)] = 10160,
  [SMALL_STATE(277)] = 10272,
  [SMALL_STATE(278)] = 10384,
  [SMALL_STATE(279)] = 10500,
  [SMALL_STATE(280)] = 10616,
  [SMALL_STATE(281)] = 10732,
  [SMALL_STATE(282)] = 10844,
  [SMALL_STATE(283)] = 10956,
  [SMALL_STATE(284)] = 11068,
  [SMALL_STATE(285)] = 11180,
  [SMALL_STATE(286)] = 11292,
  [SMALL_STATE(287)] = 11404,
  [SMALL_STATE(288)] = 11516,
  [SMALL_STATE(289)] = 11630,
  [SMALL_STATE(290)] = 11742,
  [SMALL_STATE(291)] = 11854,
  [SMALL_STATE(292)] = 11966,
  [SMALL_STATE(293)] = 12082,
  [SMALL_STATE(294)] = 12196,
  [SMALL_STATE(295)] = 12308,
  [SMALL_STATE(296)] = 12420,
  [SMALL_STATE(297)] = 12534,
  [SMALL_STATE(298)] = 12646,
  [SMALL_STATE(299)] = 12760,
  [SMALL_STATE(300)] = 12872,
  [SMALL_STATE(301)] = 12988,
  [SMALL_STATE(302)] = 13100,
  [SMALL_STATE(303)] = 13212,
  [SMALL_STATE(304)] = 13324,
  [SMALL_STATE(305)] = 13436,
  [SMALL_STATE(306)] = 13548,
  [SMALL_STATE(307)] = 13660,
  [SMALL_STATE(308)] = 13774,
  [SMALL_STATE(309)] = 13886,
  [SMALL_STATE(310)] = 13998,
  [SMALL_STATE(311)] = 14110,
  [SMALL_STATE(312)] = 14222,
  [SMALL_STATE(313)] = 14334,
  [SMALL_STATE(314)] = 14448,
  [SMALL_STATE(315)] = 14560,
  [SMALL_STATE(316)] = 14672,
  [SMALL_STATE(317)] = 14786,
  [SMALL_STATE(318)] = 14898,
  [SMALL_STATE(319)] = 15010,
  [SMALL_STATE(320)] = 15122,
  [SMALL_STATE(321)] = 15234,
  [SMALL_STATE(322)] = 15346,
  [SMALL_STATE(323)] = 15458,
  [SMALL_STATE(324)] = 15572,
  [SMALL_STATE(325)] = 15688,
  [SMALL_STATE(326)] = 15800,
  [SMALL_STATE(327)] = 15909,
  [SMALL_STATE(328)] = 16018,
  [SMALL_STATE(329)] = 16115,
  [SMALL_STATE(330)] = 16224,
  [SMALL_STATE(331)] = 16333,
  [SMALL_STATE(332)] = 16442,
  [SMALL_STATE(333)] = 16551,
  [SMALL_STATE(334)] = 16660,
  [SMALL_STATE(335)] = 16769,
  [SMALL_STATE(336)] = 16878,
  [SMALL_STATE(337)] = 16987,
  [SMALL_STATE(338)] = 17096,
  [SMALL_STATE(339)] = 17205,
  [SMALL_STATE(340)] = 17314,
  [SMALL_STATE(341)] = 17423,
  [SMALL_STATE(342)] = 17532,
  [SMALL_STATE(343)] = 17641,
  [SMALL_STATE(344)] = 17746,
  [SMALL_STATE(345)] = 17855,
  [SMALL_STATE(346)] = 17964,
  [SMALL_STATE(347)] = 18069,
  [SMALL_STATE(348)] = 18178,
  [SMALL_STATE(349)] = 18286,
  [SMALL_STATE(350)] = 18394,
  [SMALL_STATE(351)] = 18502,
  [SMALL_STATE(352)] = 18610,
  [SMALL_STATE(353)] = 18718,
  [SMALL_STATE(354)] = 18826,
  [SMALL_STATE(355)] = 18934,
  [SMALL_STATE(356)] = 19042,
  [SMALL_STATE(357)] = 19148,
  [SMALL_STATE(358)] = 19256,
  [SMALL_STATE(359)] = 19364,
  [SMALL_STATE(360)] = 19472,
  [SMALL_STATE(361)] = 19580,
  [SMALL_STATE(362)] = 19688,
  [SMALL_STATE(363)] = 19796,
  [SMALL_STATE(364)] = 19904,
  [SMALL_STATE(365)] = 20010,
  [SMALL_STATE(366)] = 20116,
  [SMALL_STATE(367)] = 20224,
  [SMALL_STATE(368)] = 20332,
  [SMALL_STATE(369)] = 20440,
  [SMALL_STATE(370)] = 20548,
  [SMALL_STATE(371)] = 20656,
  [SMALL_STATE(372)] = 20751,
  [SMALL_STATE(373)] = 20858,
  [SMALL_STATE(374)] = 20965,
  [SMALL_STATE(375)] = 21072,
  [SMALL_STATE(376)] = 21177,
  [SMALL_STATE(377)] = 21284,
  [SMALL_STATE(378)] = 21389,
  [SMALL_STATE(379)] = 21496,
  [SMALL_STATE(380)] = 21601,
  [SMALL_STATE(381)] = 21708,
  [SMALL_STATE(382)] = 21815,
  [SMALL_STATE(383)] = 21920,
  [SMALL_STATE(384)] = 22027,
  [SMALL_STATE(385)] = 22134,
  [SMALL_STATE(386)] = 22239,
  [SMALL_STATE(387)] = 22346,
  [SMALL_STATE(388)] = 22451,
  [SMALL_STATE(389)] = 22558,
  [SMALL_STATE(390)] = 22665,
  [SMALL_STATE(391)] = 22772,
  [SMALL_STATE(392)] = 22879,
  [SMALL_STATE(393)] = 22986,
  [SMALL_STATE(394)] = 23093,
  [SMALL_STATE(395)] = 23200,
  [SMALL_STATE(396)] = 23307,
  [SMALL_STATE(397)] = 23414,
  [SMALL_STATE(398)] = 23521,
  [SMALL_STATE(399)] = 23628,
  [SMALL_STATE(400)] = 23735,
  [SMALL_STATE(401)] = 23842,
  [SMALL_STATE(402)] = 23937,
  [SMALL_STATE(403)] = 24044,
  [SMALL_STATE(404)] = 24151,
  [SMALL_STATE(405)] = 24258,
  [SMALL_STATE(406)] = 24365,
  [SMALL_STATE(407)] = 24472,
  [SMALL_STATE(408)] = 24579,
  [SMALL_STATE(409)] = 24686,
  [SMALL_STATE(410)] = 24780,
  [SMALL_STATE(411)] = 24884,
  [SMALL_STATE(412)] = 24986,
  [SMALL_STATE(413)] = 25090,
  [SMALL_STATE(414)] = 25186,
  [SMALL_STATE(415)] = 25290,
  [SMALL_STATE(416)] = 25394,
  [SMALL_STATE(417)] = 25496,
  [SMALL_STATE(418)] = 25600,
  [SMALL_STATE(419)] = 25702,
  [SMALL_STATE(420)] = 25806,
  [SMALL_STATE(421)] = 25910,
  [SMALL_STATE(422)] = 26012,
  [SMALL_STATE(423)] = 26116,
  [SMALL_STATE(424)] = 26218,
  [SMALL_STATE(425)] = 26320,
  [SMALL_STATE(426)] = 26424,
  [SMALL_STATE(427)] = 26528,
  [SMALL_STATE(428)] = 26632,
  [SMALL_STATE(429)] = 26734,
  [SMALL_STATE(430)] = 26836,
  [SMALL_STATE(431)] = 26938,
  [SMALL_STATE(432)] = 27040,
  [SMALL_STATE(433)] = 27144,
  [SMALL_STATE(434)] = 27246,
  [SMALL_STATE(435)] = 27350,
  [SMALL_STATE(436)] = 27454,
  [SMALL_STATE(437)] = 27556,
  [SMALL_STATE(438)] = 27658,
  [SMALL_STATE(439)] = 27760,
  [SMALL_STATE(440)] = 27864,
  [SMALL_STATE(441)] = 27966,
  [SMALL_STATE(442)] = 28070,
  [SMALL_STATE(443)] = 28172,
  [SMALL_STATE(444)] = 28276,
  [SMALL_STATE(445)] = 28378,
  [SMALL_STATE(446)] = 28472,
  [SMALL_STATE(447)] = 28574,
  [SMALL_STATE(448)] = 28668,
  [SMALL_STATE(449)] = 28770,
  [SMALL_STATE(450)] = 28874,
  [SMALL_STATE(451)] = 28976,
  [SMALL_STATE(452)] = 29078,
  [SMALL_STATE(453)] = 29180,
  [SMALL_STATE(454)] = 29284,
  [SMALL_STATE(455)] = 29386,
  [SMALL_STATE(456)] = 29488,
  [SMALL_STATE(457)] = 29582,
  [SMALL_STATE(458)] = 29684,
  [SMALL_STATE(459)] = 29786,
  [SMALL_STATE(460)] = 29888,
  [SMALL_STATE(461)] = 29990,
  [SMALL_STATE(462)] = 30091,
  [SMALL_STATE(463)] = 30192,
  [SMALL_STATE(464)] = 30269,
  [SMALL_STATE(465)] = 30370,
  [SMALL_STATE(466)] = 30471,
  [SMALL_STATE(467)] = 30572,
  [SMALL_STATE(468)] = 30673,
  [SMALL_STATE(469)] = 30774,
  [SMALL_STATE(470)] = 30875,
  [SMALL_STATE(471)] = 30950,
  [SMALL_STATE(472)] = 31051,
  [SMALL_STATE(473)] = 31152,
  [SMALL_STATE(474)] = 31253,
  [SMALL_STATE(475)] = 31328,
  [SMALL_STATE(476)] = 31429,
  [SMALL_STATE(477)] = 31504,
  [SMALL_STATE(478)] = 31605,
  [SMALL_STATE(479)] = 31706,
  [SMALL_STATE(480)] = 31807,
  [SMALL_STATE(481)] = 31905,
  [SMALL_STATE(482)] = 32005,
  [SMALL_STATE(483)] = 32103,
  [SMALL_STATE(484)] = 32201,
  [SMALL_STATE(485)] = 32299,
  [SMALL_STATE(486)] = 32397,
  [SMALL_STATE(487)] = 32495,
  [SMALL_STATE(488)] = 32593,
  [SMALL_STATE(489)] = 32691,
  [SMALL_STATE(490)] = 32789,
  [SMALL_STATE(491)] = 32887,
  [SMALL_STATE(492)] = 32985,
  [SMALL_STATE(493)] = 33057,
  [SMALL_STATE(494)] = 33129,
  [SMALL_STATE(495)] = 33227,
  [SMALL_STATE(496)] = 33325,
  [SMALL_STATE(497)] = 33423,
  [SMALL_STATE(498)] = 33495,
  [SMALL_STATE(499)] = 33567,
  [SMALL_STATE(500)] = 33665,
  [SMALL_STATE(501)] = 33765,
  [SMALL_STATE(502)] = 33863,
  [SMALL_STATE(503)] = 33961,
  [SMALL_STATE(504)] = 34059,
  [SMALL_STATE(505)] = 34159,
  [SMALL_STATE(506)] = 34257,
  [SMALL_STATE(507)] = 34355,
  [SMALL_STATE(508)] = 34453,
  [SMALL_STATE(509)] = 34551,
  [SMALL_STATE(510)] = 34649,
  [SMALL_STATE(511)] = 34747,
  [SMALL_STATE(512)] = 34845,
  [SMALL_STATE(513)] = 34943,
  [SMALL_STATE(514)] = 35041,
  [SMALL_STATE(515)] = 35139,
  [SMALL_STATE(516)] = 35239,
  [SMALL_STATE(517)] = 35337,
  [SMALL_STATE(518)] = 35435,
  [SMALL_STATE(519)] = 35533,
  [SMALL_STATE(520)] = 35631,
  [SMALL_STATE(521)] = 35729,
  [SMALL_STATE(522)] = 35827,
  [SMALL_STATE(523)] = 35925,
  [SMALL_STATE(524)] = 36023,
  [SMALL_STATE(525)] = 36121,
  [SMALL_STATE(526)] = 36219,
  [SMALL_STATE(527)] = 36317,
  [SMALL_STATE(528)] = 36389,
  [SMALL_STATE(529)] = 36461,
  [SMALL_STATE(530)] = 36559,
  [SMALL_STATE(531)] = 36657,
  [SMALL_STATE(532)] = 36755,
  [SMALL_STATE(533)] = 36853,
  [SMALL_STATE(534)] = 36951,
  [SMALL_STATE(535)] = 37049,
  [SMALL_STATE(536)] = 37147,
  [SMALL_STATE(537)] = 37245,
  [SMALL_STATE(538)] = 37343,
  [SMALL_STATE(539)] = 37441,
  [SMALL_STATE(540)] = 37539,
  [SMALL_STATE(541)] = 37637,
  [SMALL_STATE(542)] = 37735,
  [SMALL_STATE(543)] = 37833,
  [SMALL_STATE(544)] = 37931,
  [SMALL_STATE(545)] = 38029,
  [SMALL_STATE(546)] = 38127,
  [SMALL_STATE(547)] = 38225,
  [SMALL_STATE(548)] = 38323,
  [SMALL_STATE(549)] = 38421,
  [SMALL_STATE(550)] = 38519,
  [SMALL_STATE(551)] = 38617,
  [SMALL_STATE(552)] = 38715,
  [SMALL_STATE(553)] = 38813,
  [SMALL_STATE(554)] = 38911,
  [SMALL_STATE(555)] = 39009,
  [SMALL_STATE(556)] = 39107,
  [SMALL_STATE(557)] = 39205,
  [SMALL_STATE(558)] = 39303,
  [SMALL_STATE(559)] = 39403,
  [SMALL_STATE(560)] = 39501,
  [SMALL_STATE(561)] = 39599,
  [SMALL_STATE(562)] = 39697,
  [SMALL_STATE(563)] = 39795,
  [SMALL_STATE(564)] = 39893,
  [SMALL_STATE(565)] = 39991,
  [SMALL_STATE(566)] = 40089,
  [SMALL_STATE(567)] = 40187,
  [SMALL_STATE(568)] = 40285,
  [SMALL_STATE(569)] = 40383,
  [SMALL_STATE(570)] = 40481,
  [SMALL_STATE(571)] = 40579,
  [SMALL_STATE(572)] = 40677,
  [SMALL_STATE(573)] = 40775,
  [SMALL_STATE(574)] = 40873,
  [SMALL_STATE(575)] = 40971,
  [SMALL_STATE(576)] = 41069,
  [SMALL_STATE(577)] = 41167,
  [SMALL_STATE(578)] = 41265,
  [SMALL_STATE(579)] = 41363,
  [SMALL_STATE(580)] = 41461,
  [SMALL_STATE(581)] = 41559,
  [SMALL_STATE(582)] = 41657,
  [SMALL_STATE(583)] = 41755,
  [SMALL_STATE(584)] = 41853,
  [SMALL_STATE(585)] = 41951,
  [SMALL_STATE(586)] = 42049,
  [SMALL_STATE(587)] = 42147,
  [SMALL_STATE(588)] = 42245,
  [SMALL_STATE(589)] = 42343,
  [SMALL_STATE(590)] = 42443,
  [SMALL_STATE(591)] = 42541,
  [SMALL_STATE(592)] = 42639,
  [SMALL_STATE(593)] = 42711,
  [SMALL_STATE(594)] = 42783,
  [SMALL_STATE(595)] = 42881,
  [SMALL_STATE(596)] = 42979,
  [SMALL_STATE(597)] = 43077,
  [SMALL_STATE(598)] = 43175,
  [SMALL_STATE(599)] = 43273,
  [SMALL_STATE(600)] = 43371,
  [SMALL_STATE(601)] = 43469,
  [SMALL_STATE(602)] = 43567,
  [SMALL_STATE(603)] = 43665,
  [SMALL_STATE(604)] = 43763,
  [SMALL_STATE(605)] = 43861,
  [SMALL_STATE(606)] = 43959,
  [SMALL_STATE(607)] = 44057,
  [SMALL_STATE(608)] = 44155,
  [SMALL_STATE(609)] = 44253,
  [SMALL_STATE(610)] = 44326,
  [SMALL_STATE(611)] = 44394,
  [SMALL_STATE(612)] = 44456,
  [SMALL_STATE(613)] = 44524,
  [SMALL_STATE(614)] = 44592,
  [SMALL_STATE(615)] = 44660,
  [SMALL_STATE(616)] = 44728,
  [SMALL_STATE(617)] = 44796,
  [SMALL_STATE(618)] = 44864,
  [SMALL_STATE(619)] = 44932,
  [SMALL_STATE(620)] = 44998,
  [SMALL_STATE(621)] = 45060,
  [SMALL_STATE(622)] = 45126,
  [SMALL_STATE(623)] = 45192,
  [SMALL_STATE(624)] = 45260,
  [SMALL_STATE(625)] = 45322,
  [SMALL_STATE(626)] = 45384,
  [SMALL_STATE(627)] = 45441,
  [SMALL_STATE(628)] = 45506,
  [SMALL_STATE(629)] = 45569,
  [SMALL_STATE(630)] = 45632,
  [SMALL_STATE(631)] = 45695,
  [SMALL_STATE(632)] = 45758,
  [SMALL_STATE(633)] = 45821,
  [SMALL_STATE(634)] = 45878,
  [SMALL_STATE(635)] = 45941,
  [SMALL_STATE(636)] = 46004,
  [SMALL_STATE(637)] = 46061,
  [SMALL_STATE(638)] = 46124,
  [SMALL_STATE(639)] = 46181,
  [SMALL_STATE(640)] = 46238,
  [SMALL_STATE(641)] = 46295,
  [SMALL_STATE(642)] = 46352,
  [SMALL_STATE(643)] = 46413,
  [SMALL_STATE(644)] = 46474,
  [SMALL_STATE(645)] = 46537,
  [SMALL_STATE(646)] = 46598,
  [SMALL_STATE(647)] = 46661,
  [SMALL_STATE(648)] = 46717,
  [SMALL_STATE(649)] = 46773,
  [SMALL_STATE(650)] = 46829,
  [SMALL_STATE(651)] = 46885,
  [SMALL_STATE(652)] = 46941,
  [SMALL_STATE(653)] = 46997,
  [SMALL_STATE(654)] = 47053,
  [SMALL_STATE(655)] = 47109,
  [SMALL_STATE(656)] = 47165,
  [SMALL_STATE(657)] = 47221,
  [SMALL_STATE(658)] = 47277,
  [SMALL_STATE(659)] = 47333,
  [SMALL_STATE(660)] = 47389,
  [SMALL_STATE(661)] = 47445,
  [SMALL_STATE(662)] = 47501,
  [SMALL_STATE(663)] = 47557,
  [SMALL_STATE(664)] = 47613,
  [SMALL_STATE(665)] = 47669,
  [SMALL_STATE(666)] = 47725,
  [SMALL_STATE(667)] = 47781,
  [SMALL_STATE(668)] = 47837,
  [SMALL_STATE(669)] = 47893,
  [SMALL_STATE(670)] = 47949,
  [SMALL_STATE(671)] = 48005,
  [SMALL_STATE(672)] = 48061,
  [SMALL_STATE(673)] = 48117,
  [SMALL_STATE(674)] = 48173,
  [SMALL_STATE(675)] = 48229,
  [SMALL_STATE(676)] = 48285,
  [SMALL_STATE(677)] = 48341,
  [SMALL_STATE(678)] = 48433,
  [SMALL_STATE(679)] = 48489,
  [SMALL_STATE(680)] = 48581,
  [SMALL_STATE(681)] = 48637,
  [SMALL_STATE(682)] = 48693,
  [SMALL_STATE(683)] = 48749,
  [SMALL_STATE(684)] = 48805,
  [SMALL_STATE(685)] = 48861,
  [SMALL_STATE(686)] = 48917,
  [SMALL_STATE(687)] = 48973,
  [SMALL_STATE(688)] = 49029,
  [SMALL_STATE(689)] = 49085,
  [SMALL_STATE(690)] = 49141,
  [SMALL_STATE(691)] = 49197,
  [SMALL_STATE(692)] = 49253,
  [SMALL_STATE(693)] = 49309,
  [SMALL_STATE(694)] = 49365,
  [SMALL_STATE(695)] = 49421,
  [SMALL_STATE(696)] = 49477,
  [SMALL_STATE(697)] = 49533,
  [SMALL_STATE(698)] = 49589,
  [SMALL_STATE(699)] = 49645,
  [SMALL_STATE(700)] = 49704,
  [SMALL_STATE(701)] = 49763,
  [SMALL_STATE(702)] = 49822,
  [SMALL_STATE(703)] = 49881,
  [SMALL_STATE(704)] = 49940,
  [SMALL_STATE(705)] = 49999,
  [SMALL_STATE(706)] = 50058,
  [SMALL_STATE(707)] = 50113,
  [SMALL_STATE(708)] = 50172,
  [SMALL_STATE(709)] = 50227,
  [SMALL_STATE(710)] = 50286,
  [SMALL_STATE(711)] = 50345,
  [SMALL_STATE(712)] = 50400,
  [SMALL_STATE(713)] = 50459,
  [SMALL_STATE(714)] = 50518,
  [SMALL_STATE(715)] = 50573,
  [SMALL_STATE(716)] = 50632,
  [SMALL_STATE(717)] = 50691,
  [SMALL_STATE(718)] = 50746,
  [SMALL_STATE(719)] = 50805,
  [SMALL_STATE(720)] = 50864,
  [SMALL_STATE(721)] = 50919,
  [SMALL_STATE(722)] = 51011,
  [SMALL_STATE(723)] = 51065,
  [SMALL_STATE(724)] = 51119,
  [SMALL_STATE(725)] = 51173,
  [SMALL_STATE(726)] = 51227,
  [SMALL_STATE(727)] = 51319,
  [SMALL_STATE(728)] = 51372,
  [SMALL_STATE(729)] = 51461,
  [SMALL_STATE(730)] = 51550,
  [SMALL_STATE(731)] = 51639,
  [SMALL_STATE(732)] = 51692,
  [SMALL_STATE(733)] = 51745,
  [SMALL_STATE(734)] = 51798,
  [SMALL_STATE(735)] = 51851,
  [SMALL_STATE(736)] = 51904,
  [SMALL_STATE(737)] = 51957,
  [SMALL_STATE(738)] = 52010,
  [SMALL_STATE(739)] = 52099,
  [SMALL_STATE(740)] = 52152,
  [SMALL_STATE(741)] = 52205,
  [SMALL_STATE(742)] = 52258,
  [SMALL_STATE(743)] = 52347,
  [SMALL_STATE(744)] = 52436,
  [SMALL_STATE(745)] = 52489,
  [SMALL_STATE(746)] = 52542,
  [SMALL_STATE(747)] = 52595,
  [SMALL_STATE(748)] = 52648,
  [SMALL_STATE(749)] = 52701,
  [SMALL_STATE(750)] = 52754,
  [SMALL_STATE(751)] = 52807,
  [SMALL_STATE(752)] = 52860,
  [SMALL_STATE(753)] = 52913,
  [SMALL_STATE(754)] = 52966,
  [SMALL_STATE(755)] = 53019,
  [SMALL_STATE(756)] = 53072,
  [SMALL_STATE(757)] = 53125,
  [SMALL_STATE(758)] = 53178,
  [SMALL_STATE(759)] = 53231,
  [SMALL_STATE(760)] = 53284,
  [SMALL_STATE(761)] = 53337,
  [SMALL_STATE(762)] = 53390,
  [SMALL_STATE(763)] = 53443,
  [SMALL_STATE(764)] = 53496,
  [SMALL_STATE(765)] = 53549,
  [SMALL_STATE(766)] = 53602,
  [SMALL_STATE(767)] = 53655,
  [SMALL_STATE(768)] = 53708,
  [SMALL_STATE(769)] = 53761,
  [SMALL_STATE(770)] = 53814,
  [SMALL_STATE(771)] = 53867,
  [SMALL_STATE(772)] = 53920,
  [SMALL_STATE(773)] = 53973,
  [SMALL_STATE(774)] = 54026,
  [SMALL_STATE(775)] = 54115,
  [SMALL_STATE(776)] = 54204,
  [SMALL_STATE(777)] = 54257,
  [SMALL_STATE(778)] = 54310,
  [SMALL_STATE(779)] = 54363,
  [SMALL_STATE(780)] = 54416,
  [SMALL_STATE(781)] = 54469,
  [SMALL_STATE(782)] = 54522,
  [SMALL_STATE(783)] = 54575,
  [SMALL_STATE(784)] = 54628,
  [SMALL_STATE(785)] = 54681,
  [SMALL_STATE(786)] = 54770,
  [SMALL_STATE(787)] = 54823,
  [SMALL_STATE(788)] = 54912,
  [SMALL_STATE(789)] = 54965,
  [SMALL_STATE(790)] = 55018,
  [SMALL_STATE(791)] = 55071,
  [SMALL_STATE(792)] = 55124,
  [SMALL_STATE(793)] = 55177,
  [SMALL_STATE(794)] = 55230,
  [SMALL_STATE(795)] = 55283,
  [SMALL_STATE(796)] = 55336,
  [SMALL_STATE(797)] = 55389,
  [SMALL_STATE(798)] = 55442,
  [SMALL_STATE(799)] = 55495,
  [SMALL_STATE(800)] = 55548,
  [SMALL_STATE(801)] = 55601,
  [SMALL_STATE(802)] = 55654,
  [SMALL_STATE(803)] = 55707,
  [SMALL_STATE(804)] = 55760,
  [SMALL_STATE(805)] = 55813,
  [SMALL_STATE(806)] = 55866,
  [SMALL_STATE(807)] = 55919,
  [SMALL_STATE(808)] = 55972,
  [SMALL_STATE(809)] = 56025,
  [SMALL_STATE(810)] = 56078,
  [SMALL_STATE(811)] = 56131,
  [SMALL_STATE(812)] = 56184,
  [SMALL_STATE(813)] = 56237,
  [SMALL_STATE(814)] = 56290,
  [SMALL_STATE(815)] = 56343,
  [SMALL_STATE(816)] = 56396,
  [SMALL_STATE(817)] = 56449,
  [SMALL_STATE(818)] = 56502,
  [SMALL_STATE(819)] = 56555,
  [SMALL_STATE(820)] = 56608,
  [SMALL_STATE(821)] = 56697,
  [SMALL_STATE(822)] = 56750,
  [SMALL_STATE(823)] = 56803,
  [SMALL_STATE(824)] = 56856,
  [SMALL_STATE(825)] = 56909,
  [SMALL_STATE(826)] = 56998,
  [SMALL_STATE(827)] = 57051,
  [SMALL_STATE(828)] = 57104,
  [SMALL_STATE(829)] = 57157,
  [SMALL_STATE(830)] = 57246,
  [SMALL_STATE(831)] = 57299,
  [SMALL_STATE(832)] = 57388,
  [SMALL_STATE(833)] = 57477,
  [SMALL_STATE(834)] = 57530,
  [SMALL_STATE(835)] = 57583,
  [SMALL_STATE(836)] = 57636,
  [SMALL_STATE(837)] = 57689,
  [SMALL_STATE(838)] = 57742,
  [SMALL_STATE(839)] = 57795,
  [SMALL_STATE(840)] = 57884,
  [SMALL_STATE(841)] = 57937,
  [SMALL_STATE(842)] = 57990,
  [SMALL_STATE(843)] = 58043,
  [SMALL_STATE(844)] = 58096,
  [SMALL_STATE(845)] = 58149,
  [SMALL_STATE(846)] = 58202,
  [SMALL_STATE(847)] = 58255,
  [SMALL_STATE(848)] = 58308,
  [SMALL_STATE(849)] = 58361,
  [SMALL_STATE(850)] = 58414,
  [SMALL_STATE(851)] = 58467,
  [SMALL_STATE(852)] = 58553,
  [SMALL_STATE(853)] = 58639,
  [SMALL_STATE(854)] = 58725,
  [SMALL_STATE(855)] = 58811,
  [SMALL_STATE(856)] = 58897,
  [SMALL_STATE(857)] = 58983,
  [SMALL_STATE(858)] = 59066,
  [SMALL_STATE(859)] = 59149,
  [SMALL_STATE(860)] = 59227,
  [SMALL_STATE(861)] = 59305,
  [SMALL_STATE(862)] = 59383,
  [SMALL_STATE(863)] = 59461,
  [SMALL_STATE(864)] = 59539,
  [SMALL_STATE(865)] = 59617,
  [SMALL_STATE(866)] = 59695,
  [SMALL_STATE(867)] = 59773,
  [SMALL_STATE(868)] = 59852,
  [SMALL_STATE(869)] = 59931,
  [SMALL_STATE(870)] = 60006,
  [SMALL_STATE(871)] = 60085,
  [SMALL_STATE(872)] = 60160,
  [SMALL_STATE(873)] = 60239,
  [SMALL_STATE(874)] = 60314,
  [SMALL_STATE(875)] = 60393,
  [SMALL_STATE(876)] = 60472,
  [SMALL_STATE(877)] = 60547,
  [SMALL_STATE(878)] = 60622,
  [SMALL_STATE(879)] = 60697,
  [SMALL_STATE(880)] = 60772,
  [SMALL_STATE(881)] = 60847,
  [SMALL_STATE(882)] = 60922,
  [SMALL_STATE(883)] = 60997,
  [SMALL_STATE(884)] = 61072,
  [SMALL_STATE(885)] = 61147,
  [SMALL_STATE(886)] = 61222,
  [SMALL_STATE(887)] = 61297,
  [SMALL_STATE(888)] = 61372,
  [SMALL_STATE(889)] = 61447,
  [SMALL_STATE(890)] = 61526,
  [SMALL_STATE(891)] = 61605,
  [SMALL_STATE(892)] = 61680,
  [SMALL_STATE(893)] = 61759,
  [SMALL_STATE(894)] = 61838,
  [SMALL_STATE(895)] = 61913,
  [SMALL_STATE(896)] = 61988,
  [SMALL_STATE(897)] = 62063,
  [SMALL_STATE(898)] = 62138,
  [SMALL_STATE(899)] = 62213,
  [SMALL_STATE(900)] = 62288,
  [SMALL_STATE(901)] = 62367,
  [SMALL_STATE(902)] = 62442,
  [SMALL_STATE(903)] = 62517,
  [SMALL_STATE(904)] = 62592,
  [SMALL_STATE(905)] = 62667,
  [SMALL_STATE(906)] = 62742,
  [SMALL_STATE(907)] = 62817,
  [SMALL_STATE(908)] = 62892,
  [SMALL_STATE(909)] = 62967,
  [SMALL_STATE(910)] = 63042,
  [SMALL_STATE(911)] = 63117,
  [SMALL_STATE(912)] = 63192,
  [SMALL_STATE(913)] = 63267,
  [SMALL_STATE(914)] = 63342,
  [SMALL_STATE(915)] = 63417,
  [SMALL_STATE(916)] = 63492,
  [SMALL_STATE(917)] = 63567,
  [SMALL_STATE(918)] = 63642,
  [SMALL_STATE(919)] = 63717,
  [SMALL_STATE(920)] = 63792,
  [SMALL_STATE(921)] = 63867,
  [SMALL_STATE(922)] = 63942,
  [SMALL_STATE(923)] = 64017,
  [SMALL_STATE(924)] = 64092,
  [SMALL_STATE(925)] = 64167,
  [SMALL_STATE(926)] = 64242,
  [SMALL_STATE(927)] = 64317,
  [SMALL_STATE(928)] = 64392,
  [SMALL_STATE(929)] = 64467,
  [SMALL_STATE(930)] = 64542,
  [SMALL_STATE(931)] = 64617,
  [SMALL_STATE(932)] = 64692,
  [SMALL_STATE(933)] = 64767,
  [SMALL_STATE(934)] = 64842,
  [SMALL_STATE(935)] = 64917,
  [SMALL_STATE(936)] = 64992,
  [SMALL_STATE(937)] = 65067,
  [SMALL_STATE(938)] = 65142,
  [SMALL_STATE(939)] = 65217,
  [SMALL_STATE(940)] = 65292,
  [SMALL_STATE(941)] = 65367,
  [SMALL_STATE(942)] = 65446,
  [SMALL_STATE(943)] = 65521,
  [SMALL_STATE(944)] = 65596,
  [SMALL_STATE(945)] = 65671,
  [SMALL_STATE(946)] = 65746,
  [SMALL_STATE(947)] = 65821,
  [SMALL_STATE(948)] = 65896,
  [SMALL_STATE(949)] = 65971,
  [SMALL_STATE(950)] = 66046,
  [SMALL_STATE(951)] = 66121,
  [SMALL_STATE(952)] = 66196,
  [SMALL_STATE(953)] = 66275,
  [SMALL_STATE(954)] = 66350,
  [SMALL_STATE(955)] = 66429,
  [SMALL_STATE(956)] = 66504,
  [SMALL_STATE(957)] = 66583,
  [SMALL_STATE(958)] = 66658,
  [SMALL_STATE(959)] = 66733,
  [SMALL_STATE(960)] = 66812,
  [SMALL_STATE(961)] = 66891,
  [SMALL_STATE(962)] = 66966,
  [SMALL_STATE(963)] = 67041,
  [SMALL_STATE(964)] = 67120,
  [SMALL_STATE(965)] = 67195,
  [SMALL_STATE(966)] = 67270,
  [SMALL_STATE(967)] = 67345,
  [SMALL_STATE(968)] = 67420,
  [SMALL_STATE(969)] = 67499,
  [SMALL_STATE(970)] = 67574,
  [SMALL_STATE(971)] = 67649,
  [SMALL_STATE(972)] = 67724,
  [SMALL_STATE(973)] = 67803,
  [SMALL_STATE(974)] = 67878,
  [SMALL_STATE(975)] = 67953,
  [SMALL_STATE(976)] = 68005,
  [SMALL_STATE(977)] = 68057,
  [SMALL_STATE(978)] = 68139,
  [SMALL_STATE(979)] = 68191,
  [SMALL_STATE(980)] = 68242,
  [SMALL_STATE(981)] = 68293,
  [SMALL_STATE(982)] = 68350,
  [SMALL_STATE(983)] = 68413,
  [SMALL_STATE(984)] = 68484,
  [SMALL_STATE(985)] = 68541,
  [SMALL_STATE(986)] = 68602,
  [SMALL_STATE(987)] = 68671,
  [SMALL_STATE(988)] = 68742,
  [SMALL_STATE(989)] = 68793,
  [SMALL_STATE(990)] = 68860,
  [SMALL_STATE(991)] = 68925,
  [SMALL_STATE(992)] = 68976,
  [SMALL_STATE(993)] = 69033,
  [SMALL_STATE(994)] = 69084,
  [SMALL_STATE(995)] = 69165,
  [SMALL_STATE(996)] = 69222,
  [SMALL_STATE(997)] = 69303,
  [SMALL_STATE(998)] = 69354,
  [SMALL_STATE(999)] = 69425,
  [SMALL_STATE(1000)] = 69493,
  [SMALL_STATE(1001)] = 69539,
  [SMALL_STATE(1002)] = 69599,
  [SMALL_STATE(1003)] = 69679,
  [SMALL_STATE(1004)] = 69749,
  [SMALL_STATE(1005)] = 69799,
  [SMALL_STATE(1006)] = 69861,
  [SMALL_STATE(1007)] = 69911,
  [SMALL_STATE(1008)] = 69979,
  [SMALL_STATE(1009)] = 70059,
  [SMALL_STATE(1010)] = 70109,
  [SMALL_STATE(1011)] = 70165,
  [SMALL_STATE(1012)] = 70211,
  [SMALL_STATE(1013)] = 70259,
  [SMALL_STATE(1014)] = 70337,
  [SMALL_STATE(1015)] = 70387,
  [SMALL_STATE(1016)] = 70457,
  [SMALL_STATE(1017)] = 70537,
  [SMALL_STATE(1018)] = 70587,
  [SMALL_STATE(1019)] = 70637,
  [SMALL_STATE(1020)] = 70687,
  [SMALL_STATE(1021)] = 70733,
  [SMALL_STATE(1022)] = 70783,
  [SMALL_STATE(1023)] = 70833,
  [SMALL_STATE(1024)] = 70899,
  [SMALL_STATE(1025)] = 70979,
  [SMALL_STATE(1026)] = 71039,
  [SMALL_STATE(1027)] = 71109,
  [SMALL_STATE(1028)] = 71165,
  [SMALL_STATE(1029)] = 71221,
  [SMALL_STATE(1030)] = 71285,
  [SMALL_STATE(1031)] = 71335,
  [SMALL_STATE(1032)] = 71391,
  [SMALL_STATE(1033)] = 71441,
  [SMALL_STATE(1034)] = 71487,
  [SMALL_STATE(1035)] = 71543,
  [SMALL_STATE(1036)] = 71589,
  [SMALL_STATE(1037)] = 71635,
  [SMALL_STATE(1038)] = 71683,
  [SMALL_STATE(1039)] = 71753,
  [SMALL_STATE(1040)] = 71799,
  [SMALL_STATE(1041)] = 71865,
  [SMALL_STATE(1042)] = 71911,
  [SMALL_STATE(1043)] = 71957,
  [SMALL_STATE(1044)] = 72005,
  [SMALL_STATE(1045)] = 72061,
  [SMALL_STATE(1046)] = 72111,
  [SMALL_STATE(1047)] = 72181,
  [SMALL_STATE(1048)] = 72237,
  [SMALL_STATE(1049)] = 72299,
  [SMALL_STATE(1050)] = 72363,
  [SMALL_STATE(1051)] = 72433,
  [SMALL_STATE(1052)] = 72489,
  [SMALL_STATE(1053)] = 72534,
  [SMALL_STATE(1054)] = 72595,
  [SMALL_STATE(1055)] = 72662,
  [SMALL_STATE(1056)] = 72721,
  [SMALL_STATE(1057)] = 72776,
  [SMALL_STATE(1058)] = 72821,
  [SMALL_STATE(1059)] = 72890,
  [SMALL_STATE(1060)] = 72951,
  [SMALL_STATE(1061)] = 73006,
  [SMALL_STATE(1062)] = 73069,
  [SMALL_STATE(1063)] = 73114,
  [SMALL_STATE(1064)] = 73179,
  [SMALL_STATE(1065)] = 73248,
  [SMALL_STATE(1066)] = 73317,
  [SMALL_STATE(1067)] = 73362,
  [SMALL_STATE(1068)] = 73407,
  [SMALL_STATE(1069)] = 73452,
  [SMALL_STATE(1070)] = 73497,
  [SMALL_STATE(1071)] = 73542,
  [SMALL_STATE(1072)] = 73587,
  [SMALL_STATE(1073)] = 73656,
  [SMALL_STATE(1074)] = 73725,
  [SMALL_STATE(1075)] = 73770,
  [SMALL_STATE(1076)] = 73815,
  [SMALL_STATE(1077)] = 73860,
  [SMALL_STATE(1078)] = 73905,
  [SMALL_STATE(1079)] = 73950,
  [SMALL_STATE(1080)] = 73999,
  [SMALL_STATE(1081)] = 74050,
  [SMALL_STATE(1082)] = 74101,
  [SMALL_STATE(1083)] = 74146,
  [SMALL_STATE(1084)] = 74197,
  [SMALL_STATE(1085)] = 74242,
  [SMALL_STATE(1086)] = 74287,
  [SMALL_STATE(1087)] = 74342,
  [SMALL_STATE(1088)] = 74391,
  [SMALL_STATE(1089)] = 74440,
  [SMALL_STATE(1090)] = 74485,
  [SMALL_STATE(1091)] = 74540,
  [SMALL_STATE(1092)] = 74585,
  [SMALL_STATE(1093)] = 74634,
  [SMALL_STATE(1094)] = 74679,
  [SMALL_STATE(1095)] = 74728,
  [SMALL_STATE(1096)] = 74773,
  [SMALL_STATE(1097)] = 74824,
  [SMALL_STATE(1098)] = 74879,
  [SMALL_STATE(1099)] = 74924,
  [SMALL_STATE(1100)] = 75001,
  [SMALL_STATE(1101)] = 75056,
  [SMALL_STATE(1102)] = 75111,
  [SMALL_STATE(1103)] = 75156,
  [SMALL_STATE(1104)] = 75201,
  [SMALL_STATE(1105)] = 75256,
  [SMALL_STATE(1106)] = 75305,
  [SMALL_STATE(1107)] = 75352,
  [SMALL_STATE(1108)] = 75397,
  [SMALL_STATE(1109)] = 75444,
  [SMALL_STATE(1110)] = 75491,
  [SMALL_STATE(1111)] = 75540,
  [SMALL_STATE(1112)] = 75585,
  [SMALL_STATE(1113)] = 75634,
  [SMALL_STATE(1114)] = 75679,
  [SMALL_STATE(1115)] = 75728,
  [SMALL_STATE(1116)] = 75777,
  [SMALL_STATE(1117)] = 75832,
  [SMALL_STATE(1118)] = 75877,
  [SMALL_STATE(1119)] = 75938,
  [SMALL_STATE(1120)] = 76007,
  [SMALL_STATE(1121)] = 76058,
  [SMALL_STATE(1122)] = 76113,
  [SMALL_STATE(1123)] = 76158,
  [SMALL_STATE(1124)] = 76217,
  [SMALL_STATE(1125)] = 76284,
  [SMALL_STATE(1126)] = 76349,
  [SMALL_STATE(1127)] = 76412,
  [SMALL_STATE(1128)] = 76457,
  [SMALL_STATE(1129)] = 76512,
  [SMALL_STATE(1130)] = 76581,
  [SMALL_STATE(1131)] = 76650,
  [SMALL_STATE(1132)] = 76699,
  [SMALL_STATE(1133)] = 76754,
  [SMALL_STATE(1134)] = 76799,
  [SMALL_STATE(1135)] = 76854,
  [SMALL_STATE(1136)] = 76915,
  [SMALL_STATE(1137)] = 76984,
  [SMALL_STATE(1138)] = 77029,
  [SMALL_STATE(1139)] = 77074,
  [SMALL_STATE(1140)] = 77129,
  [SMALL_STATE(1141)] = 77188,
  [SMALL_STATE(1142)] = 77235,
  [SMALL_STATE(1143)] = 77302,
  [SMALL_STATE(1144)] = 77347,
  [SMALL_STATE(1145)] = 77412,
  [SMALL_STATE(1146)] = 77457,
  [SMALL_STATE(1147)] = 77502,
  [SMALL_STATE(1148)] = 77565,
  [SMALL_STATE(1149)] = 77612,
  [SMALL_STATE(1150)] = 77659,
  [SMALL_STATE(1151)] = 77708,
  [SMALL_STATE(1152)] = 77763,
  [SMALL_STATE(1153)] = 77832,
  [SMALL_STATE(1154)] = 77901,
  [SMALL_STATE(1155)] = 77946,
  [SMALL_STATE(1156)] = 78015,
  [SMALL_STATE(1157)] = 78078,
  [SMALL_STATE(1158)] = 78133,
  [SMALL_STATE(1159)] = 78198,
  [SMALL_STATE(1160)] = 78265,
  [SMALL_STATE(1161)] = 78324,
  [SMALL_STATE(1162)] = 78368,
  [SMALL_STATE(1163)] = 78432,
  [SMALL_STATE(1164)] = 78480,
  [SMALL_STATE(1165)] = 78526,
  [SMALL_STATE(1166)] = 78570,
  [SMALL_STATE(1167)] = 78616,
  [SMALL_STATE(1168)] = 78662,
  [SMALL_STATE(1169)] = 78706,
  [SMALL_STATE(1170)] = 78750,
  [SMALL_STATE(1171)] = 78794,
  [SMALL_STATE(1172)] = 78840,
  [SMALL_STATE(1173)] = 78886,
  [SMALL_STATE(1174)] = 78932,
  [SMALL_STATE(1175)] = 78976,
  [SMALL_STATE(1176)] = 79020,
  [SMALL_STATE(1177)] = 79064,
  [SMALL_STATE(1178)] = 79108,
  [SMALL_STATE(1179)] = 79152,
  [SMALL_STATE(1180)] = 79228,
  [SMALL_STATE(1181)] = 79274,
  [SMALL_STATE(1182)] = 79318,
  [SMALL_STATE(1183)] = 79366,
  [SMALL_STATE(1184)] = 79410,
  [SMALL_STATE(1185)] = 79454,
  [SMALL_STATE(1186)] = 79498,
  [SMALL_STATE(1187)] = 79542,
  [SMALL_STATE(1188)] = 79586,
  [SMALL_STATE(1189)] = 79640,
  [SMALL_STATE(1190)] = 79694,
  [SMALL_STATE(1191)] = 79742,
  [SMALL_STATE(1192)] = 79792,
  [SMALL_STATE(1193)] = 79836,
  [SMALL_STATE(1194)] = 79880,
  [SMALL_STATE(1195)] = 79924,
  [SMALL_STATE(1196)] = 79968,
  [SMALL_STATE(1197)] = 80012,
  [SMALL_STATE(1198)] = 80056,
  [SMALL_STATE(1199)] = 80100,
  [SMALL_STATE(1200)] = 80144,
  [SMALL_STATE(1201)] = 80192,
  [SMALL_STATE(1202)] = 80236,
  [SMALL_STATE(1203)] = 80280,
  [SMALL_STATE(1204)] = 80324,
  [SMALL_STATE(1205)] = 80368,
  [SMALL_STATE(1206)] = 80414,
  [SMALL_STATE(1207)] = 80458,
  [SMALL_STATE(1208)] = 80504,
  [SMALL_STATE(1209)] = 80548,
  [SMALL_STATE(1210)] = 80594,
  [SMALL_STATE(1211)] = 80648,
  [SMALL_STATE(1212)] = 80692,
  [SMALL_STATE(1213)] = 80736,
  [SMALL_STATE(1214)] = 80796,
  [SMALL_STATE(1215)] = 80844,
  [SMALL_STATE(1216)] = 80888,
  [SMALL_STATE(1217)] = 80956,
  [SMALL_STATE(1218)] = 81010,
  [SMALL_STATE(1219)] = 81054,
  [SMALL_STATE(1220)] = 81098,
  [SMALL_STATE(1221)] = 81142,
  [SMALL_STATE(1222)] = 81186,
  [SMALL_STATE(1223)] = 81244,
  [SMALL_STATE(1224)] = 81310,
  [SMALL_STATE(1225)] = 81358,
  [SMALL_STATE(1226)] = 81420,
  [SMALL_STATE(1227)] = 81470,
  [SMALL_STATE(1228)] = 81514,
  [SMALL_STATE(1229)] = 81562,
  [SMALL_STATE(1230)] = 81610,
  [SMALL_STATE(1231)] = 81658,
  [SMALL_STATE(1232)] = 81726,
  [SMALL_STATE(1233)] = 81794,
  [SMALL_STATE(1234)] = 81838,
  [SMALL_STATE(1235)] = 81886,
  [SMALL_STATE(1236)] = 81962,
  [SMALL_STATE(1237)] = 82006,
  [SMALL_STATE(1238)] = 82050,
  [SMALL_STATE(1239)] = 82094,
  [SMALL_STATE(1240)] = 82138,
  [SMALL_STATE(1241)] = 82182,
  [SMALL_STATE(1242)] = 82226,
  [SMALL_STATE(1243)] = 82272,
  [SMALL_STATE(1244)] = 82318,
  [SMALL_STATE(1245)] = 82366,
  [SMALL_STATE(1246)] = 82412,
  [SMALL_STATE(1247)] = 82460,
  [SMALL_STATE(1248)] = 82506,
  [SMALL_STATE(1249)] = 82554,
  [SMALL_STATE(1250)] = 82600,
  [SMALL_STATE(1251)] = 82648,
  [SMALL_STATE(1252)] = 82696,
  [SMALL_STATE(1253)] = 82744,
  [SMALL_STATE(1254)] = 82792,
  [SMALL_STATE(1255)] = 82838,
  [SMALL_STATE(1256)] = 82884,
  [SMALL_STATE(1257)] = 82928,
  [SMALL_STATE(1258)] = 82972,
  [SMALL_STATE(1259)] = 83016,
  [SMALL_STATE(1260)] = 83060,
  [SMALL_STATE(1261)] = 83104,
  [SMALL_STATE(1262)] = 83152,
  [SMALL_STATE(1263)] = 83196,
  [SMALL_STATE(1264)] = 83240,
  [SMALL_STATE(1265)] = 83284,
  [SMALL_STATE(1266)] = 83328,
  [SMALL_STATE(1267)] = 83372,
  [SMALL_STATE(1268)] = 83416,
  [SMALL_STATE(1269)] = 83460,
  [SMALL_STATE(1270)] = 83504,
  [SMALL_STATE(1271)] = 83548,
  [SMALL_STATE(1272)] = 83592,
  [SMALL_STATE(1273)] = 83636,
  [SMALL_STATE(1274)] = 83680,
  [SMALL_STATE(1275)] = 83756,
  [SMALL_STATE(1276)] = 83800,
  [SMALL_STATE(1277)] = 83844,
  [SMALL_STATE(1278)] = 83888,
  [SMALL_STATE(1279)] = 83932,
  [SMALL_STATE(1280)] = 83976,
  [SMALL_STATE(1281)] = 84020,
  [SMALL_STATE(1282)] = 84064,
  [SMALL_STATE(1283)] = 84108,
  [SMALL_STATE(1284)] = 84152,
  [SMALL_STATE(1285)] = 84196,
  [SMALL_STATE(1286)] = 84240,
  [SMALL_STATE(1287)] = 84284,
  [SMALL_STATE(1288)] = 84327,
  [SMALL_STATE(1289)] = 84370,
  [SMALL_STATE(1290)] = 84413,
  [SMALL_STATE(1291)] = 84456,
  [SMALL_STATE(1292)] = 84501,
  [SMALL_STATE(1293)] = 84544,
  [SMALL_STATE(1294)] = 84587,
  [SMALL_STATE(1295)] = 84630,
  [SMALL_STATE(1296)] = 84673,
  [SMALL_STATE(1297)] = 84716,
  [SMALL_STATE(1298)] = 84759,
  [SMALL_STATE(1299)] = 84802,
  [SMALL_STATE(1300)] = 84845,
  [SMALL_STATE(1301)] = 84888,
  [SMALL_STATE(1302)] = 84931,
  [SMALL_STATE(1303)] = 84974,
  [SMALL_STATE(1304)] = 85017,
  [SMALL_STATE(1305)] = 85060,
  [SMALL_STATE(1306)] = 85103,
  [SMALL_STATE(1307)] = 85146,
  [SMALL_STATE(1308)] = 85193,
  [SMALL_STATE(1309)] = 85240,
  [SMALL_STATE(1310)] = 85283,
  [SMALL_STATE(1311)] = 85330,
  [SMALL_STATE(1312)] = 85373,
  [SMALL_STATE(1313)] = 85416,
  [SMALL_STATE(1314)] = 85459,
  [SMALL_STATE(1315)] = 85502,
  [SMALL_STATE(1316)] = 85545,
  [SMALL_STATE(1317)] = 85588,
  [SMALL_STATE(1318)] = 85631,
  [SMALL_STATE(1319)] = 85674,
  [SMALL_STATE(1320)] = 85717,
  [SMALL_STATE(1321)] = 85760,
  [SMALL_STATE(1322)] = 85803,
  [SMALL_STATE(1323)] = 85846,
  [SMALL_STATE(1324)] = 85889,
  [SMALL_STATE(1325)] = 85932,
  [SMALL_STATE(1326)] = 85975,
  [SMALL_STATE(1327)] = 86018,
  [SMALL_STATE(1328)] = 86061,
  [SMALL_STATE(1329)] = 86104,
  [SMALL_STATE(1330)] = 86147,
  [SMALL_STATE(1331)] = 86190,
  [SMALL_STATE(1332)] = 86233,
  [SMALL_STATE(1333)] = 86280,
  [SMALL_STATE(1334)] = 86327,
  [SMALL_STATE(1335)] = 86378,
  [SMALL_STATE(1336)] = 86421,
  [SMALL_STATE(1337)] = 86464,
  [SMALL_STATE(1338)] = 86507,
  [SMALL_STATE(1339)] = 86550,
  [SMALL_STATE(1340)] = 86593,
  [SMALL_STATE(1341)] = 86638,
  [SMALL_STATE(1342)] = 86683,
  [SMALL_STATE(1343)] = 86728,
  [SMALL_STATE(1344)] = 86773,
  [SMALL_STATE(1345)] = 86816,
  [SMALL_STATE(1346)] = 86861,
  [SMALL_STATE(1347)] = 86904,
  [SMALL_STATE(1348)] = 86947,
  [SMALL_STATE(1349)] = 86990,
  [SMALL_STATE(1350)] = 87033,
  [SMALL_STATE(1351)] = 87076,
  [SMALL_STATE(1352)] = 87119,
  [SMALL_STATE(1353)] = 87162,
  [SMALL_STATE(1354)] = 87205,
  [SMALL_STATE(1355)] = 87248,
  [SMALL_STATE(1356)] = 87293,
  [SMALL_STATE(1357)] = 87336,
  [SMALL_STATE(1358)] = 87379,
  [SMALL_STATE(1359)] = 87422,
  [SMALL_STATE(1360)] = 87465,
  [SMALL_STATE(1361)] = 87508,
  [SMALL_STATE(1362)] = 87551,
  [SMALL_STATE(1363)] = 87594,
  [SMALL_STATE(1364)] = 87639,
  [SMALL_STATE(1365)] = 87682,
  [SMALL_STATE(1366)] = 87725,
  [SMALL_STATE(1367)] = 87768,
  [SMALL_STATE(1368)] = 87811,
  [SMALL_STATE(1369)] = 87854,
  [SMALL_STATE(1370)] = 87901,
  [SMALL_STATE(1371)] = 87948,
  [SMALL_STATE(1372)] = 87991,
  [SMALL_STATE(1373)] = 88034,
  [SMALL_STATE(1374)] = 88077,
  [SMALL_STATE(1375)] = 88122,
  [SMALL_STATE(1376)] = 88165,
  [SMALL_STATE(1377)] = 88208,
  [SMALL_STATE(1378)] = 88251,
  [SMALL_STATE(1379)] = 88294,
  [SMALL_STATE(1380)] = 88337,
  [SMALL_STATE(1381)] = 88380,
  [SMALL_STATE(1382)] = 88427,
  [SMALL_STATE(1383)] = 88470,
  [SMALL_STATE(1384)] = 88513,
  [SMALL_STATE(1385)] = 88556,
  [SMALL_STATE(1386)] = 88601,
  [SMALL_STATE(1387)] = 88644,
  [SMALL_STATE(1388)] = 88687,
  [SMALL_STATE(1389)] = 88730,
  [SMALL_STATE(1390)] = 88773,
  [SMALL_STATE(1391)] = 88816,
  [SMALL_STATE(1392)] = 88859,
  [SMALL_STATE(1393)] = 88906,
  [SMALL_STATE(1394)] = 88949,
  [SMALL_STATE(1395)] = 88994,
  [SMALL_STATE(1396)] = 89037,
  [SMALL_STATE(1397)] = 89084,
  [SMALL_STATE(1398)] = 89127,
  [SMALL_STATE(1399)] = 89170,
  [SMALL_STATE(1400)] = 89215,
  [SMALL_STATE(1401)] = 89260,
  [SMALL_STATE(1402)] = 89305,
  [SMALL_STATE(1403)] = 89348,
  [SMALL_STATE(1404)] = 89391,
  [SMALL_STATE(1405)] = 89434,
  [SMALL_STATE(1406)] = 89477,
  [SMALL_STATE(1407)] = 89520,
  [SMALL_STATE(1408)] = 89571,
  [SMALL_STATE(1409)] = 89614,
  [SMALL_STATE(1410)] = 89657,
  [SMALL_STATE(1411)] = 89700,
  [SMALL_STATE(1412)] = 89743,
  [SMALL_STATE(1413)] = 89790,
  [SMALL_STATE(1414)] = 89837,
  [SMALL_STATE(1415)] = 89880,
  [SMALL_STATE(1416)] = 89923,
  [SMALL_STATE(1417)] = 89966,
  [SMALL_STATE(1418)] = 90013,
  [SMALL_STATE(1419)] = 90056,
  [SMALL_STATE(1420)] = 90101,
  [SMALL_STATE(1421)] = 90144,
  [SMALL_STATE(1422)] = 90189,
  [SMALL_STATE(1423)] = 90232,
  [SMALL_STATE(1424)] = 90275,
  [SMALL_STATE(1425)] = 90318,
  [SMALL_STATE(1426)] = 90363,
  [SMALL_STATE(1427)] = 90406,
  [SMALL_STATE(1428)] = 90449,
  [SMALL_STATE(1429)] = 90492,
  [SMALL_STATE(1430)] = 90539,
  [SMALL_STATE(1431)] = 90582,
  [SMALL_STATE(1432)] = 90625,
  [SMALL_STATE(1433)] = 90668,
  [SMALL_STATE(1434)] = 90711,
  [SMALL_STATE(1435)] = 90754,
  [SMALL_STATE(1436)] = 90797,
  [SMALL_STATE(1437)] = 90840,
  [SMALL_STATE(1438)] = 90887,
  [SMALL_STATE(1439)] = 90930,
  [SMALL_STATE(1440)] = 90973,
  [SMALL_STATE(1441)] = 91016,
  [SMALL_STATE(1442)] = 91059,
  [SMALL_STATE(1443)] = 91104,
  [SMALL_STATE(1444)] = 91149,
  [SMALL_STATE(1445)] = 91192,
  [SMALL_STATE(1446)] = 91235,
  [SMALL_STATE(1447)] = 91278,
  [SMALL_STATE(1448)] = 91321,
  [SMALL_STATE(1449)] = 91364,
  [SMALL_STATE(1450)] = 91407,
  [SMALL_STATE(1451)] = 91449,
  [SMALL_STATE(1452)] = 91493,
  [SMALL_STATE(1453)] = 91535,
  [SMALL_STATE(1454)] = 91585,
  [SMALL_STATE(1455)] = 91627,
  [SMALL_STATE(1456)] = 91669,
  [SMALL_STATE(1457)] = 91711,
  [SMALL_STATE(1458)] = 91753,
  [SMALL_STATE(1459)] = 91795,
  [SMALL_STATE(1460)] = 91837,
  [SMALL_STATE(1461)] = 91885,
  [SMALL_STATE(1462)] = 91927,
  [SMALL_STATE(1463)] = 91969,
  [SMALL_STATE(1464)] = 92013,
  [SMALL_STATE(1465)] = 92055,
  [SMALL_STATE(1466)] = 92097,
  [SMALL_STATE(1467)] = 92141,
  [SMALL_STATE(1468)] = 92185,
  [SMALL_STATE(1469)] = 92227,
  [SMALL_STATE(1470)] = 92269,
  [SMALL_STATE(1471)] = 92311,
  [SMALL_STATE(1472)] = 92353,
  [SMALL_STATE(1473)] = 92395,
  [SMALL_STATE(1474)] = 92437,
  [SMALL_STATE(1475)] = 92481,
  [SMALL_STATE(1476)] = 92523,
  [SMALL_STATE(1477)] = 92567,
  [SMALL_STATE(1478)] = 92609,
  [SMALL_STATE(1479)] = 92651,
  [SMALL_STATE(1480)] = 92693,
  [SMALL_STATE(1481)] = 92735,
  [SMALL_STATE(1482)] = 92777,
  [SMALL_STATE(1483)] = 92819,
  [SMALL_STATE(1484)] = 92861,
  [SMALL_STATE(1485)] = 92903,
  [SMALL_STATE(1486)] = 92945,
  [SMALL_STATE(1487)] = 92987,
  [SMALL_STATE(1488)] = 93033,
  [SMALL_STATE(1489)] = 93075,
  [SMALL_STATE(1490)] = 93121,
  [SMALL_STATE(1491)] = 93167,
  [SMALL_STATE(1492)] = 93209,
  [SMALL_STATE(1493)] = 93251,
  [SMALL_STATE(1494)] = 93295,
  [SMALL_STATE(1495)] = 93339,
  [SMALL_STATE(1496)] = 93383,
  [SMALL_STATE(1497)] = 93425,
  [SMALL_STATE(1498)] = 93466,
  [SMALL_STATE(1499)] = 93509,
  [SMALL_STATE(1500)] = 93550,
  [SMALL_STATE(1501)] = 93593,
  [SMALL_STATE(1502)] = 93636,
  [SMALL_STATE(1503)] = 93679,
  [SMALL_STATE(1504)] = 93720,
  [SMALL_STATE(1505)] = 93761,
  [SMALL_STATE(1506)] = 93802,
  [SMALL_STATE(1507)] = 93845,
  [SMALL_STATE(1508)] = 93886,
  [SMALL_STATE(1509)] = 93929,
  [SMALL_STATE(1510)] = 93972,
  [SMALL_STATE(1511)] = 94015,
  [SMALL_STATE(1512)] = 94056,
  [SMALL_STATE(1513)] = 94099,
  [SMALL_STATE(1514)] = 94140,
  [SMALL_STATE(1515)] = 94181,
  [SMALL_STATE(1516)] = 94222,
  [SMALL_STATE(1517)] = 94296,
  [SMALL_STATE(1518)] = 94370,
  [SMALL_STATE(1519)] = 94438,
  [SMALL_STATE(1520)] = 94506,
  [SMALL_STATE(1521)] = 94574,
  [SMALL_STATE(1522)] = 94642,
  [SMALL_STATE(1523)] = 94710,
  [SMALL_STATE(1524)] = 94778,
  [SMALL_STATE(1525)] = 94846,
  [SMALL_STATE(1526)] = 94914,
  [SMALL_STATE(1527)] = 94982,
  [SMALL_STATE(1528)] = 95050,
  [SMALL_STATE(1529)] = 95118,
  [SMALL_STATE(1530)] = 95186,
  [SMALL_STATE(1531)] = 95254,
  [SMALL_STATE(1532)] = 95322,
  [SMALL_STATE(1533)] = 95390,
  [SMALL_STATE(1534)] = 95458,
  [SMALL_STATE(1535)] = 95526,
  [SMALL_STATE(1536)] = 95594,
  [SMALL_STATE(1537)] = 95662,
  [SMALL_STATE(1538)] = 95730,
  [SMALL_STATE(1539)] = 95798,
  [SMALL_STATE(1540)] = 95866,
  [SMALL_STATE(1541)] = 95934,
  [SMALL_STATE(1542)] = 96002,
  [SMALL_STATE(1543)] = 96070,
  [SMALL_STATE(1544)] = 96138,
  [SMALL_STATE(1545)] = 96206,
  [SMALL_STATE(1546)] = 96274,
  [SMALL_STATE(1547)] = 96342,
  [SMALL_STATE(1548)] = 96410,
  [SMALL_STATE(1549)] = 96478,
  [SMALL_STATE(1550)] = 96546,
  [SMALL_STATE(1551)] = 96614,
  [SMALL_STATE(1552)] = 96682,
  [SMALL_STATE(1553)] = 96750,
  [SMALL_STATE(1554)] = 96818,
  [SMALL_STATE(1555)] = 96883,
  [SMALL_STATE(1556)] = 96948,
  [SMALL_STATE(1557)] = 97013,
  [SMALL_STATE(1558)] = 97078,
  [SMALL_STATE(1559)] = 97143,
  [SMALL_STATE(1560)] = 97209,
  [SMALL_STATE(1561)] = 97275,
  [SMALL_STATE(1562)] = 97341,
  [SMALL_STATE(1563)] = 97407,
  [SMALL_STATE(1564)] = 97473,
  [SMALL_STATE(1565)] = 97539,
  [SMALL_STATE(1566)] = 97605,
  [SMALL_STATE(1567)] = 97671,
  [SMALL_STATE(1568)] = 97737,
  [SMALL_STATE(1569)] = 97803,
  [SMALL_STATE(1570)] = 97869,
  [SMALL_STATE(1571)] = 97935,
  [SMALL_STATE(1572)] = 98001,
  [SMALL_STATE(1573)] = 98067,
  [SMALL_STATE(1574)] = 98133,
  [SMALL_STATE(1575)] = 98199,
  [SMALL_STATE(1576)] = 98265,
  [SMALL_STATE(1577)] = 98331,
  [SMALL_STATE(1578)] = 98397,
  [SMALL_STATE(1579)] = 98463,
  [SMALL_STATE(1580)] = 98526,
  [SMALL_STATE(1581)] = 98584,
  [SMALL_STATE(1582)] = 98642,
  [SMALL_STATE(1583)] = 98700,
  [SMALL_STATE(1584)] = 98758,
  [SMALL_STATE(1585)] = 98816,
  [SMALL_STATE(1586)] = 98874,
  [SMALL_STATE(1587)] = 98932,
  [SMALL_STATE(1588)] = 98990,
  [SMALL_STATE(1589)] = 99032,
  [SMALL_STATE(1590)] = 99074,
  [SMALL_STATE(1591)] = 99106,
  [SMALL_STATE(1592)] = 99138,
  [SMALL_STATE(1593)] = 99170,
  [SMALL_STATE(1594)] = 99210,
  [SMALL_STATE(1595)] = 99242,
  [SMALL_STATE(1596)] = 99282,
  [SMALL_STATE(1597)] = 99322,
  [SMALL_STATE(1598)] = 99362,
  [SMALL_STATE(1599)] = 99394,
  [SMALL_STATE(1600)] = 99426,
  [SMALL_STATE(1601)] = 99463,
  [SMALL_STATE(1602)] = 99502,
  [SMALL_STATE(1603)] = 99541,
  [SMALL_STATE(1604)] = 99580,
  [SMALL_STATE(1605)] = 99617,
  [SMALL_STATE(1606)] = 99656,
  [SMALL_STATE(1607)] = 99686,
  [SMALL_STATE(1608)] = 99716,
  [SMALL_STATE(1609)] = 99746,
  [SMALL_STATE(1610)] = 99776,
  [SMALL_STATE(1611)] = 99814,
  [SMALL_STATE(1612)] = 99844,
  [SMALL_STATE(1613)] = 99874,
  [SMALL_STATE(1614)] = 99912,
  [SMALL_STATE(1615)] = 99950,
  [SMALL_STATE(1616)] = 99980,
  [SMALL_STATE(1617)] = 100010,
  [SMALL_STATE(1618)] = 100048,
  [SMALL_STATE(1619)] = 100077,
  [SMALL_STATE(1620)] = 100124,
  [SMALL_STATE(1621)] = 100171,
  [SMALL_STATE(1622)] = 100218,
  [SMALL_STATE(1623)] = 100247,
  [SMALL_STATE(1624)] = 100294,
  [SMALL_STATE(1625)] = 100341,
  [SMALL_STATE(1626)] = 100370,
  [SMALL_STATE(1627)] = 100399,
  [SMALL_STATE(1628)] = 100428,
  [SMALL_STATE(1629)] = 100453,
  [SMALL_STATE(1630)] = 100482,
  [SMALL_STATE(1631)] = 100511,
  [SMALL_STATE(1632)] = 100558,
  [SMALL_STATE(1633)] = 100587,
  [SMALL_STATE(1634)] = 100634,
  [SMALL_STATE(1635)] = 100663,
  [SMALL_STATE(1636)] = 100688,
  [SMALL_STATE(1637)] = 100717,
  [SMALL_STATE(1638)] = 100746,
  [SMALL_STATE(1639)] = 100775,
  [SMALL_STATE(1640)] = 100804,
  [SMALL_STATE(1641)] = 100833,
  [SMALL_STATE(1642)] = 100880,
  [SMALL_STATE(1643)] = 100909,
  [SMALL_STATE(1644)] = 100938,
  [SMALL_STATE(1645)] = 100967,
  [SMALL_STATE(1646)] = 100996,
  [SMALL_STATE(1647)] = 101025,
  [SMALL_STATE(1648)] = 101054,
  [SMALL_STATE(1649)] = 101083,
  [SMALL_STATE(1650)] = 101108,
  [SMALL_STATE(1651)] = 101155,
  [SMALL_STATE(1652)] = 101184,
  [SMALL_STATE(1653)] = 101213,
  [SMALL_STATE(1654)] = 101238,
  [SMALL_STATE(1655)] = 101285,
  [SMALL_STATE(1656)] = 101314,
  [SMALL_STATE(1657)] = 101360,
  [SMALL_STATE(1658)] = 101406,
  [SMALL_STATE(1659)] = 101452,
  [SMALL_STATE(1660)] = 101498,
  [SMALL_STATE(1661)] = 101544,
  [SMALL_STATE(1662)] = 101572,
  [SMALL_STATE(1663)] = 101618,
  [SMALL_STATE(1664)] = 101664,
  [SMALL_STATE(1665)] = 101688,
  [SMALL_STATE(1666)] = 101734,
  [SMALL_STATE(1667)] = 101764,
  [SMALL_STATE(1668)] = 101810,
  [SMALL_STATE(1669)] = 101834,
  [SMALL_STATE(1670)] = 101880,
  [SMALL_STATE(1671)] = 101912,
  [SMALL_STATE(1672)] = 101944,
  [SMALL_STATE(1673)] = 101968,
  [SMALL_STATE(1674)] = 101992,
  [SMALL_STATE(1675)] = 102038,
  [SMALL_STATE(1676)] = 102066,
  [SMALL_STATE(1677)] = 102109,
  [SMALL_STATE(1678)] = 102149,
  [SMALL_STATE(1679)] = 102189,
  [SMALL_STATE(1680)] = 102215,
  [SMALL_STATE(1681)] = 102255,
  [SMALL_STATE(1682)] = 102295,
  [SMALL_STATE(1683)] = 102332,
  [SMALL_STATE(1684)] = 102369,
  [SMALL_STATE(1685)] = 102410,
  [SMALL_STATE(1686)] = 102433,
  [SMALL_STATE(1687)] = 102474,
  [SMALL_STATE(1688)] = 102493,
  [SMALL_STATE(1689)] = 102514,
  [SMALL_STATE(1690)] = 102533,
  [SMALL_STATE(1691)] = 102574,
  [SMALL_STATE(1692)] = 102615,
  [SMALL_STATE(1693)] = 102634,
  [SMALL_STATE(1694)] = 102661,
  [SMALL_STATE(1695)] = 102702,
  [SMALL_STATE(1696)] = 102743,
  [SMALL_STATE(1697)] = 102770,
  [SMALL_STATE(1698)] = 102795,
  [SMALL_STATE(1699)] = 102836,
  [SMALL_STATE(1700)] = 102863,
  [SMALL_STATE(1701)] = 102904,
  [SMALL_STATE(1702)] = 102942,
  [SMALL_STATE(1703)] = 102980,
  [SMALL_STATE(1704)] = 103018,
  [SMALL_STATE(1705)] = 103056,
  [SMALL_STATE(1706)] = 103094,
  [SMALL_STATE(1707)] = 103132,
  [SMALL_STATE(1708)] = 103170,
  [SMALL_STATE(1709)] = 103208,
  [SMALL_STATE(1710)] = 103240,
  [SMALL_STATE(1711)] = 103278,
  [SMALL_STATE(1712)] = 103316,
  [SMALL_STATE(1713)] = 103354,
  [SMALL_STATE(1714)] = 103392,
  [SMALL_STATE(1715)] = 103430,
  [SMALL_STATE(1716)] = 103468,
  [SMALL_STATE(1717)] = 103506,
  [SMALL_STATE(1718)] = 103544,
  [SMALL_STATE(1719)] = 103582,
  [SMALL_STATE(1720)] = 103620,
  [SMALL_STATE(1721)] = 103658,
  [SMALL_STATE(1722)] = 103696,
  [SMALL_STATE(1723)] = 103734,
  [SMALL_STATE(1724)] = 103772,
  [SMALL_STATE(1725)] = 103810,
  [SMALL_STATE(1726)] = 103848,
  [SMALL_STATE(1727)] = 103886,
  [SMALL_STATE(1728)] = 103915,
  [SMALL_STATE(1729)] = 103944,
  [SMALL_STATE(1730)] = 103969,
  [SMALL_STATE(1731)] = 103998,
  [SMALL_STATE(1732)] = 104027,
  [SMALL_STATE(1733)] = 104056,
  [SMALL_STATE(1734)] = 104085,
  [SMALL_STATE(1735)] = 104108,
  [SMALL_STATE(1736)] = 104129,
  [SMALL_STATE(1737)] = 104158,
  [SMALL_STATE(1738)] = 104175,
  [SMALL_STATE(1739)] = 104192,
  [SMALL_STATE(1740)] = 104221,
  [SMALL_STATE(1741)] = 104238,
  [SMALL_STATE(1742)] = 104263,
  [SMALL_STATE(1743)] = 104292,
  [SMALL_STATE(1744)] = 104321,
  [SMALL_STATE(1745)] = 104344,
  [SMALL_STATE(1746)] = 104369,
  [SMALL_STATE(1747)] = 104390,
  [SMALL_STATE(1748)] = 104419,
  [SMALL_STATE(1749)] = 104444,
  [SMALL_STATE(1750)] = 104461,
  [SMALL_STATE(1751)] = 104480,
  [SMALL_STATE(1752)] = 104497,
  [SMALL_STATE(1753)] = 104526,
  [SMALL_STATE(1754)] = 104551,
  [SMALL_STATE(1755)] = 104570,
  [SMALL_STATE(1756)] = 104595,
  [SMALL_STATE(1757)] = 104624,
  [SMALL_STATE(1758)] = 104653,
  [SMALL_STATE(1759)] = 104670,
  [SMALL_STATE(1760)] = 104699,
  [SMALL_STATE(1761)] = 104724,
  [SMALL_STATE(1762)] = 104753,
  [SMALL_STATE(1763)] = 104778,
  [SMALL_STATE(1764)] = 104807,
  [SMALL_STATE(1765)] = 104836,
  [SMALL_STATE(1766)] = 104865,
  [SMALL_STATE(1767)] = 104894,
  [SMALL_STATE(1768)] = 104923,
  [SMALL_STATE(1769)] = 104941,
  [SMALL_STATE(1770)] = 104963,
  [SMALL_STATE(1771)] = 104987,
  [SMALL_STATE(1772)] = 105007,
  [SMALL_STATE(1773)] = 105031,
  [SMALL_STATE(1774)] = 105055,
  [SMALL_STATE(1775)] = 105073,
  [SMALL_STATE(1776)] = 105095,
  [SMALL_STATE(1777)] = 105115,
  [SMALL_STATE(1778)] = 105131,
  [SMALL_STATE(1779)] = 105149,
  [SMALL_STATE(1780)] = 105169,
  [SMALL_STATE(1781)] = 105191,
  [SMALL_STATE(1782)] = 105215,
  [SMALL_STATE(1783)] = 105239,
  [SMALL_STATE(1784)] = 105255,
  [SMALL_STATE(1785)] = 105273,
  [SMALL_STATE(1786)] = 105295,
  [SMALL_STATE(1787)] = 105319,
  [SMALL_STATE(1788)] = 105335,
  [SMALL_STATE(1789)] = 105353,
  [SMALL_STATE(1790)] = 105369,
  [SMALL_STATE(1791)] = 105389,
  [SMALL_STATE(1792)] = 105413,
  [SMALL_STATE(1793)] = 105443,
  [SMALL_STATE(1794)] = 105459,
  [SMALL_STATE(1795)] = 105479,
  [SMALL_STATE(1796)] = 105503,
  [SMALL_STATE(1797)] = 105527,
  [SMALL_STATE(1798)] = 105551,
  [SMALL_STATE(1799)] = 105571,
  [SMALL_STATE(1800)] = 105595,
  [SMALL_STATE(1801)] = 105619,
  [SMALL_STATE(1802)] = 105643,
  [SMALL_STATE(1803)] = 105659,
  [SMALL_STATE(1804)] = 105681,
  [SMALL_STATE(1805)] = 105702,
  [SMALL_STATE(1806)] = 105723,
  [SMALL_STATE(1807)] = 105744,
  [SMALL_STATE(1808)] = 105773,
  [SMALL_STATE(1809)] = 105800,
  [SMALL_STATE(1810)] = 105817,
  [SMALL_STATE(1811)] = 105838,
  [SMALL_STATE(1812)] = 105861,
  [SMALL_STATE(1813)] = 105880,
  [SMALL_STATE(1814)] = 105905,
  [SMALL_STATE(1815)] = 105926,
  [SMALL_STATE(1816)] = 105955,
  [SMALL_STATE(1817)] = 105978,
  [SMALL_STATE(1818)] = 105999,
  [SMALL_STATE(1819)] = 106020,
  [SMALL_STATE(1820)] = 106037,
  [SMALL_STATE(1821)] = 106064,
  [SMALL_STATE(1822)] = 106085,
  [SMALL_STATE(1823)] = 106102,
  [SMALL_STATE(1824)] = 106125,
  [SMALL_STATE(1825)] = 106150,
  [SMALL_STATE(1826)] = 106173,
  [SMALL_STATE(1827)] = 106192,
  [SMALL_STATE(1828)] = 106213,
  [SMALL_STATE(1829)] = 106238,
  [SMALL_STATE(1830)] = 106265,
  [SMALL_STATE(1831)] = 106290,
  [SMALL_STATE(1832)] = 106319,
  [SMALL_STATE(1833)] = 106336,
  [SMALL_STATE(1834)] = 106361,
  [SMALL_STATE(1835)] = 106390,
  [SMALL_STATE(1836)] = 106419,
  [SMALL_STATE(1837)] = 106434,
  [SMALL_STATE(1838)] = 106455,
  [SMALL_STATE(1839)] = 106484,
  [SMALL_STATE(1840)] = 106505,
  [SMALL_STATE(1841)] = 106526,
  [SMALL_STATE(1842)] = 106551,
  [SMALL_STATE(1843)] = 106572,
  [SMALL_STATE(1844)] = 106589,
  [SMALL_STATE(1845)] = 106610,
  [SMALL_STATE(1846)] = 106631,
  [SMALL_STATE(1847)] = 106654,
  [SMALL_STATE(1848)] = 106683,
  [SMALL_STATE(1849)] = 106706,
  [SMALL_STATE(1850)] = 106733,
  [SMALL_STATE(1851)] = 106756,
  [SMALL_STATE(1852)] = 106779,
  [SMALL_STATE(1853)] = 106808,
  [SMALL_STATE(1854)] = 106835,
  [SMALL_STATE(1855)] = 106864,
  [SMALL_STATE(1856)] = 106885,
  [SMALL_STATE(1857)] = 106902,
  [SMALL_STATE(1858)] = 106921,
  [SMALL_STATE(1859)] = 106948,
  [SMALL_STATE(1860)] = 106975,
  [SMALL_STATE(1861)] = 107004,
  [SMALL_STATE(1862)] = 107031,
  [SMALL_STATE(1863)] = 107057,
  [SMALL_STATE(1864)] = 107075,
  [SMALL_STATE(1865)] = 107095,
  [SMALL_STATE(1866)] = 107113,
  [SMALL_STATE(1867)] = 107131,
  [SMALL_STATE(1868)] = 107153,
  [SMALL_STATE(1869)] = 107175,
  [SMALL_STATE(1870)] = 107197,
  [SMALL_STATE(1871)] = 107219,
  [SMALL_STATE(1872)] = 107245,
  [SMALL_STATE(1873)] = 107267,
  [SMALL_STATE(1874)] = 107287,
  [SMALL_STATE(1875)] = 107313,
  [SMALL_STATE(1876)] = 107333,
  [SMALL_STATE(1877)] = 107359,
  [SMALL_STATE(1878)] = 107377,
  [SMALL_STATE(1879)] = 107403,
  [SMALL_STATE(1880)] = 107429,
  [SMALL_STATE(1881)] = 107453,
  [SMALL_STATE(1882)] = 107469,
  [SMALL_STATE(1883)] = 107495,
  [SMALL_STATE(1884)] = 107517,
  [SMALL_STATE(1885)] = 107543,
  [SMALL_STATE(1886)] = 107569,
  [SMALL_STATE(1887)] = 107595,
  [SMALL_STATE(1888)] = 107613,
  [SMALL_STATE(1889)] = 107631,
  [SMALL_STATE(1890)] = 107649,
  [SMALL_STATE(1891)] = 107675,
  [SMALL_STATE(1892)] = 107697,
  [SMALL_STATE(1893)] = 107723,
  [SMALL_STATE(1894)] = 107747,
  [SMALL_STATE(1895)] = 107773,
  [SMALL_STATE(1896)] = 107791,
  [SMALL_STATE(1897)] = 107817,
  [SMALL_STATE(1898)] = 107839,
  [SMALL_STATE(1899)] = 107857,
  [SMALL_STATE(1900)] = 107879,
  [SMALL_STATE(1901)] = 107897,
  [SMALL_STATE(1902)] = 107915,
  [SMALL_STATE(1903)] = 107937,
  [SMALL_STATE(1904)] = 107961,
  [SMALL_STATE(1905)] = 107983,
  [SMALL_STATE(1906)] = 108009,
  [SMALL_STATE(1907)] = 108033,
  [SMALL_STATE(1908)] = 108059,
  [SMALL_STATE(1909)] = 108075,
  [SMALL_STATE(1910)] = 108101,
  [SMALL_STATE(1911)] = 108123,
  [SMALL_STATE(1912)] = 108149,
  [SMALL_STATE(1913)] = 108171,
  [SMALL_STATE(1914)] = 108189,
  [SMALL_STATE(1915)] = 108206,
  [SMALL_STATE(1916)] = 108223,
  [SMALL_STATE(1917)] = 108240,
  [SMALL_STATE(1918)] = 108255,
  [SMALL_STATE(1919)] = 108272,
  [SMALL_STATE(1920)] = 108289,
  [SMALL_STATE(1921)] = 108310,
  [SMALL_STATE(1922)] = 108327,
  [SMALL_STATE(1923)] = 108348,
  [SMALL_STATE(1924)] = 108365,
  [SMALL_STATE(1925)] = 108386,
  [SMALL_STATE(1926)] = 108409,
  [SMALL_STATE(1927)] = 108426,
  [SMALL_STATE(1928)] = 108439,
  [SMALL_STATE(1929)] = 108462,
  [SMALL_STATE(1930)] = 108475,
  [SMALL_STATE(1931)] = 108496,
  [SMALL_STATE(1932)] = 108513,
  [SMALL_STATE(1933)] = 108528,
  [SMALL_STATE(1934)] = 108545,
  [SMALL_STATE(1935)] = 108558,
  [SMALL_STATE(1936)] = 108575,
  [SMALL_STATE(1937)] = 108596,
  [SMALL_STATE(1938)] = 108609,
  [SMALL_STATE(1939)] = 108626,
  [SMALL_STATE(1940)] = 108649,
  [SMALL_STATE(1941)] = 108666,
  [SMALL_STATE(1942)] = 108683,
  [SMALL_STATE(1943)] = 108700,
  [SMALL_STATE(1944)] = 108721,
  [SMALL_STATE(1945)] = 108742,
  [SMALL_STATE(1946)] = 108763,
  [SMALL_STATE(1947)] = 108784,
  [SMALL_STATE(1948)] = 108801,
  [SMALL_STATE(1949)] = 108814,
  [SMALL_STATE(1950)] = 108827,
  [SMALL_STATE(1951)] = 108848,
  [SMALL_STATE(1952)] = 108869,
  [SMALL_STATE(1953)] = 108890,
  [SMALL_STATE(1954)] = 108911,
  [SMALL_STATE(1955)] = 108926,
  [SMALL_STATE(1956)] = 108943,
  [SMALL_STATE(1957)] = 108956,
  [SMALL_STATE(1958)] = 108969,
  [SMALL_STATE(1959)] = 108990,
  [SMALL_STATE(1960)] = 109003,
  [SMALL_STATE(1961)] = 109024,
  [SMALL_STATE(1962)] = 109047,
  [SMALL_STATE(1963)] = 109068,
  [SMALL_STATE(1964)] = 109081,
  [SMALL_STATE(1965)] = 109100,
  [SMALL_STATE(1966)] = 109113,
  [SMALL_STATE(1967)] = 109130,
  [SMALL_STATE(1968)] = 109151,
  [SMALL_STATE(1969)] = 109164,
  [SMALL_STATE(1970)] = 109179,
  [SMALL_STATE(1971)] = 109192,
  [SMALL_STATE(1972)] = 109213,
  [SMALL_STATE(1973)] = 109226,
  [SMALL_STATE(1974)] = 109241,
  [SMALL_STATE(1975)] = 109258,
  [SMALL_STATE(1976)] = 109275,
  [SMALL_STATE(1977)] = 109296,
  [SMALL_STATE(1978)] = 109313,
  [SMALL_STATE(1979)] = 109330,
  [SMALL_STATE(1980)] = 109351,
  [SMALL_STATE(1981)] = 109368,
  [SMALL_STATE(1982)] = 109385,
  [SMALL_STATE(1983)] = 109402,
  [SMALL_STATE(1984)] = 109423,
  [SMALL_STATE(1985)] = 109444,
  [SMALL_STATE(1986)] = 109465,
  [SMALL_STATE(1987)] = 109480,
  [SMALL_STATE(1988)] = 109493,
  [SMALL_STATE(1989)] = 109506,
  [SMALL_STATE(1990)] = 109527,
  [SMALL_STATE(1991)] = 109548,
  [SMALL_STATE(1992)] = 109565,
  [SMALL_STATE(1993)] = 109588,
  [SMALL_STATE(1994)] = 109611,
  [SMALL_STATE(1995)] = 109632,
  [SMALL_STATE(1996)] = 109645,
  [SMALL_STATE(1997)] = 109662,
  [SMALL_STATE(1998)] = 109681,
  [SMALL_STATE(1999)] = 109698,
  [SMALL_STATE(2000)] = 109719,
  [SMALL_STATE(2001)] = 109736,
  [SMALL_STATE(2002)] = 109749,
  [SMALL_STATE(2003)] = 109766,
  [SMALL_STATE(2004)] = 109779,
  [SMALL_STATE(2005)] = 109792,
  [SMALL_STATE(2006)] = 109807,
  [SMALL_STATE(2007)] = 109828,
  [SMALL_STATE(2008)] = 109849,
  [SMALL_STATE(2009)] = 109866,
  [SMALL_STATE(2010)] = 109887,
  [SMALL_STATE(2011)] = 109908,
  [SMALL_STATE(2012)] = 109923,
  [SMALL_STATE(2013)] = 109940,
  [SMALL_STATE(2014)] = 109961,
  [SMALL_STATE(2015)] = 109978,
  [SMALL_STATE(2016)] = 109995,
  [SMALL_STATE(2017)] = 110008,
  [SMALL_STATE(2018)] = 110021,
  [SMALL_STATE(2019)] = 110038,
  [SMALL_STATE(2020)] = 110055,
  [SMALL_STATE(2021)] = 110078,
  [SMALL_STATE(2022)] = 110090,
  [SMALL_STATE(2023)] = 110102,
  [SMALL_STATE(2024)] = 110122,
  [SMALL_STATE(2025)] = 110134,
  [SMALL_STATE(2026)] = 110146,
  [SMALL_STATE(2027)] = 110158,
  [SMALL_STATE(2028)] = 110174,
  [SMALL_STATE(2029)] = 110188,
  [SMALL_STATE(2030)] = 110204,
  [SMALL_STATE(2031)] = 110216,
  [SMALL_STATE(2032)] = 110236,
  [SMALL_STATE(2033)] = 110252,
  [SMALL_STATE(2034)] = 110264,
  [SMALL_STATE(2035)] = 110278,
  [SMALL_STATE(2036)] = 110290,
  [SMALL_STATE(2037)] = 110306,
  [SMALL_STATE(2038)] = 110318,
  [SMALL_STATE(2039)] = 110330,
  [SMALL_STATE(2040)] = 110342,
  [SMALL_STATE(2041)] = 110360,
  [SMALL_STATE(2042)] = 110380,
  [SMALL_STATE(2043)] = 110394,
  [SMALL_STATE(2044)] = 110410,
  [SMALL_STATE(2045)] = 110422,
  [SMALL_STATE(2046)] = 110434,
  [SMALL_STATE(2047)] = 110454,
  [SMALL_STATE(2048)] = 110466,
  [SMALL_STATE(2049)] = 110482,
  [SMALL_STATE(2050)] = 110502,
  [SMALL_STATE(2051)] = 110520,
  [SMALL_STATE(2052)] = 110532,
  [SMALL_STATE(2053)] = 110544,
  [SMALL_STATE(2054)] = 110564,
  [SMALL_STATE(2055)] = 110584,
  [SMALL_STATE(2056)] = 110602,
  [SMALL_STATE(2057)] = 110618,
  [SMALL_STATE(2058)] = 110638,
  [SMALL_STATE(2059)] = 110650,
  [SMALL_STATE(2060)] = 110662,
  [SMALL_STATE(2061)] = 110674,
  [SMALL_STATE(2062)] = 110686,
  [SMALL_STATE(2063)] = 110698,
  [SMALL_STATE(2064)] = 110716,
  [SMALL_STATE(2065)] = 110736,
  [SMALL_STATE(2066)] = 110748,
  [SMALL_STATE(2067)] = 110760,
  [SMALL_STATE(2068)] = 110780,
  [SMALL_STATE(2069)] = 110792,
  [SMALL_STATE(2070)] = 110810,
  [SMALL_STATE(2071)] = 110828,
  [SMALL_STATE(2072)] = 110840,
  [SMALL_STATE(2073)] = 110860,
  [SMALL_STATE(2074)] = 110878,
  [SMALL_STATE(2075)] = 110896,
  [SMALL_STATE(2076)] = 110910,
  [SMALL_STATE(2077)] = 110926,
  [SMALL_STATE(2078)] = 110938,
  [SMALL_STATE(2079)] = 110956,
  [SMALL_STATE(2080)] = 110976,
  [SMALL_STATE(2081)] = 110994,
  [SMALL_STATE(2082)] = 111012,
  [SMALL_STATE(2083)] = 111024,
  [SMALL_STATE(2084)] = 111044,
  [SMALL_STATE(2085)] = 111064,
  [SMALL_STATE(2086)] = 111076,
  [SMALL_STATE(2087)] = 111096,
  [SMALL_STATE(2088)] = 111114,
  [SMALL_STATE(2089)] = 111134,
  [SMALL_STATE(2090)] = 111154,
  [SMALL_STATE(2091)] = 111174,
  [SMALL_STATE(2092)] = 111186,
  [SMALL_STATE(2093)] = 111198,
  [SMALL_STATE(2094)] = 111210,
  [SMALL_STATE(2095)] = 111222,
  [SMALL_STATE(2096)] = 111234,
  [SMALL_STATE(2097)] = 111254,
  [SMALL_STATE(2098)] = 111266,
  [SMALL_STATE(2099)] = 111278,
  [SMALL_STATE(2100)] = 111290,
  [SMALL_STATE(2101)] = 111302,
  [SMALL_STATE(2102)] = 111322,
  [SMALL_STATE(2103)] = 111338,
  [SMALL_STATE(2104)] = 111358,
  [SMALL_STATE(2105)] = 111370,
  [SMALL_STATE(2106)] = 111382,
  [SMALL_STATE(2107)] = 111394,
  [SMALL_STATE(2108)] = 111414,
  [SMALL_STATE(2109)] = 111434,
  [SMALL_STATE(2110)] = 111450,
  [SMALL_STATE(2111)] = 111466,
  [SMALL_STATE(2112)] = 111480,
  [SMALL_STATE(2113)] = 111496,
  [SMALL_STATE(2114)] = 111508,
  [SMALL_STATE(2115)] = 111528,
  [SMALL_STATE(2116)] = 111544,
  [SMALL_STATE(2117)] = 111564,
  [SMALL_STATE(2118)] = 111576,
  [SMALL_STATE(2119)] = 111592,
  [SMALL_STATE(2120)] = 111604,
  [SMALL_STATE(2121)] = 111624,
  [SMALL_STATE(2122)] = 111636,
  [SMALL_STATE(2123)] = 111650,
  [SMALL_STATE(2124)] = 111670,
  [SMALL_STATE(2125)] = 111690,
  [SMALL_STATE(2126)] = 111710,
  [SMALL_STATE(2127)] = 111722,
  [SMALL_STATE(2128)] = 111740,
  [SMALL_STATE(2129)] = 111752,
  [SMALL_STATE(2130)] = 111768,
  [SMALL_STATE(2131)] = 111780,
  [SMALL_STATE(2132)] = 111792,
  [SMALL_STATE(2133)] = 111812,
  [SMALL_STATE(2134)] = 111824,
  [SMALL_STATE(2135)] = 111836,
  [SMALL_STATE(2136)] = 111848,
  [SMALL_STATE(2137)] = 111860,
  [SMALL_STATE(2138)] = 111872,
  [SMALL_STATE(2139)] = 111892,
  [SMALL_STATE(2140)] = 111909,
  [SMALL_STATE(2141)] = 111926,
  [SMALL_STATE(2142)] = 111941,
  [SMALL_STATE(2143)] = 111954,
  [SMALL_STATE(2144)] = 111971,
  [SMALL_STATE(2145)] = 111988,
  [SMALL_STATE(2146)] = 111999,
  [SMALL_STATE(2147)] = 112014,
  [SMALL_STATE(2148)] = 112025,
  [SMALL_STATE(2149)] = 112036,
  [SMALL_STATE(2150)] = 112051,
  [SMALL_STATE(2151)] = 112062,
  [SMALL_STATE(2152)] = 112077,
  [SMALL_STATE(2153)] = 112088,
  [SMALL_STATE(2154)] = 112105,
  [SMALL_STATE(2155)] = 112122,
  [SMALL_STATE(2156)] = 112133,
  [SMALL_STATE(2157)] = 112144,
  [SMALL_STATE(2158)] = 112161,
  [SMALL_STATE(2159)] = 112178,
  [SMALL_STATE(2160)] = 112189,
  [SMALL_STATE(2161)] = 112204,
  [SMALL_STATE(2162)] = 112221,
  [SMALL_STATE(2163)] = 112236,
  [SMALL_STATE(2164)] = 112247,
  [SMALL_STATE(2165)] = 112264,
  [SMALL_STATE(2166)] = 112281,
  [SMALL_STATE(2167)] = 112292,
  [SMALL_STATE(2168)] = 112303,
  [SMALL_STATE(2169)] = 112314,
  [SMALL_STATE(2170)] = 112331,
  [SMALL_STATE(2171)] = 112342,
  [SMALL_STATE(2172)] = 112357,
  [SMALL_STATE(2173)] = 112374,
  [SMALL_STATE(2174)] = 112389,
  [SMALL_STATE(2175)] = 112402,
  [SMALL_STATE(2176)] = 112413,
  [SMALL_STATE(2177)] = 112424,
  [SMALL_STATE(2178)] = 112439,
  [SMALL_STATE(2179)] = 112454,
  [SMALL_STATE(2180)] = 112465,
  [SMALL_STATE(2181)] = 112476,
  [SMALL_STATE(2182)] = 112487,
  [SMALL_STATE(2183)] = 112498,
  [SMALL_STATE(2184)] = 112515,
  [SMALL_STATE(2185)] = 112526,
  [SMALL_STATE(2186)] = 112537,
  [SMALL_STATE(2187)] = 112548,
  [SMALL_STATE(2188)] = 112559,
  [SMALL_STATE(2189)] = 112570,
  [SMALL_STATE(2190)] = 112581,
  [SMALL_STATE(2191)] = 112592,
  [SMALL_STATE(2192)] = 112603,
  [SMALL_STATE(2193)] = 112618,
  [SMALL_STATE(2194)] = 112629,
  [SMALL_STATE(2195)] = 112646,
  [SMALL_STATE(2196)] = 112663,
  [SMALL_STATE(2197)] = 112680,
  [SMALL_STATE(2198)] = 112697,
  [SMALL_STATE(2199)] = 112708,
  [SMALL_STATE(2200)] = 112725,
  [SMALL_STATE(2201)] = 112742,
  [SMALL_STATE(2202)] = 112757,
  [SMALL_STATE(2203)] = 112768,
  [SMALL_STATE(2204)] = 112779,
  [SMALL_STATE(2205)] = 112790,
  [SMALL_STATE(2206)] = 112801,
  [SMALL_STATE(2207)] = 112818,
  [SMALL_STATE(2208)] = 112835,
  [SMALL_STATE(2209)] = 112846,
  [SMALL_STATE(2210)] = 112857,
  [SMALL_STATE(2211)] = 112868,
  [SMALL_STATE(2212)] = 112879,
  [SMALL_STATE(2213)] = 112890,
  [SMALL_STATE(2214)] = 112901,
  [SMALL_STATE(2215)] = 112918,
  [SMALL_STATE(2216)] = 112929,
  [SMALL_STATE(2217)] = 112940,
  [SMALL_STATE(2218)] = 112951,
  [SMALL_STATE(2219)] = 112962,
  [SMALL_STATE(2220)] = 112973,
  [SMALL_STATE(2221)] = 112984,
  [SMALL_STATE(2222)] = 112995,
  [SMALL_STATE(2223)] = 113012,
  [SMALL_STATE(2224)] = 113025,
  [SMALL_STATE(2225)] = 113036,
  [SMALL_STATE(2226)] = 113051,
  [SMALL_STATE(2227)] = 113068,
  [SMALL_STATE(2228)] = 113079,
  [SMALL_STATE(2229)] = 113094,
  [SMALL_STATE(2230)] = 113111,
  [SMALL_STATE(2231)] = 113122,
  [SMALL_STATE(2232)] = 113139,
  [SMALL_STATE(2233)] = 113154,
  [SMALL_STATE(2234)] = 113169,
  [SMALL_STATE(2235)] = 113180,
  [SMALL_STATE(2236)] = 113191,
  [SMALL_STATE(2237)] = 113202,
  [SMALL_STATE(2238)] = 113217,
  [SMALL_STATE(2239)] = 113234,
  [SMALL_STATE(2240)] = 113245,
  [SMALL_STATE(2241)] = 113256,
  [SMALL_STATE(2242)] = 113267,
  [SMALL_STATE(2243)] = 113278,
  [SMALL_STATE(2244)] = 113295,
  [SMALL_STATE(2245)] = 113312,
  [SMALL_STATE(2246)] = 113323,
  [SMALL_STATE(2247)] = 113334,
  [SMALL_STATE(2248)] = 113345,
  [SMALL_STATE(2249)] = 113356,
  [SMALL_STATE(2250)] = 113373,
  [SMALL_STATE(2251)] = 113384,
  [SMALL_STATE(2252)] = 113395,
  [SMALL_STATE(2253)] = 113406,
  [SMALL_STATE(2254)] = 113417,
  [SMALL_STATE(2255)] = 113428,
  [SMALL_STATE(2256)] = 113439,
  [SMALL_STATE(2257)] = 113450,
  [SMALL_STATE(2258)] = 113461,
  [SMALL_STATE(2259)] = 113472,
  [SMALL_STATE(2260)] = 113483,
  [SMALL_STATE(2261)] = 113494,
  [SMALL_STATE(2262)] = 113505,
  [SMALL_STATE(2263)] = 113516,
  [SMALL_STATE(2264)] = 113531,
  [SMALL_STATE(2265)] = 113546,
  [SMALL_STATE(2266)] = 113557,
  [SMALL_STATE(2267)] = 113572,
  [SMALL_STATE(2268)] = 113589,
  [SMALL_STATE(2269)] = 113601,
  [SMALL_STATE(2270)] = 113615,
  [SMALL_STATE(2271)] = 113629,
  [SMALL_STATE(2272)] = 113639,
  [SMALL_STATE(2273)] = 113653,
  [SMALL_STATE(2274)] = 113665,
  [SMALL_STATE(2275)] = 113679,
  [SMALL_STATE(2276)] = 113693,
  [SMALL_STATE(2277)] = 113707,
  [SMALL_STATE(2278)] = 113721,
  [SMALL_STATE(2279)] = 113731,
  [SMALL_STATE(2280)] = 113745,
  [SMALL_STATE(2281)] = 113757,
  [SMALL_STATE(2282)] = 113771,
  [SMALL_STATE(2283)] = 113785,
  [SMALL_STATE(2284)] = 113799,
  [SMALL_STATE(2285)] = 113813,
  [SMALL_STATE(2286)] = 113827,
  [SMALL_STATE(2287)] = 113841,
  [SMALL_STATE(2288)] = 113855,
  [SMALL_STATE(2289)] = 113867,
  [SMALL_STATE(2290)] = 113881,
  [SMALL_STATE(2291)] = 113895,
  [SMALL_STATE(2292)] = 113907,
  [SMALL_STATE(2293)] = 113919,
  [SMALL_STATE(2294)] = 113933,
  [SMALL_STATE(2295)] = 113945,
  [SMALL_STATE(2296)] = 113957,
  [SMALL_STATE(2297)] = 113971,
  [SMALL_STATE(2298)] = 113985,
  [SMALL_STATE(2299)] = 113999,
  [SMALL_STATE(2300)] = 114013,
  [SMALL_STATE(2301)] = 114027,
  [SMALL_STATE(2302)] = 114039,
  [SMALL_STATE(2303)] = 114049,
  [SMALL_STATE(2304)] = 114063,
  [SMALL_STATE(2305)] = 114075,
  [SMALL_STATE(2306)] = 114089,
  [SMALL_STATE(2307)] = 114103,
  [SMALL_STATE(2308)] = 114117,
  [SMALL_STATE(2309)] = 114131,
  [SMALL_STATE(2310)] = 114145,
  [SMALL_STATE(2311)] = 114155,
  [SMALL_STATE(2312)] = 114169,
  [SMALL_STATE(2313)] = 114183,
  [SMALL_STATE(2314)] = 114197,
  [SMALL_STATE(2315)] = 114211,
  [SMALL_STATE(2316)] = 114225,
  [SMALL_STATE(2317)] = 114239,
  [SMALL_STATE(2318)] = 114253,
  [SMALL_STATE(2319)] = 114267,
  [SMALL_STATE(2320)] = 114277,
  [SMALL_STATE(2321)] = 114287,
  [SMALL_STATE(2322)] = 114301,
  [SMALL_STATE(2323)] = 114315,
  [SMALL_STATE(2324)] = 114329,
  [SMALL_STATE(2325)] = 114343,
  [SMALL_STATE(2326)] = 114357,
  [SMALL_STATE(2327)] = 114369,
  [SMALL_STATE(2328)] = 114381,
  [SMALL_STATE(2329)] = 114395,
  [SMALL_STATE(2330)] = 114409,
  [SMALL_STATE(2331)] = 114423,
  [SMALL_STATE(2332)] = 114437,
  [SMALL_STATE(2333)] = 114451,
  [SMALL_STATE(2334)] = 114465,
  [SMALL_STATE(2335)] = 114479,
  [SMALL_STATE(2336)] = 114493,
  [SMALL_STATE(2337)] = 114507,
  [SMALL_STATE(2338)] = 114517,
  [SMALL_STATE(2339)] = 114531,
  [SMALL_STATE(2340)] = 114545,
  [SMALL_STATE(2341)] = 114559,
  [SMALL_STATE(2342)] = 114573,
  [SMALL_STATE(2343)] = 114587,
  [SMALL_STATE(2344)] = 114601,
  [SMALL_STATE(2345)] = 114615,
  [SMALL_STATE(2346)] = 114629,
  [SMALL_STATE(2347)] = 114643,
  [SMALL_STATE(2348)] = 114657,
  [SMALL_STATE(2349)] = 114671,
  [SMALL_STATE(2350)] = 114685,
  [SMALL_STATE(2351)] = 114699,
  [SMALL_STATE(2352)] = 114713,
  [SMALL_STATE(2353)] = 114727,
  [SMALL_STATE(2354)] = 114741,
  [SMALL_STATE(2355)] = 114755,
  [SMALL_STATE(2356)] = 114769,
  [SMALL_STATE(2357)] = 114779,
  [SMALL_STATE(2358)] = 114791,
  [SMALL_STATE(2359)] = 114805,
  [SMALL_STATE(2360)] = 114819,
  [SMALL_STATE(2361)] = 114833,
  [SMALL_STATE(2362)] = 114847,
  [SMALL_STATE(2363)] = 114861,
  [SMALL_STATE(2364)] = 114875,
  [SMALL_STATE(2365)] = 114889,
  [SMALL_STATE(2366)] = 114903,
  [SMALL_STATE(2367)] = 114917,
  [SMALL_STATE(2368)] = 114931,
  [SMALL_STATE(2369)] = 114945,
  [SMALL_STATE(2370)] = 114955,
  [SMALL_STATE(2371)] = 114969,
  [SMALL_STATE(2372)] = 114983,
  [SMALL_STATE(2373)] = 114997,
  [SMALL_STATE(2374)] = 115011,
  [SMALL_STATE(2375)] = 115025,
  [SMALL_STATE(2376)] = 115039,
  [SMALL_STATE(2377)] = 115053,
  [SMALL_STATE(2378)] = 115067,
  [SMALL_STATE(2379)] = 115081,
  [SMALL_STATE(2380)] = 115095,
  [SMALL_STATE(2381)] = 115109,
  [SMALL_STATE(2382)] = 115123,
  [SMALL_STATE(2383)] = 115137,
  [SMALL_STATE(2384)] = 115151,
  [SMALL_STATE(2385)] = 115165,
  [SMALL_STATE(2386)] = 115179,
  [SMALL_STATE(2387)] = 115193,
  [SMALL_STATE(2388)] = 115207,
  [SMALL_STATE(2389)] = 115221,
  [SMALL_STATE(2390)] = 115235,
  [SMALL_STATE(2391)] = 115249,
  [SMALL_STATE(2392)] = 115263,
  [SMALL_STATE(2393)] = 115277,
  [SMALL_STATE(2394)] = 115291,
  [SMALL_STATE(2395)] = 115305,
  [SMALL_STATE(2396)] = 115319,
  [SMALL_STATE(2397)] = 115333,
  [SMALL_STATE(2398)] = 115347,
  [SMALL_STATE(2399)] = 115361,
  [SMALL_STATE(2400)] = 115375,
  [SMALL_STATE(2401)] = 115389,
  [SMALL_STATE(2402)] = 115403,
  [SMALL_STATE(2403)] = 115417,
  [SMALL_STATE(2404)] = 115431,
  [SMALL_STATE(2405)] = 115445,
  [SMALL_STATE(2406)] = 115459,
  [SMALL_STATE(2407)] = 115473,
  [SMALL_STATE(2408)] = 115487,
  [SMALL_STATE(2409)] = 115501,
  [SMALL_STATE(2410)] = 115515,
  [SMALL_STATE(2411)] = 115529,
  [SMALL_STATE(2412)] = 115543,
  [SMALL_STATE(2413)] = 115557,
  [SMALL_STATE(2414)] = 115571,
  [SMALL_STATE(2415)] = 115585,
  [SMALL_STATE(2416)] = 115599,
  [SMALL_STATE(2417)] = 115613,
  [SMALL_STATE(2418)] = 115627,
  [SMALL_STATE(2419)] = 115641,
  [SMALL_STATE(2420)] = 115655,
  [SMALL_STATE(2421)] = 115667,
  [SMALL_STATE(2422)] = 115681,
  [SMALL_STATE(2423)] = 115691,
  [SMALL_STATE(2424)] = 115705,
  [SMALL_STATE(2425)] = 115719,
  [SMALL_STATE(2426)] = 115733,
  [SMALL_STATE(2427)] = 115745,
  [SMALL_STATE(2428)] = 115759,
  [SMALL_STATE(2429)] = 115773,
  [SMALL_STATE(2430)] = 115787,
  [SMALL_STATE(2431)] = 115797,
  [SMALL_STATE(2432)] = 115811,
  [SMALL_STATE(2433)] = 115825,
  [SMALL_STATE(2434)] = 115839,
  [SMALL_STATE(2435)] = 115853,
  [SMALL_STATE(2436)] = 115867,
  [SMALL_STATE(2437)] = 115881,
  [SMALL_STATE(2438)] = 115895,
  [SMALL_STATE(2439)] = 115909,
  [SMALL_STATE(2440)] = 115923,
  [SMALL_STATE(2441)] = 115937,
  [SMALL_STATE(2442)] = 115951,
  [SMALL_STATE(2443)] = 115965,
  [SMALL_STATE(2444)] = 115979,
  [SMALL_STATE(2445)] = 115993,
  [SMALL_STATE(2446)] = 116007,
  [SMALL_STATE(2447)] = 116021,
  [SMALL_STATE(2448)] = 116033,
  [SMALL_STATE(2449)] = 116047,
  [SMALL_STATE(2450)] = 116061,
  [SMALL_STATE(2451)] = 116075,
  [SMALL_STATE(2452)] = 116089,
  [SMALL_STATE(2453)] = 116103,
  [SMALL_STATE(2454)] = 116117,
  [SMALL_STATE(2455)] = 116131,
  [SMALL_STATE(2456)] = 116145,
  [SMALL_STATE(2457)] = 116159,
  [SMALL_STATE(2458)] = 116173,
  [SMALL_STATE(2459)] = 116187,
  [SMALL_STATE(2460)] = 116199,
  [SMALL_STATE(2461)] = 116213,
  [SMALL_STATE(2462)] = 116227,
  [SMALL_STATE(2463)] = 116241,
  [SMALL_STATE(2464)] = 116255,
  [SMALL_STATE(2465)] = 116267,
  [SMALL_STATE(2466)] = 116281,
  [SMALL_STATE(2467)] = 116295,
  [SMALL_STATE(2468)] = 116309,
  [SMALL_STATE(2469)] = 116323,
  [SMALL_STATE(2470)] = 116337,
  [SMALL_STATE(2471)] = 116351,
  [SMALL_STATE(2472)] = 116365,
  [SMALL_STATE(2473)] = 116377,
  [SMALL_STATE(2474)] = 116391,
  [SMALL_STATE(2475)] = 116405,
  [SMALL_STATE(2476)] = 116419,
  [SMALL_STATE(2477)] = 116433,
  [SMALL_STATE(2478)] = 116447,
  [SMALL_STATE(2479)] = 116461,
  [SMALL_STATE(2480)] = 116475,
  [SMALL_STATE(2481)] = 116489,
  [SMALL_STATE(2482)] = 116503,
  [SMALL_STATE(2483)] = 116517,
  [SMALL_STATE(2484)] = 116531,
  [SMALL_STATE(2485)] = 116545,
  [SMALL_STATE(2486)] = 116559,
  [SMALL_STATE(2487)] = 116573,
  [SMALL_STATE(2488)] = 116587,
  [SMALL_STATE(2489)] = 116599,
  [SMALL_STATE(2490)] = 116613,
  [SMALL_STATE(2491)] = 116627,
  [SMALL_STATE(2492)] = 116641,
  [SMALL_STATE(2493)] = 116655,
  [SMALL_STATE(2494)] = 116669,
  [SMALL_STATE(2495)] = 116683,
  [SMALL_STATE(2496)] = 116697,
  [SMALL_STATE(2497)] = 116711,
  [SMALL_STATE(2498)] = 116725,
  [SMALL_STATE(2499)] = 116739,
  [SMALL_STATE(2500)] = 116753,
  [SMALL_STATE(2501)] = 116767,
  [SMALL_STATE(2502)] = 116781,
  [SMALL_STATE(2503)] = 116791,
  [SMALL_STATE(2504)] = 116805,
  [SMALL_STATE(2505)] = 116819,
  [SMALL_STATE(2506)] = 116831,
  [SMALL_STATE(2507)] = 116845,
  [SMALL_STATE(2508)] = 116859,
  [SMALL_STATE(2509)] = 116873,
  [SMALL_STATE(2510)] = 116887,
  [SMALL_STATE(2511)] = 116901,
  [SMALL_STATE(2512)] = 116915,
  [SMALL_STATE(2513)] = 116927,
  [SMALL_STATE(2514)] = 116941,
  [SMALL_STATE(2515)] = 116951,
  [SMALL_STATE(2516)] = 116963,
  [SMALL_STATE(2517)] = 116977,
  [SMALL_STATE(2518)] = 116991,
  [SMALL_STATE(2519)] = 117005,
  [SMALL_STATE(2520)] = 117019,
  [SMALL_STATE(2521)] = 117033,
  [SMALL_STATE(2522)] = 117047,
  [SMALL_STATE(2523)] = 117061,
  [SMALL_STATE(2524)] = 117075,
  [SMALL_STATE(2525)] = 117089,
  [SMALL_STATE(2526)] = 117101,
  [SMALL_STATE(2527)] = 117111,
  [SMALL_STATE(2528)] = 117125,
  [SMALL_STATE(2529)] = 117134,
  [SMALL_STATE(2530)] = 117143,
  [SMALL_STATE(2531)] = 117154,
  [SMALL_STATE(2532)] = 117163,
  [SMALL_STATE(2533)] = 117174,
  [SMALL_STATE(2534)] = 117183,
  [SMALL_STATE(2535)] = 117192,
  [SMALL_STATE(2536)] = 117201,
  [SMALL_STATE(2537)] = 117210,
  [SMALL_STATE(2538)] = 117219,
  [SMALL_STATE(2539)] = 117228,
  [SMALL_STATE(2540)] = 117237,
  [SMALL_STATE(2541)] = 117246,
  [SMALL_STATE(2542)] = 117255,
  [SMALL_STATE(2543)] = 117266,
  [SMALL_STATE(2544)] = 117277,
  [SMALL_STATE(2545)] = 117286,
  [SMALL_STATE(2546)] = 117295,
  [SMALL_STATE(2547)] = 117304,
  [SMALL_STATE(2548)] = 117313,
  [SMALL_STATE(2549)] = 117322,
  [SMALL_STATE(2550)] = 117331,
  [SMALL_STATE(2551)] = 117340,
  [SMALL_STATE(2552)] = 117349,
  [SMALL_STATE(2553)] = 117358,
  [SMALL_STATE(2554)] = 117367,
  [SMALL_STATE(2555)] = 117376,
  [SMALL_STATE(2556)] = 117385,
  [SMALL_STATE(2557)] = 117394,
  [SMALL_STATE(2558)] = 117403,
  [SMALL_STATE(2559)] = 117412,
  [SMALL_STATE(2560)] = 117421,
  [SMALL_STATE(2561)] = 117430,
  [SMALL_STATE(2562)] = 117439,
  [SMALL_STATE(2563)] = 117448,
  [SMALL_STATE(2564)] = 117457,
  [SMALL_STATE(2565)] = 117466,
  [SMALL_STATE(2566)] = 117477,
  [SMALL_STATE(2567)] = 117488,
  [SMALL_STATE(2568)] = 117497,
  [SMALL_STATE(2569)] = 117508,
  [SMALL_STATE(2570)] = 117517,
  [SMALL_STATE(2571)] = 117526,
  [SMALL_STATE(2572)] = 117535,
  [SMALL_STATE(2573)] = 117544,
  [SMALL_STATE(2574)] = 117553,
  [SMALL_STATE(2575)] = 117562,
  [SMALL_STATE(2576)] = 117573,
  [SMALL_STATE(2577)] = 117582,
  [SMALL_STATE(2578)] = 117591,
  [SMALL_STATE(2579)] = 117600,
  [SMALL_STATE(2580)] = 117609,
  [SMALL_STATE(2581)] = 117618,
  [SMALL_STATE(2582)] = 117629,
  [SMALL_STATE(2583)] = 117640,
  [SMALL_STATE(2584)] = 117651,
  [SMALL_STATE(2585)] = 117662,
  [SMALL_STATE(2586)] = 117671,
  [SMALL_STATE(2587)] = 117682,
  [SMALL_STATE(2588)] = 117693,
  [SMALL_STATE(2589)] = 117704,
  [SMALL_STATE(2590)] = 117713,
  [SMALL_STATE(2591)] = 117724,
  [SMALL_STATE(2592)] = 117733,
  [SMALL_STATE(2593)] = 117742,
  [SMALL_STATE(2594)] = 117751,
  [SMALL_STATE(2595)] = 117760,
  [SMALL_STATE(2596)] = 117769,
  [SMALL_STATE(2597)] = 117778,
  [SMALL_STATE(2598)] = 117789,
  [SMALL_STATE(2599)] = 117798,
  [SMALL_STATE(2600)] = 117807,
  [SMALL_STATE(2601)] = 117816,
  [SMALL_STATE(2602)] = 117825,
  [SMALL_STATE(2603)] = 117834,
  [SMALL_STATE(2604)] = 117843,
  [SMALL_STATE(2605)] = 117854,
  [SMALL_STATE(2606)] = 117865,
  [SMALL_STATE(2607)] = 117874,
  [SMALL_STATE(2608)] = 117883,
  [SMALL_STATE(2609)] = 117892,
  [SMALL_STATE(2610)] = 117901,
  [SMALL_STATE(2611)] = 117912,
  [SMALL_STATE(2612)] = 117921,
  [SMALL_STATE(2613)] = 117930,
  [SMALL_STATE(2614)] = 117941,
  [SMALL_STATE(2615)] = 117950,
  [SMALL_STATE(2616)] = 117959,
  [SMALL_STATE(2617)] = 117968,
  [SMALL_STATE(2618)] = 117977,
  [SMALL_STATE(2619)] = 117988,
  [SMALL_STATE(2620)] = 117999,
  [SMALL_STATE(2621)] = 118008,
  [SMALL_STATE(2622)] = 118017,
  [SMALL_STATE(2623)] = 118026,
  [SMALL_STATE(2624)] = 118035,
  [SMALL_STATE(2625)] = 118044,
  [SMALL_STATE(2626)] = 118055,
  [SMALL_STATE(2627)] = 118066,
  [SMALL_STATE(2628)] = 118075,
  [SMALL_STATE(2629)] = 118084,
  [SMALL_STATE(2630)] = 118092,
  [SMALL_STATE(2631)] = 118100,
  [SMALL_STATE(2632)] = 118108,
  [SMALL_STATE(2633)] = 118116,
  [SMALL_STATE(2634)] = 118124,
  [SMALL_STATE(2635)] = 118132,
  [SMALL_STATE(2636)] = 118140,
  [SMALL_STATE(2637)] = 118148,
  [SMALL_STATE(2638)] = 118156,
  [SMALL_STATE(2639)] = 118164,
  [SMALL_STATE(2640)] = 118172,
  [SMALL_STATE(2641)] = 118180,
  [SMALL_STATE(2642)] = 118188,
  [SMALL_STATE(2643)] = 118196,
  [SMALL_STATE(2644)] = 118204,
  [SMALL_STATE(2645)] = 118212,
  [SMALL_STATE(2646)] = 118220,
  [SMALL_STATE(2647)] = 118228,
  [SMALL_STATE(2648)] = 118236,
  [SMALL_STATE(2649)] = 118244,
  [SMALL_STATE(2650)] = 118252,
  [SMALL_STATE(2651)] = 118260,
  [SMALL_STATE(2652)] = 118268,
  [SMALL_STATE(2653)] = 118276,
  [SMALL_STATE(2654)] = 118284,
  [SMALL_STATE(2655)] = 118292,
  [SMALL_STATE(2656)] = 118300,
  [SMALL_STATE(2657)] = 118308,
  [SMALL_STATE(2658)] = 118316,
  [SMALL_STATE(2659)] = 118324,
  [SMALL_STATE(2660)] = 118332,
  [SMALL_STATE(2661)] = 118340,
  [SMALL_STATE(2662)] = 118348,
  [SMALL_STATE(2663)] = 118356,
  [SMALL_STATE(2664)] = 118364,
  [SMALL_STATE(2665)] = 118372,
  [SMALL_STATE(2666)] = 118380,
  [SMALL_STATE(2667)] = 118388,
  [SMALL_STATE(2668)] = 118396,
  [SMALL_STATE(2669)] = 118404,
  [SMALL_STATE(2670)] = 118412,
  [SMALL_STATE(2671)] = 118420,
  [SMALL_STATE(2672)] = 118428,
  [SMALL_STATE(2673)] = 118436,
  [SMALL_STATE(2674)] = 118444,
  [SMALL_STATE(2675)] = 118452,
  [SMALL_STATE(2676)] = 118460,
  [SMALL_STATE(2677)] = 118468,
  [SMALL_STATE(2678)] = 118476,
  [SMALL_STATE(2679)] = 118484,
  [SMALL_STATE(2680)] = 118492,
  [SMALL_STATE(2681)] = 118500,
  [SMALL_STATE(2682)] = 118508,
  [SMALL_STATE(2683)] = 118516,
  [SMALL_STATE(2684)] = 118524,
  [SMALL_STATE(2685)] = 118532,
  [SMALL_STATE(2686)] = 118540,
  [SMALL_STATE(2687)] = 118548,
  [SMALL_STATE(2688)] = 118556,
  [SMALL_STATE(2689)] = 118564,
  [SMALL_STATE(2690)] = 118572,
  [SMALL_STATE(2691)] = 118580,
  [SMALL_STATE(2692)] = 118588,
  [SMALL_STATE(2693)] = 118596,
  [SMALL_STATE(2694)] = 118604,
  [SMALL_STATE(2695)] = 118612,
  [SMALL_STATE(2696)] = 118620,
  [SMALL_STATE(2697)] = 118628,
  [SMALL_STATE(2698)] = 118636,
  [SMALL_STATE(2699)] = 118644,
  [SMALL_STATE(2700)] = 118652,
  [SMALL_STATE(2701)] = 118660,
  [SMALL_STATE(2702)] = 118668,
  [SMALL_STATE(2703)] = 118676,
  [SMALL_STATE(2704)] = 118684,
  [SMALL_STATE(2705)] = 118692,
  [SMALL_STATE(2706)] = 118700,
  [SMALL_STATE(2707)] = 118708,
  [SMALL_STATE(2708)] = 118716,
  [SMALL_STATE(2709)] = 118724,
  [SMALL_STATE(2710)] = 118732,
  [SMALL_STATE(2711)] = 118740,
  [SMALL_STATE(2712)] = 118748,
  [SMALL_STATE(2713)] = 118756,
  [SMALL_STATE(2714)] = 118764,
  [SMALL_STATE(2715)] = 118772,
  [SMALL_STATE(2716)] = 118780,
  [SMALL_STATE(2717)] = 118788,
  [SMALL_STATE(2718)] = 118796,
  [SMALL_STATE(2719)] = 118804,
  [SMALL_STATE(2720)] = 118812,
  [SMALL_STATE(2721)] = 118820,
  [SMALL_STATE(2722)] = 118828,
  [SMALL_STATE(2723)] = 118836,
  [SMALL_STATE(2724)] = 118844,
  [SMALL_STATE(2725)] = 118852,
  [SMALL_STATE(2726)] = 118860,
  [SMALL_STATE(2727)] = 118868,
  [SMALL_STATE(2728)] = 118876,
  [SMALL_STATE(2729)] = 118884,
  [SMALL_STATE(2730)] = 118892,
  [SMALL_STATE(2731)] = 118900,
  [SMALL_STATE(2732)] = 118908,
  [SMALL_STATE(2733)] = 118916,
  [SMALL_STATE(2734)] = 118924,
  [SMALL_STATE(2735)] = 118932,
  [SMALL_STATE(2736)] = 118940,
  [SMALL_STATE(2737)] = 118948,
  [SMALL_STATE(2738)] = 118956,
  [SMALL_STATE(2739)] = 118964,
  [SMALL_STATE(2740)] = 118972,
  [SMALL_STATE(2741)] = 118980,
  [SMALL_STATE(2742)] = 118988,
  [SMALL_STATE(2743)] = 118996,
  [SMALL_STATE(2744)] = 119004,
  [SMALL_STATE(2745)] = 119012,
  [SMALL_STATE(2746)] = 119020,
  [SMALL_STATE(2747)] = 119028,
  [SMALL_STATE(2748)] = 119036,
  [SMALL_STATE(2749)] = 119044,
  [SMALL_STATE(2750)] = 119052,
  [SMALL_STATE(2751)] = 119060,
  [SMALL_STATE(2752)] = 119068,
  [SMALL_STATE(2753)] = 119076,
  [SMALL_STATE(2754)] = 119084,
  [SMALL_STATE(2755)] = 119092,
  [SMALL_STATE(2756)] = 119100,
  [SMALL_STATE(2757)] = 119108,
  [SMALL_STATE(2758)] = 119116,
  [SMALL_STATE(2759)] = 119124,
  [SMALL_STATE(2760)] = 119132,
  [SMALL_STATE(2761)] = 119140,
  [SMALL_STATE(2762)] = 119148,
  [SMALL_STATE(2763)] = 119156,
  [SMALL_STATE(2764)] = 119164,
  [SMALL_STATE(2765)] = 119172,
  [SMALL_STATE(2766)] = 119180,
  [SMALL_STATE(2767)] = 119188,
  [SMALL_STATE(2768)] = 119196,
  [SMALL_STATE(2769)] = 119204,
  [SMALL_STATE(2770)] = 119212,
  [SMALL_STATE(2771)] = 119220,
  [SMALL_STATE(2772)] = 119228,
  [SMALL_STATE(2773)] = 119236,
  [SMALL_STATE(2774)] = 119244,
  [SMALL_STATE(2775)] = 119252,
  [SMALL_STATE(2776)] = 119260,
  [SMALL_STATE(2777)] = 119268,
  [SMALL_STATE(2778)] = 119276,
  [SMALL_STATE(2779)] = 119284,
  [SMALL_STATE(2780)] = 119292,
  [SMALL_STATE(2781)] = 119300,
  [SMALL_STATE(2782)] = 119308,
  [SMALL_STATE(2783)] = 119316,
  [SMALL_STATE(2784)] = 119324,
  [SMALL_STATE(2785)] = 119332,
  [SMALL_STATE(2786)] = 119340,
  [SMALL_STATE(2787)] = 119348,
  [SMALL_STATE(2788)] = 119356,
  [SMALL_STATE(2789)] = 119364,
  [SMALL_STATE(2790)] = 119372,
  [SMALL_STATE(2791)] = 119380,
  [SMALL_STATE(2792)] = 119388,
  [SMALL_STATE(2793)] = 119396,
  [SMALL_STATE(2794)] = 119404,
  [SMALL_STATE(2795)] = 119412,
  [SMALL_STATE(2796)] = 119420,
  [SMALL_STATE(2797)] = 119428,
  [SMALL_STATE(2798)] = 119436,
  [SMALL_STATE(2799)] = 119444,
  [SMALL_STATE(2800)] = 119452,
  [SMALL_STATE(2801)] = 119460,
  [SMALL_STATE(2802)] = 119468,
  [SMALL_STATE(2803)] = 119476,
  [SMALL_STATE(2804)] = 119484,
  [SMALL_STATE(2805)] = 119492,
  [SMALL_STATE(2806)] = 119500,
  [SMALL_STATE(2807)] = 119508,
  [SMALL_STATE(2808)] = 119516,
  [SMALL_STATE(2809)] = 119524,
  [SMALL_STATE(2810)] = 119532,
  [SMALL_STATE(2811)] = 119540,
  [SMALL_STATE(2812)] = 119548,
  [SMALL_STATE(2813)] = 119556,
  [SMALL_STATE(2814)] = 119564,
  [SMALL_STATE(2815)] = 119572,
  [SMALL_STATE(2816)] = 119580,
  [SMALL_STATE(2817)] = 119588,
  [SMALL_STATE(2818)] = 119596,
  [SMALL_STATE(2819)] = 119604,
  [SMALL_STATE(2820)] = 119612,
  [SMALL_STATE(2821)] = 119620,
  [SMALL_STATE(2822)] = 119628,
  [SMALL_STATE(2823)] = 119636,
  [SMALL_STATE(2824)] = 119644,
  [SMALL_STATE(2825)] = 119652,
  [SMALL_STATE(2826)] = 119660,
  [SMALL_STATE(2827)] = 119668,
  [SMALL_STATE(2828)] = 119676,
  [SMALL_STATE(2829)] = 119684,
  [SMALL_STATE(2830)] = 119692,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [5] = {.entry = {.count = 1, .reusable = false}}, SHIFT_EXTRA(),
  [7] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module, 0),
  [9] = {.entry = {.count = 1, .reusable = false}}, SHIFT(619),
  [11] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2267),
  [13] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1906),
  [15] = {.entry = {.count = 1, .reusable = true}}, SHIFT(191),
  [17] = {.entry = {.count = 1, .reusable = true}}, SHIFT(956),
  [19] = {.entry = {.count = 1, .reusable = false}}, SHIFT(83),
  [21] = {.entry = {.count = 1, .reusable = false}}, SHIFT(605),
  [23] = {.entry = {.count = 1, .reusable = false}}, SHIFT(385),
  [25] = {.entry = {.count = 1, .reusable = false}}, SHIFT(478),
  [27] = {.entry = {.count = 1, .reusable = false}}, SHIFT(350),
  [29] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2537),
  [31] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2540),
  [33] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2541),
  [35] = {.entry = {.count = 1, .reusable = false}}, SHIFT(600),
  [37] = {.entry = {.count = 1, .reusable = false}}, SHIFT(85),
  [39] = {.entry = {.count = 1, .reusable = false}}, SHIFT(474),
  [41] = {.entry = {.count = 1, .reusable = false}}, SHIFT(785),
  [43] = {.entry = {.count = 1, .reusable = false}}, SHIFT(597),
  [45] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2807),
  [47] = {.entry = {.count = 1, .reusable = false}}, SHIFT(419),
  [49] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2805),
  [51] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2802),
  [53] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2731),
  [55] = {.entry = {.count = 1, .reusable = false}}, SHIFT(470),
  [57] = {.entry = {.count = 1, .reusable = false}}, SHIFT(74),
  [59] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2796),
  [61] = {.entry = {.count = 1, .reusable = true}}, SHIFT(196),
  [63] = {.entry = {.count = 1, .reusable = true}}, SHIFT(582),
  [65] = {.entry = {.count = 1, .reusable = true}}, SHIFT(879),
  [67] = {.entry = {.count = 1, .reusable = true}}, SHIFT(197),
  [69] = {.entry = {.count = 1, .reusable = false}}, SHIFT(581),
  [71] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1659),
  [73] = {.entry = {.count = 1, .reusable = false}}, SHIFT(353),
  [75] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1057),
  [77] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1057),
  [79] = {.entry = {.count = 1, .reusable = false}}, SHIFT(154),
  [81] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1764),
  [83] = {.entry = {.count = 1, .reusable = false}}, SHIFT(580),
  [85] = {.entry = {.count = 1, .reusable = false}}, SHIFT(86),
  [87] = {.entry = {.count = 1, .reusable = false}}, SHIFT(476),
  [89] = {.entry = {.count = 1, .reusable = false}}, SHIFT(729),
  [91] = {.entry = {.count = 1, .reusable = false}}, SHIFT(583),
  [93] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2795),
  [95] = {.entry = {.count = 1, .reusable = false}}, SHIFT(427),
  [97] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2820),
  [99] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2797),
  [101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(695),
  [103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(653),
  [105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(660),
  [107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2536),
  [109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(656),
  [111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(680),
  [113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(689),
  [115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2273),
  [117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2426),
  [119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(697),
  [121] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module, 1),
  [123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(652),
  [125] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(619),
  [128] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(2267),
  [131] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(1906),
  [134] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(191),
  [137] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(956),
  [140] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(83),
  [143] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(605),
  [146] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(385),
  [149] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(478),
  [152] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(350),
  [155] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(2537),
  [158] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(2540),
  [161] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(2541),
  [164] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(580),
  [167] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(86),
  [170] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(476),
  [173] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(729),
  [176] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(583),
  [179] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(2795),
  [182] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(427),
  [185] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(2820),
  [188] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(2802),
  [191] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(2731),
  [194] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(470),
  [197] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(74),
  [200] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(2797),
  [203] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(196),
  [206] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(582),
  [209] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(879),
  [212] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(197),
  [215] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(581),
  [218] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(1659),
  [221] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(353),
  [224] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(1057),
  [227] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(1057),
  [230] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(154),
  [233] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_module_repeat1, 2),
  [235] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(1764),
  [238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(691),
  [240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(683),
  [242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2531),
  [244] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(600),
  [247] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(85),
  [250] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(474),
  [253] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(785),
  [256] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(597),
  [259] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(2807),
  [262] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(419),
  [265] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(2805),
  [268] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_module_repeat1, 2), SHIFT_REPEAT(2796),
  [271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(665),
  [273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(667),
  [275] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1191),
  [277] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_primary_expression, 1, .production_id = 1),
  [279] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_primary_expression, 1, .production_id = 1),
  [281] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_expression, 1, .production_id = 1), SHIFT(307),
  [284] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_pattern, 1, .production_id = 1), REDUCE(sym_primary_expression, 1, .production_id = 1),
  [287] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_primary_expression, 1, .production_id = 1), SHIFT(968),
  [290] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1209),
  [292] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__named_expression_lhs, 1, .production_id = 1),
  [294] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_pattern, 1, .production_id = 1), REDUCE(sym_primary_expression, 1, .production_id = 1),
  [297] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_primary_expression, 1, .production_id = 1), SHIFT(2747),
  [300] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1207),
  [302] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pattern, 1, .production_id = 1),
  [304] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_expression, 1, .production_id = 1), SHIFT(318),
  [307] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_primary_expression, 1, .production_id = 1), SHIFT(873),
  [310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(212),
  [312] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_primary_expression, 1, .production_id = 1), SHIFT(573),
  [315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(873),
  [317] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1665),
  [319] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pattern, 1, .production_id = 1),
  [321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1365),
  [323] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1365),
  [325] = {.entry = {.count = 1, .reusable = false}}, SHIFT(167),
  [327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1757),
  [329] = {.entry = {.count = 1, .reusable = false}}, SHIFT(609),
  [331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(215),
  [333] = {.entry = {.count = 1, .reusable = false}}, SHIFT(874),
  [335] = {.entry = {.count = 1, .reusable = false}}, SHIFT(84),
  [337] = {.entry = {.count = 1, .reusable = false}}, SHIFT(623),
  [339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2747),
  [341] = {.entry = {.count = 1, .reusable = false}}, SHIFT(463),
  [343] = {.entry = {.count = 1, .reusable = false}}, SHIFT(73),
  [345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(199),
  [347] = {.entry = {.count = 1, .reusable = false}}, SHIFT(155),
  [349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(815),
  [351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(31),
  [353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(800),
  [355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(57),
  [357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(802),
  [359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5),
  [361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(808),
  [363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12),
  [365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(762),
  [367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(43),
  [369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(812),
  [371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(28),
  [373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(791),
  [375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(35),
  [377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(769),
  [379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(47),
  [381] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1043),
  [383] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_expression, 1, .production_id = 1), SHIFT(298),
  [386] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_primary_expression, 1, .production_id = 1), SHIFT(875),
  [389] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1037),
  [391] = {.entry = {.count = 1, .reusable = false}}, SHIFT(524),
  [393] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1012),
  [395] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_expression, 1, .production_id = 1), SHIFT(299),
  [398] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_primary_expression, 1, .production_id = 1), SHIFT(879),
  [401] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_primary_expression, 1, .production_id = 1), SHIFT(581),
  [404] = {.entry = {.count = 1, .reusable = false}}, SHIFT(157),
  [406] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1205),
  [408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(307),
  [410] = {.entry = {.count = 1, .reusable = false}}, SHIFT(893),
  [412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(318),
  [414] = {.entry = {.count = 1, .reusable = false}}, SHIFT(873),
  [416] = {.entry = {.count = 1, .reusable = false}}, SHIFT(573),
  [418] = {.entry = {.count = 1, .reusable = false}}, SHIFT(621),
  [420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(696),
  [422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(32),
  [424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(794),
  [426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(55),
  [428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(659),
  [430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(36),
  [432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2528),
  [434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21),
  [436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(756),
  [438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11),
  [440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(710),
  [442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(38),
  [444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(663),
  [446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4),
  [448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(713),
  [450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(50),
  [452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(722),
  [454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2),
  [456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(846),
  [458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18),
  [460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(662),
  [462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(34),
  [464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(778),
  [466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(26),
  [468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(830),
  [470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(22),
  [472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(610),
  [474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(24),
  [476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(776),
  [478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16),
  [480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(735),
  [482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17),
  [484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(765),
  [486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15),
  [488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(654),
  [490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13),
  [492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(719),
  [494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7),
  [496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(759),
  [498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6),
  [500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1830),
  [502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(56),
  [504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(751),
  [506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(46),
  [508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(760),
  [510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20),
  [512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1841),
  [514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(54),
  [516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(750),
  [518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(30),
  [520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(701),
  [522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19),
  [524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(748),
  [526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(37),
  [528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(711),
  [530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9),
  [532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2550),
  [534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8),
  [536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2547),
  [538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(42),
  [540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(737),
  [542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(61),
  [544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(675),
  [546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(59),
  [548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2593),
  [550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(52),
  [552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2598),
  [554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(48),
  [556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(772),
  [558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(60),
  [560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(780),
  [562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(53),
  [564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(716),
  [566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(45),
  [568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(617),
  [570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(40),
  [572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(843),
  [574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14),
  [576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(833),
  [578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(27),
  [580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2555),
  [582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(41),
  [584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(705),
  [586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(25),
  [588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(805),
  [590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(58),
  [592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(717),
  [594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(39),
  [596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(724),
  [598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(23),
  [600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(816),
  [602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(51),
  [604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(698),
  [606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(33),
  [608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(838),
  [610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(29),
  [612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(671),
  [614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3),
  [616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(834),
  [618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10),
  [620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2567),
  [622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(650),
  [624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(690),
  [626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2326),
  [628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2304),
  [630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(688),
  [632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(666),
  [634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(655),
  [636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(684),
  [638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(664),
  [640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(657),
  [642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(647),
  [644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2534),
  [646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(681),
  [648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(694),
  [650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(678),
  [652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(298),
  [654] = {.entry = {.count = 1, .reusable = false}}, SHIFT(875),
  [656] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1143),
  [658] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1145),
  [660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(299),
  [662] = {.entry = {.count = 1, .reusable = false}}, SHIFT(879),
  [664] = {.entry = {.count = 1, .reusable = false}}, SHIFT(161),
  [666] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_splat_pattern, 2, .production_id = 5),
  [668] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_primary_expression, 1, .production_id = 1), REDUCE(sym_list_splat_pattern, 2, .production_id = 5),
  [671] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list_splat_pattern, 2, .production_id = 5),
  [673] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1434),
  [675] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1436),
  [677] = {.entry = {.count = 1, .reusable = false}}, SHIFT(177),
  [679] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_expression, 1, .production_id = 1), REDUCE(sym_list_splat_pattern, 2, .production_id = 5),
  [682] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1241),
  [684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(293),
  [686] = {.entry = {.count = 1, .reusable = false}}, SHIFT(870),
  [688] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1256),
  [690] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1257),
  [692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(320),
  [694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(869),
  [696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(198),
  [698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1241),
  [700] = {.entry = {.count = 1, .reusable = false}}, SHIFT(168),
  [702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1727),
  [704] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1169),
  [706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(323),
  [708] = {.entry = {.count = 1, .reusable = false}}, SHIFT(959),
  [710] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1184),
  [712] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1185),
  [714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(290),
  [716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(967),
  [718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(200),
  [720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1169),
  [722] = {.entry = {.count = 1, .reusable = false}}, SHIFT(178),
  [724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1766),
  [726] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1337),
  [728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(316),
  [730] = {.entry = {.count = 1, .reusable = false}}, SHIFT(954),
  [732] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1384),
  [734] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1379),
  [736] = {.entry = {.count = 1, .reusable = false}}, SHIFT(541),
  [738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(286),
  [740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(891),
  [742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(204),
  [744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1337),
  [746] = {.entry = {.count = 1, .reusable = false}}, SHIFT(185),
  [748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1767),
  [750] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1306),
  [752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(288),
  [754] = {.entry = {.count = 1, .reusable = false}}, SHIFT(900),
  [756] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1350),
  [758] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1352),
  [760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(317),
  [762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(964),
  [764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(195),
  [766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1306),
  [768] = {.entry = {.count = 1, .reusable = false}}, SHIFT(175),
  [770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1742),
  [772] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1450),
  [774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(296),
  [776] = {.entry = {.count = 1, .reusable = false}}, SHIFT(963),
  [778] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1458),
  [780] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1461),
  [782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(294),
  [784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(973),
  [786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(218),
  [788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1450),
  [790] = {.entry = {.count = 1, .reusable = false}}, SHIFT(184),
  [792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1736),
  [794] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1414),
  [796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(313),
  [798] = {.entry = {.count = 1, .reusable = false}}, SHIFT(972),
  [800] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1444),
  [802] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1445),
  [804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(277),
  [806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(971),
  [808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(205),
  [810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1414),
  [812] = {.entry = {.count = 1, .reusable = false}}, SHIFT(186),
  [814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1759),
  [816] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1200),
  [818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(201),
  [820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(504),
  [822] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1246),
  [824] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1234),
  [826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(206),
  [828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1655),
  [830] = {.entry = {.count = 1, .reusable = false}}, SHIFT(518),
  [832] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1660),
  [834] = {.entry = {.count = 1, .reusable = false}}, SHIFT(368),
  [836] = {.entry = {.count = 1, .reusable = false}}, SHIFT(172),
  [838] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1261),
  [840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(190),
  [842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1374),
  [844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(481),
  [846] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1214),
  [848] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1190),
  [850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(209),
  [852] = {.entry = {.count = 1, .reusable = false}}, SHIFT(503),
  [854] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1662),
  [856] = {.entry = {.count = 1, .reusable = false}}, SHIFT(351),
  [858] = {.entry = {.count = 1, .reusable = false}}, SHIFT(182),
  [860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(628),
  [862] = {.entry = {.count = 1, .reusable = false}}, SHIFT(622),
  [864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1590),
  [866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1501),
  [868] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1106),
  [870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(280),
  [872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2724),
  [874] = {.entry = {.count = 1, .reusable = false}}, SHIFT(558),
  [876] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1109),
  [878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(578),
  [880] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1108),
  [882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1354),
  [884] = {.entry = {.count = 1, .reusable = false}}, SHIFT(501),
  [886] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1656),
  [888] = {.entry = {.count = 1, .reusable = false}}, SHIFT(253),
  [890] = {.entry = {.count = 1, .reusable = false}}, SHIFT(165),
  [892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(646),
  [894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2809),
  [896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1146),
  [898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2819),
  [900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1258),
  [902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(632),
  [904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2739),
  [906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1186),
  [908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1425),
  [910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1394),
  [912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1180),
  [914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2679),
  [916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1378),
  [918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2688),
  [920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1448),
  [922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1443),
  [924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1645),
  [926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1164),
  [928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1385),
  [930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1652),
  [932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1640),
  [934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2816),
  [936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1439),
  [938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1500),
  [940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1591),
  [942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(631),
  [944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1634),
  [946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2641),
  [948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1462),
  [950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1643),
  [952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1399),
  [954] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1400),
  [956] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pattern_list, 3),
  [958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(220),
  [960] = {.entry = {.count = 1, .reusable = false}}, SHIFT(956),
  [962] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1363),
  [964] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1355),
  [966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(202),
  [968] = {.entry = {.count = 1, .reusable = false}}, SHIFT(176),
  [970] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pattern_list, 2),
  [972] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1226),
  [974] = {.entry = {.count = 1, .reusable = false}}, SHIFT(872),
  [976] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1340),
  [978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2822),
  [980] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1343),
  [982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2004),
  [984] = {.entry = {.count = 1, .reusable = false}}, SHIFT(514),
  [986] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1663),
  [988] = {.entry = {.count = 1, .reusable = false}}, SHIFT(173),
  [990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2136),
  [992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1937),
  [994] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1092),
  [996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(208),
  [998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(870),
  [1000] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1115),
  [1002] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1114),
  [1004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(203),
  [1006] = {.entry = {.count = 1, .reusable = false}}, SHIFT(590),
  [1008] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1657),
  [1010] = {.entry = {.count = 1, .reusable = false}}, SHIFT(159),
  [1012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1927),
  [1014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1929),
  [1016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2061),
  [1018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2017),
  [1020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1948),
  [1022] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1120),
  [1024] = {.entry = {.count = 1, .reusable = false}}, SHIFT(889),
  [1026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2746),
  [1028] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1088),
  [1030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(300),
  [1032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1309),
  [1034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2780),
  [1036] = {.entry = {.count = 1, .reusable = false}}, SHIFT(481),
  [1038] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1079),
  [1040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(505),
  [1042] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1087),
  [1044] = {.entry = {.count = 1, .reusable = false}}, SHIFT(166),
  [1046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1206),
  [1048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2771),
  [1050] = {.entry = {.count = 1, .reusable = false}}, SHIFT(968),
  [1052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1268),
  [1054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2774),
  [1056] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1096),
  [1058] = {.entry = {.count = 1, .reusable = false}}, SHIFT(941),
  [1060] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1171),
  [1062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2696),
  [1064] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1172),
  [1066] = {.entry = {.count = 1, .reusable = false}}, SHIFT(535),
  [1068] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1669),
  [1070] = {.entry = {.count = 1, .reusable = false}}, SHIFT(169),
  [1072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1471),
  [1074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2659),
  [1076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1078),
  [1078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2692),
  [1080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1376),
  [1082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2680),
  [1084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1311),
  [1086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2654),
  [1088] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1498),
  [1090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(213),
  [1092] = {.entry = {.count = 1, .reusable = false}}, SHIFT(952),
  [1094] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1508),
  [1096] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1509),
  [1098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(194),
  [1100] = {.entry = {.count = 1, .reusable = false}}, SHIFT(187),
  [1102] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1141),
  [1104] = {.entry = {.count = 1, .reusable = false}}, SHIFT(526),
  [1106] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yield, 1),
  [1108] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1149),
  [1110] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1148),
  [1112] = {.entry = {.count = 1, .reusable = false}}, SHIFT(160),
  [1114] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1242),
  [1116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1353),
  [1118] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1245),
  [1120] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1243),
  [1122] = {.entry = {.count = 1, .reusable = false}}, SHIFT(174),
  [1124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1387),
  [1126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2665),
  [1128] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1307),
  [1130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(324),
  [1132] = {.entry = {.count = 1, .reusable = false}}, SHIFT(515),
  [1134] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1310),
  [1136] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1308),
  [1138] = {.entry = {.count = 1, .reusable = false}}, SHIFT(183),
  [1140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1237),
  [1142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1296),
  [1144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1240),
  [1146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1239),
  [1148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1238),
  [1150] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1255),
  [1152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(292),
  [1154] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1249),
  [1156] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1254),
  [1158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1317),
  [1160] = {.entry = {.count = 1, .reusable = false}}, SHIFT(179),
  [1162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1452),
  [1164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1197),
  [1166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1272),
  [1168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1280),
  [1170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1277),
  [1172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1113),
  [1174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1276),
  [1176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1137),
  [1178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1389),
  [1180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1275),
  [1182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1409),
  [1184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1138),
  [1186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1273),
  [1188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1133),
  [1190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1318),
  [1192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1459),
  [1194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1301),
  [1196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1303),
  [1198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1111),
  [1200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1093),
  [1202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1386),
  [1204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1315),
  [1206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1316),
  [1208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1346),
  [1210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1325),
  [1212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1435),
  [1214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1428),
  [1216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1347),
  [1218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1304),
  [1220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1326),
  [1222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1465),
  [1224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1360),
  [1226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1361),
  [1228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1456),
  [1230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1408),
  [1232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1351),
  [1234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1305),
  [1236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1198),
  [1238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1454),
  [1240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1455),
  [1242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1300),
  [1244] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1345),
  [1246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(278),
  [1248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(500),
  [1250] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__collection_elements, 2),
  [1252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(959),
  [1254] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_in_clause, 7, .production_id = 110),
  [1256] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_in_clause, 7, .production_id = 110),
  [1258] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1658),
  [1260] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_in_clause, 5, .production_id = 79),
  [1262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(954),
  [1264] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_in_clause, 5, .production_id = 79),
  [1266] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1674),
  [1268] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_in_clause, 6, .production_id = 98),
  [1270] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_in_clause, 6, .production_id = 98),
  [1272] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_in_clause, 6, .production_id = 99),
  [1274] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_in_clause, 6, .production_id = 99),
  [1276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(279),
  [1278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(589),
  [1280] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__collection_elements, 3),
  [1282] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1173),
  [1284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(515),
  [1286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(972),
  [1288] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1667),
  [1290] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression_list, 2),
  [1292] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression_list, 3),
  [1294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1285),
  [1296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1299),
  [1298] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_raise_statement, 1),
  [1300] = {.entry = {.count = 1, .reusable = false}}, SHIFT(513),
  [1302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(875),
  [1304] = {.entry = {.count = 1, .reusable = false}}, SHIFT(522),
  [1306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(900),
  [1308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1236),
  [1310] = {.entry = {.count = 1, .reusable = false}}, SHIFT(579),
  [1312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1344),
  [1314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1215),
  [1316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1282),
  [1318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1329),
  [1320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1068),
  [1322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1102),
  [1324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1457),
  [1326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1289),
  [1328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1395),
  [1330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1327),
  [1332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1477),
  [1334] = {.entry = {.count = 1, .reusable = false}}, SHIFT(588),
  [1336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(963),
  [1338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1359),
  [1340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1372),
  [1342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(377),
  [1344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1324),
  [1346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1511),
  [1348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1177),
  [1350] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_slice, 2),
  [1352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(440),
  [1354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(626),
  [1356] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_slice, 1),
  [1358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(438),
  [1360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1161),
  [1362] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression_list, 2),
  [1364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1074),
  [1366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1035),
  [1368] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression_list, 3),
  [1370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1497),
  [1372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1178),
  [1374] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_statement, 1),
  [1376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1484),
  [1378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1491),
  [1380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1492),
  [1382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1089),
  [1384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1505),
  [1386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1271),
  [1388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1041),
  [1390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1219),
  [1392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1033),
  [1394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(639),
  [1396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1174),
  [1398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(641),
  [1400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1426),
  [1402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1431),
  [1404] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dictionary_splat_pattern, 2, .production_id = 5),
  [1406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1312),
  [1408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1411),
  [1410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1446),
  [1412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1314),
  [1414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1091),
  [1416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1382),
  [1418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1380),
  [1420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2639),
  [1422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(256),
  [1424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(893),
  [1426] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_with_clause, 3),
  [1428] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_with_clause, 2),
  [1430] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_slice, 4),
  [1432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2794),
  [1434] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_slice, 3),
  [1436] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression_statement, 3),
  [1438] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_print_statement, 4, .production_id = 14),
  [1440] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression_statement, 2),
  [1442] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_print_statement, 3, .dynamic_precedence = -1, .production_id = 6),
  [1444] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_print_statement, 3),
  [1446] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_print_statement, 4, .dynamic_precedence = -1, .production_id = 15),
  [1448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2483),
  [1450] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2472),
  [1452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1730),
  [1454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(104),
  [1456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2375),
  [1458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2275),
  [1460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(728),
  [1462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(415),
  [1464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2646),
  [1466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2274),
  [1468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(831),
  [1470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(426),
  [1472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2821),
  [1474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(89),
  [1476] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1251),
  [1478] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1244),
  [1480] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1248),
  [1482] = {.entry = {.count = 1, .reusable = false}}, SHIFT(171),
  [1484] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 5, .production_id = 63),
  [1486] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_statement, 5, .production_id = 63),
  [1488] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2733),
  [1490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(598),
  [1492] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2704),
  [1494] = {.entry = {.count = 1, .reusable = false}}, SHIFT(464),
  [1496] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 4, .production_id = 42),
  [1498] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_statement, 4, .production_id = 42),
  [1500] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1495),
  [1502] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1493),
  [1504] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1494),
  [1506] = {.entry = {.count = 1, .reusable = false}}, SHIFT(170),
  [1508] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1230),
  [1510] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1228),
  [1512] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1229),
  [1514] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1476),
  [1516] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1474),
  [1518] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1451),
  [1520] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2792),
  [1522] = {.entry = {.count = 1, .reusable = false}}, SHIFT(477),
  [1524] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2694),
  [1526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(546),
  [1528] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1080),
  [1530] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1083),
  [1532] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1081),
  [1534] = {.entry = {.count = 1, .reusable = false}}, SHIFT(163),
  [1536] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1463),
  [1538] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1467),
  [1540] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1466),
  [1542] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_primary_expression, 1),
  [1544] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_pattern, 1), REDUCE(sym_primary_expression, 1),
  [1547] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_primary_expression, 1),
  [1549] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__named_expression_lhs, 1),
  [1551] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_pattern, 1), REDUCE(sym_primary_expression, 1),
  [1554] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pattern, 1),
  [1556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(259),
  [1558] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pattern, 1),
  [1560] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 4, .production_id = 37),
  [1562] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 4, .production_id = 37),
  [1564] = {.entry = {.count = 1, .reusable = false}}, SHIFT(495),
  [1566] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_try_statement_repeat1, 2),
  [1568] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_try_statement_repeat1, 2),
  [1570] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_try_statement_repeat1, 2), SHIFT_REPEAT(464),
  [1573] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 5, .production_id = 57),
  [1575] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 5, .production_id = 57),
  [1577] = {.entry = {.count = 1, .reusable = false}}, SHIFT(601),
  [1579] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 5, .production_id = 56),
  [1581] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 5, .production_id = 56),
  [1583] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 6, .production_id = 83),
  [1585] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 6, .production_id = 83),
  [1587] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_try_statement_repeat2, 2),
  [1589] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_try_statement_repeat2, 2),
  [1591] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_try_statement_repeat2, 2), SHIFT_REPEAT(598),
  [1594] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_try_statement_repeat1, 2), SHIFT_REPEAT(477),
  [1597] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_try_statement_repeat2, 2), SHIFT_REPEAT(546),
  [1600] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subscript, 5, .production_id = 48),
  [1602] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subscript, 5, .production_id = 48),
  [1604] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_splat_pattern, 2),
  [1606] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_splat_type, 2),
  [1608] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_expression, 1), REDUCE(sym_list_splat_pattern, 2),
  [1611] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_primary_expression, 1), REDUCE(sym_list_splat_pattern, 2),
  [1614] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list_splat_pattern, 2),
  [1616] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_splat_type, 2),
  [1618] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple, 2),
  [1620] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_tuple_pattern, 2), REDUCE(sym_tuple, 2),
  [1623] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tuple, 2),
  [1625] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_pattern, 2),
  [1627] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tuple_pattern, 2),
  [1629] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_primary_expression, 1, .production_id = 2),
  [1631] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_pattern, 1), REDUCE(sym_primary_expression, 1, .production_id = 2),
  [1634] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_primary_expression, 1, .production_id = 2),
  [1636] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list, 2),
  [1638] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_list_pattern, 2), REDUCE(sym_list, 2),
  [1641] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list, 2),
  [1643] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list_pattern, 2),
  [1645] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_pattern, 2),
  [1647] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subscript, 5, .production_id = 72),
  [1649] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subscript, 5, .production_id = 72),
  [1651] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_if_statement_repeat1, 2, .production_id = 81),
  [1653] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_if_statement_repeat1, 2, .production_id = 81),
  [1655] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_if_statement_repeat1, 2, .production_id = 81), SHIFT_REPEAT(601),
  [1658] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subscript, 4, .production_id = 48),
  [1660] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subscript, 4, .production_id = 48),
  [1662] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subscript, 6, .production_id = 72),
  [1664] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subscript, 6, .production_id = 72),
  [1666] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute, 3, .production_id = 23),
  [1668] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_attribute, 3, .production_id = 23),
  [1670] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_if_statement_repeat1, 2, .production_id = 81), SHIFT_REPEAT(495),
  [1673] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__simple_statements, 3),
  [1675] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__simple_statements, 3),
  [1677] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_except_group_clause, 6, .production_id = 129),
  [1679] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_except_group_clause, 6, .production_id = 129),
  [1681] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_except_group_clause, 5),
  [1683] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_except_group_clause, 5),
  [1685] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_except_clause, 5),
  [1687] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_except_clause, 5),
  [1689] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 2),
  [1691] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 2),
  [1693] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 1),
  [1695] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 1),
  [1697] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_except_clause, 3, .production_id = 90),
  [1699] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_except_clause, 3, .production_id = 90),
  [1701] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__simple_statements, 4),
  [1703] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__simple_statements, 4),
  [1705] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__simple_statements, 2),
  [1707] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__simple_statements, 2),
  [1709] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_except_clause, 4),
  [1711] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_except_clause, 4),
  [1713] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_except_clause, 4, .production_id = 106),
  [1715] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_except_clause, 4, .production_id = 106),
  [1717] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_except_group_clause, 4, .production_id = 106),
  [1719] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_except_group_clause, 4, .production_id = 106),
  [1721] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_except_clause, 6, .production_id = 129),
  [1723] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_except_clause, 6, .production_id = 129),
  [1725] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_except_group_clause, 7),
  [1727] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_except_group_clause, 7),
  [1729] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_except_clause, 7),
  [1731] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_except_clause, 7),
  [1733] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1599),
  [1735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(193),
  [1737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(868),
  [1739] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1594),
  [1741] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1592),
  [1743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(214),
  [1745] = {.entry = {.count = 1, .reusable = false}}, SHIFT(328),
  [1747] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 8, .production_id = 114),
  [1749] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 8, .production_id = 114),
  [1751] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 7, .production_id = 105),
  [1753] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 7, .production_id = 105),
  [1755] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while_statement, 4, .production_id = 41),
  [1757] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_statement, 4, .production_id = 41),
  [1759] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_statement, 5, .production_id = 42),
  [1761] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 5, .production_id = 42),
  [1763] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 7, .production_id = 101),
  [1765] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 7, .production_id = 101),
  [1767] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_if_statement_repeat1, 1, .production_id = 54),
  [1769] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_if_statement_repeat1, 1, .production_id = 54),
  [1771] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_statement, 5, .production_id = 62),
  [1773] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while_statement, 5, .production_id = 62),
  [1775] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_elif_clause, 5, .production_id = 57),
  [1777] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_elif_clause, 5, .production_id = 57),
  [1779] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_statement, 6, .production_id = 63),
  [1781] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 6, .production_id = 63),
  [1783] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 6, .production_id = 88),
  [1785] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 6, .production_id = 88),
  [1787] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_elif_clause, 4, .production_id = 37),
  [1789] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_elif_clause, 4, .production_id = 37),
  [1791] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1642),
  [1793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(207),
  [1795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2302),
  [1797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(892),
  [1799] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1626),
  [1801] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1627),
  [1803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(189),
  [1805] = {.entry = {.count = 1, .reusable = false}}, SHIFT(409),
  [1807] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_else_clause, 3, .production_id = 42),
  [1809] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_else_clause, 3, .production_id = 42),
  [1811] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_else_clause, 4, .production_id = 63),
  [1813] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_else_clause, 4, .production_id = 63),
  [1815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2430),
  [1817] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__match_block, 2),
  [1819] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__match_block, 2),
  [1821] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1651),
  [1823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(210),
  [1825] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1648),
  [1827] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1646),
  [1829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(211),
  [1831] = {.entry = {.count = 1, .reusable = false}}, SHIFT(413),
  [1833] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__patterns, 2),
  [1835] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 7, .production_id = 108),
  [1837] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 7, .production_id = 108),
  [1839] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_definition, 7, .production_id = 109),
  [1841] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 7, .production_id = 109),
  [1843] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 6, .production_id = 91),
  [1845] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 6, .production_id = 91),
  [1847] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 6, .production_id = 92),
  [1849] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 6, .production_id = 92),
  [1851] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_statement, 5, .production_id = 61),
  [1853] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while_statement, 5, .production_id = 61),
  [1855] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_with_statement, 5, .production_id = 60),
  [1857] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_with_statement, 5, .production_id = 60),
  [1859] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_match_statement, 5, .production_id = 59),
  [1861] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_match_statement, 5, .production_id = 59),
  [1863] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_match_statement, 5, .production_id = 58),
  [1865] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_match_statement, 5, .production_id = 58),
  [1867] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 5, .production_id = 55),
  [1869] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 5, .production_id = 55),
  [1871] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_definition, 6, .production_id = 93),
  [1873] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 6, .production_id = 93),
  [1875] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_with_statement, 5, .production_id = 64),
  [1877] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_with_statement, 5, .production_id = 64),
  [1879] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 5, .production_id = 65),
  [1881] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 5, .production_id = 65),
  [1883] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 5, .production_id = 66),
  [1885] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_definition, 5, .production_id = 66),
  [1887] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 5, .production_id = 67),
  [1889] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_definition, 5, .production_id = 67),
  [1891] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 5, .production_id = 68),
  [1893] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_definition, 5, .production_id = 68),
  [1895] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 6, .production_id = 80),
  [1897] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 6, .production_id = 80),
  [1899] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 6, .production_id = 82),
  [1901] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 6, .production_id = 82),
  [1903] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__match_block, 3, .production_id = 84),
  [1905] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__match_block, 3, .production_id = 84),
  [1907] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_statement, 6, .production_id = 42),
  [1909] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 6, .production_id = 42),
  [1911] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_finally_clause, 3, .production_id = 90),
  [1913] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_finally_clause, 3, .production_id = 90),
  [1915] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_match_statement, 6, .production_id = 85),
  [1917] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_match_statement, 6, .production_id = 85),
  [1919] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_with_statement, 6, .production_id = 86),
  [1921] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_with_statement, 6, .production_id = 86),
  [1923] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 6, .production_id = 87),
  [1925] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 6, .production_id = 87),
  [1927] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_definition, 6, .production_id = 94),
  [1929] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 6, .production_id = 94),
  [1931] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 8, .production_id = 113),
  [1933] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 8, .production_id = 113),
  [1935] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 8, .production_id = 115),
  [1937] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 8, .production_id = 115),
  [1939] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_statement, 6, .production_id = 89),
  [1941] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while_statement, 6, .production_id = 89),
  [1943] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 8, .production_id = 116),
  [1945] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 8, .production_id = 116),
  [1947] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 8, .production_id = 117),
  [1949] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 8, .production_id = 117),
  [1951] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 8, .production_id = 118),
  [1953] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 8, .production_id = 118),
  [1955] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 8, .production_id = 119),
  [1957] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 8, .production_id = 119),
  [1959] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_definition, 6, .production_id = 95),
  [1961] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 6, .production_id = 95),
  [1963] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 4, .production_id = 44),
  [1965] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_definition, 4, .production_id = 44),
  [1967] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__patterns, 3),
  [1969] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_with_statement, 4, .production_id = 43),
  [1971] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_with_statement, 4, .production_id = 43),
  [1973] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_match_statement, 4, .production_id = 39),
  [1975] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_match_statement, 4, .production_id = 39),
  [1977] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__match_block, 1),
  [1979] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__match_block, 1),
  [1981] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 7, .production_id = 100),
  [1983] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 7, .production_id = 100),
  [1985] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1622),
  [1987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(217),
  [1989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(890),
  [1991] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1632),
  [1993] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1629),
  [1995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(219),
  [1997] = {.entry = {.count = 1, .reusable = false}}, SHIFT(445),
  [1999] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 7, .production_id = 102),
  [2001] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 7, .production_id = 102),
  [2003] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 7, .production_id = 107),
  [2005] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 7, .production_id = 107),
  [2007] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 7, .production_id = 103),
  [2009] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 7, .production_id = 103),
  [2011] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 7, .production_id = 104),
  [2013] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 7, .production_id = 104),
  [2015] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 9, .production_id = 126),
  [2017] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 9, .production_id = 126),
  [2019] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_finally_clause, 4),
  [2021] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_finally_clause, 4),
  [2023] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 9, .production_id = 128),
  [2025] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 9, .production_id = 128),
  [2027] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 7, .production_id = 63),
  [2029] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_statement, 7, .production_id = 63),
  [2031] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 9, .production_id = 127),
  [2033] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 9, .production_id = 127),
  [2035] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 9, .production_id = 130),
  [2037] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 9, .production_id = 130),
  [2039] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 10, .production_id = 135),
  [2041] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 10, .production_id = 135),
  [2043] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pattern_list, 3),
  [2045] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_decorated_definition, 2, .production_id = 12),
  [2047] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_decorated_definition, 2, .production_id = 12),
  [2049] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pattern_list, 2),
  [2051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(952),
  [2053] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1644),
  [2055] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_keyword_separator, 1),
  [2057] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1625),
  [2059] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1618),
  [2061] = {.entry = {.count = 1, .reusable = false}}, SHIFT(447),
  [2063] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1612),
  [2065] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1607),
  [2067] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1606),
  [2069] = {.entry = {.count = 1, .reusable = false}}, SHIFT(371),
  [2071] = {.entry = {.count = 1, .reusable = false}}, SHIFT(894),
  [2073] = {.entry = {.count = 1, .reusable = false}}, SHIFT(937),
  [2075] = {.entry = {.count = 1, .reusable = false}}, SHIFT(876),
  [2077] = {.entry = {.count = 1, .reusable = false}}, SHIFT(910),
  [2079] = {.entry = {.count = 1, .reusable = false}}, SHIFT(969),
  [2081] = {.entry = {.count = 1, .reusable = false}}, SHIFT(970),
  [2083] = {.entry = {.count = 1, .reusable = false}}, SHIFT(938),
  [2085] = {.entry = {.count = 1, .reusable = false}}, SHIFT(887),
  [2087] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1639),
  [2089] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1636),
  [2091] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1637),
  [2093] = {.entry = {.count = 1, .reusable = false}}, SHIFT(456),
  [2095] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1182),
  [2097] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1163),
  [2099] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1224),
  [2101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(162),
  [2103] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1460),
  [2105] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1489),
  [2107] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1487),
  [2109] = {.entry = {.count = 1, .reusable = false}}, SHIFT(180),
  [2111] = {.entry = {.count = 1, .reusable = false}}, SHIFT(627),
  [2113] = {.entry = {.count = 1, .reusable = false}}, SHIFT(642),
  [2115] = {.entry = {.count = 1, .reusable = false}}, SHIFT(643),
  [2117] = {.entry = {.count = 1, .reusable = false}}, SHIFT(156),
  [2119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1094),
  [2121] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1112),
  [2123] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1110),
  [2125] = {.entry = {.count = 1, .reusable = false}}, SHIFT(158),
  [2127] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1334),
  [2129] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1490),
  [2131] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1412),
  [2133] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1370),
  [2135] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1369),
  [2137] = {.entry = {.count = 1, .reusable = false}}, SHIFT(164),
  [2139] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1392),
  [2141] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1429),
  [2143] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1437),
  [2145] = {.entry = {.count = 1, .reusable = false}}, SHIFT(181),
  [2147] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1407),
  [2149] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1512),
  [2151] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1506),
  [2153] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1510),
  [2155] = {.entry = {.count = 1, .reusable = false}}, SHIFT(188),
  [2157] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1396),
  [2159] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1332),
  [2161] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1333),
  [2163] = {.entry = {.count = 1, .reusable = false}}, SHIFT(645),
  [2165] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1253),
  [2167] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1250),
  [2169] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1252),
  [2171] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1608),
  [2173] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1616),
  [2175] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1609),
  [2177] = {.entry = {.count = 1, .reusable = false}}, SHIFT(401),
  [2179] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1453),
  [2181] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1381),
  [2183] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1417),
  [2185] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1413),
  [2187] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_concatenated_string, 2),
  [2189] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_concatenated_string, 2),
  [2191] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression, 1),
  [2193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2808),
  [2195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(248),
  [2197] = {.entry = {.count = 1, .reusable = false}}, SHIFT(934),
  [2199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(933),
  [2201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(932),
  [2203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(921),
  [2205] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression, 1),
  [2207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(449),
  [2209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(934),
  [2211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(871),
  [2213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(898),
  [2215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2642),
  [2217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(897),
  [2219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(888),
  [2221] = {.entry = {.count = 1, .reusable = false}}, SHIFT(932),
  [2223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(866),
  [2225] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2),
  [2227] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_concatenated_string_repeat1, 2),
  [2229] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2), SHIFT_REPEAT(1764),
  [2232] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binary_operator, 3, .production_id = 21),
  [2234] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binary_operator, 3, .production_id = 21),
  [2236] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 24),
  [2238] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 24),
  [2240] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_comparison_operator_repeat1, 3, .production_id = 49),
  [2242] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_comparison_operator_repeat1, 3, .production_id = 49),
  [2244] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2), SHIFT_REPEAT(1766),
  [2247] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unary_operator, 2, .production_id = 9),
  [2249] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unary_operator, 2, .production_id = 9),
  [2251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2810),
  [2253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(238),
  [2255] = {.entry = {.count = 1, .reusable = false}}, SHIFT(886),
  [2257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(885),
  [2259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(884),
  [2261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(882),
  [2263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(441),
  [2265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(886),
  [2267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(881),
  [2269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(880),
  [2271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2753),
  [2273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(878),
  [2275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(877),
  [2277] = {.entry = {.count = 1, .reusable = false}}, SHIFT(884),
  [2279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(861),
  [2281] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_await, 2),
  [2283] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_await, 2),
  [2285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2710),
  [2287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(240),
  [2289] = {.entry = {.count = 1, .reusable = false}}, SHIFT(896),
  [2291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(899),
  [2293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(913),
  [2295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(914),
  [2297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(439),
  [2299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(896),
  [2301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(915),
  [2303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(923),
  [2305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2806),
  [2307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(926),
  [2309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(929),
  [2311] = {.entry = {.count = 1, .reusable = false}}, SHIFT(913),
  [2313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(864),
  [2315] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2), SHIFT_REPEAT(1727),
  [2318] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_comparison_operator_repeat1, 3, .production_id = 50),
  [2320] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_comparison_operator_repeat1, 3, .production_id = 50),
  [2322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2684),
  [2324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(236),
  [2326] = {.entry = {.count = 1, .reusable = false}}, SHIFT(951),
  [2328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(950),
  [2330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(949),
  [2332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(948),
  [2334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(410),
  [2336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(951),
  [2338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(947),
  [2340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(946),
  [2342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2801),
  [2344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(945),
  [2346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(944),
  [2348] = {.entry = {.count = 1, .reusable = false}}, SHIFT(949),
  [2350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(865),
  [2352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2648),
  [2354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(249),
  [2356] = {.entry = {.count = 1, .reusable = false}}, SHIFT(965),
  [2358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(962),
  [2360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(961),
  [2362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(958),
  [2364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(435),
  [2366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(965),
  [2368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(957),
  [2370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(955),
  [2372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2728),
  [2374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(953),
  [2376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(943),
  [2378] = {.entry = {.count = 1, .reusable = false}}, SHIFT(961),
  [2380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(860),
  [2382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2720),
  [2384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(414),
  [2386] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2), SHIFT_REPEAT(1767),
  [2389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2749),
  [2391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(257),
  [2393] = {.entry = {.count = 1, .reusable = false}}, SHIFT(927),
  [2395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(925),
  [2397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(924),
  [2399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(922),
  [2401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(443),
  [2403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(927),
  [2405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(920),
  [2407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(919),
  [2409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2681),
  [2411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(918),
  [2413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(917),
  [2415] = {.entry = {.count = 1, .reusable = false}}, SHIFT(924),
  [2417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(862),
  [2419] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2), SHIFT_REPEAT(1742),
  [2422] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 2),
  [2424] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 2),
  [2426] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2), SHIFT_REPEAT(1759),
  [2429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2660),
  [2431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(250),
  [2433] = {.entry = {.count = 1, .reusable = false}}, SHIFT(901),
  [2435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(902),
  [2437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(903),
  [2439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(904),
  [2441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(453),
  [2443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(901),
  [2445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(905),
  [2447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(906),
  [2449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2701),
  [2451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(907),
  [2453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(908),
  [2455] = {.entry = {.count = 1, .reusable = false}}, SHIFT(903),
  [2457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(863),
  [2459] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 3),
  [2461] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 3),
  [2463] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2), SHIFT_REPEAT(1757),
  [2466] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list, 3),
  [2468] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list, 3),
  [2470] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dictionary, 3),
  [2472] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dictionary, 3),
  [2474] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dictionary, 5),
  [2476] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dictionary, 5),
  [2478] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_set, 3),
  [2480] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_set, 3),
  [2482] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 3),
  [2484] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 3),
  [2486] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 2),
  [2488] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 2),
  [2490] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple, 3),
  [2492] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tuple, 3),
  [2494] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_expression, 3),
  [2496] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_expression, 3),
  [2498] = {.entry = {.count = 1, .reusable = false}}, SHIFT(539),
  [2500] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dictionary_comprehension, 4, .production_id = 34),
  [2502] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dictionary_comprehension, 4, .production_id = 34),
  [2504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(237),
  [2506] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_set_comprehension, 4, .production_id = 34),
  [2508] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_set_comprehension, 4, .production_id = 34),
  [2510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2683),
  [2512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(247),
  [2514] = {.entry = {.count = 1, .reusable = false}}, SHIFT(936),
  [2516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(935),
  [2518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(931),
  [2520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(930),
  [2522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(434),
  [2524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(936),
  [2526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(928),
  [2528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(916),
  [2530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2650),
  [2532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(911),
  [2534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(909),
  [2536] = {.entry = {.count = 1, .reusable = false}}, SHIFT(931),
  [2538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(859),
  [2540] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dictionary, 4),
  [2542] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dictionary, 4),
  [2544] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_comprehension, 4, .production_id = 34),
  [2546] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list_comprehension, 4, .production_id = 34),
  [2548] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2), SHIFT_REPEAT(1736),
  [2551] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 5, .production_id = 33),
  [2553] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 5, .production_id = 33),
  [2555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(235),
  [2557] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_generator_expression, 4, .production_id = 34),
  [2559] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_generator_expression, 4, .production_id = 34),
  [2561] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call, 2, .production_id = 10),
  [2563] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call, 2, .production_id = 10),
  [2565] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 4, .production_id = 33),
  [2567] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 4, .production_id = 33),
  [2569] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 5),
  [2571] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 5),
  [2573] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 4),
  [2575] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 4),
  [2577] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dictionary, 2),
  [2579] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dictionary, 2),
  [2581] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 3, .production_id = 33),
  [2583] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 3, .production_id = 33),
  [2585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(255),
  [2587] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1803),
  [2589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1534),
  [2591] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2601),
  [2593] = {.entry = {.count = 1, .reusable = false}}, SHIFT(511),
  [2595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(120),
  [2597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2601),
  [2599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1527),
  [2601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2530),
  [2603] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2019),
  [2605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1565),
  [2607] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1908),
  [2609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1908),
  [2611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(115),
  [2613] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1821),
  [2615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1537),
  [2617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2261),
  [2619] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2617),
  [2621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2617),
  [2623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1538),
  [2625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2619),
  [2627] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2076),
  [2629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1572),
  [2631] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2011),
  [2633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2011),
  [2635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2155),
  [2637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2208),
  [2639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2202),
  [2641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2066),
  [2643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2185),
  [2645] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1840),
  [2647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1519),
  [2649] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2563),
  [2651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2563),
  [2653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1536),
  [2655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2091),
  [2657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2565),
  [2659] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2129),
  [2661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1563),
  [2663] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1986),
  [2665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1986),
  [2667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2030),
  [2669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2265),
  [2671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2121),
  [2673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2025),
  [2675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2037),
  [2677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2212),
  [2679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2187),
  [2681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2191),
  [2683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2259),
  [2685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2104),
  [2687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2213),
  [2689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2188),
  [2691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2170),
  [2693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2167),
  [2695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2198),
  [2697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2240),
  [2699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2235),
  [2701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2113),
  [2703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2254),
  [2705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2234),
  [2707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2227),
  [2709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2203),
  [2711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2239),
  [2713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2156),
  [2715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2247),
  [2717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2252),
  [2719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2175),
  [2721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2071),
  [2723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2166),
  [2725] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1842),
  [2727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1532),
  [2729] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2623),
  [2731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2623),
  [2733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1533),
  [2735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2626),
  [2737] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2032),
  [2739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1567),
  [2741] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1954),
  [2743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1954),
  [2745] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1790),
  [2747] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2491),
  [2749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2260),
  [2751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2211),
  [2753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2100),
  [2755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2224),
  [2757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2193),
  [2759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2117),
  [2761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2021),
  [2763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2190),
  [2765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2258),
  [2767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2246),
  [2769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2045),
  [2771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2218),
  [2773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2189),
  [2775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2163),
  [2777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2134),
  [2779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2257),
  [2781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2242),
  [2783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2181),
  [2785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2210),
  [2787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2179),
  [2789] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1913),
  [2791] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2118),
  [2793] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2111),
  [2795] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1969),
  [2797] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1900),
  [2799] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2028),
  [2801] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2048),
  [2803] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1901),
  [2805] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2042),
  [2807] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2036),
  [2809] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2008),
  [2811] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 25),
  [2813] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 25), SHIFT_REPEAT(932),
  [2816] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 25),
  [2818] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 25), SHIFT_REPEAT(2642),
  [2821] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 25), SHIFT_REPEAT(932),
  [2824] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 25), SHIFT_REPEAT(866),
  [2827] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_comparison_operator, 2, .production_id = 11),
  [2829] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_comparison_operator, 2, .production_id = 11),
  [2831] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 25), SHIFT_REPEAT(949),
  [2834] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 25), SHIFT_REPEAT(2801),
  [2837] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 25), SHIFT_REPEAT(949),
  [2840] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 25), SHIFT_REPEAT(865),
  [2843] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 25), SHIFT_REPEAT(961),
  [2846] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 25), SHIFT_REPEAT(2728),
  [2849] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 25), SHIFT_REPEAT(961),
  [2852] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 25), SHIFT_REPEAT(860),
  [2855] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 25), SHIFT_REPEAT(931),
  [2858] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 25), SHIFT_REPEAT(2650),
  [2861] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 25), SHIFT_REPEAT(931),
  [2864] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 25), SHIFT_REPEAT(859),
  [2867] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 25), SHIFT_REPEAT(913),
  [2870] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 25), SHIFT_REPEAT(2806),
  [2873] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 25), SHIFT_REPEAT(913),
  [2876] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 25), SHIFT_REPEAT(864),
  [2879] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 25), SHIFT_REPEAT(884),
  [2882] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 25), SHIFT_REPEAT(2753),
  [2885] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 25), SHIFT_REPEAT(884),
  [2888] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 25), SHIFT_REPEAT(861),
  [2891] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dictionary_splat_pattern, 2),
  [2893] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 25), SHIFT_REPEAT(903),
  [2896] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 25), SHIFT_REPEAT(2701),
  [2899] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 25), SHIFT_REPEAT(903),
  [2902] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 25), SHIFT_REPEAT(863),
  [2905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(222),
  [2907] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__patterns_repeat1, 2),
  [2909] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__patterns_repeat1, 2), SHIFT_REPEAT(855),
  [2912] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 25), SHIFT_REPEAT(924),
  [2915] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 25), SHIFT_REPEAT(2681),
  [2918] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 25), SHIFT_REPEAT(924),
  [2921] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_comparison_operator_repeat1, 2, .production_id = 25), SHIFT_REPEAT(862),
  [2924] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_pattern, 3),
  [2926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2693),
  [2928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(432),
  [2930] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_pattern, 3),
  [2932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2512),
  [2934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(726),
  [2936] = {.entry = {.count = 1, .reusable = false}}, SHIFT(857),
  [2938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(596),
  [2940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(867),
  [2942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2539),
  [2944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(577),
  [2946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(442),
  [2948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(591),
  [2950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(566),
  [2952] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__patterns_repeat1, 2), SHIFT_REPEAT(851),
  [2955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(523),
  [2957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(486),
  [2959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(483),
  [2961] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__right_hand_side, 1),
  [2963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(246),
  [2965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(221),
  [2967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(216),
  [2969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(436),
  [2971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(547),
  [2973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(223),
  [2975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(251),
  [2977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(424),
  [2979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(254),
  [2981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2146),
  [2983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(721),
  [2985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2538),
  [2987] = {.entry = {.count = 1, .reusable = false}}, SHIFT(858),
  [2989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(960),
  [2991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2589),
  [2993] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__parameters, 3),
  [2995] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__parameters, 2),
  [2997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(338),
  [2999] = {.entry = {.count = 1, .reusable = false}}, SHIFT(602),
  [3001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(561),
  [3003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(562),
  [3005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2828),
  [3007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(743),
  [3009] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__collection_elements, 1),
  [3011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(603),
  [3013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(512),
  [3015] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_as_pattern, 3, .production_id = 22),
  [3017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(484),
  [3019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(485),
  [3021] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_boolean_operator, 3, .production_id = 21),
  [3023] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_not_operator, 2, .production_id = 6),
  [3025] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_conditional_expression, 5),
  [3027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(553),
  [3029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(548),
  [3031] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda, 4, .production_id = 47),
  [3033] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_named_expression, 3, .production_id = 18),
  [3035] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_named_expression, 3, .production_id = 18), SHIFT(553),
  [3038] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda, 3, .production_id = 17),
  [3040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(326),
  [3042] = {.entry = {.count = 1, .reusable = false}}, SHIFT(570),
  [3044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(559),
  [3046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2825),
  [3048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(829),
  [3050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(571),
  [3052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(576),
  [3054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1286),
  [3056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(281),
  [3058] = {.entry = {.count = 1, .reusable = false}}, SHIFT(519),
  [3060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(549),
  [3062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2772),
  [3064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(738),
  [3066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(517),
  [3068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(516),
  [3070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1227),
  [3072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(272),
  [3074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1288),
  [3076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(342),
  [3078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1085),
  [3080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1195),
  [3082] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression_statement, 1),
  [3084] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type, 1),
  [3086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(452),
  [3088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1292),
  [3090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(295),
  [3092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1416),
  [3094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1263),
  [3096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1468),
  [3098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(322),
  [3100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1348),
  [3102] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_with_item, 1, .dynamic_precedence = 1, .production_id = 7), SHIFT(342),
  [3105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1475),
  [3107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1335),
  [3109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(303),
  [3111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1356),
  [3113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(310),
  [3115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1440),
  [3117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1070),
  [3119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(289),
  [3121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1319),
  [3123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(273),
  [3125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(227),
  [3127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1883),
  [3129] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1883),
  [3131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1076),
  [3133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1107),
  [3135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(536),
  [3137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(568),
  [3139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(534),
  [3141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(531),
  [3143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2369),
  [3145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1196),
  [3147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(343),
  [3149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(563),
  [3151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(564),
  [3153] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__f_expression, 1),
  [3155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(560),
  [3157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(557),
  [3159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1202),
  [3161] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_named_expression, 3, .production_id = 18), SHIFT(536),
  [3164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1420),
  [3166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1082),
  [3168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(545),
  [3170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(555),
  [3172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(525),
  [3174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(529),
  [3176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1181),
  [3178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2502),
  [3180] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_named_expression, 3, .production_id = 18), SHIFT(545),
  [3183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1259),
  [3185] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yield, 2),
  [3187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1410),
  [3189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1208),
  [3191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1165),
  [3193] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_string_repeat1, 2), SHIFT_REPEAT(227),
  [3196] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_string_repeat1, 2), SHIFT_REPEAT(1883),
  [3199] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_string_repeat1, 2), SHIFT_REPEAT(1883),
  [3202] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_string_repeat1, 2),
  [3204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1194),
  [3206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1020),
  [3208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1042),
  [3210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1052),
  [3212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1260),
  [3214] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_named_expression, 3, .production_id = 18), SHIFT(488),
  [3217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(489),
  [3219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(490),
  [3221] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_boolean_operator, 3, .production_id = 21),
  [3223] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_named_expression, 3, .production_id = 18), SHIFT(563),
  [3226] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_dotted_name_repeat1, 2),
  [3228] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_dotted_name_repeat1, 2), SHIFT_REPEAT(2676),
  [3231] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_as_pattern, 3, .production_id = 22),
  [3233] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_assert_statement_repeat1, 2),
  [3235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(488),
  [3237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(574),
  [3239] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_named_expression, 3, .production_id = 18), SHIFT(602),
  [3242] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_not_operator, 2, .production_id = 6),
  [3244] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dotted_name, 1),
  [3246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2676),
  [3248] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_raise_statement, 2),
  [3250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(565),
  [3252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(379),
  [3254] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yield, 3),
  [3256] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dotted_name, 2),
  [3258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1587),
  [3260] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_named_expression, 3, .production_id = 18), SHIFT(570),
  [3263] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expression_within_for_in_clause, 1),
  [3265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(372),
  [3267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(375),
  [3269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1339),
  [3271] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exec_statement, 4, .production_id = 8),
  [3273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(551),
  [3275] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_named_expression, 3, .production_id = 18), SHIFT(519),
  [3278] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__simple_pattern, 1),
  [3280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2694),
  [3282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(380),
  [3284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1071),
  [3286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2800),
  [3288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1580),
  [3290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2649),
  [3292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2805),
  [3294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2796),
  [3296] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pair, 3, .production_id = 45),
  [3298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2824),
  [3300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2820),
  [3302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2797),
  [3304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2704),
  [3306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(392),
  [3308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1278),
  [3310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(376),
  [3312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(638),
  [3314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(403),
  [3316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1424),
  [3318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(393),
  [3320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1000),
  [3322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2714),
  [3324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1584),
  [3326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2758),
  [3328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1586),
  [3330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(397),
  [3332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1168),
  [3334] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_delete_statement, 2),
  [3336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(373),
  [3338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1499),
  [3340] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_statement, 2),
  [3342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(386),
  [3344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1481),
  [3346] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assert_statement, 2),
  [3348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(404),
  [3350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1438),
  [3352] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_print_statement, 2, .dynamic_precedence = -1, .production_id = 6),
  [3354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(454),
  [3356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(360),
  [3358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1067),
  [3360] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_clause, 2),
  [3362] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_dotted_name_repeat1, 2), SHIFT_REPEAT(2758),
  [3365] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_dotted_name_repeat1, 2), SHIFT_REPEAT(2714),
  [3368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(510),
  [3370] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__comprehension_clauses, 2),
  [3372] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__comprehension_clauses_repeat1, 2), SHIFT_REPEAT(542),
  [3375] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__comprehension_clauses_repeat1, 2), SHIFT_REPEAT(2828),
  [3378] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__comprehension_clauses_repeat1, 2), SHIFT_REPEAT(743),
  [3381] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__comprehension_clauses_repeat1, 2),
  [3383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(533),
  [3385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(542),
  [3387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(467),
  [3389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2299),
  [3391] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_print_statement_repeat1, 2, .production_id = 6),
  [3393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1991),
  [3395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2197),
  [3397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2551),
  [3399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(370),
  [3401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1406),
  [3403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(462),
  [3405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2407),
  [3407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(479),
  [3409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(92),
  [3411] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__simple_pattern, 2),
  [3413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2568),
  [3415] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string_content, 1),
  [3417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1910),
  [3419] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1910),
  [3421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(105),
  [3423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(94),
  [3425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(367),
  [3427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1485),
  [3429] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_dotted_name_repeat1, 2), SHIFT_REPEAT(2800),
  [3432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(363),
  [3434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1302),
  [3436] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__comprehension_clauses, 1),
  [3438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(355),
  [3440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1203),
  [3442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(421),
  [3444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(431),
  [3446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(358),
  [3448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1294),
  [3450] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_chevron, 2),
  [3452] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__comprehension_clauses_repeat1, 2), SHIFT_REPEAT(533),
  [3455] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__comprehension_clauses_repeat1, 2), SHIFT_REPEAT(2772),
  [3458] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__comprehension_clauses_repeat1, 2), SHIFT_REPEAT(738),
  [3461] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_subscript_repeat1, 2, .production_id = 71),
  [3463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(357),
  [3465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1266),
  [3467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2173),
  [3469] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2708),
  [3471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(128),
  [3473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2532),
  [3475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(369),
  [3477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1403),
  [3479] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_string_content_repeat1, 2),
  [3481] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_string_content_repeat1, 2), SHIFT_REPEAT(1910),
  [3484] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_string_content_repeat1, 2), SHIFT_REPEAT(1910),
  [3487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(433),
  [3489] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__comprehension_clauses_repeat1, 2), SHIFT_REPEAT(510),
  [3492] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__comprehension_clauses_repeat1, 2), SHIFT_REPEAT(2825),
  [3495] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__comprehension_clauses_repeat1, 2), SHIFT_REPEAT(829),
  [3498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2697),
  [3500] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interpolation, 4, .production_id = 53),
  [3502] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interpolation, 4, .production_id = 53),
  [3504] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interpolation, 4, .production_id = 52),
  [3506] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interpolation, 4, .production_id = 52),
  [3508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1525),
  [3510] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interpolation, 4, .production_id = 26),
  [3512] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interpolation, 4, .production_id = 26),
  [3514] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interpolation, 5, .production_id = 74),
  [3516] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interpolation, 5, .production_id = 74),
  [3518] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_assert_statement_repeat1, 2), SHIFT_REPEAT(508),
  [3521] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_splat, 2),
  [3523] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_decorated_definition_repeat1, 2),
  [3525] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_decorated_definition_repeat1, 2), SHIFT_REPEAT(582),
  [3528] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_slice, 5),
  [3530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2791),
  [3532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(226),
  [3534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(260),
  [3536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1957),
  [3538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(261),
  [3540] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_in_clause, 6, .production_id = 110),
  [3542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(333),
  [3544] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter, 5),
  [3546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(225),
  [3548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2097),
  [3550] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interpolation, 5, .production_id = 75),
  [3552] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interpolation, 5, .production_id = 75),
  [3554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2618),
  [3556] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interpolation, 5, .production_id = 76),
  [3558] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interpolation, 5, .production_id = 76),
  [3560] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_raise_statement, 3, .production_id = 16),
  [3562] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter, 4),
  [3564] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_union_pattern, 2),
  [3566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1582),
  [3568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(232),
  [3570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2003),
  [3572] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_in_clause, 4, .production_id = 79),
  [3574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(330),
  [3576] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_in_clause_repeat1, 2), SHIFT_REPEAT(411),
  [3579] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_for_in_clause_repeat1, 2),
  [3581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(340),
  [3583] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__collection_elements_repeat1, 2),
  [3585] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dictionary_splat, 2),
  [3587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(344),
  [3589] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_in_clause, 5, .production_id = 98),
  [3591] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_with_item, 1, .dynamic_precedence = 1, .production_id = 7),
  [3593] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_argument_list_repeat1, 2),
  [3595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2625),
  [3597] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_union_pattern_repeat1, 2),
  [3599] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_union_pattern_repeat1, 2), SHIFT_REPEAT(1582),
  [3602] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter, 3),
  [3604] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_generic_type, 2),
  [3606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(606),
  [3608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(607),
  [3610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(87),
  [3612] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_union_type, 3),
  [3614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2673),
  [3616] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constrained_type, 3),
  [3618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(241),
  [3620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(265),
  [3622] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_member_type, 3),
  [3624] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_in_clause_repeat1, 2), SHIFT_REPEAT(446),
  [3627] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment, 3, .production_id = 19),
  [3629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2635),
  [3631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(234),
  [3633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(192),
  [3635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(267),
  [3637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2597),
  [3639] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_in_clause, 5, .production_id = 99),
  [3641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(332),
  [3643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(331),
  [3645] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__patterns_repeat1, 2), SHIFT_REPEAT(856),
  [3648] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interpolation, 6, .production_id = 97),
  [3650] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interpolation, 6, .production_id = 97),
  [3652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(341),
  [3654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(346),
  [3656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(336),
  [3658] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_keyword_argument, 3, .production_id = 70),
  [3660] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_raise_statement, 4, .production_id = 36),
  [3662] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_keyword_argument, 3, .production_id = 18),
  [3664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2566),
  [3666] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_typed_default_parameter, 5, .production_id = 96),
  [3668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(224),
  [3670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2016),
  [3672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(608),
  [3674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(97),
  [3676] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_match_statement_repeat1, 2, .production_id = 38),
  [3678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(335),
  [3680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(334),
  [3682] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interpolation, 3, .production_id = 26),
  [3684] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interpolation, 3, .production_id = 26),
  [3686] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_dotted_name_repeat1, 2), SHIFT_REPEAT(2697),
  [3689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2575),
  [3691] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_typed_parameter, 3, .production_id = 46),
  [3693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(540),
  [3695] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_keyword_pattern, 3),
  [3697] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_default_parameter, 3, .production_id = 18),
  [3699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2613),
  [3701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(327),
  [3703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(679),
  [3705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(345),
  [3707] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_in_clause_repeat1, 2), SHIFT_REPEAT(418),
  [3710] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_pattern, 1),
  [3712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1516),
  [3714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2777),
  [3716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(511),
  [3718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(127),
  [3720] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dict_pattern, 2),
  [3722] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__list_pattern, 3),
  [3724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2690),
  [3726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(268),
  [3728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(552),
  [3730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(270),
  [3732] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__list_pattern, 4),
  [3734] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda_within_for_in_clause, 4, .production_id = 47),
  [3736] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_union_pattern_repeat1, 2), SHIFT_REPEAT(1583),
  [3739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(382),
  [3741] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_pattern, 3),
  [3743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(550),
  [3745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1585),
  [3747] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_splat_pattern, 2),
  [3749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1549),
  [3751] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__tuple_pattern, 4),
  [3753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1568),
  [3755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2219),
  [3757] = {.entry = {.count = 1, .reusable = false}}, SHIFT(228),
  [3759] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_specifier, 2),
  [3761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2049),
  [3763] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_union_pattern_repeat1, 2), SHIFT_REPEAT(1585),
  [3766] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dict_pattern, 5, .production_id = 122),
  [3768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2194),
  [3770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1583),
  [3772] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_format_specifier_repeat1, 2), SHIFT_REPEAT(228),
  [3775] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_format_specifier_repeat1, 2),
  [3777] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_format_specifier_repeat1, 2), SHIFT_REPEAT(2049),
  [3780] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__import_list, 2, .production_id = 4),
  [3782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2116),
  [3784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2158),
  [3786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2000),
  [3788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2411),
  [3790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(587),
  [3792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1576),
  [3794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2150),
  [3796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(118),
  [3798] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda_within_for_in_clause, 3, .production_id = 17),
  [3800] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_complex_pattern, 4),
  [3802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(595),
  [3804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(133),
  [3806] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_pattern, 5),
  [3808] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_parameter_repeat1, 2),
  [3810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1570),
  [3812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2251),
  [3814] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_pattern, 6),
  [3816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(506),
  [3818] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__import_list, 3, .production_id = 13),
  [3820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1548),
  [3822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1581),
  [3824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(135),
  [3826] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_alias_statement, 4, .dynamic_precedence = 1),
  [3828] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_complex_pattern, 3),
  [3830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(114),
  [3832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(93),
  [3834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2205),
  [3836] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__import_list, 1, .production_id = 4),
  [3838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2050),
  [3840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2706),
  [3842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(271),
  [3844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(121),
  [3846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(123),
  [3848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(124),
  [3850] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__list_pattern, 5),
  [3852] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dict_pattern, 3),
  [3854] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_pattern, 4),
  [3856] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dict_pattern, 4, .production_id = 122),
  [3858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(480),
  [3860] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dict_pattern, 4),
  [3862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2143),
  [3864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2464),
  [3866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2478),
  [3868] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_assert_statement_repeat1, 2), SHIFT_REPEAT(551),
  [3871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(130),
  [3873] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__tuple_pattern, 2),
  [3875] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dict_pattern, 4, .production_id = 120),
  [3877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(499),
  [3879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1517),
  [3881] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_union_pattern_repeat1, 2), SHIFT_REPEAT(1581),
  [3884] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__tuple_pattern, 5),
  [3886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(594),
  [3888] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_specifier, 1),
  [3890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2041),
  [3892] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dict_pattern, 4, .production_id = 111),
  [3894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(100),
  [3896] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__list_pattern, 2),
  [3898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1545),
  [3900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(112),
  [3902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(496),
  [3904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(584),
  [3906] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dict_pattern, 3, .production_id = 111),
  [3908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1561),
  [3910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2093),
  [3912] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__tuple_pattern, 3),
  [3914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(554),
  [3916] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dict_pattern, 5, .production_id = 120),
  [3918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(136),
  [3920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1556),
  [3922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(740),
  [3924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(269),
  [3926] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_print_statement_repeat1, 2, .production_id = 35),
  [3928] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_print_statement_repeat1, 2, .production_id = 35), SHIFT_REPEAT(494),
  [3931] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_dict_pattern_repeat1, 2),
  [3933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2292),
  [3935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2493),
  [3937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1913),
  [3939] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 1),
  [3941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(243),
  [3943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(509),
  [3945] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_nonlocal_statement, 2),
  [3947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2711),
  [3949] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_global_statement, 2),
  [3951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1676),
  [3953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2128),
  [3955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1529),
  [3957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2657),
  [3959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1918),
  [3961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2349),
  [3963] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__as_pattern, 3),
  [3965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(448),
  [3967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(727),
  [3969] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_print_statement, 2),
  [3971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(455),
  [3973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(754),
  [3975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2165),
  [3977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2671),
  [3979] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_clause_repeat1, 2), SHIFT_REPEAT(1557),
  [3982] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_case_clause_repeat1, 2),
  [3984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1528),
  [3986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2752),
  [3988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2022),
  [3990] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_import_prefix, 1),
  [3992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2237),
  [3994] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__import_list_repeat1, 2, .production_id = 27),
  [3996] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__import_list_repeat1, 2, .production_id = 28),
  [3998] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__import_list_repeat1, 2, .production_id = 28), SHIFT_REPEAT(2398),
  [4001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2216),
  [4003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1520),
  [4005] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exec_statement, 5, .production_id = 8),
  [4007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1544),
  [4009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2255),
  [4011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2256),
  [4013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1541),
  [4015] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_global_statement_repeat1, 2),
  [4017] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_global_statement_repeat1, 2), SHIFT_REPEAT(2711),
  [4020] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_decorator, 3),
  [4022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2145),
  [4024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1553),
  [4026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1551),
  [4028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2147),
  [4030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2094),
  [4032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1522),
  [4034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(826),
  [4036] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__import_list, 2, .production_id = 13),
  [4038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2081),
  [4040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2074),
  [4042] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__match_block_repeat1, 2, .production_id = 81), SHIFT_REPEAT(1556),
  [4045] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__match_block_repeat1, 2, .production_id = 81),
  [4047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2184),
  [4049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1539),
  [4051] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_nonlocal_statement, 3),
  [4053] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_global_statement, 3),
  [4055] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_import_prefix_repeat1, 2),
  [4057] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_import_prefix_repeat1, 2), SHIFT_REPEAT(2237),
  [4060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2250),
  [4062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1518),
  [4064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1540),
  [4066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2209),
  [4068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2204),
  [4070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1547),
  [4072] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_print_statement, 3, .production_id = 14),
  [4074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(450),
  [4076] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assert_statement, 3),
  [4078] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_print_statement, 3, .dynamic_precedence = -1, .production_id = 15),
  [4080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(459),
  [4082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(839),
  [4084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(473),
  [4086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(471),
  [4088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(784),
  [4090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2139),
  [4092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(793),
  [4094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2161),
  [4096] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_clause_repeat1, 2), SHIFT_REPEAT(1554),
  [4099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(150),
  [4101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(465),
  [4103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2341),
  [4105] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__parameters_repeat1, 2), SHIFT_REPEAT(1682),
  [4108] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__parameters_repeat1, 2),
  [4110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(79),
  [4112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2612),
  [4114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2614),
  [4116] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__collection_elements_repeat1, 2), SHIFT_REPEAT(356),
  [4119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(140),
  [4121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2420),
  [4123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(138),
  [4125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(682),
  [4127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(354),
  [4129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(337),
  [4131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1336),
  [4133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(308),
  [4135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(398),
  [4137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(633),
  [4139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(148),
  [4141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(676),
  [4143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(396),
  [4145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(636),
  [4147] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_dictionary_repeat1, 2), SHIFT_REPEAT(387),
  [4150] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_dictionary_repeat1, 2),
  [4152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(312),
  [4154] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subscript_repeat1, 2, .production_id = 73), SHIFT_REPEAT(422),
  [4157] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_subscript_repeat1, 2, .production_id = 73),
  [4159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(314),
  [4161] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_aliased_import, 3, .production_id = 29),
  [4163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(390),
  [4165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1075),
  [4167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(406),
  [4169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1077),
  [4171] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_parameter_repeat1, 2), SHIFT_REPEAT(258),
  [4174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(774),
  [4176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(466),
  [4178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(231),
  [4180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(339),
  [4182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(82),
  [4184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1681),
  [4186] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__parameters_repeat1, 2), SHIFT_REPEAT(1683),
  [4189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(457),
  [4191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(451),
  [4193] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_format_specifier_repeat1, 1, .production_id = 51),
  [4195] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_format_specifier_repeat1, 1, .production_id = 51),
  [4197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2579),
  [4199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2632),
  [4201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(412),
  [4203] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__collection_elements_repeat1, 2), SHIFT_REPEAT(365),
  [4206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1575),
  [4208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2215),
  [4210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(283),
  [4212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(460),
  [4214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1546),
  [4216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(81),
  [4218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2616),
  [4220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1550),
  [4222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(229),
  [4224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1543),
  [4226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(75),
  [4228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1574),
  [4230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2245),
  [4232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(80),
  [4234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1559),
  [4236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2248),
  [4238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(78),
  [4240] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_match_statement_repeat1, 2, .production_id = 40), SHIFT_REPEAT(507),
  [4243] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_match_statement_repeat1, 2, .production_id = 40),
  [4245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(77),
  [4247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1919),
  [4249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(458),
  [4251] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_with_clause_repeat1, 2),
  [4253] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_with_clause_repeat1, 2), SHIFT_REPEAT(461),
  [4256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(444),
  [4258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1526),
  [4260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(423),
  [4262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(111),
  [4264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1566),
  [4266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2182),
  [4268] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__patterns_repeat1, 2), SHIFT_REPEAT(852),
  [4271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1571),
  [4273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2180),
  [4275] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_relative_import, 1),
  [4277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(142),
  [4279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(685),
  [4281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1569),
  [4283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2095),
  [4285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1531),
  [4287] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_assert_statement_repeat1, 2), SHIFT_REPEAT(575),
  [4290] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__patterns_repeat1, 2), SHIFT_REPEAT(853),
  [4293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(383),
  [4295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1504),
  [4297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1523),
  [4299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(391),
  [4301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1503),
  [4303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1552),
  [4305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(787),
  [4307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(389),
  [4309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1496),
  [4311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(132),
  [4313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(388),
  [4315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1488),
  [4317] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__patterns, 1),
  [4319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(730),
  [4321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(139),
  [4323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(141),
  [4325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(820),
  [4327] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_dict_pattern_repeat1, 2, .production_id = 121), SHIFT_REPEAT(1579),
  [4330] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_dict_pattern_repeat1, 2, .production_id = 121),
  [4332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(399),
  [4334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1449),
  [4336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(400),
  [4338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1447),
  [4340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(311),
  [4342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(366),
  [4344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(315),
  [4346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2620),
  [4348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2624),
  [4350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1349),
  [4352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(304),
  [4354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1464),
  [4356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(321),
  [4358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(475),
  [4360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2388),
  [4362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(361),
  [4364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(832),
  [4366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1916),
  [4368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(302),
  [4370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1578),
  [4372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2148),
  [4374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(301),
  [4376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(146),
  [4378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(405),
  [4380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1322),
  [4382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(402),
  [4384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1320),
  [4386] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_argument_list_repeat1, 2), SHIFT_REPEAT(329),
  [4389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(230),
  [4391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(359),
  [4393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(147),
  [4395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(658),
  [4397] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_assert_statement_repeat1, 2), SHIFT_REPEAT(532),
  [4400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(362),
  [4402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(76),
  [4404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(285),
  [4406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1562),
  [4408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2253),
  [4410] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__collection_elements_repeat1, 2), SHIFT_REPEAT(364),
  [4413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(347),
  [4415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1677),
  [4417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1573),
  [4419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2105),
  [4421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1535),
  [4423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(384),
  [4425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1176),
  [4427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1530),
  [4429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(374),
  [4431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1175),
  [4433] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__patterns_repeat1, 2), SHIFT_REPEAT(854),
  [4436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1560),
  [4438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2221),
  [4440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(319),
  [4442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1577),
  [4444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2217),
  [4446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(468),
  [4448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(309),
  [4450] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__simple_statements_repeat1, 2), SHIFT_REPEAT(153),
  [4453] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__simple_statements_repeat1, 2),
  [4455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(417),
  [4457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1521),
  [4459] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_assert_statement_repeat1, 2), SHIFT_REPEAT(521),
  [4462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(472),
  [4464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1297),
  [4466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(297),
  [4468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(233),
  [4470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(420),
  [4472] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_with_clause, 1),
  [4474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(151),
  [4476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(692),
  [4478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(349),
  [4480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(425),
  [4482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1313),
  [4484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(325),
  [4486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(428),
  [4488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(144),
  [4490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2154),
  [4492] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exec_statement, 2, .production_id = 8),
  [4494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(604),
  [4496] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__import_list_repeat1, 2, .production_id = 28), SHIFT_REPEAT(2456),
  [4499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(143),
  [4501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(670),
  [4503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2291),
  [4505] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__parameters, 1),
  [4507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1678),
  [4509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(145),
  [4511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(152),
  [4513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2144),
  [4515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1524),
  [4517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(395),
  [4519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1036),
  [4521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(381),
  [4523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1039),
  [4525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(287),
  [4527] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__key_value_pattern, 3, .production_id = 45),
  [4529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2638),
  [4531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(352),
  [4533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(284),
  [4535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1555),
  [4537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2294),
  [4539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(430),
  [4541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1233),
  [4543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(276),
  [4545] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_clause_repeat1, 2), SHIFT_REPEAT(1558),
  [4548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(378),
  [4550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1269),
  [4552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1170),
  [4554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(282),
  [4556] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_with_clause_repeat1, 2), SHIFT_REPEAT(469),
  [4559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(275),
  [4561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(544),
  [4563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(274),
  [4565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1680),
  [4567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(407),
  [4569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1398),
  [4571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(408),
  [4573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1397),
  [4575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(348),
  [4577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1564),
  [4579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2126),
  [4581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(149),
  [4583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(394),
  [4585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1270),
  [4587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(305),
  [4589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(306),
  [4591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(137),
  [4593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2591),
  [4595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1542),
  [4597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1154),
  [4599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(291),
  [4601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(244),
  [4603] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_clause, 7, .production_id = 138),
  [4605] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment, 5, .production_id = 69),
  [4607] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1881),
  [4609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1881),
  [4611] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2082),
  [4613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2082),
  [4615] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_from_statement, 4, .production_id = 31),
  [4617] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_dict_pattern_repeat1, 2, .production_id = 111),
  [4619] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pass_statement, 1),
  [4621] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameters, 2),
  [4623] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_positional_separator, 1),
  [4625] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_break_statement, 1),
  [4627] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_continue_statement, 1),
  [4629] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_future_import_statement, 4, .production_id = 30),
  [4631] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_clause, 6, .production_id = 131),
  [4633] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_clause, 6, .production_id = 132),
  [4635] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_clause, 6, .production_id = 133),
  [4637] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_clause, 6, .production_id = 134),
  [4639] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_wildcard_import, 1),
  [4641] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_clause, 4, .production_id = 112),
  [4643] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_from_statement, 4, .production_id = 32),
  [4645] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_clause, 7, .production_id = 136),
  [4647] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__match_block_repeat1, 1, .production_id = 54),
  [4649] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_clause, 7, .production_id = 137),
  [4651] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2186),
  [4653] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2005),
  [4655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2005),
  [4657] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2220),
  [4659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2220),
  [4661] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2060),
  [4663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2060),
  [4665] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_clause, 8, .production_id = 139),
  [4667] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameters, 3),
  [4669] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2241),
  [4671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2241),
  [4673] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_list_splat, 3, .production_id = 33),
  [4675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(96),
  [4677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(252),
  [4679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(88),
  [4681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(239),
  [4683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(101),
  [4685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(266),
  [4687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(99),
  [4689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(242),
  [4691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(106),
  [4693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(264),
  [4695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(113),
  [4697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(262),
  [4699] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_statement, 2, .production_id = 3),
  [4701] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_clause, 5, .production_id = 125),
  [4703] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_future_import_statement, 6, .production_id = 77),
  [4705] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_clause, 5, .production_id = 124),
  [4707] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2176),
  [4709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2176),
  [4711] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_clause, 5, .production_id = 123),
  [4713] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2119),
  [4715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(102),
  [4717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(245),
  [4719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(677),
  [4721] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_from_statement, 6, .production_id = 78),
  [4723] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_augmented_assignment, 3, .production_id = 21),
  [4725] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment, 3, .production_id = 20),
  [4727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(134),
  [4729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(263),
  [4731] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_argument_list_repeat1, 2, .production_id = 33),
  [4733] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_list_splat, 3),
  [4735] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2152),
  [4737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2152),
  [4739] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2168),
  [4741] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2230),
  [4743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2230),
  [4745] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1973),
  [4747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1973),
  [4749] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2033),
  [4751] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2262),
  [4753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2262),
  [4755] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1932),
  [4757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1932),
  [4759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(538),
  [4761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1279),
  [4763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1095),
  [4765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(487),
  [4767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1418),
  [4769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1995),
  [4771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1478),
  [4773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2337),
  [4775] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_with_clause, 4),
  [4777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1479),
  [4779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(883),
  [4781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1098),
  [4783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1486),
  [4785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(491),
  [4787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2249),
  [4789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2357),
  [4791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1391),
  [4793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(895),
  [4795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1483),
  [4797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1482),
  [4799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1473),
  [4801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1472),
  [4803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2514),
  [4805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(125),
  [4807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1187),
  [4809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1103),
  [4811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1915),
  [4813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1390),
  [4815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2594),
  [4817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1287),
  [4819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1357),
  [4821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1358),
  [4823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1371),
  [4825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(129),
  [4827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2608),
  [4829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1364),
  [4831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1965),
  [4833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1368),
  [4835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(437),
  [4837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1836),
  [4839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1084),
  [4841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1874),
  [4843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(912),
  [4845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1978),
  [4847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1480),
  [4849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1388),
  [4851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(599),
  [4853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(585),
  [4855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1402),
  [4857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1672),
  [4859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2068),
  [4861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1404),
  [4863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1507),
  [4865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(91),
  [4867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2098),
  [4869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1988),
  [4871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2099),
  [4873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1415),
  [4875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1373),
  [4877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2130),
  [4879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(974),
  [4881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(567),
  [4883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1375),
  [4885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(103),
  [4887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1323),
  [4889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2310),
  [4891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1653),
  [4893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2046),
  [4895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(122),
  [4897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1192),
  [4899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2319),
  [4901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1199),
  [4903] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_relative_import, 2),
  [4905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1970),
  [4907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(117),
  [4909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(530),
  [4911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1405),
  [4913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(640),
  [4915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(108),
  [4917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1933),
  [4919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1422),
  [4921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2301),
  [4923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(940),
  [4925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(126),
  [4927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1377),
  [4929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2149),
  [4931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(95),
  [4933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1441),
  [4935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1201),
  [4937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2295),
  [4939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1298),
  [4941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1649),
  [4943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2554),
  [4945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2572),
  [4947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1204),
  [4949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(416),
  [4951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(586),
  [4953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1968),
  [4955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2051),
  [4957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2288),
  [4959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1393),
  [4961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(119),
  [4963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2278),
  [4965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(942),
  [4967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1264),
  [4969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1069),
  [4971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(502),
  [4973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1972),
  [4975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1211),
  [4977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(429),
  [4979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1673),
  [4981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1427),
  [4983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1212),
  [4985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1220),
  [4987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1383),
  [4989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1066),
  [4991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2422),
  [4993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1221),
  [4995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(775),
  [4997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1122),
  [4999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2606),
  [5001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(98),
  [5003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2159),
  [5005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(90),
  [5007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(482),
  [5009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2546),
  [5011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(569),
  [5013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1284),
  [5015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1331),
  [5017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1283),
  [5019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1330),
  [5021] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda_parameters, 1),
  [5023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1328),
  [5025] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [5027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(543),
  [5029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2062),
  [5031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(131),
  [5033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1321),
  [5035] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_with_clause, 5),
  [5037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(107),
  [5039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2138),
  [5041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2088),
  [5043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1931),
  [5045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1281),
  [5047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1949),
  [5049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(939),
  [5051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2151),
  [5053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(520),
  [5055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(116),
  [5057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2153),
  [5059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(966),
  [5061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(110),
  [5063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1062),
  [5065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1011),
  [5067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(556),
  [5069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(537),
  [5071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1295),
  [5073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1267),
  [5075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(109),
  [5077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1293),
  [5079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2571),
  [5081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2200),
  [5083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2226),
  [5085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2038),
  [5087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(825),
  [5089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1338),
  [5091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(742),
  [5093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1265),
  [5095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(572),
};

enum ts_external_scanner_symbol_identifiers {
  ts_external_token__newline = 0,
  ts_external_token__indent = 1,
  ts_external_token__dedent = 2,
  ts_external_token_string_start = 3,
  ts_external_token__string_content = 4,
  ts_external_token_escape_interpolation = 5,
  ts_external_token_string_end = 6,
  ts_external_token_comment = 7,
  ts_external_token_RBRACK = 8,
  ts_external_token_RPAREN = 9,
  ts_external_token_RBRACE = 10,
  ts_external_token_except = 11,
};

static const TSSymbol ts_external_scanner_symbol_map[EXTERNAL_TOKEN_COUNT] = {
  [ts_external_token__newline] = sym__newline,
  [ts_external_token__indent] = sym__indent,
  [ts_external_token__dedent] = sym__dedent,
  [ts_external_token_string_start] = sym_string_start,
  [ts_external_token__string_content] = sym__string_content,
  [ts_external_token_escape_interpolation] = sym_escape_interpolation,
  [ts_external_token_string_end] = sym_string_end,
  [ts_external_token_comment] = sym_comment,
  [ts_external_token_RBRACK] = anon_sym_RBRACK,
  [ts_external_token_RPAREN] = anon_sym_RPAREN,
  [ts_external_token_RBRACE] = anon_sym_RBRACE,
  [ts_external_token_except] = anon_sym_except,
};

static const bool ts_external_scanner_states[20][EXTERNAL_TOKEN_COUNT] = {
  [1] = {
    [ts_external_token__newline] = true,
    [ts_external_token__indent] = true,
    [ts_external_token__dedent] = true,
    [ts_external_token_string_start] = true,
    [ts_external_token__string_content] = true,
    [ts_external_token_escape_interpolation] = true,
    [ts_external_token_string_end] = true,
    [ts_external_token_comment] = true,
    [ts_external_token_RBRACK] = true,
    [ts_external_token_RPAREN] = true,
    [ts_external_token_RBRACE] = true,
    [ts_external_token_except] = true,
  },
  [2] = {
    [ts_external_token_string_start] = true,
    [ts_external_token_comment] = true,
  },
  [3] = {
    [ts_external_token__dedent] = true,
    [ts_external_token_string_start] = true,
    [ts_external_token_comment] = true,
  },
  [4] = {
    [ts_external_token__newline] = true,
    [ts_external_token_string_start] = true,
    [ts_external_token_comment] = true,
  },
  [5] = {
    [ts_external_token__newline] = true,
    [ts_external_token__indent] = true,
    [ts_external_token_string_start] = true,
    [ts_external_token_comment] = true,
  },
  [6] = {
    [ts_external_token_string_start] = true,
    [ts_external_token_comment] = true,
    [ts_external_token_RBRACE] = true,
  },
  [7] = {
    [ts_external_token_string_start] = true,
    [ts_external_token_comment] = true,
    [ts_external_token_RPAREN] = true,
  },
  [8] = {
    [ts_external_token_string_start] = true,
    [ts_external_token_comment] = true,
    [ts_external_token_RBRACK] = true,
  },
  [9] = {
    [ts_external_token__newline] = true,
    [ts_external_token_comment] = true,
  },
  [10] = {
    [ts_external_token__dedent] = true,
    [ts_external_token_string_start] = true,
    [ts_external_token_comment] = true,
    [ts_external_token_except] = true,
  },
  [11] = {
    [ts_external_token_string_start] = true,
    [ts_external_token_comment] = true,
    [ts_external_token_except] = true,
  },
  [12] = {
    [ts_external_token_comment] = true,
    [ts_external_token_RBRACE] = true,
  },
  [13] = {
    [ts_external_token_comment] = true,
  },
  [14] = {
    [ts_external_token_comment] = true,
    [ts_external_token_RPAREN] = true,
  },
  [15] = {
    [ts_external_token_comment] = true,
    [ts_external_token_RBRACK] = true,
  },
  [16] = {
    [ts_external_token__string_content] = true,
    [ts_external_token_escape_interpolation] = true,
    [ts_external_token_string_end] = true,
    [ts_external_token_comment] = true,
  },
  [17] = {
    [ts_external_token_comment] = true,
    [ts_external_token_except] = true,
  },
  [18] = {
    [ts_external_token__dedent] = true,
    [ts_external_token_comment] = true,
  },
  [19] = {
    [ts_external_token__newline] = true,
    [ts_external_token__indent] = true,
    [ts_external_token_comment] = true,
  },
};

#ifdef __cplusplus
extern "C" {
#endif
void *tree_sitter_python_external_scanner_create(void);
void tree_sitter_python_external_scanner_destroy(void *);
bool tree_sitter_python_external_scanner_scan(void *, TSLexer *, const bool *);
unsigned tree_sitter_python_external_scanner_serialize(void *, char *);
void tree_sitter_python_external_scanner_deserialize(void *, const char *, unsigned);

#ifdef _WIN32
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_python() {
  static const TSLanguage language = {
    .version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = ts_lex_modes,
    .lex_fn = ts_lex,
    .keyword_lex_fn = ts_lex_keywords,
    .keyword_capture_token = sym_identifier,
    .external_scanner = {
      &ts_external_scanner_states[0][0],
      ts_external_scanner_symbol_map,
      tree_sitter_python_external_scanner_create,
      tree_sitter_python_external_scanner_destroy,
      tree_sitter_python_external_scanner_scan,
      tree_sitter_python_external_scanner_serialize,
      tree_sitter_python_external_scanner_deserialize,
    },
    .primary_state_ids = ts_primary_state_ids,
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
